C------------------------------------------------------------------
C------------------------------------------------------------------
      double precision function A183_HQQ_EFF(hmass,iana)
c
c Input:  higgs mass and The HQQ analysis code number
c Return the (linearly-interpolated) signal 4-jets efficiency, as 
c a function of mH. 
c
c                 0.D0 <= A183_HQQ_EFF <= 1.D0
c
c mH = 60, 70, 80, 85, 90, 95, 100 GeV 
c i  =  1,  2,  3,  4,  5,  6,  7
c                                                       PTD 19-Feb-98.
c                                                   mod. PM 16-Jun-98.
      implicit none
      logical first
      integer il,iu,iana
      double precision lower,upper,hmass,eff1(7),eff2(7),eff3(7)
      double precision delta,dprime
      data first /.true./
      data eff1 /  9.29D-2, 12.35D-2, 23.49D-2, 26.14D-2,
     &            24.55D-2, 19.08D-2, 14.24D-2/
      data eff2 /  8.11D-2,  8.99D-2,  5.19D-2,  5.21D-2,
     &             4.62D-2,  5.98D-2,  6.88D-2/
      data eff3 /  5.36D-2,  8.64D-2,  7.42D-2,  7.77D-2,
     &             9.43D-2,  7.60D-2,  6.57D-2/
c
      A183_HQQ_EFF = 0.D0
c
      lower = 60.D0
      upper = 70.D0
      il = 1
      iu = 2
      if (hmass.lt.lower) then
         goto 2010
      endif
      if (hmass.ge.lower .and. hmass.le.upper) then
         goto 2001
      end if
c
      lower = 70.D0
      upper = 80.D0
      il = 2
      iu = 3
      if (hmass.gt.lower .and. hmass.le.upper) then
         goto 2001
      end if
c
      lower = 80.D0
      upper = 85.D0
      il = 3
      iu = 4
      if (hmass.gt.lower .and. hmass.le.upper) then
         goto 2001
      end if
c
      lower = 85.D0
      upper = 90.D0
      il = 4
      iu = 5
      if (hmass.gt.lower .and. hmass.le.upper) then
         goto 2001
      end if
c
      lower = 90.D0
      upper = 95.D0
      il = 5
      iu = 6
      if (hmass.gt.lower .and. hmass.le.upper) then
         goto 2001
      end if
c
      lower = 95.D0
      upper = 100.D0
      il = 6
      iu = 7
      if (hmass.gt.lower .and. hmass.le.upper) then
         goto 2001
      end if
      goto 2010
c
c Interpolate efficiency from the two nearest mass points:
c
 2001 continue
      delta = upper - lower
      dprime= hmass - lower
      if (iana.eq.1) then
        A183_HQQ_EFF = (eff1(iu) - eff1(il)) * dprime / delta
        A183_HQQ_EFF = A183_HQQ_EFF + eff1(il)
      else if (iana.eq.2) then
        A183_HQQ_EFF = (eff2(iu) - eff2(il)) * dprime / delta
        A183_HQQ_EFF = A183_HQQ_EFF + eff2(il)
      else if (iana.eq.3) then
        A183_HQQ_EFF = (eff3(iu) - eff3(il)) * dprime / delta
        A183_HQQ_EFF = A183_HQQ_EFF + eff3(il)
      endif
 2010 continue
c
      end
C------------------------------------------------------------------
C------------------------------------------------------------------
      double precision function A183_HQQ_BKG(iana)

      if (iana.eq.1) then
        A183_HQQ_BKG = 1.356
      else if (iana.eq.2) then
        A183_HQQ_BKG = 1.002
      else if (iana.eq.3) then
        A183_HQQ_BKG = 2.090
      endif

      END
C------------------------------------------------------------------
C------------------------------------------------------------------

      INTEGER FUNCTION A183_HQQ_NUMCAND(IANA)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      A183_HQQ_NUMCAND = 0
      IF (IANA.EQ.1) THEN
        A183_HQQ_NUMCAND = 1
      ELSE IF (IANA.EQ.2) THEN
        A183_HQQ_NUMCAND = 1
      ELSE IF (IANA.EQ.3) THEN
        A183_HQQ_NUMCAND = 2
      ENDIF
      END
C------------------------------------------------------------------
C------------------------------------------------------------------

      DOUBLE PRECISION FUNCTION A183_HQQ_MASS_CAND(IANA,ICAND)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      A183_HQQ_MASS_CAND = 0D0
      IF (IANA.EQ.1) THEN
        IF (ICAND.EQ.1) THEN
          A183_HQQ_MASS_CAND = 71.52D0
        ENDIF
      ELSE IF (IANA.EQ.2) THEN
        IF (ICAND.EQ.1) THEN
          A183_HQQ_MASS_CAND = 85.24D0
        ENDIF
      ELSE IF (IANA.EQ.3) THEN
        IF (ICAND.EQ.1) THEN
          A183_HQQ_MASS_CAND = 84.95D0
        ELSE IF (ICAND.EQ.2) THEN
          A183_HQQ_MASS_CAND = 76.06D0
        ENDIF
      ENDIF
      END

C------------------------------------------------------------------
C------------------------------------------------------------------
      REAL*8 FUNCTION A183_hqq_mass_sig(x,hmass,iana)  
C------------------------------------------------------------------
C User function for the signal mass distribution
C------------------------------------------------------------------
      real*8 x,hmass
      real*8 A183_HQQ_SIGFIT
      real*8 xmin,xmax

      PARAMETER ( xmin=31.D0, xmax = 91.8D0 )

      EXTERNAL A183_HQQ_SIGFIT
      A183_hqq_mass_sig=1.E-08
      if(x.ge.xmin.and.x.lt.xmax)then
        A183_hqq_mass_sig=A183_HQQ_SIGFIT(x,hmass,iana)
      endif
      if(A183_hqq_mass_sig.le.0.) A183_hqq_mass_sig=1.E-08
      END

C------------------------------------------------------------------
C------------------------------------------------------------------

      REAL*8 FUNCTION A183_hqq_mass_bkg(x,iana)                                       
C------------------------------------------------------------------
C User function for the background mass distribution
C------------------------------------------------------------------

      implicit real*8(A-H,O-Z)

      real denlan
      external denlan

      PARAMETER ( xmin=31.D0, xmax = 91.8D0 )      

      A183_hqq_mass_bkg=1.E-08
      IF ( x .Le. xmax .AND. x .GE. xmin ) THEN                         
        IF(iana.eq.1)then
C**** ZZ
*1)
          area1=44.011
          peak1=83.584
          width1=-1.4209
          
          xland1=area1*denlan(sngl((x-peak1)/width1))
*2)
          area2=214.31
          peak2=89.459
          width2=-0.96984
          xland2=area2*denlan(sngl((x-peak2)/width2))
c
          pi=3.1415926
          area1=20.167
          xmean1=59.419
          sigma1=4.9035

          area2=27.167
          xmean2=73.581
          sigma2=2.1129
          xgauss1=area1*exp(-0.5*((x-xmean1)/sigma1)**2)/
     &            sqrt(2*pi)/sigma1
          xgauss2=area2*exp(-0.5*((x-xmean2)/sigma2)**2)/
     &            sqrt(2*pi)/sigma2

          zzfit=(xland1+xland2+xgauss1+xgauss2)/327.
C**** QQ
          pi=3.1415926
          area3=18.384
          xmean3=76.392
          sigma3=9.4809

          area6=6.4790
          xmean6=87.140
          sigma6=2.0303
          xgauss3=area3*exp(-0.5*((x-xmean3)/sigma3)**2)/
     &            sqrt(2*pi)/sigma3
          xgauss6=area6*exp(-0.5*((x-xmean6)/sigma6)**2)/
     &            sqrt(2*pi)/sigma6
          qqfit=(xgauss3+xgauss6)/28.
C**** WW
          pi=3.1415926
          area4=29.896
          xmean4=70.791
          sigma4=11.504

          area5=29.355
          xmean5=83.789
          sigma5=3.8753
          xgauss4=area4*exp(-0.5*((x-xmean4)/sigma4)**2)/
     &            sqrt(2*pi)/sigma4
          xgauss5=area5*exp(-0.5*((x-xmean5)/sigma5)**2)/
     &            sqrt(2*pi)/sigma5
          wwfit=(xgauss4+xgauss5)/67.
*SUM)
          pz=0.9188
          pq=0.2331
          pw=0.2038
          bkgfit=pz*zzfit+pq*qqfit+pw*wwfit
        elseif(iana.eq.2)then
          area1=0.13515
          peak1=80.770
          width1=-6.2077
          xland1=area1*denlan(sngl((x-peak1)/width1))
          bkgfit=xland1
        elseif(iana.eq.3)then
          xnorm=-0.7337
          poly1=8.70182E-02
          poly2=-3.42141E-03
          poly3=5.63996E-05
          poly4=-3.14909E-07
          offset=6.8148
          bkgfit=xnorm
     &         +poly1*(x-offset)
     &         +poly2*(x-offset)**2
     &         +poly3*(x-offset)**3
     &         +poly4*(x-offset)**4
        endif
        A183_hqq_mass_bkg=bkgfit
      ENDIF
      if(A183_hqq_mass_bkg.le.0.) A183_hqq_mass_bkg=1.E-08
      END


C------------------------------------------------------------------
C------------------------------------------------------------------

      DOUBLE PRECISION FUNCTION A183_HQQ_SIGFIT(X,HMASS,iana)
C
      DOUBLE PRECISION X,DELTA1,DELTA2,REFMH1,REFMH2,F1,F2,
     &     SINT60,SINT70,SINT80,SINT85,SINT90,SINT95,SINT100,XKL
      DOUBLE PRECISION A183_HQQ_M_60
      DOUBLE PRECISION A183_HQQ_M_70
      DOUBLE PRECISION A183_HQQ_M_80
      DOUBLE PRECISION A183_HQQ_M_85
      DOUBLE PRECISION A183_HQQ_M_90
      DOUBLE PRECISION A183_HQQ_M_95
      DOUBLE PRECISION A183_HQQ_M_100
      LOGICAL FIRST
      DATA FIRST /.TRUE./
      common /anaflg/jana     ! OD
C
c
c---- Integrals of the signal functions given;
c  23 March 1998 / Shapes for final results;
      PARAMETER(SINT60=1.82845038158944D0,
     &     SINT70=1.95130481972557D0,
     &     SINT80=1.93871883461036D0,
     &     SINT85=1.93143080943899D0,
     &     SINT90=1.98220177198918D0,
     &     SINT95=2.07419392439117D0,
     &     SINT100=1.89825899981325D0,
c kinematic limit
     .     XKL=91.8D0)
C
      DOUBLE PRECISION HMASS
C
      jana = iana
      IF (FIRST) THEN
         FIRST = .FALSE.
         write (6,*) '================================================'
         WRITE (6,*) 'The integrals of the signal functions are:'
         WRITE (6,'((a7,f8.6,a7,f8.6))') 
     &        '  60-->',SINT60,'; 70-->',SINT70,'  80-->',SINT80,
     &        '; 85-->',SINT85,'  90-->',SINT90,'; 95-->',SINT95,
     &        ' 100-->',SINT100
         write (6,*) '================================================'
         write (6,*) 'The kinematic boundary is set at ',sngl(XKL)
      END IF
C
      IF (HMASS.GE.60D0 .AND. HMASS.LE.70D0) THEN
         REFMH1 = 60D0
         REFMH2 = 70D0
         DELTA1 = HMASS - REFMH1
         DELTA2 = REFMH2 - HMASS
         F1 = A183_HQQ_M_60(X-DELTA1) / SINT60
         F2 = A183_HQQ_M_70(X+DELTA2) / SINT70
      ELSE IF (HMASS.GT.70D0 .AND. HMASS.LE.80D0) THEN
         REFMH1 = 70D0
         REFMH2 = 80D0
         DELTA1 = HMASS - REFMH1
         DELTA2 = REFMH2 - HMASS
         F1 = A183_HQQ_M_70(X-DELTA1) / SINT70
         F2 = A183_HQQ_M_80(X+DELTA2) / SINT80
      ELSE IF (HMASS.GT.80D0 .AND. HMASS.LE.85D0) THEN
         REFMH1 = 80D0
         REFMH2 = 85D0
         DELTA1 = HMASS - REFMH1
         DELTA2 = REFMH2 - HMASS
         F1 = A183_HQQ_M_80(X-DELTA1) / SINT80
         F2 = A183_HQQ_M_85(X+DELTA2) / SINT85
      ELSE IF (HMASS.GT.85D0 .AND. HMASS.LE.90D0) THEN
         REFMH1 = 85D0
         REFMH2 = 90D0
         DELTA1 = HMASS - REFMH1
         DELTA2 = REFMH2 - HMASS
         F1 = A183_HQQ_M_85(X-DELTA1) / SINT85
         F2 = A183_HQQ_M_90(X+DELTA2) / SINT90
      ELSE IF (HMASS.GT.90D0 .AND. HMASS.LE.95D0) THEN
         REFMH1 = 90D0
         REFMH2 = 95D0
         DELTA1 = HMASS - REFMH1
         DELTA2 = REFMH2 - HMASS
c
c Do not attempt to shift functions beyond the kinematic limit!
c
c         F1 = A183_HQQ_M_90(X-DELTA1) / SINT90
c         F2 = A183_HQQ_M_95(X+DELTA2) / SINT95
         F1 = A183_HQQ_M_90(X) / SINT90
         F2 = A183_HQQ_M_95(X) / SINT95
      ELSE IF (HMASS.GT.95D0 .AND. HMASS.LE.100D0) THEN
         REFMH1 = 95D0
         REFMH2 = 100D0
         DELTA1 = HMASS - REFMH1
         DELTA2 = REFMH2 - HMASS
c
c Do not attempt to shift functions beyond the kinematic limit!
c
c         F1 = A183_HQQ_M_95(X-DELTA1) / SINT95
c         F2 = A183_HQQ_M_100(X+DELTA2) / SINT100
         F1 = A183_HQQ_M_95(X) / SINT95
         F2 = A183_HQQ_M_100(X) / SINT100
      ELSE
         A183_HQQ_SIGFIT = 0D0
         RETURN
      END IF
C
      A183_HQQ_SIGFIT = (DELTA2 * F1 + DELTA1 * F2) / (REFMH2 - REFMH1)
      IF (A183_HQQ_SIGFIT.LT.1.D-5) A183_HQQ_SIGFIT = 1.D-5
c
c NB all the INPUT functions vanish at the kinematic 
c limit x = 183. - 91.2 = 91.8; The interpolated functions may (because of 
c the TRANSLATION involved) have a tiny tail of non-zero values beyond the KL.
c This is not physical and is corrected here:
c
      if (x.gt.xkl) A183_HQQ_SIGFIT = 1.D-5
C
      RETURN
      END

C------------------------------------------------------------------
C------------------------------------------------------------------

      double precision function A183_hqq_m_60(x)
      implicit real*8(a-h,o-z)
      parameter (nmass = 1)
      common /anaflg/iana     ! OD
      dimension sm(nmass),c10(nmass,10,3)
      data sm/60./
      data c10/
c mH=60, ibranch=1,2,3;
     .     -0.13452E-01, 0.24944E-03, 0.54845E-05,-0.33358E-07,
     .     0.65236E+00, 0.20000E+01, 0.33696E+00, 0.60000E+01,
     .     0.59454E+02, 0.58798E+02,
     .     -0.23494E-01, 0.68579E-03, 0.40721E-05,-0.97349E-07,
     .     0.41115E+00, 0.20000E+01, 0.10514E+01, 0.60000E+01,
     .     0.58966E+02, 0.61619E+02,
     .     -0.47503E-01, 0.15130E-02, 0.87234E-05,-0.21832E-06,
     .     0.34690E+00, 0.20000E+01, 0.22495E+00, 0.60000E+01,
     .     0.58446E+02, 0.70313E+02
c
     . /                   
c
      dimension par(10)
      
      if(iana.lt.1) iana = 1
      if(iana.gt.3) iana = 3

      IM = 1

      par(1) = c10(im,1,iana)
      par(2) = c10(im,2,iana)
      par(3) = c10(im,3,iana)
      par(4) = c10(im,4,iana)
      par(5) = c10(im,5,iana)
      par(6) = c10(im,6,iana)
      par(7) = c10(im,7,iana)
      par(8) = c10(im,8,iana)
      par(9) = c10(im,9,iana)
      par(10) = c10(im,10,iana)

      tau=2.D0
      corr = 1.D0
      cutoff=1-exp((x-91-corr)/tau)
      if(cutoff.lt.0) cutoff=0
      rt2pi=(2*3.1415)**0.5
       p=par(1)+par(2)*x+par(3)*x**2+par(4)*x**3
       g1=par(5)*exp(-(x-par(9))**2/2./par(6)**2)/rt2pi/par(6)
       g2=par(7)*exp(-(x-par(10))**2/2./par(8)**2)/rt2pi/par(8)
       ga1=0.076789*exp((par(9)-85.06-corr)/1.6417)+1
       ga2=0.24962*exp((par(10)-83.53-corr)/3.94)+1
      A183_hqq_m_60 = (p+g1*ga1+g2*ga2)*cutoff
      return
      end      
c
c ------------------------------------------------------------------ c 
c
      double precision function A183_hqq_m_70(x)
      implicit real*8(a-h,o-z)
      parameter (nmass = 1)
      common /anaflg/iana     ! OD
      dimension sm(nmass),c10(nmass,10,3)
      data sm/70./
      data c10/
c mH=70
     .     -0.79616E-02, 0.16133E-03, 0.31950E-05,-0.18023E-07,
     .     0.34158E+00, 0.20000E+01, 0.10417E+01, 0.60000E+01,
     .     0.69758E+02, 0.72698E+02,
     .     -0.28826E-01, 0.80472E-03, 0.49508E-05,-0.11371E-06,
     .     0.71418E+00, 0.20000E+01, 0.72467E+00, 0.60000E+01,
     .     0.69893E+02, 0.69006E+02,
     .     0.63541E-02, 0.66320E-04, 0.11123E-06,-0.86377E-08,
     .     0.26173E+00, 0.20000E+01, 0.10643E+01, 0.60000E+01,
     .     0.70579E+02, 0.70859E+02
     . /
c
      dimension par(10)
      
      if(iana.lt.1) iana = 1
      if(iana.gt.3) iana = 3

      IM = 1

      par(1) = c10(im,1,iana)
      par(2) = c10(im,2,iana)
      par(3) = c10(im,3,iana)
      par(4) = c10(im,4,iana)
      par(5) = c10(im,5,iana)
      par(6) = c10(im,6,iana)
      par(7) = c10(im,7,iana)
      par(8) = c10(im,8,iana)
      par(9) = c10(im,9,iana)
      par(10) = c10(im,10,iana)

      tau=2.D0
      corr = 1.D0
      cutoff=1-exp((x-91-corr)/tau)
      if(cutoff.lt.0) cutoff=0
      rt2pi=(2*3.1415)**0.5
       p=par(1)+par(2)*x+par(3)*x**2+par(4)*x**3
       g1=par(5)*exp(-(x-par(9))**2/2./par(6)**2)/rt2pi/par(6)
       g2=par(7)*exp(-(x-par(10))**2/2./par(8)**2)/rt2pi/par(8)
       ga1=0.076789*exp((par(9)-85.06-corr)/1.6417)+1
       ga2=0.24962*exp((par(10)-83.53-corr)/3.94)+1
      A183_hqq_m_70 = (p+g1*ga1+g2*ga2)*cutoff
      return
      end      
c
c ------------------------------------------------------------------ c 
c
      double precision function A183_hqq_m_80(x)
      implicit real*8(a-h,o-z)
      parameter (nmass = 1)
      common /anaflg/iana     ! OD
      dimension sm(nmass),c10(nmass,10,3)
      data sm/80./
      data c10/
c mH=80
     .     -0.16321E-01, 0.29184E-03, 0.69789E-05,-0.81217E-07,
     .     0.93546E+00, 0.20000E+01, 0.59499E+00, 0.60000E+01,
     .     0.80089E+02, 0.82005E+02,
     .     -0.13778E-01, 0.32688E-03, 0.56575E-05,-0.55104E-07,
     .     0.45013E+00, 0.20000E+01, 0.66786E+00, 0.60000E+01,
     .     0.81068E+02, 0.75925E+02,
     .     -0.25597E-01, 0.63207E-03, 0.89852E-05,-0.14006E-06,
     .     0.25885E+00, 0.20000E+01, 0.94737E+00, 0.60000E+01,
     .     0.78959E+02, 0.79088E+02
c
     . /                   
c
      dimension par(10)
      
      if(iana.lt.1) iana = 1
      if(iana.gt.3) iana = 3

      IM = 1

      par(1) = c10(im,1,iana)
      par(2) = c10(im,2,iana)
      par(3) = c10(im,3,iana)
      par(4) = c10(im,4,iana)
      par(5) = c10(im,5,iana)
      par(6) = c10(im,6,iana)
      par(7) = c10(im,7,iana)
      par(8) = c10(im,8,iana)
      par(9) = c10(im,9,iana)
      par(10) = c10(im,10,iana)

      tau=2.D0
      corr = 1.D0
      cutoff=1-exp((x-91-corr)/tau)
      if(cutoff.lt.0) cutoff=0
      rt2pi=(2*3.1415)**0.5
       p=par(1)+par(2)*x+par(3)*x**2+par(4)*x**3
       g1=par(5)*exp(-(x-par(9))**2/2./par(6)**2)/rt2pi/par(6)
       g2=par(7)*exp(-(x-par(10))**2/2./par(8)**2)/rt2pi/par(8)
       ga1=0.076789*exp((par(9)-85.06-corr)/1.6417)+1
       ga2=0.24962*exp((par(10)-83.53-corr)/3.94)+1
      A183_hqq_m_80 = (p+g1*ga1+g2*ga2)*cutoff
      return
      end      
c
c ------------------------------------------------------------------ c 
c
      double precision function A183_hqq_m_85(x)
      implicit real*8(a-h,o-z)
      parameter (nmass = 1)
      common /anaflg/iana     ! OD
      dimension sm(nmass),c10(nmass,10,3)
      data sm/85./
      data c10/
c mH=85 WP fit HongBo
     .     0.1504,-.1003e-1,.2164e-3,-.1447e-5,.7252,
     .     2.000,1.122,6.000,84.84,86.20,
     .         -.5199e-2,.9136e-4,.3407e-5,.9483e-9,.6199,
     .     2.,.4949,6.,84.94,79.96,
     .         -.5671e-2,.2089e-3,.4796e-5,-.2829e-7,.3935,
     .     2.,.4304,6.,85.08,80.53
c mH=85 my fit  
c     .     -0.27962E-01, 0.57334E-03, 0.11000E-04,-0.16589E-06,
c     .     0.88662E+00, 0.20000E+01, 0.79074E+00, 0.60000E+01,
c     .     0.84788E+02, 0.86676E+02,
c     .     0.31110E-03, 0.26168E-04, 0.10711E-05, 0.25982E-07,
c     .     0.65802E+00, 0.20000E+01, 0.46554E+00, 0.60000E+01,
c     .     0.84290E+02, 0.78658E+02,
c     .     0.24576E-02, 0.10052E-03, 0.15720E-05, 0.20997E-08,
c     .     0.38364E+00, 0.20000E+01, 0.57477E+00, 0.60000E+01,
c     .     0.85439E+02, 0.78304E+02,
c
     . /                   
c
      dimension par(10)
      
      if(iana.lt.1) iana = 1
      if(iana.gt.3) iana = 3

      IM = 1

      par(1) = c10(im,1,iana)
      par(2) = c10(im,2,iana)
      par(3) = c10(im,3,iana)
      par(4) = c10(im,4,iana)
      par(5) = c10(im,5,iana)
      par(6) = c10(im,6,iana)
      par(7) = c10(im,7,iana)
      par(8) = c10(im,8,iana)
      par(9) = c10(im,9,iana)
      par(10) = c10(im,10,iana)

      tau=2.D0
      corr = 1.D0
      cutoff=1-exp((x-91-corr)/tau)
      if(cutoff.lt.0) cutoff=0
      rt2pi=(2*3.1415)**0.5
       p=par(1)+par(2)*x+par(3)*x**2+par(4)*x**3
       g1=par(5)*exp(-(x-par(9))**2/2./par(6)**2)/rt2pi/par(6)
       g2=par(7)*exp(-(x-par(10))**2/2./par(8)**2)/rt2pi/par(8)
       ga1=0.076789*exp((par(9)-85.06-corr)/1.6417)+1
       ga2=0.24962*exp((par(10)-83.53-corr)/3.94)+1
      A183_hqq_m_85 = (p+g1*ga1+g2*ga2)*cutoff
      return
      end      
c
c ------------------------------------------------------------------ c 
c
      double precision function A183_hqq_m_90(x)
      implicit real*8(a-h,o-z)
      parameter (nmass = 1)
      common /anaflg/iana     ! OD
      dimension sm(nmass),c10(nmass,10,3)
      data sm/90./
      data c10/
c mH=90
     .     -0.11146E-01, 0.32625E-03, 0.40491E-05,-0.52518E-07,
     .     0.61316E+00, 0.20000E+01, 0.79831E+00, 0.60000E+01,
     .     0.91382E+02, 0.93568E+02,
     .     -0.13849E-01, 0.44119E-03, 0.42424E-05,-0.96692E-07,
     .     0.63835E+00, 0.20000E+01, 0.10313E+01, 0.60000E+01,
     .     0.90594E+02, 0.85852E+02,
     .     0.26105E-01,-0.45757E-03,-0.52891E-05, 0.17142E-06,
     .     0.36835E+00, 0.20000E+01, 0.32608E-01, 0.60000E+01,
     .     0.90870E+02, 0.19102E+03
c
     . /                   
c
      dimension par(10)
      
      if(iana.lt.1) iana = 1
      if(iana.gt.3) iana = 3

      IM = 1

      par(1) = c10(im,1,iana)
      par(2) = c10(im,2,iana)
      par(3) = c10(im,3,iana)
      par(4) = c10(im,4,iana)
      par(5) = c10(im,5,iana)
      par(6) = c10(im,6,iana)
      par(7) = c10(im,7,iana)
      par(8) = c10(im,8,iana)
      par(9) = c10(im,9,iana)
      par(10) = c10(im,10,iana)

      tau=2.D0
      corr = 1.D0
      cutoff=1-exp((x-91-corr)/tau)
      if(cutoff.lt.0) cutoff=0
      rt2pi=(2*3.1415)**0.5
       p=par(1)+par(2)*x+par(3)*x**2+par(4)*x**3
       g1=par(5)*exp(-(x-par(9))**2/2./par(6)**2)/rt2pi/par(6)
       g2=par(7)*exp(-(x-par(10))**2/2./par(8)**2)/rt2pi/par(8)
       ga1=0.076789*exp((par(9)-85.06-corr)/1.6417)+1
       ga2=0.24962*exp((par(10)-83.53-corr)/3.94)+1
      A183_hqq_m_90 = (p+g1*ga1+g2*ga2)*cutoff
      return
      end      
c
c ------------------------------------------------------------------ c 
c
      double precision function A183_hqq_m_95(x)
      implicit real*8(a-h,o-z)
      parameter (nmass = 1)
      common /anaflg/iana     ! OD
      dimension sm(nmass),c10(nmass,10,3)
      data sm/95./
      data c10/
c mH=95 
     .     -0.19433E-01, 0.44470E-03, 0.62126E-05,-0.72885E-07,
     .     0.25046E+01, 0.20000E+01, 0.97313E+00, 0.60000E+01,
     .     0.96445E+02, 0.89920E+02,
     .     0.30191E-01,-0.78807E-03,-0.10910E-04, 0.33551E-06,
     .     -0.43252E-01, 0.20000E+01, 0.32477E+00, 0.60000E+01,
     .     0.78349E+02, 0.11047E+03,
     .     0.15612E-01,-0.24752E-03,-0.20793E-05, 0.12437E-06,
     .     0.22603E+00, 0.20000E+01,-0.73826E+00, 0.60000E+01,
     .     0.89549E+02, 0.12516E+03
c
     . /                   
c
      dimension par(10)
      
      if(iana.lt.1) iana = 1
      if(iana.gt.3) iana = 3

      IM = 1

      par(1) = c10(im,1,iana)
      par(2) = c10(im,2,iana)
      par(3) = c10(im,3,iana)
      par(4) = c10(im,4,iana)
      par(5) = c10(im,5,iana)
      par(6) = c10(im,6,iana)
      par(7) = c10(im,7,iana)
      par(8) = c10(im,8,iana)
      par(9) = c10(im,9,iana)
      par(10) = c10(im,10,iana)

      tau=2.D0
      corr = 1.D0
      cutoff=1-exp((x-91-corr)/tau)
      if(cutoff.lt.0) cutoff=0
      rt2pi=(2*3.1415)**0.5
       p=par(1)+par(2)*x+par(3)*x**2+par(4)*x**3
       g1=par(5)*exp(-(x-par(9))**2/2./par(6)**2)/rt2pi/par(6)
       g2=par(7)*exp(-(x-par(10))**2/2./par(8)**2)/rt2pi/par(8)
       ga1=0.076789*exp((par(9)-85.06-corr)/1.6417)+1
       ga2=0.24962*exp((par(10)-83.53-corr)/3.94)+1
      A183_hqq_m_95 = (p+g1*ga1+g2*ga2)*cutoff
      return
      end      
      
c
c ------------------------------------------------------------------ c 
c
      double precision function A183_hqq_m_100(x)
      implicit real*8(a-h,o-z)
      parameter (nmass = 1)
      common /anaflg/iana     ! OD
      dimension sm(nmass),c10(nmass,10,3)
      data sm/100./
      data c10/
c mH=100 
     .     -0.76413E-02, 0.12696E-03, 0.30906E-05, 0.27401E-07,
     .     0.93594E-01, 0.20000E+01, 0.63432E+00, 0.60000E+01,
     .     0.81813E+02, 0.91577E+02,
     .     0.25028E-01,-0.69021E-03,-0.75852E-05, 0.28280E-06,
     .     0.82561E-01, 0.20000E+01, 0.56559E-01, 0.60000E+01,
     .     0.84055E+02, 0.10867E+03,
     .     -0.12510E-01, 0.46437E-03, 0.58460E-05,-0.33470E-07,
     .     0.12277E+00, 0.20000E+01,-0.70072E+00, 0.60000E+01,
     .     0.92045E+02, 0.11427E+03
c
     . /                   
c
      dimension par(10)
      
      if(iana.lt.1) iana = 1
      if(iana.gt.3) iana = 3

      IM = 1

      par(1) = c10(im,1,iana)
      par(2) = c10(im,2,iana)
      par(3) = c10(im,3,iana)
      par(4) = c10(im,4,iana)
      par(5) = c10(im,5,iana)
      par(6) = c10(im,6,iana)
      par(7) = c10(im,7,iana)
      par(8) = c10(im,8,iana)
      par(9) = c10(im,9,iana)
      par(10) = c10(im,10,iana)

      tau=2.D0
      corr = 1.D0
      cutoff=1-exp((x-91-corr)/tau)
      if(cutoff.lt.0) cutoff=0
      rt2pi=(2*3.1415)**0.5
       p=par(1)+par(2)*x+par(3)*x**2+par(4)*x**3
       g1=par(5)*exp(-(x-par(9))**2/2./par(6)**2)/rt2pi/par(6)
       g2=par(7)*exp(-(x-par(10))**2/2./par(8)**2)/rt2pi/par(8)
       ga1=0.076789*exp((par(9)-85.06-corr)/1.6417)+1
       ga2=0.24962*exp((par(10)-83.53-corr)/3.94)+1
      A183_hqq_m_100 = (p+g1*ga1+g2*ga2)*cutoff
      return
      end      




