C--------------------------------------------------------------------
      REAL*8 FUNCTION A183_HTT_EFF(H_MASS)
C
C Fit the signal eff for HZ->H[tt] to P2
C      
      IMPLICIT NONE

      REAL*8 H_MASS
      REAL*8 COEFF(3)
      DATA COEFF / -1.198 , 0.3845E-01 , -0.2579E-03 /
     
      A183_HTT_EFF = COEFF(1) + COEFF(2)*H_MASS +
     .     COEFF(3)*H_MASS**2

      IF (H_MASS.LT.60.)  A183_HTT_EFF = 0.
      IF (H_MASS.GT.100.) A183_HTT_EFF = 0.

      RETURN
      END
C---------------------------------------------------------------------
C---------------------------------------------------------------------
      REAL*8 FUNCTION A183_HTT_BKG()
C
C Background is not a function of the mass
C
      A183_HTT_BKG = 0.172D0
      RETURN
      END
C---------------------------------------------------------------------
C---------------------------------------------------------------------

      INTEGER FUNCTION A183_HTT_NUMCAND()

      A183_HTT_NUMCAND = 0

      END

C---------------------------------------------------------------------
C---------------------------------------------------------------------

      REAL*8 FUNCTION A183_HTT_MASS_CAND(ICAND)

      A183_HTT_MASS_CAND = 0D0

      END

C---------------------------------------------------------------------
C---------------------------------------------------------------------
      REAL*8 FUNCTION A183_HTT_MASS_BKG(X)
C X:  reconstructed mass
C
C 1st degree polynomial fit to reconstructed mass distribution
C
      IMPLICIT NONE       

      REAL*8 X, XMIN, XMAX
      PARAMETER ( XMIN = 50D0, XMAX = 102D0 )                           

      REAL*8 PBAK_COEFF(2)
      DATA PBAK_COEFF / -0.1153D-01, 0.3363D-03 /
C                                                                       
      IF ( X .LE. XMAX .AND. X .GE. XMIN ) THEN                         
         A183_HTT_MASS_BKG = PBAK_COEFF(1) + PBAK_COEFF(2)*X
      ELSE                                                              
         A183_HTT_MASS_BKG= 0.
      ENDIF
C
      RETURN                                                            
      END  
C---------------------------------------------------------------------
C---------------------------------------------------------------------
      REAL*8 FUNCTION A183_HTT_MASS_SIG(X, HMASS)
C X: reconstructed mass
C HMASS: Higgs mass hypothesis
C
C Signal mass distribution is fit to a single Gaussian for some masses.
C In between these masses, a Gaussian is constructed by linearly
C interpolating the means and widths of the two nearest Gaussians.
C
      IMPLICIT NONE                                          

      REAL*8 X, XMIN, XMAX
      PARAMETER ( XMIN = 50.D0, XMAX = 102.D0 )                           

      REAL*8 SIGPAR(28), QNEWPAR(4)
      REAL*8 HMASS 
      REAL*8 WEIGHT, SIGMASS
      DATA  SIGPAR
     .     / 1.       , 60.      , 3.7       , 0.0     ,
     .       45.51    , 70.13    , 3.714     , 0.0     ,
     .       51.90    , 79.27    , 3.030     , 0.0     ,
     .       51.93    , 84.32    , 2.847     , 0.0     ,
     .       54.85    , 87.99    , 2.714     , 0.0     ,
     .       29.53    , 88.34    , 3.315     , 0.0     ,
     .       13.21    , 90.      , 4.        , 0.0       /
C
C  Interpolation of fit parameters between two nearest fitted masses
      IF ( HMASS .GE. 60.0 .AND. HMASS .LT. 70.0) THEN
         WEIGHT = (HMASS - 60.0)/10.0
         QNEWPAR(4) = (1.0 - WEIGHT)*SIGPAR(4) + WEIGHT*SIGPAR(8)
         QNEWPAR(1) = (1.0 - WEIGHT)*SIGPAR(1) + WEIGHT*SIGPAR(5)
         QNEWPAR(2) = (1.0 - WEIGHT)*SIGPAR(2) + WEIGHT*SIGPAR(6)
         QNEWPAR(3) = (1.0 - WEIGHT)*SIGPAR(3) + WEIGHT*SIGPAR(7)
      ELSE IF ( HMASS .GE. 70.0 .AND. HMASS .LT. 80.0) THEN
         WEIGHT = (HMASS - 70.0)/10.0
         QNEWPAR(4) = (1.0 - WEIGHT)*SIGPAR(8) + WEIGHT*SIGPAR(12)
         QNEWPAR(1) = (1.0 - WEIGHT)*SIGPAR(5) + WEIGHT*SIGPAR(9)
         QNEWPAR(2) = (1.0 - WEIGHT)*SIGPAR(6) + WEIGHT*SIGPAR(10)
         QNEWPAR(3) = (1.0 - WEIGHT)*SIGPAR(7) + WEIGHT*SIGPAR(11)
      ELSE IF ( HMASS .GE. 80.0 .AND. HMASS .LT. 85.0) THEN
         WEIGHT = (HMASS - 80.0)/5.0
         QNEWPAR(4) = (1.0 - WEIGHT)*SIGPAR(12) + WEIGHT*SIGPAR(16)
         QNEWPAR(1) = (1.0 - WEIGHT)*SIGPAR(9) + WEIGHT*SIGPAR(13)
         QNEWPAR(2) = (1.0 - WEIGHT)*SIGPAR(10) + WEIGHT*SIGPAR(14)
         QNEWPAR(3) = (1.0 - WEIGHT)*SIGPAR(11) + WEIGHT*SIGPAR(15)
      ELSE IF ( HMASS .GE. 85.0 .AND. HMASS .LT. 90.0) THEN
         WEIGHT = (HMASS - 85.0)/5.0
         QNEWPAR(4) = (1.0 - WEIGHT)*SIGPAR(16) + WEIGHT*SIGPAR(20)
         QNEWPAR(1) = (1.0 - WEIGHT)*SIGPAR(13) + WEIGHT*SIGPAR(17)
         QNEWPAR(2) = (1.0 - WEIGHT)*SIGPAR(14) + WEIGHT*SIGPAR(18)
         QNEWPAR(3) = (1.0 - WEIGHT)*SIGPAR(15) + WEIGHT*SIGPAR(19)
      ELSE IF ( HMASS .GE. 90.0 .AND. HMASS .LT. 95.0) THEN
         WEIGHT = (HMASS - 90.0)/5.0
         QNEWPAR(4) = (1.0 - WEIGHT)*SIGPAR(20) + WEIGHT*SIGPAR(24)
         QNEWPAR(1) = (1.0 - WEIGHT)*SIGPAR(17) + WEIGHT*SIGPAR(21)
         QNEWPAR(2) = (1.0 - WEIGHT)*SIGPAR(18) + WEIGHT*SIGPAR(22)
         QNEWPAR(3) = (1.0 - WEIGHT)*SIGPAR(19) + WEIGHT*SIGPAR(23)
      ELSE IF ( HMASS .GE. 95.0 .AND. HMASS .LE. 100.0) THEN
         WEIGHT = (HMASS - 95.0)/5.0
         QNEWPAR(4) = (1.0 - WEIGHT)*SIGPAR(24) + WEIGHT*SIGPAR(28)
         QNEWPAR(1) = (1.0 - WEIGHT)*SIGPAR(21) + WEIGHT*SIGPAR(25)
         QNEWPAR(2) = (1.0 - WEIGHT)*SIGPAR(22) + WEIGHT*SIGPAR(26)
         QNEWPAR(3) = (1.0 - WEIGHT)*SIGPAR(23) + WEIGHT*SIGPAR(27)
      ELSE
c         WRITE(6,*) '<a183_htt> Higgs mass out of range!',hmass
         A183_HTT_MASS_SIG = 0.
         RETURN
      ENDIF
C
      SIGMASS = QNEWPAR(4) +
     .     QNEWPAR(1)*EXP(-0.5*((x - QNEWPAR(2))/QNEWPAR(3))**2.)
C                                                                      
      IF ( X .LE. XMAX .AND. X .GE. XMIN .AND. SIGMASS .GE. 0 ) THEN      
        A183_HTT_MASS_SIG = SIGMASS            
      ELSE                                                              
        A183_HTT_MASS_SIG = 0.
      ENDIF                                                             
C                                                                       
      RETURN                                                            
      END                                                               
C---------------------------------------------------------------------
C---------------------------------------------------------------------

