CC-*-FORTRAN-*-
CC
C      subroutine a2000_xtt_cand(iebin,ncand,xtt_mass,ibranch)
CC
CC     Return the number of Cuts 4-jet candidates in the large energy bin
CC     IEBIN 
CC     The branch (ibranch) is defined by the user
CC     thus func can return hzexcl,haexcl,ovlpha,ovlphz
CC     The candidate properties are also returned in 
CC     the arrays xtt_mass,
CC                                    J Kennedy, June-2000.
Cc     Modified:
Cc     - minor changes, to update JK's version (for 4jets CUTS) to Xtt;
Cc                                    PTD, 02-Jul-2000.
CC
CC     - final update of candidates for July 20, LEPC; PTD, 11-Jul-2000.
CC
CC
C      implicit none
C      integer i,ncand,nmax,ntotal,iebin,n1,n2,ibranch
C      parameter (n1=50,n2=500)
C      logical first
C      data first /.true./
C      real emin,emax,xtt_mass(n1),
C     +     ecms(n2),mass(n2),btag(n2),branch(n2)
C      save ecms,mass,ntotal
Cc
C      include 'a_2000_vars.inc'
Cc
C      if (FIRST) then
C         FIRST = .false.
Cc
Cc     Fill in the database:
Cc     ecms, mass & branch for each candidate
Cc     ntotal=total number of candidates in database
C         ntotal = 1
Cc
Cc++hz excl (ibranch=4)
Cc
C         ecms(ntotal) = 204.8120
C         mass(ntotal) = 83.2795
C         branch(ntotal) = 4
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 205.2960
C         mass(ntotal) = 113.0488
C         branch(ntotal) = 4
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 205.2520
C         mass(ntotal) = 75.0441
C         branch(ntotal) = 4
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 206.0700
C         mass(ntotal) = 87.6652
C         branch(ntotal) = 4
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 206.6200
C         mass(ntotal) = 93.1472
C         branch(ntotal) = 4
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 206.5380
C         mass(ntotal) = 117.3283
C         branch(ntotal) = 4
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 208.1320
C         mass(ntotal) = 115.3910
C         branch(ntotal) = 4
Cc
Cc++ha excl (ibranch=1)
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 205.2160
C         mass(ntotal) = 76.8765
C         branch(ntotal) = 1
Cc
Cc++ovlap as hz (ibranch=3)
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 205.1280
C         mass(ntotal) = 88.2699
C         branch(ntotal) = 3
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 208.3760
C         mass(ntotal) = 101.4672
C         branch(ntotal) = 3
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 208.1460
C         mass(ntotal) = 94.1215
C         branch(ntotal) = 3
C
Cc
Cc++ovlap as ha (ibranch=2)
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 205.1280
C         mass(ntotal) = 91.7498
C         branch(ntotal) = 2
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 208.3760
C         mass(ntotal) = 93.7971
C         branch(ntotal) = 2
Cc
C         ntotal = ntotal + 1
C         ecms(ntotal) = 208.1460
C         mass(ntotal) = 92.5717
C         branch(ntotal) = 2
C
Cc
Cc         write (6,*) '+---------------------------------------------+'
Cc         write (6,*) '| Xtt candidates from BEHOLD <= 26/06/2000. '
Cc         write (6,*) '| Last considered RUN NO: ',54984
Cc         write (6,*) '| N(entries) in Y2000 database = ',ntotal
Cc         write (6,*) '+---------------------------------------------+'
Cc
C      end if                    ! FIRST
Cc
Cc     Initialize output variables
Cc
C      ncand = 0
C      call vzero(xtt_mass,n1)
Cc
Cc     Boundaries for thsi energy bin are:
Cc
C      emin = 199.+0.1*(ilow_energy(iebin)-1)
C      emax = 199.+0.1*(ihigh_energy(iebin))
Cc      write (6,*) 'Searching for the C4J-2000 candidates in the range',
Cc     +     emin,emax,' GeV.'
Cc
Cc     Search the database for all candidates in [Emin,Emax]
Cc
C      do i=1,ntotal
C	if(branch(i).eq.ibranch) then
C         if (ecms(i).ge.emin .AND. ecms(i).lt.emax) then
C            ncand = ncand + 1
C            xtt_mass(ncand) = mass(i)
C         end if
C	endif
C      end do                    ! ntotal
Cc
C      return
C      end
C-*-FORTRAN-*-
c
      subroutine xtt_convert(ityp,isig,idecay)
c
c     Converts the ITYP=1,11 index for the 11 different Xtt final states
c     in the Y2000 code by Jason Nielsen, to the ISIG,IDECAY indices that 
c     are necessary when calling the sahpes & efficiency functions.
c
c     INPUT: ITYP 
c     OUTPUT: ISIG,IDECAY
c
c     Created: 02-Jul-2000, Pedro Teixeira-Dias.
c
c     Modified:
c     
      implicit none
      integer ityp,isig,idecay
c
c      ityp = 0
c
      if (ityp.lt.1 .or. ityp.gt.11) then
         write (6,*) '<xtt_convert> Error! ityp out of range!',ityp
         write (6,*) '<xtt_convert> will return ITYP=0!!'
         return
      end if
c
      if (ityp.eq.1) then
         isig = 1
         idecay = 1
      else if (ityp.eq.2) then
         isig = 1
         idecay = 2
      else if (ityp.eq.3) then
         isig = 1
         idecay = 3
      else if (ityp.eq.4) then
         isig = 1
         idecay = 4
      else if (ityp.eq.5) then
         isig = 1
         idecay = 5
      else if (ityp.eq.6) then
         isig = 2
         idecay = 0
      else if (ityp.eq.7) then
         isig = 3
         idecay = 1
      else if (ityp.eq.8) then
         isig = 3
         idecay = 2
      else if (ityp.eq.9) then
         isig = 3
         idecay = 3
      else if (ityp.eq.10) then
         isig = 3
         idecay = 4
      else if (ityp.eq.11) then
         isig = 3
         idecay = 5
      end if
c
      return
      end
