*-----------------------------------------------------------------------------*
c!                                                                             *
c!Subroutines for creation/handling of histograms, needed for ALEPH inputs   *
c!                                                                             *
*-----------------------------------------------------------------------------*

c! --------
c! subroutine ahistread1 -- reads in 1D signal histograms into local storage.
c! just a copy of ohistread1 but uses the aleph common block

      subroutine ahistread1(filename,ichan)
      implicit none
      include 'a_inputs.inc'
      include 'a_internal.inc'
      character*(*) filename
      integer ichan
      integer i,ios
      logical first
      data first /.true./
      save first
      if (first) then
        call vzero(ich,amaxhis)
        ihis = 0
        first = .false.
      endif
      ihis = ihis + 1
      if (ihis.gt.amaxhis) then
        write(*,*) 'ahistread1 -- too many histograms.  Max=',
     >              amaxhis,' Needed: ',ihis,filename
        stop
      endif
      ich(ihis) = ichan
      open(unit=a_histinlun,status='OLD',
     >     file=filename,err=10,iostat=ios)
      goto 20
 10   continue
      write(*,*) 'Error opening histogram file: ',filename
      write(*,*) 'OPEN returns error code: ',ios
      write(*,*) 'Aborting.'
      stop
 20   continue
      read(a_histinlun,*) xmc(ihis),nehis(ihis),xl(ihis),xu(ihis)
      do i=1,nehis(ihis)
        read(a_histinlun,*) his(i,ihis)
        if (his(i,ihis).lt.1.0e-20) his(i,ihis) = 0.0
      enddo
      close(a_histinlun)
      return
      end


c---------------------------------------------------------------

c! --------
c! subroutine asinterp1 -- interpolated (in 1D) signal histograms.  Uses
c!                         data collected in ohistread1.
c!                         The histo is not necessarily normalized.
c interpolate 1D histograms from a list using P. Bock's interpolator.  Most
c code in this subroutine is by P. Bock.
c just a copy of the OPAL one osinterp1 -- calls the same utility functions
c only difference -- this one includes the aleph histogram common block
c ahistcom

      subroutine asinterp1(ichan,mh,nbinsint,xlc,xuc,sighist)
      implicit none
      include 'a_internal.inc'
      integer ichan,nbinsint
      real mh,xlc,xuc,sighist(*)

      integer j,k,k2,kuclos,klclos,j1,j2,ier
      real xref,sum1ch
      real dx1ch
      real xm1,xm2,sig1,sig2,sum1,sum2,emx1,emx2,w

c interpolate for mh - just one variable, called mh for convenience

      kuclos=0
      klclos=0

*  find the two monte carlo masses closest to the test mass mh

      do k=1,ihis
        if (ich(k).eq.ichan) then
          xref = mh
          if (xref.ge.xmc(k)) then
            if (klclos.eq.0) then
              klclos=k
            elseif ((xref-xmc(k)).lt.(xref-xmc(klclos))) then
              klclos=k
            endif
          else
            if (kuclos.eq.0) then
              kuclos=k
            elseif ((xmc(k)-xref).lt.(xmc(kuclos)-xref)) then
              kuclos=k
            endif
          endif
        endif
      enddo

*  copy the histograms into the channel histograms
*  select case
      j2=0
      if (klclos.gt.0) then
        j1=klclos
        if (kuclos.gt.0) j2=kuclos
      else
        if (kuclos.gt.0) then
          j1=kuclos
        else
          write(*,*) '*** ohinterp: missing histogram for',
     +               ' channel',ichan
          stop
        endif
      endif

c first, if we only have one histogram, just copy it to the output

      if (j2.le.0) then
        k=j1
        ier=0
        emx1=0.
        sum1ch=0.
        do j=1,nehis(k)
          if (his(j,k).lt.0.) then
            ier = 2
            sighist(j) = 0.
          else
            sighist(j) = his(j,k)
            sum1ch = sum1ch + his(j,k)
          endif
          if (his(j,k).gt.emx1) emx1=his(j,k)
        enddo

*  check histogram
        if (emx1.lt.1.e-6) then
           write(*,*) 'Max entry too small in osinterp1',
     +        ichan,k,emx1,nehis(k)
           stop
        endif
        if (ier.eq.2) write(*,*) 
     +        '*** osinterp1: negative entries in histogram',
     +                    k,' set to zero'
        do j=1,nehis(k)
          sighist(j)=sighist(j)/emx1
        enddo
        sum1ch=sum1ch/emx1
        xlc =xl(k)+mh-xmc(k)
        xuc =xu(k)+mh-xmc(k)
        nbinsint =nehis(k)
        dx1ch =(xu(k)-xl(k))/float(nehis(k))

      else

c  combine two distributions if we have two

        k=j1
        k2=j2
c  find mean masses and variances
        call atrhpar(nehis(k),his(1,k),xl(k),xu(k),
     +              xm1,sig1,sum1,emx1,ier)
        if (ier.eq.4) then
          write(*,*) 
     +      'osinterp1: histogram without entries ',k
          stop
        endif
        if (ier.eq.2) then
           write(*,*) 
     +        'osinterp1: negative entries in histogram',
     +                 k,' set to zero'
        endif

        call atrhpar(nehis(k2),his(1,k2),xl(k2),xu(k2),
     +              xm2,sig2,sum2,emx2,ier)
        if (ier.eq.4) then
          write(*,*) 
     +      'osinterp1: histogram without entries ',k2
          stop
        endif
        if (ier.eq.2) then
          write(*,*) 
     +      'osinterp1: negative entries in histogram',
     +                 k2,' set to zero'
        endif

c  combine histograms
        if (abs(xmc(k2)-xmc(k)).lt.0.01) then
           write(*,*) 'osinterp1: duplicate MC mass found'
           stop
        endif
        w=(xmc(k2)-mh)/(xmc(k2)-xmc(k))

        nbinsint = max(nehis(k),nehis(k2))
        call atrhadd(nehis(k),his(1,k),xl(k),xu(k),
     +              xm1,sig1,sum1,emx1,
     +              nehis(k2),his(1,k2),xl(k2),xu(k2),
     +              xm2,sig2,sum2,emx2,
     +              w,nbinsint,sighist,xlc,xuc,
     +              dx1ch,sum1ch)
      endif
      
      return
      end


c---------------------------------------------------------------
c! --------
c! subroutine abhcreate2(xl,xh,nbins,func1,func2,iana,bhist)
c! subroutine abhcreate2 -- produces a background histogram from a function
c!                          and histogram spec (xl, xh, nbins)
c!  assume total background is given by func2 and that we have to normalize it
c!  in the range xl--xh

      subroutine abhcreate2(xl,xh,nbins,func1,func2,iana,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd
      real xl,xh,bhist(*),bsum,btot
      integer nbins
      integer i,iana
      real x,dx
      dx = (xh-xl)/float(nbins)
      bsum = 0.0
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func1(xd,iana)*dx
        bsum = bsum + bhist(i)
      enddo
      btot = func2(iana)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end

c! --------
c! subroutine abhcreate5(xl,xh,nbins,func1,func2,bhist)
c! subroutine abhcreate5 -- same as abhcreate2 but no iana

      subroutine abhcreate5(xl,xh,nbins,func1,func2,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd
      real xl,xh,bhist(*),bsum,btot
      integer nbins
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      bsum = 0.0
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func1(xd)*dx
        bsum = bsum + bhist(i)
      enddo
      btot = func2()
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end

c! --------
c! subroutine abhcreate7(xl,xh,nbins,func1,func2,iana,ibkg,bhist)
c! subroutine abhcreate7 -- same but iana and ibkg

      subroutine abhcreate7(xl,xh,nbins,func1,func2,iana,ibkg,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd
      real xl,xh,bhist(*),bsum,btot
      integer nbins
      integer i,iana,ibkg
      real x,dx
      dx = (xh-xl)/float(nbins)
      bsum = 0.0
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func1(xd,iana,ibkg)*dx
        bsum = bsum + bhist(i)
      enddo
      btot = func2(iana,ibkg)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end

c! --------
c! subroutine abhcreateB(xl,xh,nbins,func1,func2,iana,ibkg,bhist)
c! subroutine abhcreateB -- same but iana and ibkg and ener

      subroutine abhcreateB(xl,xh,nbins,func1,func2,iana,ibkg,
     &                      ener,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd,ener
      real xl,xh,bhist(*),bsum,btot
      integer nbins
      integer i,iana,ibkg
      real x,dx
      dx = (xh-xl)/float(nbins)
      bsum = 0.0
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func1(ener,xd,iana,ibkg)*dx
        bsum = bsum + bhist(i)
      enddo
      btot = func2(ener,iana,ibkg)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end

c! --------
c! subroutine abhcreateC(xl,xh,nbins,func1,func2,iana,ibkg,bhist)
c! subroutine abhcreateC -- same but alternate internal ordering

      subroutine abhcreateC(xl,xh,nbins,func1,func2,iana,ibkg,
     &                      ener,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd,ener
      real xl,xh,bhist(*),bsum,btot
      integer nbins
      integer i,iana,ibkg
      real x,dx
      dx = (xh-xl)/float(nbins)
      bsum = 0.0
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func1(ener,ibkg,iana,xd)*dx
        bsum = bsum + bhist(i)
      enddo
      btot = func2(ener,iana,ibkg)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end
c! --------
c! subroutine abhcreateD(xl,xh,nbins,func1,func2,iana,ibkg,bhist)
c! subroutine abhcreateD -- same but no iana

      subroutine abhcreateD(xl,xh,nbins,func1,func2,ibkg,
     &                      ener,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd,ener
      real xl,xh,bhist(*),bsum,btot
      integer nbins
      integer i,iana,ibkg
      real x,dx
      dx = (xh-xl)/float(nbins)
      bsum = 0.0
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func1(ener,ibkg,xd)*dx
        bsum = bsum + bhist(i)
      enddo
      btot = func2(ener,ibkg)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end

c! --------
c! subroutine abhcreateD(xl,xh,nbins,func1,func2,iana,ibkg,bhist)
c! subroutine abhcreateD -- same but no iana

      subroutine abhcreateD_fancy(xl,xh,nbins,xchange,
     &                      func1,func2,ibkg,
     &                      ener,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd,ener
      real xl,xh,bhist(*),bsum,btot
      integer nbins
      integer i,iana,ibkg
      real x,dx1,dx2,xchange
      bsum = 0.0
      dx1 = (xchange-xl)/float(nbins/2)
      do i=1,nbins/2
        x = xl + (float(i)-0.5)*dx1
        xd = x
        bhist(i) = func1(ener,ibkg,xd)*dx1
        bsum = bsum + bhist(i)
      enddo
      dx2 = (xh-xchange)/float(nbins-nbins/2)
      do i=nbins/2+1,nbins
        x = xchange + (float(i-nbins/2)-0.5)*dx2
        xd = x
        bhist(i) = func1(ener,ibkg,xd)*dx2
        bsum = bsum + bhist(i)
      enddo
      btot = func2(ener,ibkg)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end

c! --------
c! subroutine abhcreateE(xl,xh,nbins,func1,func2,iana,ibkg,ener,bhist)
c! subroutine abhcreateE -- same but iana and ibkg and ener

      subroutine abhcreateE(xl,xh,nbins,func1,func2,iana,ibkg,
     &                      ener,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd,ener
      real xl,xh,bhist(*),bsum,btot
      integer nbins
      integer i,iana,ibkg
      real x,dx
      dx = (xh-xl)/float(nbins)
      bsum = 0.0
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func1(xd,ener,iana,ibkg)*dx
        bsum = bsum + bhist(i)
      enddo
      btot = func2(ener,iana,ibkg)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end

c! --------
c! subroutine abhcreate_fancy(xl,xh,nbins,func1,func2,iana,ibkg,ener,bhist)
c! subroutine abhcreate_fancy -- same but iana and ibkg and ener

      subroutine abhcreateE_fancy(xl,xh,nbins,xchange,
     &                      func1,func2,iana,ibkg,
     &                      ener,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd,ener
      real xl,xh,bhist(*),bsum,btot,xchange
      integer nbins
      integer i,iana,ibkg
      real x,dx1,dx2
      bsum = 0.0
      dx1 = (xchange-xl)/float(nbins/2)
      do i=1,nbins/2
        x = xl + (float(i)-0.5)*dx1
        xd = x
        bhist(i) = func1(xd,ener,iana,ibkg)*dx1
        bsum = bsum + bhist(i)
      enddo
      dx2 = (xh-xchange)/float(nbins-nbins/2)
      do i=nbins/2+1,nbins
        x = xchange + (float(i-nbins/2)-0.5)*dx2
        xd = x
        bhist(i) = func1(xd,ener,iana,ibkg)*dx2
        bsum = bsum + bhist(i)
      enddo
      btot = func2(ener,iana,ibkg)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end



c! 
c! subroutine abhcreate8(xl,xh,nbins,func1,func2,iana,ibkg,h,bhist)
c! same as abhcreate 7, but added mH (temporarily in use, for Hvv 19x backgrounds)
c  PAM, 27-Jul-1999.

      subroutine abhcreate8(xl,xh,nbins,func1,func2,iana,ibkg,h,bhist)
      implicit none
      double precision func1,func2
      external func1,func2
      double precision xd,hd
      real xl,xh,bhist(*),bsum,btot
      real h
      integer nbins
      integer i,iana,ibkg
      real x,dx
      dx = (xh-xl)/float(nbins)
      bsum = 0.0
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        hd = h
        bhist(i) = func1(xd,iana,ibkg,hd)*dx
        bsum = bsum + bhist(i)
      enddo
      btot = func2(iana,ibkg)
      if (bsum.gt.0.0) then
        do i=1,nbins
          bhist(i) = bhist(i)*btot/bsum
        enddo
      endif
      return
      end


c! --------
c! subroutine ascreate2(xl,xh,nbins,func,h,iana,bhist)
c! for making signal histograms -- use the iana index for analyses

      subroutine ascreate2(xl,xh,nbins,func,h,iana,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        hd = h
        bhist(i) = func(xd,hd,iana)
      enddo
      return
      end

c! --------
c! subroutine ascreate2F(xl,xh,nbins,func,h,ss,bhist)
c! for making signal histograms -- use the ss input for ECM value
c! (as ascreate2, except SS real*8 argument now replaces IANA index)

      subroutine ascreate2F(xl,xh,nbins,func,h,ss,bhist)
      implicit none
      double precision func
      double precision xd,hd,ss
      external func
      real xl,xh,bhist(*),h
      integer nbins
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        hd = h
        bhist(i) = func(xd,hd,ss)
      enddo
      return
      end

c! --------
c! subroutine ascreate2f_fancy(xl,xh,nbins,xchange,func,bhist)

      subroutine ascreate2f_fancy(xl,xh,nbins,xchange,func,h,ss,bhist)
      implicit none
      double precision func
      double precision xd
      double precision ss,hd
      real h
      external func
      real xl,xh,bhist(*)
      integer nbins,i
      real x,dx1,dx2,xchange
      dx1 = (xchange-xl)/float(nbins/2)
      do i=1,nbins/2
        x = xl + (float(i)-0.5)*dx1
        xd = x
        hd = h
        bhist(i) = max(sngl(func(xd,hd,ss)),0.0)
      enddo
      dx2 = (xh-xchange)/float(nbins-nbins/2)
      do i=nbins/2+1,nbins
        x = xchange + (float(i-nbins/2)-0.5)*dx2
        xd = x
        hd = h
        bhist(i) = max(sngl(func(xd,hd,ss)),0.0)
      enddo
      return
      end



c! --------
c! subroutine ascreate3(xl,xh,nbins,func,h,bhist)
c! same, but no iana

      subroutine ascreate3(xl,xh,nbins,func,h,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        hd = h
c        bhist(i) = max(func(xd,hd),1.0E-6)
        bhist(i) = max(sngl(func(xd,hd)),1.0E-6)
      enddo
      return
      end

c! --------
c! subroutine ascreate3_fancy(xl,xh,nbins,xchange,func,bhist)

      subroutine ascreate3_fancy(xl,xh,nbins,xchange,func,h,bhist)
      implicit none
      double precision func
      double precision xd
      double precision ss,hd
      real h
      external func
      real xl,xh,bhist(*)
      integer nbins,i
      real x,dx1,dx2,xchange
      dx1 = (xchange-xl)/float(nbins/2)
      do i=1,nbins/2
        x = xl + (float(i)-0.5)*dx1
        xd = x
        hd = h
        bhist(i) = max(sngl(func(xd,hd)),0.0)
      enddo
      dx2 = (xh-xchange)/float(nbins-nbins/2)
      do i=nbins/2+1,nbins
        x = xchange + (float(i-nbins/2)-0.5)*dx2
        xd = x
        hd = h
        bhist(i) = max(sngl(func(xd,hd)),0.0)
      enddo
      return
      end



c! --------
c! subroutine ascreate4(xl,xh,nbins,func,h,bhist)
c! same, but no iana, and two arguments of the same value to the func

      subroutine ascreate4(xl,xh,nbins,func,h,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        hd = h
        bhist(i) = max(sngl(func(xd,hd,hd)),1.0E-6)
      enddo
      return
      end


c! --------
c! subroutine ascreate5(xl,xh,nbins,func,bhist)
c! same as 3, but no h masss argument (simple!)

      subroutine ascreate5(xl,xh,nbins,func,bhist)
      implicit none
      double precision func
      double precision xd
      external func
      real xl,xh,bhist(*)
      integer nbins,i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = max(sngl(func(xd)),0.0)
      enddo
      return
      end

c! --------
c! subroutine ascreate5_fancy(xl,xh,nbins,xchange,func,bhist)
c! same as 3, but no h masss argument (simple!)

      subroutine ascreate5_fancy(xl,xh,nbins,xchange,func,bhist)
      implicit none
      double precision func
      double precision xd
      external func
      real xl,xh,bhist(*)
      integer nbins,i
      real x,dx1,dx2,xchange
      dx1 = (xchange-xl)/float(nbins/2)
      do i=1,nbins/2
        x = xl + (float(i)-0.5)*dx1
        xd = x
        bhist(i) = max(sngl(func(xd)),0.0)
      enddo
      dx2 = (xh-xchange)/float(nbins-nbins/2)
      do i=nbins/2+1,nbins
        x = xchange + (float(i-nbins/2)-0.5)*dx2
        xd = x
        bhist(i) = max(sngl(func(xd)),0.0)
      enddo
      return
      end


c! --------
c! subroutine ascreate7(xl,xh,nbins,func,iana,bhist)
c! same as 5 (i.e., no hmass argument), but iana
c  PTD, 27-Jul-1999.
c
      subroutine ascreate7(xl,xh,nbins,func,iana,bhist)
      implicit none
      double precision func
      double precision xd
      external func
      real xl,xh,bhist(*)
      integer nbins,i,iana
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = max(sngl(func(xd,iana)),0.0)
      enddo
      return
      end

c! --------
c! subroutine ascreate6(xl,xh,nbins,func,h,iana,isig,bhist)
c! same as 2, but use the iana and isig index for analyses

      subroutine ascreate6(xl,xh,nbins,func,h,iana,isig,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        hd = h
        bhist(i) = func(xd,hd,iana,isig)
      enddo
      return
      end

c! --------
c! subroutine ascreate8(xl,xh,nbins,func,hd,iana,isig,iener,bhist)
c! same as 2, but use the iana and isig index for analyses, and the
c! iener index for centre-of-mass-energy.
c  PTD, 31-Jul-1999.

      subroutine ascreate8(xl,xh,nbins,func,hd,iana,isig,iener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig,iener
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
c        hd = h
        bhist(i) = func(xd,hd,iana,isig,iener)
      enddo
      return
      end

c! --------
c! subroutine ascreate9(xl,xh,nbins,func,iana,isig,iener,bhist)
c! same as 8, (iana, isig and iener indices) but no mass arg
c  PAM, 11-Aug-1999.

      subroutine ascreate9(xl,xh,nbins,func,iana,isig,iener,bhist)
      implicit none
      double precision func
      double precision xd
      external func
      real xl,xh,bhist(*)
      integer nbins,iana,isig,iener
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func(xd,iana,isig,iener)
c        write(6,*) 'internal ',i,x,xd,hd,bhist(i)
      enddo
      return
      end

c! --------
c! subroutine ascreateA(xl,xh,nbins,func,iana,isig,iener,bhist)
c! same as 8, (isig and iener indices) but no iana arg
c  PAM, 11-Aug-1999.

      subroutine ascreateA(xl,xh,nbins,func,h,isig,iener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,h,bhist(*)
      integer nbins,iana,isig,iener
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        hd = h
        bhist(i) = func(xd,hd,isig,iener)
c        write(6,*) 'internal ',i,x,xd,hd,bhist(i)
      enddo
      return
      end

c! --------
c! subroutine ascreateB(xl,xh,nbins,func,hd,iana,isig,iener,bhist)
c! same as 2, but use the iana and isig index for analyses, and the
c! ener input for centre-of-mass-energy.
c  PTD, 31-Jul-1999.

      subroutine ascreateB(xl,xh,nbins,func,hd,iana,isig,ener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig
      double precision ener
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
c        hd = h
        bhist(i) = func(hd,ener,xd,iana,isig)
c        write(6,*) 'internal ',i,x,xd,hd,bhist(i)
      enddo
      return
      end

c! --------
c! subroutine ascreateC(xl,xh,nbins,func,hd,iana,isig,iener,bhist)
c! same as 2, but use the iana index for analyses, and the
c! ener input for centre-of-mass-energy.
c  PTD, 31-Jul-1999.

      subroutine ascreateC(xl,xh,nbins,func,hd,iana,ener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig
      double precision ener
      integer i
      real x,dx
c      write (6,*) 'in ascreateC',nbins,xh,xl
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = DBLE(x)
c        hd = h
        bhist(i) = func(ener,iana,hd,xd)
      enddo
      return
      end
c! subroutine ascreateD(xl,xh,nbins,func,hd,isig,iener,bhist)
c! like C, but no iana index for analyses, and the
c! ener input for centre-of-mass-energy.
c  PTD, 31-Jul-1999.

      subroutine ascreateD(xl,xh,nbins,func,hd,isig,ener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig
      double precision ener
      integer i
      real x,dx
c      write (6,*) 'in ascreateD',nbins,xh,xl
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = DBLE(x)
c        hd = h
c        write(*,*) ener,xd,hd,isig
        bhist(i) = func(ener,isig,hd,xd)
c        write(*,*) bhist(i)
      enddo
      return
      end

c! subroutine ascreateD(xl,xh,nbins,func,hd,isig,iener,bhist)
c! like C, but no iana index for analyses, and the
c! ener input for centre-of-mass-energy.
c  PTD, 31-Jul-1999.

      subroutine ascreateD_fancy(xl,xh,nbins,xchange,
     &                       func,hd,isig,ener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig
      double precision ener
      integer i
      real x,dx1,dx2,xchange
c      write (6,*) 'in ascreateD',nbins,xh,xl
      dx1 = (xchange-xl)/float(nbins/2)
      do i=1,nbins/2
        x = xl + (float(i)-0.5)*dx1
        xd = DBLE(x)
c        hd = h
c        write(*,*) ener,xd,hd,isig
        bhist(i) = func(ener,isig,hd,xd)
c        write(*,*) bhist(i)
      enddo
      dx2 = (xh-xchange)/float(nbins-nbins/2)
      do i=nbins/2+1,nbins
        x = xchange + (float(i-nbins/2)-0.5)*dx2
        xd = DBLE(x)
c        hd = h
c        write(*,*) ener,xd,hd,isig
        bhist(i) = func(ener,isig,hd,xd)
c        write(*,*) bhist(i)
      enddo
      return
      end

c! --------
c! subroutine ascreateE(xl,xh,nbins,func,hd,iana,isig,iener,bhist)
c! same as 2, but use the iana and isig index for analyses, and the
c! ener input for centre-of-mass-energy.
c  PTD, 31-Jul-1999.

      subroutine ascreateE(xl,xh,nbins,func,hd,iana,isig,ener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig
      double precision ener
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
c        hd = h
        bhist(i) = func(xd,hd,ener,iana,isig)
c        write(6,*) 'internal ',i,x,xd,hd,bhist(i)
      enddo
      return
      end
c! --------
c! subroutine ascreate_fancy(xl,xh,nbins,func,hd,iana,isig,iener,bhist)
c! same as 2, but use the iana and isig index for analyses, and the
c! ener input for centre-of-mass-energy.
c  PTD, 31-Jul-1999.

      subroutine ascreateE_fancy(xl,xh,nbins,xchange,
     &                 func,hd,iana,isig,ener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,xchange,bhist(*),h
      integer nbins,iana,isig
      double precision ener
      integer i,j,k
      real x,dx1,dx2
      dx1 = (xchange-xl)/float(nbins/2)
      do i=1,nbins/2
        x = xl + (float(i)-0.5)*dx1
        xd = x
        bhist(i) = func(xd,hd,ener,iana,isig)*(xchange-xl)/(xh-xl)
      enddo
      dx2 = (xh-xchange)/float(nbins-nbins/2)
      do i=nbins/2+1,nbins
        x = xchange + (float(i-nbins/2)-0.5)*dx2
        xd = x
c        hd = h
        bhist(i) = func(xd,hd,ener,iana,isig)*(xh-xchange)/(xh-xl)
c        write(6,*) 'internal ',i,x,xd,hd,bhist(i)
      enddo
      return
      end
c! --------
c!      subroutine ascreateF(xl,xh,nbins,func,hd,ecm,
c!     +                     ibranch,isig,bhist)
c! specific for Xtt signal shapes in Y2000 (use ISIG for sig type:hZ/hA)
c! IBRANCH indicates haexc,asha,ashz,hzexc
c  PTD, 02-Jul-2000.

      subroutine ascreateF(xl,xh,nbins,func,hd,ecm,
     +                     ibranch,isig,bhist)
      implicit none
      double precision func
      double precision xd,hd,ecm
      external func
      real xl,xh,bhist(*),h
      integer nbins,ibranch,isig
      integer i
      real x,dx

      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
c
        bhist(i) = func(ecm,hd,xd,ibranch,isig)
      enddo
      return
      end

c! --------
c!      subroutine abcreateF(xl,xh,nbins,func,ecm,
c!     +                     ibranch,ityp,bhist)
c! specific for Xtt signal shapes in Y2000 (use Ityp for bgd type)
c! IBRANCH indicates haexc,asha,ashz,hzexc
c  PTD, 02-Jul-2000.

      subroutine abcreateF(xl,xh,nbins,func,ecm,
     +                     ibranch,ityp,bhist)
      implicit none
      double precision func
      double precision xd,ecm
      external func
      real xl,xh,bhist(*),h
      integer nbins,ibranch,ityp
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
c 
        bhist(i) = func(ecm,xd,ibranch,ityp,dble(xl),dble(xh))

      enddo
      return
      end



c! --------
c! subroutine abcreate8(xl,xh,nbins,func,iana,isig,iener,bhist)
c! same as ascreate8, except no h (for bgd)
c! i.e.: use the IANA and ISIG index for analyses, and the
c! IENER index for centre-of-mass-energy.
c  PTD, 31-Jul-1999.

      subroutine abcreate8(xl,xh,nbins,func,iana,isig,iener,bhist)
      implicit none
      double precision func
      double precision xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig,iener
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        bhist(i) = func(xd,iana,isig,iener)
      enddo
      return
      end

c! --------
c! subroutine a_create6_hc(xl,xh,nbins,func,h,iana,isig,bhist)
c! same as ascreate6, but func is a REAL*4 function; for charged Higgs

      subroutine a_create6_hc(xl,xh,nbins,func,h,iana,isig,bhist)
      implicit none
      real func
      real xd,hd
      external func
      real xl,xh,bhist(*),h
      integer nbins,iana,isig
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        xd = x
        hd = h
        bhist(i) = func(isig,iana,xd,hd)
      enddo
      return
      end

c! --------
c! subroutine abhcreate3(nbinsint1,xl1,xu1,nbinsint2,xl2,xu2,
c!>                    iana,func1,func2,func3,backw,
c!>                    xl1o,xu1o,xl2o,xu2o)
c! 2D background histograms in independent variables.
c! need to normalize the total background to func3.
c! so need original bounds for entire bg spectrum.

      subroutine abhcreate3(nbinsint1,xl1,xu1,nbinsint2,xl2,xu2,
     >                    iana,func1,func2,func3,backw,
     >                    xl1o,xu1o,xl2o,xu2o)
      implicit none
      integer nbinsint1,nbinsint2,iana
      real xl1,xu1,xl2,xu2
      double precision func1,func2,func3
      external func1,func2,func3
      double precision x,y,dx1,dx2
      integer i,j,k
      real backw(*)
      real xl1o,xl2o,xu1o,xu2o
      real bg,bgsum,scf

c compute bg normalization scale factor

      bgsum = 0.0
      dx1 = dble((xu1o-xl1o)/float(nbinsint1))
      dx2 = dble((xu2o-xl2o)/float(nbinsint2))
      do i=1,nbinsint1
        do j=1,nbinsint2
          x = xl1o + (float(i)-0.5)*dx1
          y = xl2o + (float(j)-0.5)*dx2
          bg = func1(x,iana)*func2(y,iana)*dx1*dx2
          bgsum = bgsum + bg
        enddo
      enddo
      scf = 0.0
      if (bgsum.gt.0.0) then
        scf = func3(iana)/bgsum
      endif

c put together the 2D background histogram in the new bins

      dx1 = (xu1-xl1)/float(nbinsint1)
      dx2 = (xu2-xl2)/float(nbinsint2)
      k = 0
      do i=1,nbinsint1
        do j=1,nbinsint2
          k = k + 1
          x = xl1 + (float(i)-0.5)*dx1
          y = xl2 + (float(j)-0.5)*dx2
          backw(k) = func1(x,iana)*func2(y,iana)*dx1*dx2*scf
        enddo
      enddo
      return
      end

c! --------
c! subroutine abhcreate4(nbinsint1,xl1,xu1,nbinsint2,xl2,xu2,
c!>                    func1,func2,func3,backw,
c!>                    xl1o,xu1o,xl2o,xu2o)
c! 2D background histograms in independent variables -- no iana variable
c! just like abhcreate3

      subroutine abhcreate4(nbinsint1,xl1,xu1,nbinsint2,xl2,xu2,
     >                    func1,func2,func3,backw,
     >                    xl1o,xu1o,xl2o,xu2o)
      implicit none
      integer nbinsint1,nbinsint2
      real xl1,xu1,xl2,xu2
      double precision func1,func2,func3
      external func1,func2,func3
      double precision x,y,dx1,dx2
      integer i,j,k
      real backw(*)
      real xl1o,xl2o,xu1o,xu2o
      real bg,bgsum,scf

c compute bg normalization scale factor

      bgsum = 0.0
      dx1 = (xu1o-xl1o)/float(nbinsint1)
      dx2 = (xu2o-xl2o)/float(nbinsint2)
      do i=1,nbinsint1
        do j=1,nbinsint2
          x = xl1o + (float(i)-0.5)*dx1
          y = xl2o + (float(j)-0.5)*dx2
          bg = func1(x)*func2(y)*dx1*dx2
          bgsum = bgsum + bg
        enddo
      enddo
      scf = 0.0
      if (bgsum.gt.0.0) then
        scf = func3()/bgsum
      endif

c put together the 2D background histogram in the new bins

      dx1 = (xu1-xl1)/float(nbinsint1)
      dx2 = (xu2-xl2)/float(nbinsint2)
      k = 0
      do i=1,nbinsint1
        do j=1,nbinsint2
          k = k + 1
          x = xl1 + (float(i)-0.5)*dx1
          y = xl2 + (float(j)-0.5)*dx2
          backw(k) = func1(x)*func2(y)*dx1*dx2*scf
        enddo
      enddo
      return
      end

c! --------
c! subroutine abhcreate6(nbinsint1,xl1,xu1,nbinsint2,xl2,xu2,
c!>                     iana,ibkg,func1,func2,func3,backw,
c!>                     xl1o,xu1o,xl2o,xu2o)
c! Same as 3, but with bkg function taking iana and ibkg

      subroutine abhcreate6(nbinsint1,xl1,xu1,nbinsint2,xl2,xu2,
     >                     iana,ibkg,func1,func2,func3,backw,
     >                     xl1o,xu1o,xl2o,xu2o)
      implicit none
      integer nbinsint1,nbinsint2,iana,ibkg
      real xl1,xu1,xl2,xu2
      double precision func1,func2,func3
      external func1,func2,func3
      double precision x,y,dx1,dx2
      integer i,j,k
      real backw(*)
      real xl1o,xl2o,xu1o,xu2o
      real bg,bgsum,scf

c compute bg normalization scale factor

      bgsum = 0.0
      dx1 = (xu1o-xl1o)/float(nbinsint1)
      dx2 = (xu2o-xl2o)/float(nbinsint2)
      do i=1,nbinsint1
        do j=1,nbinsint2
          x = xl1o + (float(i)-0.5)*dx1
          y = xl2o + (float(j)-0.5)*dx2
          bg = func1(x,iana,ibkg)*func2(y,iana,ibkg)*dx1*dx2
          bgsum = bgsum + bg
        enddo
      enddo
      scf = 0.0
      if (bgsum.gt.0.0) then
        scf = func3(iana,ibkg)/bgsum
      endif

c put together the 2D background histogram in the new bins

      dx1 = (xu1-xl1)/float(nbinsint1)
      dx2 = (xu2-xl2)/float(nbinsint2)
      k = 0
      do i=1,nbinsint1
        do j=1,nbinsint2
          k = k + 1
          x = xl1 + (float(i)-0.5)*dx1
          y = xl2 + (float(j)-0.5)*dx2
          backw(k) = func1(x,iana,ibkg)*func2(y,iana,ibkg)*
     &               dx1*dx2*scf
        enddo
      enddo
      return
      end


c! --------
c! subroutine amerge1(nbins,inhist1,outhist)
c! add an histogram to a previously existing histogram
c  PTD, 31-Jul-1999.
c
      subroutine amerge1(nbins,inhist1,outhist)

      implicit none

      integer nbins,ibin

      real inhist1(*)
      real outhist(*)

      do ibin = 1,nbins
        outhist(ibin) = outhist(ibin)+inhist1(ibin)
      enddo

      end

c! --------
c! subroutine amerge2(nbins,inhist1,inhist2,outhist)
c! add 2 histograms

      subroutine amerge2(nbins,inhist1,inhist2,outhist)

      implicit none

      integer nbins,ibin

      real inhist1(*)
      real inhist2(*)
      real outhist(*)

      do ibin = 1,nbins
        outhist(ibin) = inhist1(ibin)+inhist2(ibin)
      enddo

      end

c! --------
c! subroutine amerge3(nbins,inhist1,inhist2,inhist3,outhist)
c! add 3 histograms

      subroutine amerge3(nbins,inhist1,inhist2,inhist3,outhist)

      implicit none

      integer nbins,ibin

      real inhist1(*)
      real inhist2(*)
      real inhist3(*)
      real outhist(*)

      do ibin = 1,nbins
        outhist(ibin) = inhist1(ibin)+inhist2(ibin)+inhist3(ibin)
      enddo

      end

c! --------
c! subroutine amerge4(nbins,inhist1,inhist2,inhist3,inhist4,
c!&                   outhist)
c! add 4 histograms

      subroutine amerge4(nbins,inhist1,inhist2,inhist3,inhist4,
     &                   outhist)

      implicit none

      integer nbins,ibin

      real inhist1(*)
      real inhist2(*)
      real inhist3(*)
      real inhist4(*)
      real outhist(*)

      do ibin = 1,nbins
        outhist(ibin) = inhist1(ibin)+inhist2(ibin)+
     &                  inhist3(ibin)+inhist4(ibin)
      enddo

      end

c! --------
c! subroutine a2dzero1(nbin1,nbin2,hist2d)
c! zero a 2D REAL array

      subroutine a2dzero1(nbin1,nbin2,hist2d)

      integer i,j
      integer nbin1,nbin2
      real hist2d(100,100)

      do i = 1,nbin1
        do j = 1,nbin2
          hist2d(i,j) = 0.
        enddo
      enddo
      end

c! --------
c! subroutine a2dzero2(nbin1,nbin2,hist2d)
c! zero a 2D INTEGER array

      subroutine a2dzero2(nbin1,nbin2,hist2d)

      integer i,j
      integer nbin1,nbin2
      integer hist2d(100,100)

      do i = 1,nbin1
        do j = 1,nbin2
          hist2d(i,j) = 0
        enddo
      enddo
      end

c! --------
c!
c! subroutine a2dadd1(nbin1,nbin2,numevt,
c!>                   inhis1,inhis2,outhis2d)
c! Add Pi*Pj (from the two input histograms) to bin (i,j) of the 
c! 2D output histogram. (Output histo is NOT reset beforehand.)
c! numevt = normalization of the component added to the histogram.
c!
      subroutine a2dadd1(nbin1,nbin2,numevt,
     >                   inhis1,inhis2,outhis2d)

      integer nbin1,nbin2
      real  numevt
      real  inhis1(*),inhis2(*)
      real  outhis2d(100,100)
      real  sum
      integer i,j

      sum = 0.
      do i = 1,nbin1
        do j = 1,nbin2
          sum = sum + inhis1(i)*inhis2(j)
        enddo
      enddo

      if (sum.ne.0.) then
        do i = 1,nbin1
          do j = 1,nbin2
            outhis2d(i,j) = outhis2d(i,j) +
     &                      inhis1(i)*inhis2(j)*numevt/sum
          enddo
        enddo
      endif
      end

c! --------
c! subroutine arebin1(nbin1,nbin2,
c!&                   sighis2d,bkghis2d,candhis2d,
c!&                   nbinout,
c!&                   sighis1d,bkghis1d,candhis1d)
      subroutine arebin1(nbin1,nbin2,
     &                   sighis2d,bkghis2d,candhis2d,
     &                   nbinout,
     &                   sighis1d,bkghis1d,candhis1d)

      integer nbin1,nbin2,nbinout
      real sighis2d(100,100)
      real bkghis2d(100,100)
      integer candhis2d(100,100)
      real sighis1d(*)
      real bkghis1d(*)
      integer candhis1d(*)
      integer i,j,k
      real max

      max = 1.
      do i = 1,nbin1
        do j = 1,nbin2
          if (bkghis2d(i,j).eq.0.) then
            write (6,*) 'AREBIN1: Error',i,j,bkghis2d(i,j)
            bkghis2d(i,j) = 1E-6
          endif
          if (sighis2d(i,j)/bkghis2d(i,j).gt.max) then
            max = sighis2d(i,j)/bkghis2d(i,j)
          endif
        enddo
      enddo

      max = max*1.001

      do k = 1,nbinout
        sighis1d(k) = 0.0
        bkghis1d(k) = 0.0
        candhis1d(k) = 0
        do i = 1,nbin1
          do j = 1,nbin2
            if ((sighis2d(i,j)/bkghis2d(i,j).lt.
     &          max*float(k)/100.).and.
     &          (sighis2d(i,j)/bkghis2d(i,j).ge.
     &          max*float(k-1)/100.)) then
              sighis1d(k) = sighis1d(k) +
     &                      sighis2d(i,j)
              bkghis1d(k) = bkghis1d(k) +
     &                      bkghis2d(i,j)
              candhis1d(k)= candhis1d(k)+
     &                      candhis2d(i,j)
            endif
          enddo
        enddo
      enddo

      end

c! --------
c! subroutine arebin2(nbin1,nbin2,
c!&                   sighis2d,bkghis2d,candhis2d,
c!&                   nbinout,
c!&                   sighis1d,bkghis1d,candhis1d)

      subroutine arebin2(nbin1,nbin2,
     &                   sighis2d,bkghis2d,candhis2d,
     &                   nbinout,
     &                   sighis1d,bkghis1d,candhis1d)
c
c     New version of AREBIN2.                         Pete McNamara.
c
      integer nbin1,nbin2,nbinout
      real sighis2d(100,100)
      real bkghis2d(100,100)
      integer candhis2d(100,100)
      real sighis1d(*)
      real bkghis1d(*)
      integer candhis1d(*)
      integer i,j,k
      real max
      integer maxxed

C Ensure some bin spacing
      max = 0.1
      maxxed = 0

C Find maximum s/b bin
      do i = 1,nbin1
        do j = 1,nbin2
          if (bkghis2d(i,j).eq.0.) then
            write (6,*) 'AREBIN2: Error',i,j,bkghis2d(i,j)
            bkghis2d(i,j) = 1E-6
          endif
          if (sighis2d(i,j)/bkghis2d(i,j).gt.max) then
            maxxed = 1
            max = sighis2d(i,j)/bkghis2d(i,j)
          endif
        enddo
      enddo


C Ensure max s/b fits in top bin
      max = max*1.000001

      do k = nbinout,1,-1
C Calculate current (highest remaining) bin contents
        sighis1d(k) = 0.0
        bkghis1d(k) = 0.0
        candhis1d(k) = 0
        do i = 1,nbin1
          do j = 1,nbin2
            if ((sighis2d(i,j)/bkghis2d(i,j).lt.
     &          max*float(k)/float(nbinout)).and.
     &          (sighis2d(i,j)/bkghis2d(i,j).ge.
     &          max*float(k-1)/float(nbinout))) then
              sighis1d(k) = sighis1d(k) +
     &                      sighis2d(i,j)
              bkghis1d(k) = bkghis1d(k) +
     &                      bkghis2d(i,j)
              candhis1d(k)= candhis1d(k)+
     &                      candhis2d(i,j)
            endif
          enddo
        enddo

C If highest bin is empty, and bins shouldn't all be zero
        if ((sighis1d(k).eq.0.).and.(maxxed.eq.1)) then
          omax = max
          max = 0.
C Recalculate maximum s/b in or below current bin
          do i = 1,nbin1
            do j = 1,nbin2
              if ((sighis2d(i,j)/bkghis2d(i,j)).le.
     &              omax*float(k)/float(nbinout)/1.000001) then
                if ((sighis2d(i,j)/bkghis2d(i,j)).gt.
     &              max*float(k)/float(nbinout)/1.000001) then
                  max = sighis2d(i,j)/bkghis2d(i,j)*float(nbinout)*
     &                  1.000001/float(k)
                endif
              endif
            enddo
          enddo
C Recalculate current bin
          if ((max.gt.0.).or.(k.eq.1)) then
            max = max*1.000001
            do i = 1,nbin1
              do j = 1,nbin2
                if ((sighis2d(i,j)/bkghis2d(i,j).le.
     &               max*float(k)/float(nbinout)).and.
     &              (sighis2d(i,j)/bkghis2d(i,j).gt.
     &               max*float(k-1)/float(nbinout))) then
                  sighis1d(k) = sighis1d(k) +
     &                          sighis2d(i,j)
                  bkghis1d(k) = bkghis1d(k) +
     &                          bkghis2d(i,j)
                  candhis1d(k)= candhis1d(k)+
     &                          candhis2d(i,j)
                endif
              enddo
            enddo
          endif
        endif
      enddo

      end


c! --------
c! subroutine arebin3(nbin1,nbin2,
c!&                   sighis2d,bkghis2d,candhis2d,
c!&                   nbinout,
c!&                   sighis1d,bkghis1d,candhis1d)

      subroutine arebin3(nbin1,nbin2,
     &                   sighis2d,bkghis2d,candhis2d,
     &                   nbinout,
     &                   sighis1d,bkghis1d,candhis1d)
c
c     New version of AREBIN3.                         Pete McNamara.
c
      integer nbin1,nbin2,nbinout
      real sighis2d(100,100)
      real bkghis2d(100,100)
      integer candhis2d(100,100)
      real ratio(10000),bigsig(10000),bigbkg(10000)
      integer order(10000),bigcand(10000)
      real sighis1d(*)
      real bkghis1d(*)
      integer candhis1d(*)
      real bounds(1000)
      integer i,j,k,icounter
      real amax,sigtot,bkgtot
      integer candtot
c---- 

c      write(*,*) 'Entering AREBIN'

      do i= 1,nbinout
        sighis1d(i) = 0.
        bkghis1d(i) = 0.
        candhis1d(i) = 0
      enddo

      do i=1,nbin1
        do j=1,nbin2
          icounter = (i-1)*nbin2+j
          if (bkghis2d(i,j).lt.1E-15) then
            if (sighis2d(i,j).lt.1E-15) then
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
            else
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
c              write(*,*) 'AREBIN3: signal in bkg free bin',i,j
c              write(*,*) bigsig(icounter),bigbkg(icounter)
            endif
          else
            bigsig(icounter) = sighis2d(i,j)
            bigbkg(icounter) = bkghis2d(i,j)
            ratio(icounter) = bigsig(icounter)/bigbkg(icounter) 
          endif
          bigcand(icounter) = candhis2d(i,j)
        enddo
      enddo

c      write(*,*) 'AREBIN: setup complete'

      sigtot = 0.
      bkgtot = 0.
      candtot = 0
      do i = 1,nbin1*nbin2
        sigtot = sigtot + bigsig(i)
        bkgtot = bkgtot + bigbkg(i)
        candtot = candtot + bigcand(i)
      enddo

c      write(*,*) sigtot,bkgtot,candtot

      call sortzv(ratio,order,nbin1*nbin2,1,0,0)

      amax = ratio(order(nbin1*nbin2))
      itop = nbin1*nbin2
      do k = nbinout,1,-1
        amax = amax*float(k-1)/float(k)
 1357   continue
        if (itop.ge.1) then
          if (ratio(order(itop)).ge.amax) then
            sighis1d(k) = sighis1d(k) + bigsig(order(itop))
            bkghis1d(k) = bkghis1d(k) + bigbkg(order(itop))
            candhis1d(k)= candhis1d(k)+ bigcand(order(itop))
            itop = itop - 1
            if (itop.ge.1) goto 1357
          else if ((sighis1d(k).lt.sigtot/float(k)).and.
     &             (bkghis1d(k).lt.bkgtot/float(k))) then
            amax = ratio(order(itop))
            goto 1357
          endif
        endif
        sigtot = sigtot - sighis1d(k)
        bkgtot = bkgtot - bkghis1d(k)
      enddo

c      sigtot = 0.
c      bkgtot = 0.

c      do k = 1,nbinout
c        sigtot = sigtot + sighis1d(k)
c        bkgtot = bkgtot + bkghis1d(k)
c      enddo

c      write(*,*) sigtot,bkgtot
c      write(*,*) 'Leaving AREBIN'

      end

c! --------
c! subroutine arebin3_big(nbin1,nbin2,
c!&                   sighis2d,bkghis2d,candhis2d,
c!&                   nbinout,
c!&                   sighis1d,bkghis1d,candhis1d)

      subroutine arebin3_big(nbin1,nbin2,
     &                   sighis2d,bkghis2d,candhis2d,
     &                   nbinout,
     &                   sighis1d,bkghis1d,candhis1d)
c
c     New version of AREBIN3.                         Pete McNamara.
c
      integer nbin1,nbin2,nbinout
      double precision sighis2d(200,200)
      double precision bkghis2d(200,200)
      integer candhis2d(200,200)
      real ratio(40000),bigsig(40000),bigbkg(40000)
      integer order(40000),bigcand(40000)
      real sighis1d(*)
      real bkghis1d(*)
      integer candhis1d(*)
      real bounds(1000)
      integer i,j,k,icounter
      real amax,sigtot,bkgtot
      integer candtot
c---- 

c      write(*,*) 'Entering AREBIN'

      do i= 1,nbinout
        sighis1d(i) = 0.
        bkghis1d(i) = 0.
        candhis1d(i) = 0
      enddo

      do i=1,nbin1
        do j=1,nbin2
          icounter = (i-1)*nbin2+j
          if (bkghis2d(i,j).lt.1E-15) then
            if (sighis2d(i,j).lt.1E-15) then
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
            else
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
c              write(*,*) 'AREBIN3: signal in bkg free bin',i,j
c              write(*,*) bigsig(icounter),bigbkg(icounter)
            endif
          else
            bigsig(icounter) = sighis2d(i,j)
            bigbkg(icounter) = bkghis2d(i,j)
            ratio(icounter) = bigsig(icounter)/bigbkg(icounter) 
          endif
          bigcand(icounter) = candhis2d(i,j)
        enddo
      enddo

c      write(*,*) 'AREBIN: setup complete'

      sigtot = 0.
      bkgtot = 0.
      candtot = 0
      do i = 1,nbin1*nbin2
        sigtot = sigtot + bigsig(i)
        bkgtot = bkgtot + bigbkg(i)
        candtot = candtot + bigcand(i)
      enddo

c      write(*,*) sigtot,bkgtot,candtot

      call sortzv(ratio,order,nbin1*nbin2,1,0,0)

      amax = ratio(order(nbin1*nbin2))
      itop = nbin1*nbin2
      do k = nbinout,1,-1
        amax = amax*float(k-1)/float(k)
 1357   continue
        if (itop.ge.1) then
          if (ratio(order(itop)).ge.amax) then
            sighis1d(k) = sighis1d(k) + bigsig(order(itop))
            bkghis1d(k) = bkghis1d(k) + bigbkg(order(itop))
            candhis1d(k)= candhis1d(k)+ bigcand(order(itop))
            itop = itop - 1
            if (itop.ge.1) goto 1357
          else if ((sighis1d(k).lt.sigtot/float(k)).and.
     &             (bkghis1d(k).lt.bkgtot/float(k))) then
            amax = ratio(order(itop))
            goto 1357
          endif
        endif
        sigtot = sigtot - sighis1d(k)
        bkgtot = bkgtot - bkghis1d(k)
      enddo

c      sigtot = 0.
c      bkgtot = 0.

c      do k = 1,nbinout
c        sigtot = sigtot + sighis1d(k)
c        bkgtot = bkgtot + bkghis1d(k)
c      enddo

c      write(*,*) sigtot,bkgtot
c      write(*,*) 'Leaving AREBIN'

      end

c! --------
c! subroutine arebin3_rescale1(nbin1,nbin2,
c!&                   sighis2d,bkghis2d,candhis2d,
c!&                   nbinout,
c!&                   sighis1d,bkghis1d,candhis1d)

      subroutine arebin3_rescale1(nbin1,nbin2,
     &                   sighis2d,bkghis2d,candhis2d,
     &                   hzhis2d,mh,ichan,nbinout,
     &                   sighis1d,bkghis1d,candhis1d)
c
c     New version of AREBIN3.                         Pete McNamara.
c
      integer nbin1,nbin2,nbinout
      real sighis2d(100,100)
      real bkghis2d(100,100)
      real hzhis2d(100,100)
      integer candhis2d(100,100)
      real ratio(10000),bigsig(10000),bigbkg(10000),bighz(10000)
      real bighz2(10000),bigbkg2(10000)
      real hzratio(10000)
      integer order(10000),bigcand(10000),hzorder(10000)
      real sighis1d(*)
      real bkghis1d(*)
      integer candhis1d(*)
      real bounds(1000)
      integer i,j,k,icounter
      real amax,sigtot,bkgtot
      integer candtot
      real mh
      integer ichan
      real a_hqq_corr
      external a_hqq_corr
c---- 

c      write(*,*) 'Entering AREBIN'

      do i= 1,nbinout
        sighis1d(i) = 0.
        bkghis1d(i) = 0.
        candhis1d(i) = 0
      enddo

      do i=1,nbin1
        do j=1,nbin2
          icounter = (i-1)*nbin2+j
          if (bkghis2d(i,j).lt.1E-15) then
            if (sighis2d(i,j).lt.1E-15) then
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
              bighz(icounter) = hzhis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
              hzratio(icounter) = 0.
            else
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
              bighz(icounter) = hzhis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
              hzratio(icounter) = 0.
c              write(*,*) 'AREBIN3: signal in bkg free bin',i,j
c              write(*,*) bigsig(icounter),bigbkg(icounter)
            endif
          else
            bigsig(icounter) = sighis2d(i,j)
            bigbkg(icounter) = bkghis2d(i,j)
            bighz(icounter) = hzhis2d(i,j)
            ratio(icounter) = bigsig(icounter)/bigbkg(icounter) 
            hzratio(icounter) =bighz(icounter)/bigbkg(icounter)
          endif
          bigcand(icounter) = candhis2d(i,j)
        enddo
      enddo

c      write(*,*) 'AREBIN: setup complete'

      sigtot = 0.
      bkgtot = 0.
      hztot  = 0.
      candtot = 0
      do i = 1,nbin1*nbin2
        sigtot = sigtot + bigsig(i)
        bkgtot = bkgtot + bigbkg(i)
        hztot  = hztot  + bighz(i)
        candtot = candtot + bigcand(i)
      enddo

c      write(*,*) sigtot,bkgtot,candtot,hztot

      call sortzv(hzratio,hzorder,nbin1*nbin2,1,0,0)

      frachz = 0.
      fracbg = 0.
      frachz2 = 0.
      fracbg2 = 0.
      do k = 1,nbin1*nbin2
c        write(*,*) k,order(k),bighz(order(k))
        frachz = frachz+bighz(hzorder(k))
        bighz2(hzorder(k)) = bighz(hzorder(k))*
     >                     a_hqq_corr(mh,ichan,1,
     >                     frachz/hztot)
c        write(*,*) 'HZ correction',bighz2(hzorder(k))/
c     >                              bighz(hzorder(k))
        frachz2 = frachz2+bighz2(hzorder(k))

        fracbg = fracbg+bigbkg(hzorder(k))
        bigbkg2(hzorder(k)) = bigbkg(hzorder(k))*
     >                      a_hqq_corr(mh,ichan,2,
     >                      fracbg/bkgtot)
c        write(*,*) 'Bkg correction',bigbkg2(hzorder(k))/
c     >                               bigbkg(hzorder(k))
        fracbg2 = fracbg2+bigbkg2(hzorder(k))
      enddo

      do k = 1,nbin1*nbin2
        bigsig(hzorder(k)) = bigsig(hzorder(k))
     >                      -bighz(hzorder(k))
     >                      +bighz2(hzorder(k))*frachz/frachz2

        bigbkg(hzorder(k)) = bigbkg2(hzorder(k))*fracbg/fracbg2
      enddo

      call sortzv(ratio,order,nbin1*nbin2,1,0,0)


      amax = ratio(order(nbin1*nbin2))
      itop = nbin1*nbin2
      do k = nbinout,1,-1
        amax = amax*float(k-1)/float(k)
 1357   continue
        if (itop.ge.1) then
          if (ratio(order(itop)).ge.amax) then
            sighis1d(k) = sighis1d(k) + bigsig(order(itop))
            bkghis1d(k) = bkghis1d(k) + bigbkg(order(itop))
            candhis1d(k)= candhis1d(k)+ bigcand(order(itop))
            itop = itop - 1
            if (itop.ge.1) goto 1357
          else if ((sighis1d(k).lt.sigtot/float(k)).and.
     &             (bkghis1d(k).lt.bkgtot/float(k))) then
            amax = ratio(order(itop))
            goto 1357
          endif
        endif
        sigtot = sigtot - sighis1d(k)
        bkgtot = bkgtot - bkghis1d(k)
      enddo

c      sigtot = 0.
c      bkgtot = 0.

c      do k = 1,nbinout
c        sigtot = sigtot + sighis1d(k)
c        bkgtot = bkgtot + bkghis1d(k)
c      enddo

c      write(*,*) sigtot,bkgtot
c      write(*,*) 'Leaving AREBIN'

      end

c! --------
c! subroutine arebin3_rescale1_big(nbin1,nbin2,
c!&                   sighis2d,bkghis2d,candhis2d,
c!&                   nbinout,
c!&                   sighis1d,bkghis1d,candhis1d)

      subroutine arebin3_rescale1_big(nbin1,nbin2,
     &                   sighis2d,bkghis2d,candhis2d,
     &                   hzhis2d,mh,ichan,nbinout,
     &                   sighis1d,bkghis1d,candhis1d)
c
c     New version of AREBIN3.                         Pete McNamara.
c
      implicit none

      integer nbin1,nbin2,nbinout
      double precision sighis2d(200,200)
      double precision bkghis2d(200,200)
      double precision hzhis2d(200,200)
      integer candhis2d(200,200)
      real ratio(40000)

      double precision bigsig(40000),bigbkg(40000),bighz(40000)
      double precision bighz2(40000),bigbkg2(40000)

      real hzratio(40000)

      integer order(40000),bigcand(40000),hzorder(40000)

      double precision sighis1d_tmp(400)
      double precision bkghis1d_tmp(400)

      real sighis1d(*)
      real bkghis1d(*)
      integer candhis1d(*)

      real bounds(1000)
      integer i,j,k,icounter

      integer itop

      real amax

      double precision sigtot,bkgtot,hztot
      double precision frachz,frachz2
      double precision fracbg,fracbg2
      integer candtot
      real mh
      integer ichan

      real a_hqq_corr
      external a_hqq_corr

c---- 

c      write(*,*) 'Entering AREBIN'

      do i= 1,nbinout
        sighis1d(i) = 0.
        bkghis1d(i) = 0.
        candhis1d(i) = 0
        sighis1d_tmp(i) = 0D0
        bkghis1d_tmp(i) = 0D0
      enddo

      do i=1,nbin1
        do j=1,nbin2
          icounter = (i-1)*nbin2+j
          if (bkghis2d(i,j).lt.1E-15) then
            if (sighis2d(i,j).lt.1E-15) then
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
              bighz(icounter) = hzhis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
              hzratio(icounter) = 0.
            else
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
              bighz(icounter) = hzhis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
              hzratio(icounter) = 0.
c              write(*,*) 'AREBIN3: signal in bkg free bin',i,j
c              write(*,*) bigsig(icounter),bigbkg(icounter)
            endif
          else
            bigsig(icounter) = sighis2d(i,j)
            bigbkg(icounter) = bkghis2d(i,j)
            bighz(icounter) = hzhis2d(i,j)
            ratio(icounter) = sngl(bigsig(icounter)/bigbkg(icounter)) 
            hzratio(icounter)=sngl(bighz(icounter)/bigbkg(icounter))
          endif
          bigcand(icounter) = candhis2d(i,j)
        enddo
      enddo

c      write(*,*) 'AREBIN: setup complete'

      sigtot = 0.
      bkgtot = 0.
      hztot  = 0.
      candtot = 0
      do i = 1,nbin1*nbin2
        sigtot = sigtot + bigsig(i)
        bkgtot = bkgtot + bigbkg(i)
        hztot  = hztot  + bighz(i)
        candtot = candtot + bigcand(i)
      enddo

c      write(*,*) sigtot,bkgtot,candtot,hztot

      call sortzv(hzratio,hzorder,nbin1*nbin2,1,0,0)

      frachz = 0.
      fracbg = 0.
      frachz2 = 0.
      fracbg2 = 0.
      do k = 1,nbin1*nbin2
c        write(*,*) k,order(k),bighz(order(k))
        frachz = frachz+bighz(hzorder(k))
        bighz2(hzorder(k)) = bighz(hzorder(k))*
     >                     a_hqq_corr(mh,ichan,1,
     >                     sngl(frachz/hztot))
c        write(*,*) 'HZ correction',bighz2(hzorder(k))/
c     >                              bighz(hzorder(k))
        frachz2 = frachz2+bighz2(hzorder(k))

        fracbg = fracbg+bigbkg(hzorder(k))
        bigbkg2(hzorder(k)) = bigbkg(hzorder(k))*
     >                      a_hqq_corr(mh,ichan,2,
     >                      sngl(fracbg/bkgtot))
c        write(*,*) 'Bkg correction',bigbkg2(hzorder(k))/
c     >                               bigbkg(hzorder(k))
        fracbg2 = fracbg2+bigbkg2(hzorder(k))
      enddo

      do k = 1,nbin1*nbin2
        bigsig(hzorder(k)) = bigsig(hzorder(k))
     >                      -bighz(hzorder(k))
     >                      +bighz2(hzorder(k))*frachz/frachz2

        bigbkg(hzorder(k)) = bigbkg2(hzorder(k))*fracbg/fracbg2
      enddo

      call sortzv(ratio,order,nbin1*nbin2,1,0,0)


      amax = ratio(order(nbin1*nbin2))
      itop = nbin1*nbin2
      do k = nbinout,1,-1
        amax = amax*float(k-1)/float(k)
 1357   continue
        if (itop.ge.1) then
          if (ratio(order(itop)).ge.amax) then
            sighis1d_tmp(k)=sighis1d_tmp(k) + bigsig(order(itop))
            bkghis1d_tmp(k)=bkghis1d_tmp(k) + bigbkg(order(itop))
            candhis1d(k)=candhis1d(k)+bigcand(order(itop))
            itop = itop - 1
            if (itop.ge.1) goto 1357
          else if ((sighis1d_tmp(k).lt.sigtot/float(k)).and.
     &             (bkghis1d_tmp(k).lt.bkgtot/float(k))) then
            amax = ratio(order(itop))
            goto 1357
          endif
        endif
        sigtot = sigtot - sighis1d_tmp(k)
        bkgtot = bkgtot - bkghis1d_tmp(k)
      enddo

      do k = 1,nbinout
        sighis1d(k) = sngl(sighis1d_tmp(k))
        bkghis1d(k) = sngl(bkghis1d_tmp(k))
      enddo

c      sigtot = 0.
c      bkgtot = 0.

c      do k = 1,nbinout
c        sigtot = sigtot + sighis1d(k)
c        bkgtot = bkgtot + bkghis1d(k)
c      enddo

c      write(*,*) sigtot,bkgtot
c      write(*,*) 'Leaving AREBIN'

      end

c! --------
c! subroutine arebin3_component(nbin1,nbin2,
c!&                   sighis2d,bkghis2d,candhis2d,
c!&                   nbinout,
c!&                   sighis1d,bkghis1d,candhis1d)

      subroutine arebin3_component(nbin1,nbin2,
     &                   sighis2d,bkghis2d,candhis2d,
     &                   qq2d,ww2d,zz2d,sigprod,
     &                   nbinout,
     &                   sighis1d,bkghis1d,candhis1d,
     &                   qq1d,ww1d,zz1d)
c
c     New version of AREBIN3.                         Pete McNamara.
c
      integer nbin1,nbin2,nbinout
      real sigprod
      real sighis2d(100,100)
      real bkghis2d(100,100)
      real qq2d(100,100)
      real ww2d(100,100)
      real zz2d(100,100)
      real qq1d(100)
      real ww1d(100)
      real zz1d(100)
      integer candhis2d(100,100)
      real ratio(10000),bigsig(10000),bigbkg(10000)
      real bigqq(10000),bigww(10000),bigzz(10000)
      integer order(10000),bigcand(10000)
      real sighis1d(*)
      real bkghis1d(*)
      integer candhis1d(*)
      real bounds(1000)
      integer i,j,k,icounter
      real amax,sigtot,bkgtot
      real qqtot,wwtot,zztot
      integer candtot
c---- 

c      write(*,*) 'Entering AREBIN'

      do i= 1,nbinout
        sighis1d(i) = 0.
        bkghis1d(i) = 0.
        qq1d(i) = 0.
        ww1d(i) = 0.
        zz1d(i) = 0.
        candhis1d(i) = 0
      enddo

      do i=1,nbin1
        do j=1,nbin2
          icounter = (i-1)*nbin2+j
          if (bkghis2d(i,j).lt.1E-15) then
            if (sighis2d(i,j).lt.1E-15) then
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
              bigqq(icounter) = qq2d(i,j)
              bigww(icounter) = ww2d(i,j)
              bigzz(icounter) = zz2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
            else
              bigsig(icounter) = sighis2d(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
              bigqq(icounter) = qq2d(i,j)
              bigww(icounter) = ww2d(i,j)
              bigzz(icounter) = zz2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
c              write(*,*) 'AREBIN3: signal in bkg free bin',i,j
c              write(*,*) bigsig(icounter),bigbkg(icounter)
            endif
          else
            bigsig(icounter) = sighis2d(i,j)
            bigbkg(icounter) = bkghis2d(i,j)
            bigqq(icounter) = qq2d(i,j)
            bigww(icounter) = ww2d(i,j)
            bigzz(icounter) = zz2d(i,j)
            ratio(icounter) = bigsig(icounter)/bigbkg(icounter) 
          endif
          bigcand(icounter) = candhis2d(i,j)
        enddo
      enddo

c      write(*,*) 'AREBIN: setup complete'

      sigtot = 0.
      bkgtot = 0.
      candtot = 0
      do i = 1,nbin1*nbin2
        sigtot = sigtot + bigsig(i)
        bkgtot = bkgtot + bigbkg(i)
        candtot = candtot + bigcand(i)
      enddo

c      write(*,*) sigtot,bkgtot,candtot

      call sortzv(ratio,order,nbin1*nbin2,1,0,0)

      amax = ratio(order(nbin1*nbin2))
      itop = nbin1*nbin2
      do k = nbinout,1,-1
        amax = amax*float(k-1)/float(k)
 1357   continue
        if (itop.ge.1) then
          if (ratio(order(itop)).ge.amax) then
            sighis1d(k) = sighis1d(k) + bigsig(order(itop))
            bkghis1d(k) = bkghis1d(k) + bigbkg(order(itop))
            qq1d(k) = qq1d(k) + bigqq(order(itop))
            ww1d(k) = ww1d(k) + bigww(order(itop))
            zz1d(k) = zz1d(k) + bigzz(order(itop))
            candhis1d(k)= candhis1d(k)+ bigcand(order(itop))
            itop = itop - 1
            if (itop.ge.1) goto 1357
          else if ((sighis1d(k).lt.sigtot/float(k)).and.
     &             (bkghis1d(k).lt.bkgtot/float(k))) then
            amax = ratio(order(itop))
            goto 1357
          endif
        endif
        sigtot = sigtot - sighis1d(k)
        bkgtot = bkgtot - bkghis1d(k)
      enddo

      sigtot = 0.
      bkgtot = 0.
      qqtot = 0.
      wwtot = 0.
      zztot = 0.

      do k = nbinout,1,-1
        sigtot = sigtot + sighis1d(k)
        bkgtot = bkgtot + bkghis1d(k)
        qqtot  =  qqtot + qq1d(k)
        wwtot  =  wwtot + ww1d(k)
        zztot  =  zztot + zz1d(k)

        write(*,*) sigtot/sigprod,qqtot,wwtot,zztot,bkgtot
      enddo


      end

c! --------
c! subroutine arebin5(nbin1,nbin2,
c!&                   sighis2d,sighis2d2,bkghis2d,candhis2d,
c!&                   nbinout,sighis1d,
c!&                   sighis1d2,bkghis1d,candhis1d)

      subroutine arebin5(nbin1,nbin2,
     &                   sighis2d,sighis2d2,bkghis2d,candhis2d,
     &                   nbinout,sighis1d,
     &                   sighis1d2,bkghis1d,candhis1d)
c
c     New version of AREBIN3.                         Pete McNamara.
c
      integer nbin1,nbin2,nbinout
      real sighis2d(100,100)
      real sighis2d2(100,100)
      real bkghis2d(100,100)
      integer candhis2d(100,100)
      real ratio(10000),bigsig(10000),bigsig2(10000),bigbkg(10000)
      integer order(10000),bigcand(10000)
      real sighis1d(*)
      real sighis1d2(*)
      real bkghis1d(*)
      integer candhis1d(*)
      real bounds(1000)
      integer i,j,k,icounter
      real amax,sigtot,bkgtot
      integer candtot
c---- 

c      write(*,*) 'Entering AREBIN'

      do i= 1,nbinout
        sighis1d(i) = 0.
        sighis1d2(i) = 0.
        bkghis1d(i) = 0.
        candhis1d(i) = 0
      enddo

      do i=1,nbin1
        do j=1,nbin2
          icounter = (i-1)*nbin2+j
          if (bkghis2d(i,j).lt.1E-15) then
            if (sighis2d(i,j).lt.1E-15) then
              bigsig(icounter) = sighis2d(i,j)
              bigsig2(icounter) = sighis2d2(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
            else
              bigsig(icounter) = sighis2d(i,j)
              bigsig2(icounter) = sighis2d2(i,j)
              bigbkg(icounter) = bkghis2d(i,j)
c              bigsig(icounter) = 0.
c              bigbkg(icounter) = 0.
              ratio(icounter) = 0.
c              write(*,*) 'AREBIN3: signal in bkg free bin',i,j
c              write(*,*) bigsig(icounter),bigbkg(icounter)
            endif
          else
            bigsig(icounter) = sighis2d(i,j)
            bigsig2(icounter) = sighis2d2(i,j)
            bigbkg(icounter) = bkghis2d(i,j)
            ratio(icounter) = bigsig(icounter)/bigbkg(icounter) 
          endif
          bigcand(icounter) = candhis2d(i,j)
        enddo
      enddo

c      write(*,*) 'AREBIN: setup complete'

      sigtot = 0.
      bkgtot = 0.
      candtot = 0
      do i = 1,nbin1*nbin2
        sigtot = sigtot + bigsig(i)
        bkgtot = bkgtot + bigbkg(i)
        candtot = candtot + bigcand(i)
      enddo

c      write(*,*) sigtot,bkgtot,candtot

      call sortzv(ratio,order,nbin1*nbin2,1,0,0)

      amax = ratio(order(nbin1*nbin2))
      itop = nbin1*nbin2
      do k = nbinout,1,-1
        amax = amax*float(k-1)/float(k)
 1357   continue
        if (itop.ge.1) then
          if (ratio(order(itop)).ge.amax) then
            sighis1d(k) = sighis1d(k) + bigsig(order(itop))
            sighis1d2(k) = sighis1d2(k) + bigsig2(order(itop))
            bkghis1d(k) = bkghis1d(k) + bigbkg(order(itop))
            candhis1d(k)= candhis1d(k)+ bigcand(order(itop))
            itop = itop - 1
            if (itop.ge.1) goto 1357
          else if ((sighis1d(k).lt.sigtot/float(k)).and.
     &             (bkghis1d(k).lt.bkgtot/float(k))) then
            amax = ratio(order(itop))
            goto 1357
          endif
        endif
        sigtot = sigtot - sighis1d(k)
        bkgtot = bkgtot - bkghis1d(k)
      enddo

c      sigtot = 0.
c      bkgtot = 0.

c      do k = 1,nbinout
c        sigtot = sigtot + sighis1d(k)
c        bkgtot = bkgtot + bkghis1d(k)
c      enddo

c      write(*,*) sigtot,bkgtot
c      write(*,*) 'Leaving AREBIN'

      end



c---------------------------------------------------------------

c! subroutine ahistscal1(nbins,hcontin,hcontout,scale)
c! subroutine ahistscal1 -- scales a 1D histogram so that its integral is
c! the given factor -- does not change the histogram -- gives
c! a copy in hcontout
      subroutine ahistscal1(nbins,hcontin,hcontout,scale)
      implicit none
      integer nbins,i
      real hcontin(*),hcontout(*),scale
      real sum,vsum
      external vsum
      sum = 0.0
      do i = 1,nbins
        if (hcontin(i).ge.0.) sum = sum + hcontin(i)
      enddo
      if (sum.lt.0.0) then
         write(*,*) 'Histogram sum is negative in ahistscal1'
         return
      endif
      if (sum.eq.0.0) then
        do i = 1,nbins
          hcontout(i) = 0.0
        enddo
      else
        do i = 1,nbins
          hcontout(i) = scale*hcontin(i)/sum
        enddo
      endif
      return
      end

