c-*-FORTRAN-*-
c
      real*8 function a_hll_bkg_level(iener,ibkg)
c
c Returns the backgrounds expected in the hll searches at different energies;
c (Currently only valid for ECM >= 191.6 GeV)
c
c iener = centre-of-mass energy index
c iener = 1 (183 GeV), 
c         2 (188.6), 
c         3 (191.6), 
c         4 (195.5),
c         5 (199.5),
c         6 (201.6)
c ibkg = bgd type (varies depending on iener)
c
c Created:                             Pedro Teixeira-Dias, 27-July-1999.
c
c Modified:
c
c     - Update: Final results for 192 -202 GeV anlayses.
c                                                      PTD, 13-Feb-2000.
c     
c
      implicit none
      integer iener,ibkg,ienermax,ibkgmax,i,j
      parameter (ienermax=6,ibkgmax=3)
      real*8 hll_norm_bkg(ienermax,ibkgmax) ! bgd per pb
      SAVE hll_norm_bkg
      logical first
      data first / .true. /
c
      real ah0_lumi
      external ah0_lumi
c
      a_hll_bkg_level = -1.D0
c
c---- Enter here the expected backgrounds per unit luminosity
c
      IF (FIRST) THEN
         FIRST = .FALSE.
c
         do i=1,ienermax
            do j=1,ibkgmax
               hll_norm_bkg(i,j) = 0.0
            end do
         end do
c
c     Tampere results / 192 + 196 GeV:
c     
c         hll_norm_bkg(3,1) = 2.38 / 26.716
c         hll_norm_bkg(3,2) = 0.22 / 26.716
c         hll_norm_bkg(4,1) = 2.36 / 23.660
c         hll_norm_bkg(4,2) = 0.23 / 23.660
c
c     Final results / 192 + 196 + 200 + 202 GeV:
c
C from the CLFFT cards:
c
c 192 *LRCH 28.923 *OPTB 2.120 0.405 0.300
c
         hll_norm_bkg(3,1) = 2.120 / 28.923
         hll_norm_bkg(3,2) = 0.405 / 28.923
         hll_norm_bkg(3,3) = 0.300 / 28.923
c
c 196 *LRCH 79.834 *OPTB 6.640 1.347 0.916
c
         hll_norm_bkg(4,1) = 6.640 / 79.834
         hll_norm_bkg(4,2) = 1.347 / 79.834
         hll_norm_bkg(4,3) = 0.916 / 79.834
c
c 200 *LRCH 86.298 *OPTB 8.205 1.756 1.220
c
         hll_norm_bkg(5,1) = 8.205 / 86.298
         hll_norm_bkg(5,2) = 1.756 / 86.298
         hll_norm_bkg(5,3) = 1.220 / 86.298
c
c 202 *LRCH 41.991 *OPTB 4.017 0.870 0.679
c
         hll_norm_bkg(6,1) = 4.017 / 41.991
         hll_norm_bkg(6,2) = 0.870 / 41.991
         hll_norm_bkg(6,3) = 0.679 / 41.991
c
      END IF                    ! FIRST
c
c---- 1999: 192 - 202 GeV
c     ibkg = 1 (ZZ), 2 (eeZ), 3 (other)
c
      if (iener.ge.3 .and. iener.le.6) then
         if (ibkg.ge.1 .or. ibkg.le.3) then
            a_hll_bkg_level = DBLE(ah0_lumi(iener)) * 
     +           hll_norm_bkg(iener,ibkg)
         end if
      end if                    ! iener
c
      if (a_hll_bkg_level.lt.0.D0) then
       write (6,*) ' <ahll_bkg> Error ! Invalid IENER/IBKG.',iener,ibkg
       a_hll_bkg_level = 0.D0
      end if
c
      end

