c-*-FORTRAN-*-
c
c A series of Hll functions to return the properties of selected candidates
c as a function of the ECM of the search.
c (Currently only valid for ECM >= 188.6 GeV)
c
c iener = centre-of-mass energy index
c iener = 1 (183 GeV), 
c         2 (188.6), 
c         3 (191.6), 
c         4 (195.5),
c         5 (199.5),
c         6 (201.6)
c
c
c Created:                             Pedro Teixeira-Dias, 27-July-1999.
c
c Modified:
c
c     - Update: Final Hll candidates for the 192 - 202 GeV analyses;
c
c                                                          PTD, 14-Feb-2000.
c
C---------------------------------------------------------------------
      integer function A_HLL_NUMCAND(iener)
      implicit none
      integer iener

      if (iener.eq.2) then
         a_hll_numcand = 14     ! 189 GeV 
      elseif (iener.eq.3) then
c     a_hll_numcand = 3       ! Tampere '99
         a_hll_numcand = 3      ! 192 GeV
      elseif (iener.eq.4) then
c     a_hll_numcand = 4       ! Tampere '99
         a_hll_numcand = 4      ! 196 GeV
      elseif (iener.eq.5) then
         a_hll_numcand = 13     ! 200 GeV
      elseif (iener.eq.6) then
         a_hll_numcand = 6      ! 202 GeV
      else
         write (6,*) ' <a_hll_numcand> Error! Invalid IENER',iener
      end if
c
      end
C---------------------------------------------------------------------
C---------------------------------------------------------------------
      real*8 function A_HLL_MASS_CAND(iener,icand)
      implicit none
      integer icand,iener

      A_HLL_MASS_CAND = 10000.

      IF (IENER.EQ.2) THEN
         if (icand.eq.1)  A_HLL_MASS_CAND = 62.5
         if (icand.eq.2)  A_HLL_MASS_CAND = 90.0
         if (icand.eq.3)  A_HLL_MASS_CAND = 95.8
         if (icand.eq.4)  A_HLL_MASS_CAND = 90.7
         if (icand.eq.5)  A_HLL_MASS_CAND = 94.8
         if (icand.eq.6)  A_HLL_MASS_CAND = 90.9
         if (icand.eq.7)  A_HLL_MASS_CAND = 93.0
         if (icand.eq.8)  A_HLL_MASS_CAND = 90.0
         if (icand.eq.9)  A_HLL_MASS_CAND = 98.4
         if (icand.eq.10) A_HLL_MASS_CAND = 90.6
         if (icand.eq.11) A_HLL_MASS_CAND = 91.4
         if (icand.eq.12) A_HLL_MASS_CAND = 89.6
         if (icand.eq.13) A_HLL_MASS_CAND = 80.0
         if (icand.eq.14) A_HLL_MASS_CAND = 92.2
      ELSEIF (IENER.EQ.3) THEN
c Tampere '99:
c         if (icand.eq.1)  A_HLL_MASS_CAND = 91.91891
c         if (icand.eq.2)  A_HLL_MASS_CAND = 89.87164
c         if (icand.eq.3)  A_HLL_MASS_CAND = 102.8845
c Final results, 192 GeV:
         if (icand.eq.1)  A_HLL_MASS_CAND = 92.33 
         if (icand.eq.2)  A_HLL_MASS_CAND = 89.88 
         if (icand.eq.3)  A_HLL_MASS_CAND = 54.91 
      ELSEIF (IENER.EQ.4) THEN                 
c Tampere '99:
c         if (icand.eq.1)  A_HLL_MASS_CAND = 99.7805
c         if (icand.eq.2)  A_HLL_MASS_CAND = 90.8139
c         if (icand.eq.3)  A_HLL_MASS_CAND = 93.3213
c         if (icand.eq.4)  A_HLL_MASS_CAND = 87.60956
c Final results, 196 GeV:
         if (icand.eq.1)  A_HLL_MASS_CAND = 98.87 
         if (icand.eq.2)  A_HLL_MASS_CAND = 89.62 
         if (icand.eq.3)  A_HLL_MASS_CAND = 92.76 
         if (icand.eq.4)  A_HLL_MASS_CAND = 86.94 
      ELSEIF (IENER.EQ.5) THEN                 
c Final results, 200 GeV:
         if (icand.eq.1)  A_HLL_MASS_CAND = 84.27 
         if (icand.eq.2)  A_HLL_MASS_CAND = 73.92 
         if (icand.eq.3)  A_HLL_MASS_CAND = 101.82
         if (icand.eq.4)  A_HLL_MASS_CAND = 84.68 
         if (icand.eq.5)  A_HLL_MASS_CAND = 92.17 
         if (icand.eq.6)  A_HLL_MASS_CAND = 94.40 
         if (icand.eq.7)  A_HLL_MASS_CAND = 59.98 
         if (icand.eq.8)  A_HLL_MASS_CAND = 97.58 
         if (icand.eq.9)  A_HLL_MASS_CAND = 92.39 
         if (icand.eq.10) A_HLL_MASS_CAND = 86.39 
         if (icand.eq.11) A_HLL_MASS_CAND = 94.20 
         if (icand.eq.12) A_HLL_MASS_CAND = 99.12 
         if (icand.eq.13) A_HLL_MASS_CAND = 92.44 
      ELSEIF (IENER.EQ.6) THEN                 
c Final results, 202 GeV:
         if (icand.eq.1)  A_HLL_MASS_CAND = 92.41 
         if (icand.eq.2)  A_HLL_MASS_CAND = 98.94 
         if (icand.eq.3)  A_HLL_MASS_CAND = 68.03 
         if (icand.eq.4)  A_HLL_MASS_CAND = 89.61 
         if (icand.eq.5)  A_HLL_MASS_CAND = 62.83 
         if (icand.eq.6)  A_HLL_MASS_CAND = 96.15 
      ELSE
         write (6,*) ' <a_hll_mass_cand> Error! Invalid IENER',iener
      END IF
c
      end
C---------------------------------------------------------------------
C---------------------------------------------------------------------
      real*8 function A_HLL_BTAG_CAND(iener,icand)
      implicit none
      integer icand,iener

      A_HLL_BTAG_CAND = 10000.

      IF (IENER.EQ.2) THEN
         if (icand.eq.1)  A_HLL_BTAG_CAND = 0.17
         if (icand.eq.2)  A_HLL_BTAG_CAND = 2.00
         if (icand.eq.3)  A_HLL_BTAG_CAND = 1.10
         if (icand.eq.4)  A_HLL_BTAG_CAND = 0.00
         if (icand.eq.5)  A_HLL_BTAG_CAND = 1.14
         if (icand.eq.6)  A_HLL_BTAG_CAND = 0.31
         if (icand.eq.7)  A_HLL_BTAG_CAND = 0.20
         if (icand.eq.8)  A_HLL_BTAG_CAND = 0.23
         if (icand.eq.9)  A_HLL_BTAG_CAND = 0.97
         if (icand.eq.10) A_HLL_BTAG_CAND = 0.41
         if (icand.eq.11) A_HLL_BTAG_CAND = 0.42
         if (icand.eq.12) A_HLL_BTAG_CAND = 0.36
         if (icand.eq.13) A_HLL_BTAG_CAND = 0.40
         if (icand.eq.14) A_HLL_BTAG_CAND = 0.24
      ELSEIF (IENER.EQ.3) THEN
c Tampere '99:
c         if (icand.eq.1)  A_HLL_BTAG_CAND = .9669828
c         if (icand.eq.2)  A_HLL_BTAG_CAND = .4954883
c         if (icand.eq.3)  A_HLL_BTAG_CAND = 1.280851
c Final results, 192 GeV:
         if (icand.eq.1)  A_HLL_BTAG_CAND = 0.973
         if (icand.eq.2)  A_HLL_BTAG_CAND = 0.503
         if (icand.eq.3)  A_HLL_BTAG_CAND = 0.697
      ELSEIF (IENER.EQ.4) THEN             
c Tampere '99:
c         if (icand.eq.1)  A_HLL_BTAG_CAND = 1.945432
c         if (icand.eq.2)  A_HLL_BTAG_CAND = .1769353
c         if (icand.eq.3)  A_HLL_BTAG_CAND = .7266793
c         if (icand.eq.4)  A_HLL_BTAG_CAND = .1639009
c Final results, 196 GeV:
         if (icand.eq.1)  A_HLL_BTAG_CAND = 1.952
         if (icand.eq.2)  A_HLL_BTAG_CAND = 0.203
         if (icand.eq.3)  A_HLL_BTAG_CAND = 0.749
         if (icand.eq.4)  A_HLL_BTAG_CAND = 0.154
      ELSEIF (IENER.EQ.5) THEN             
c Final results, 200 GeV:
         if (icand.eq.1)  A_HLL_BTAG_CAND = 0.780
         if (icand.eq.2)  A_HLL_BTAG_CAND = 0.377
         if (icand.eq.3)  A_HLL_BTAG_CAND = 0.031
         if (icand.eq.4)  A_HLL_BTAG_CAND = 0.067
         if (icand.eq.5)  A_HLL_BTAG_CAND = 0.374
         if (icand.eq.6)  A_HLL_BTAG_CAND = 2.000
         if (icand.eq.7)  A_HLL_BTAG_CAND = 0.949
         if (icand.eq.8)  A_HLL_BTAG_CAND = 1.077
         if (icand.eq.9)  A_HLL_BTAG_CAND = 0.418
         if (icand.eq.10) A_HLL_BTAG_CAND = 0.195
         if (icand.eq.11) A_HLL_BTAG_CAND = 0.175
         if (icand.eq.12) A_HLL_BTAG_CAND = 1.463
         if (icand.eq.13) A_HLL_BTAG_CAND = 1.202
      ELSEIF (IENER.EQ.6) THEN             
c Final results, 202 GeV:
         if (icand.eq.1)  A_HLL_BTAG_CAND = 0.102
         if (icand.eq.2)  A_HLL_BTAG_CAND = 0.834
         if (icand.eq.3)  A_HLL_BTAG_CAND = 0.560
         if (icand.eq.4)  A_HLL_BTAG_CAND = 0.152
         if (icand.eq.5)  A_HLL_BTAG_CAND = 0.411
         if (icand.eq.6)  A_HLL_BTAG_CAND = 0.838
      ELSE
         write (6,*) ' <a_hll_btag_cand> Error! Invalid IENER',iener
      END IF
c     
      end
C---------------------------------------------------------------------
