C-*-FORTRAN-*-
c
c A series of functions that 
c return the signal and background shapes for the hll searches 
c at different energies;
c (Currently only valid for ECM >= 191.6 GeV)
c
c iener = centre-of-mass energy index
c iener = 1 (183 GeV), 
c         2 (188.6), 
c         3 (191.6), 
c         4 (195.5)
c         5 (199.5)
c         6 (201.6)
c
c ibkg = bgd type (varies depending on iener)
c
c Created:                             Pedro Teixeira-Dias, 27-July-1999.
c
c Modified:
c
c     - Update: Hll functions for final 192 - 202 GeV analyses.
c                                                      PTD, 13-Feb-2000.
c
c---------------------------  S I G N A L -----------------------------
      double precision function a_hll_sig_h0mass(recmas,trumas,iener)
c
      implicit none
      double precision recmas,trumas
      integer iener
      real*8 a192_hll_sig_h0mass,a196_hll_sig_h0mass,
     +     a200_hll_sig_h0mass,a202_hll_sig_h0mass
      external a192_hll_sig_h0mass,a196_hll_sig_h0mass,
     +     a200_hll_sig_h0mass,a202_hll_sig_h0mass
c
      a_hll_sig_h0mass = 0.D0
c
      if (iener.eq.3) then
         a_hll_sig_h0mass = a192_hll_sig_h0mass(recmas,trumas)
      else if (iener.eq.4) then
         a_hll_sig_h0mass = a196_hll_sig_h0mass(recmas,trumas)
      else if (iener.eq.5) then
         a_hll_sig_h0mass = a200_hll_sig_h0mass(recmas,trumas)
      else if (iener.eq.6) then
         a_hll_sig_h0mass = a202_hll_sig_h0mass(recmas,trumas)
      end if
c
      end
c---------------
cx      double precision function ahll_hmm_btag(recmas,iener)
cxc
cx      implicit none
cx      double precision recmas
cx      integer iener
cx      double precision a192_hll_hmm_btag,a196_hll_hmm_btag
cx      external a192_hll_hmm_btag,a196_hll_hmm_btag
cxc
cx      ahll_hmm_btag = 0.D0
cxc
cx      if (iener.eq.3) then
cx         ahll_hmm_btag = a192_hll_hmm_btag(recmas)
cx      else if (iener.eq.4) then                  
cx         ahll_hmm_btag = a196_hll_hmm_btag(recmas)
cx      end if
cxc
cx      end
cxc---------------
cx      double precision function ahll_hee_mass(recmas,trumas,iener)
cxc
cx      implicit none
cx      double precision recmas,trumas
cx      integer iener
cx      double precision a192_hll_hee_mass,a196_hll_hee_mass
cx      external a192_hll_hee_mass,a196_hll_hee_mass
cxc
cx      ahll_hee_mass = 0.D0
cxc
cx      if (iener.eq.3) then
cx         ahll_hee_mass = a192_hll_hee_mass(recmas,trumas)
cx      else if (iener.eq.4) then
cx         ahll_hee_mass = a196_hll_hee_mass(recmas,trumas)
cx      end if
cxc
cx      end
cxc---------------
cx      double precision function ahll_hee_btag(recmas,iener)
cxc
cx      implicit none
cx      double precision recmas
cx      integer iener
cx      double precision a192_hll_hee_btag,a196_hll_hee_btag
cx      external a192_hll_hee_btag,a196_hll_hee_btag
cxc
cx      ahll_hee_btag = 0.D0
cxc
cx      if (iener.eq.3) then
cx         ahll_hee_btag = a192_hll_hee_btag(recmas)
cx      else if (iener.eq.4) then                  
cx         ahll_hee_btag = a196_hll_hee_btag(recmas)
cx      end if
cxc
cx      end
cxc---------------
cx      double precision function ahll_zfus_mass(recmas,trumas,iener) 
cxc
cx      implicit none
cx      double precision recmas,trumas
cx      integer iener
cx      double precision a192_hll_zfus_mass,a196_hll_zfus_mass
cx      external a192_hll_zfus_mass,a196_hll_zfus_mass
cxc
cx      ahll_zfus_mass = 0.D0
cxc
cx      if (iener.eq.3) then
cx         ahll_zfus_mass = a192_hll_zfus_mass(recmas,trumas)
cx      else if (iener.eq.4) then
cx         ahll_zfus_mass = a196_hll_zfus_mass(recmas,trumas)
cx      end if
cxc
cx      end
cxc---------------
cx      double precision function ahll_zfus_btag(recmas,iener)
cxc
cx      implicit none
cx      double precision recmas
cx      integer iener
cx      double precision a192_hll_zfus_btag,a196_hll_zfus_btag
cx      external a192_hll_zfus_btag,a196_hll_zfus_btag
cxc
cx      ahll_zfus_btag = 0.D0
cxc
cx      if (iener.eq.3) then
cx         ahll_zfus_btag = a192_hll_zfus_btag(recmas)
cx      else if (iener.eq.4) then                  
cx         ahll_zfus_btag = a196_hll_zfus_btag(recmas)
cx      end if
cxc
cx      end
c---------------
c---------------------------  B A C K G R O U N D ------------------------
      double precision function a_hll_bkg_mass(recmas,iener,ibkg)
c
      implicit none
      integer iener,ibkg
      double precision recmas
      real*8 
     +     a192_hll_zz_h0mass,a192_hll_eez_h0mass,a192_hll_other_h0mass,
     +     a196_hll_zz_h0mass,a196_hll_eez_h0mass,a196_hll_other_h0mass,
     +     a200_hll_zz_h0mass,a200_hll_eez_h0mass,a200_hll_other_h0mass,
     +     a202_hll_zz_h0mass,a202_hll_eez_h0mass,a202_hll_other_h0mass
      external
     +     a192_hll_zz_h0mass,a192_hll_eez_h0mass,a192_hll_other_h0mass,
     +     a196_hll_zz_h0mass,a196_hll_eez_h0mass,a196_hll_other_h0mass,
     +     a200_hll_zz_h0mass,a200_hll_eez_h0mass,a200_hll_other_h0mass,
     +     a202_hll_zz_h0mass,a202_hll_eez_h0mass,a202_hll_other_h0mass
c
      a_hll_bkg_mass = 1.D-6
      if (iener.lt.3 .or. iener.gt.6 .or. 
     +    ibkg.lt.1 .or. ibkg.gt.3 ) then
         write (6,*) '<a_hll_bkg_mass> Invalid IENER/IBKG!',iener,ibkg
      end if
c
      if (iener.eq.3) then
         if (ibkg.eq.1) then    ! ZZ background
            a_hll_bkg_mass = a192_hll_zz_h0mass(recmas) 
         else if (ibkg.eq.2) then ! eeZ background
            a_hll_bkg_mass = a192_hll_eez_h0mass(recmas) 
         else if (ibkg.eq.3) then ! other background
            a_hll_bkg_mass = a192_hll_other_h0mass(recmas) 
         end if
      else if (iener.eq.4) then
         if (ibkg.eq.1) then    ! ZZ background
            a_hll_bkg_mass = a196_hll_zz_h0mass(recmas) 
         else if (ibkg.eq.2) then ! eeZ background
            a_hll_bkg_mass = a196_hll_eez_h0mass(recmas) 
         else if (ibkg.eq.3) then ! other background
            a_hll_bkg_mass = a196_hll_other_h0mass(recmas) 
         end if
      else if (iener.eq.5) then
         if (ibkg.eq.1) then    ! ZZ background
            a_hll_bkg_mass = a200_hll_zz_h0mass(recmas) 
         else if (ibkg.eq.2) then ! eeZ background
            a_hll_bkg_mass = a200_hll_eez_h0mass(recmas) 
         else if (ibkg.eq.3) then ! other background
            a_hll_bkg_mass = a200_hll_other_h0mass(recmas) 
         end if
      else if (iener.eq.6) then
         if (ibkg.eq.1) then    ! ZZ background
            a_hll_bkg_mass = a202_hll_zz_h0mass(recmas) 
         else if (ibkg.eq.2) then ! eeZ background
            a_hll_bkg_mass = a202_hll_eez_h0mass(recmas) 
         else if (ibkg.eq.3) then ! other background
            a_hll_bkg_mass = a202_hll_other_h0mass(recmas) 
         end if
      end if
c
      if (a_hll_bkg_mass .lt. 1.D-6) then
         a_hll_bkg_mass = 1.D-6
      end if
c
      end
c--------
      double precision function a_hll_bkg_btag(x,iener,ibkg)
c
c NB: the b-tag pdfs are independent of the recmas variable. 
c For purely technical reasons, will keep same format as for mass pdf, though.
c                                                          PTD, 27-Jul-1999.
c
      implicit none
      integer iener,ibkg
      double precision x
      real*8
     +     a192_hll_zz_btag,a192_hll_eez_btag,a192_hll_other_btag,
     +     a196_hll_zz_btag,a196_hll_eez_btag,a196_hll_other_btag,
     +     a200_hll_zz_btag,a200_hll_eez_btag,a200_hll_other_btag,
     +     a202_hll_zz_btag,a202_hll_eez_btag,a202_hll_other_btag
c
      a_hll_bkg_btag = 1.D-6
c
      if (iener.lt.3 .or. iener.gt.6 .or. 
     +    ibkg.lt.1 .or. ibkg.gt.3 ) then
         write (6,*) ' <a_hll_bkg_btag> Error ! Invalid IENER/ITYPE.',
     +        iener,ibkg
      end if
c
      if (iener.eq.3) then
         if (ibkg.eq.1) then    ! ZZ background
            a_hll_bkg_btag = a192_hll_zz_btag(x)
         else if (ibkg.eq.2) then ! eeZ background
            a_hll_bkg_btag = a192_hll_eez_btag(x)
         else if (ibkg.eq.3) then ! other background
            a_hll_bkg_btag = a192_hll_other_btag(x)
         end if
      else if (iener.eq.4) then
         if (ibkg.eq.1) then    ! ZZ background
            a_hll_bkg_btag = a196_hll_zz_btag(x)
         else if (ibkg.eq.2) then ! eeZ background
            a_hll_bkg_btag = a196_hll_eez_btag(x)
         else if (ibkg.eq.3) then ! other background
            a_hll_bkg_btag = a196_hll_other_btag(x)
         end if
      else if (iener.eq.5) then
         if (ibkg.eq.1) then    ! ZZ background
            a_hll_bkg_btag = a200_hll_zz_btag(x)
         else if (ibkg.eq.2) then ! eeZ background
            a_hll_bkg_btag = a200_hll_eez_btag(x)
         else if (ibkg.eq.3) then ! other background
            a_hll_bkg_btag = a200_hll_other_btag(x)
         end if
      else if (iener.eq.6) then
         if (ibkg.eq.1) then    ! ZZ background
            a_hll_bkg_btag = a202_hll_zz_btag(x)
         else if (ibkg.eq.2) then ! eeZ background
            a_hll_bkg_btag = a202_hll_eez_btag(x)
         else if (ibkg.eq.3) then ! other background
            a_hll_bkg_btag = a202_hll_other_btag(x)
         end if
      end if
c
      if (a_hll_bkg_btag .lt. 1.D-6) then
         a_hll_bkg_btag = 1.D-6
      end if
c
      end
c--------
