C-*-FORTRAN-*-
c
c Modified:
c     - corrected binning of discriminant variable for all channels >= 192 GeV.
c                                                P Seager, 17-Feb-2000.
c
c     - added cssc channels for Y2000;            E Locci, 22-Jun-2000.
c     - added tntn, tncs channels for Y2000;
c                                       E Locci & P Colas, 28-Jun-2000.
c
c     - eliminate tntn & tncs empty channels booked at 204,206,207,208 GeV.
c       (for Y2000, tntn and tncs are calculated in a single lumi/energy bin
c        at 205 GeV).
c                                         P Teixeira-Dias, 01-Jul-2000.
c
c 
c Charged Higgs / 183 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=1,3
           if (xtest18x) write (6,*) ahc_lumi(5,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 183 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 183 H+H- >tncs'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 183 H+H- >cssc'
            nbinsint = 6       ! event counting in mass wdw
            xl = mhc - 0.2 - 3.0 ! see ahc_sig_dis() for more details...
            xu = mhc - 0.2 + 3.0
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c
          xlhphm = xhphm(14)*ahc_lumi(5,iana)
          ratech = ahc_eff(5,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,5,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(5,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,5,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
c     Get candidates information:
c
          call ahc_candidates(5,iana,mhc,nacand,mreco)
c
          if (xtest18x) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(5,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(5,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) and 2 (tncs) only event counting is done
c     ---> put all candidates in the same bin
c
             IF (IANA.LT.3) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSEIF (IANA.EQ.3) THEN
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
       enddo                    ! (iana)
      endif                     ! (switch)

c Charged Higgs / 189 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
C      dosyst = .false.
C      subbg = .false.
      if (switch) then
        do iana=1,3
        if (xtest18x) write (6,*) ahc_lumi(6,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 189 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 189 H+H- >tncs'
            nbinsint = 38        ! mass distribution
            xl = 20.0 
            xu = 94.3 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 189 H+H- >cssc'
            nbinsint = 35       ! mass distribution
            xl = 60.0 
            xu = 94.3 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c
          xlhphm = xhphm(15)*ahc_lumi(6,iana)
          ratech = ahc_eff(6,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,6,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(6,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,6,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTEST18X) then
             write (6,*) 'Charged Higgs / 189 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTEST18X
c     Get candidates information:
c
          call ahc_candidates(6,iana,mhc,nacand,mreco)
c
          if (xtest18x) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(6,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(6,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSEIF (IANA.GT.1) THEN
                candmass = mreco(i)
                if (xtest18x) write (6,*) 
     +  'H+H-/189 xl,xu,candmass,iana:',xl,xu,candmass,iana
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
          if (xtest18x) write (6,*) 'H+H+189 getting ready for systs...'
c     
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.028
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.075
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.032
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.028
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021 
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)
      if (xtest18x) write (6,*) 'H+H- 189 done.'


c Charged Higgs / 192 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=1,3
          if (xtest19x) write (6,*) ahc_lumi(7,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 192 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 192 H+H- >tncs'
            nbinsint = 38        ! mass distribution
            xl = 20.0 
            xu = 96.0 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 192 H+H- >cssc'
            nbinsint = 36       ! mass distribution
            xl = 60.0 
            xu = 96.0 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c
          xlhphm = xhphm(16)*ahc_lumi(7,iana)
          ratech = ahc_eff(7,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,7,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
          if (xtest19x) write (6,*) 'H+H- 192 signal done/ iana:',iana
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(7,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,7,backhist1)
          if (xtest19x) write (6,*) 'H+H- 192 bgd done/ iana:',iana
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTEST19X) then
             write (6,*) 'Charged Higgs / 192 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTEST19X
c     Get candidates information:
c
          call ahc_candidates(7,iana,mhc,nacand,mreco)
c
          if (xtest19x) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(7,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(7,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC No cut on E12
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.030
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.049 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023 
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)


c Charged Higgs / 196 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=1,3
          if (xtest19x) write (6,*) ahc_lumi(8,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 196 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 196 H+H- >tncs'
            nbinsint = 39        ! mass distribution
            xl = 20.0 
            xu = 98.0 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 196 H+H- >cssc'
            nbinsint = 38       ! mass distribution
            xl = 60.0 
            xu = 98.0 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c
          xlhphm = xhphm(17)*ahc_lumi(8,iana)
          ratech = ahc_eff(8,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,8,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(8,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,8,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTEST19X) then
             write (6,*) 'Charged Higgs / 196 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTEST19X
c     Get candidates information:
c
          call ahc_candidates(8,iana,mhc,nacand,mreco)
c
          if (xtest19x) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(8,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(8,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC No cut on E12
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.020
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023
          ENDIF
        enddo                    ! (iana)
      endif                     ! (switch)



c Charged Higgs / 200 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=1,3
          if (xtest19x) write (6,*) ahc_lumi(9,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 200 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 200 H+H- >tncs'
            nbinsint = 40        ! mass distribution
            xl = 20.0 
            xu = 100.0 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 200 H+H- >cssc'
            nbinsint = 40       ! mass distribution
            xl = 60.0 
            xu = 100.0 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c
          xlhphm = xhphm(18)*ahc_lumi(9,iana)
          ratech = ahc_eff(9,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,9,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(9,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,9,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTEST19X) then
             write (6,*) 'Charged Higgs / 200 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTEST19X
c     Get candidates information:
c
          call ahc_candidates(9,iana,mhc,nacand,mreco)
c
          if (xtest19x) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(9,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(9,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC No cut on E12
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.019
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)



c Charged Higgs / 202 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=1,3
          if (xtest19x) write (6,*) ahc_lumi(10,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 202 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 202 H+H- >tncs'
            nbinsint = 41        ! mass distribution
            xl = 20.0 
            xu = 101.0 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 202 H+H- >cssc'
            nbinsint = 41       ! mass distribution
            xl = 60.0 
            xu = 101.0 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c
          xlhphm = xhphm(19)*ahc_lumi(10,iana)
          ratech = ahc_eff(10,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,10,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(10,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,10,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTEST19X) then
             write (6,*) 'Charged Higgs / 202 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTEST19X
c     Get candidates information:
c
          call ahc_candidates(10,iana,mhc,nacand,mreco)
c
          if (xtest19x) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(10,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(10,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC No cut on E12
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.027
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)



c Charged Higgs / 204 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=3,3
          if (xtesty2k) write (6,*) ahc_lumi(11,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 204 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 204 H+H- >tncs'
            nbinsint = 41        ! mass distribution
            xl = 20.0 
            xu = 102.0 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 204 H+H- >cssc'
            nbinsint = 42       ! mass distribution
            xl = 60.0 
            xu = 102.0 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c        
C          xlhphm = xhphm(19)*ahc_lumi(11,iana)
          ener=204.0
          xlhphm = xsec_interp(7,xsec,SNGL(ener))*ahc_lumi(11,iana)
          ratech = ahc_eff(11,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,11,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(11,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,11,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTESTY2K) then
             write (6,*) 'Charged Higgs / 204 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTESTY2K
c     Get candidates information:
c
          call ahc_candidates(11,iana,mhc,nacand,mreco)
c
          if (xtesty2k) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(11,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(11,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC no cut on E12
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.027
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)



c Charged Higgs / 205 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=1,3
          if (xtesty2k) write (6,*) ahc_lumi(12,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 205 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 102.5
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 205 H+H- >tncs'
            nbinsint = 42        ! mass distribution
            xl = 20.0 
            xu = 102.5 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 205 H+H- >cssc'
            nbinsint = 43       ! mass distribution
            xl = 60.0 
            xu = 102.5 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c        
C          xlhphm = xhphm(19)*ahc_lumi(11,iana)
          ener=205.0
          xlhphm = xsec_interp(7,xsec,SNGL(ener))*ahc_lumi(12,iana)
          ratech = ahc_eff(12,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,12,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(12,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,12,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTESTY2K) then
             write (6,*) 'Charged Higgs / 205 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTESTY2K
c     Get candidates information:
c
          call ahc_candidates(12,iana,mhc,nacand,mreco)
c
          if (xtesty2k) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(12,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(12,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC No cut on E12      
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.027
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)




c Charged Higgs / 206 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=3,3
          if (xtesty2k) write (6,*) ahc_lumi(13,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 206 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 206 H+H- >tncs'
            nbinsint = 42        ! mass distribution
            xl = 20.0 
            xu = 103.0 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 206 H+H- >cssc'
            nbinsint = 43       ! mass distribution
            xl = 60.0 
            xu = 103. 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c        
C          xlhphm = xhphm(19)*ahc_lumi(11,iana)
          ener=206.0
          xlhphm = xsec_interp(7,xsec,SNGL(ener))*ahc_lumi(13,iana)
          ratech = ahc_eff(13,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,13,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(13,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,13,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTESTY2K) then
             write (6,*) 'Charged Higgs / 206 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTESTY2K
c     Get candidates information:
c
          call ahc_candidates(13,iana,mhc,nacand,mreco)
c
          if (xtesty2k) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(13,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(13,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC No cut on E12
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.027
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)




c Charged Higgs / 207 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=3,3
          if (xtesty2k) write (6,*) ahc_lumi(14,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 207 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 207 H+H- >tncs'
            nbinsint = 42        ! mass distribution
            xl = 20.0 
            xu = 103.5
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 207 H+H- >cssc'
            nbinsint = 44       ! mass distribution
            xl = 60.0 
            xu = 103.5 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c        
C          xlhphm = xhphm(19)*ahc_lumi(11,iana)
          ener=207.0
          xlhphm = xsec_interp(7,xsec,SNGL(ener))*ahc_lumi(14,iana)
          ratech = ahc_eff(14,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,14,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(14,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,14,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTESTY2K) then
             write (6,*) 'Charged Higgs / 207 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTESTY2K
c     Get candidates information:
c
          call ahc_candidates(14,iana,mhc,nacand,mreco)
c
          if (xtesty2k) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(14,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(14,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC No cut on E12
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.027
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)




c Charged Higgs / 208 -- three analyses: IANA=1 (tntn), 2 (tncs), 3 (cssc)

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=3,3
          if (xtesty2k) write (6,*) ahc_lumi(15,iana)
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 208 H+H- >tntn'
            nbinsint = 1        ! event counting only
            xl = 45.
            xu = 100.
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 208 H+H- >tncs'
            nbinsint = 42        ! mass distribution
            xl = 20.0 
            xu = 104. 
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 208 H+H- >cssc'
            nbinsint = 44       ! mass distribution
            xl = 60.0 
            xu = 104. 
          endif
c
c create binned shape info
c
c     Prepare SIGNAL histogram:
c        
C          xlhphm = xhphm(19)*ahc_lumi(11,iana)
          ener=208.0
          xlhphm = xsec_interp(7,xsec,SNGL(ener))*ahc_lumi(15,iana)
          ratech = ahc_eff(15,iana,mhc)*xlhphm
c
          if (iana.eq.1) then     ! H+H- -> tntn
             ratech = ratech * bhctn**2
          elseif (iana.eq.2) then ! H+H- -> tncs
             ratech = ratech * bhctn * (1.0-bhctn) * 2.0
          elseif (iana.eq.3) then ! H+H- -> cssc
             ratech = ratech * (1.0 - bhctn)**2
          end if
          if (ratech.lt.0.0) ratech=0.0
c
          call a_create6_hc(xl,xu,nbinsint,ahc_sig_dis,
     >                   mhc,iana,15,sighist)
          call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
c
c     Prepare SUBTRACTABLE BACKGROUND histogram:
c
          call vzero(aux,10)
c     aux(1) = subtractable bkg; aux(2) = total bkg
          call ahc_bkg(15,iana,mhc,aux(1),aux(2))
          bkglevel = aux(1)
c
          call a_create6_hc(xl,xu,nbinsint,ahc_bkg_dis,
     >                   mhc,iana,15,backhist1)
          call ahistscal1(nbinsint,backhist1,backg(nbins+1),bkglevel)
c
          if (XTESTY2K) then
             write (6,*) 'Charged Higgs / 208 GeV, IANA:',iana
             write (6,*) 'sig()=',(sig(nbins+j),j=1,nbinsint)
             write (6,*) 'backg()=',(backg(nbins+j),j=1,nbinsint)
          end if                ! XTESTY2K
c     Get candidates information:
c
          call ahc_candidates(15,iana,mhc,nacand,mreco)
c
          if (xtesty2k) write (6,*) 
     +'*** H+H-:iana,mhc,rate,eff(15,iana,mhc),bsub,btot,Ncand',
     +         iana,mhc,ratech,ahc_eff(15,iana,mhc),aux(1),aux(2),nacand
c
          do i=1,nacand
c
c     NB for iana = 1 (tntn) 
c     ---> put all candidates in the same bin
c
             IF (IANA.EQ.1) THEN
                ncand(nbins+1) = ncand(nbins+1) + 1
             ELSE
                candmass = mreco(i)
                call abin1(candmass,xl,xu,nbinsint,ibin)
                if (ibin.gt.0.and.ibin.le.nbinsint) then
                   ncand(nbins+ibin) = ncand(nbins+ibin) + 1
                endif
             END IF             ! IANA
          enddo                 ! i
c
c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
             if (aux(1).gt.0.) then
                aux(3) = aux(2) / aux(1)
             else 
                aux(3) = 0.0
             end if
c
c            CALL VSCALE(a,alpha,x,n) ---> x(i)=a(i)*alpha; i=1, ..., n
c
            call vscale(backg(nbins+1),aux(3),backw(nbins+1),nbinsint)
          else
            call vscale(backg(nbins+1),1.0,backw(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
C  Now the systematics
          IF (IANA.EQ.1) THEN ! tntn
CC No cut on E12
CC           CORSIG(NCHAN) = 0.011
CC           UNCSIG(NCHAN) = 0.025
CC           CORBKG(NCHAN) = 0.021
CC           UNCBKG(NCHAN) = 0.072
CC Cut E12=0
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.025
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.021
CC
          ENDIF
          IF (IANA.EQ.2) THEN ! tncs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.027
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.046 
          ENDIF
          IF (IANA.EQ.3) THEN ! cscs
           CORSIG(NCHAN) = 0.011
           UNCSIG(NCHAN) = 0.015
           CORBKG(NCHAN) = 0.021
           UNCBKG(NCHAN) = 0.023
          ENDIF
       enddo                    ! (iana)
      endif                     ! (switch)






