C-*-FORTRAN-*-
c
c ALEPH inputs 
c
c Mods: 
c
c (...)
c---- vsn 4.X (Summer 2002)
c
c     - analysis in Y2000: neutral and charged Higgs searches 
c       E_CM < 210 GeV
c
c     - the input xsection array XSEC(,) ecm-indexing has been updated to match
c       the new cross-section database provided by Chris. This is an
c       important change, and requires ACTION on the user's part! The new
c       correspondence between the energy indices and ECM is as follows:
c
c 14: 183.0 |15: 188.6 |16: 191.6 |17: 195.5 |18: 199.5 |19: 201.6 |20: 202.5
c 21: 203.0 |22: 203.5 |23: 204.0 |24: 204.5 |25: 205.0 |26: 205.5 |27: 206.0
c 28: 206.5 |29: 207.0 |30: 207.5 |31: 208.0 |32: 208.5 |33: 209.0 |34: 209.5
c 35: 210.0 |          |          |          |          |          |
c
c     - added the fermiophobic Higgs analysis (all LEP1 and LEP2 energies, up 
c       to 210 GeV).                                        09-Jul-2000.
c
c
c---- vsn 2.0 (Feb 2000) 
c     
c     - Final results, using the 192 - 202 GeV data.
c     - Major new change to inputs: 
c      xsec(5,i) is now the total h nu_e nu_e cross-section
c      xsec(6,i) is now the total hee cross-section
c     (these used to be resp. the WW/ZZ fusion contributions only); 
c     The code has been changed so that these changes are backwards-compatible
c     (i.e. for all the searches with Ecm<=189 GeV)
c                                                     PTD + PAM, 12-Feb-2000.
c
c----------------------------------------------------------------------------
c     NB For each new channel, explicitely add the upper and lower bounds of
c          mH, outside of which the efficiencies have to be explicitely 
c          set to ZERO!
c
c==============================================================================
c   INPUTS: xmass, xsec, brfrac
c   OUTPUTS: nchan, ifirst, channame 
c            nbins, sig, backg, backw, ncand
c     
c arguments:
c-------------------------------------------------------
c  xmass(4)     INPUT   (real) in GeV
c   1: h mass
c   2: A mass
c   3: Heavy Higgs (H) mass 
c   4: Charged Higgs mass 
c-------------------------------------------------------
c  xsec(7,a_maxnener) -- cross-sections (defined below) INPUT (real) in picobarns
c
c Two indices for cross sections -- first one: type of cross section
c  1 = sigma(e+e- -> Zh)  -- at several energies
c  2 = sigma(e+e- -> hA)  -- at several energies
c  3 = sigma(e+e- -> ZH) (heavy higgs)
c  4 = sigma(e+e- -> HA) (heavy higgs)  (currently unused)
c  5 = sigma(e+e- -> h nue nue ) *total* cross-section
c      (i.e., includes HZ + WW-fusion + interference)
c  6 = sigma(e+e- -> hee ) *total* cross-section
c      (i.e., includes HZ + ZZ-fusion + interference)
c  7 = sigma(e+e- -> H+H-)
c
c Second index for cross section input, the energy point:
c   Energy lists for cross sections:  (dimensioned a_maxnener,
c                                      defined in a_inputs.inc)
c iener=
c      1: 88.4   GeV
c      2: 89.4
c      3: 90.2
c      4: 91.4
c      5: 92.0
c      6: 93.0
c      7: 93.4
c      8: 161.3
c      9: 170.0
c     10: 172.0
c     11: 130.0
c     12: 136.0
c     13: 182.0
c     14: 183.0
c     15: 188.6
c     16: 191.6
c     17: 195.5
c     18: 199.5
c     19: 201.6
c     20: 202.5
c     21: 203.0
c     22: 203.5
c     23: 204.0
c     24: 204.5
c     25: 205.0
c     26: 205.5
c     27: 206.0
c     28: 206.5
c     29: 207.0
c     30: 207.5
c     31: 208.0
c     32: 208.5
c     33: 209.0
c     34: 209.5
c     35: 210.0
c
c--------------------------------------------------------
c  brfrac(16) -- input branching fractions (defined below) INPUT (real)
c  1:  branching fraction of h->bbar
c  2:  branching fraction of h->ccbar
c  3:  branching fraction of h->tautau
c  4:  branching fraction of h->ss
c  5:  branching fraction of h->glue glue
c  6:  branching fraction of h->AA
c  7:  branching fraction of A->bbar
c  8:  branching fraction of A->ccbar
c  9:  branching fraction of A->tautau
c  10: branching fraction of A->ss
c  11: branching fraction of braglgl = A->glgl
c  12: branching fraction of H->bbar  (heavy Higgs)
c  13: branching fraction of h->invisibly decaying neutralinos
c  14: branching fraction of H+/- -> tau nu (assume 1-BR is H+/- -> cs)
c  15: branching fraction of h-> gamma gamma
c  16: branching fraction of h-> WW
c
c-------------------------------------------------------
c iopt (INPUT) (integer) -- choice of overlap treatment for neutral
c                      Higgs analyses (4 jet and Xtautau final states):  
c                      0 = automatic choice,
c                      1 = as hZ/HZ, 2 = as hA
c-------------------------------------------------------
c nchan  (OUTPUT) (integer) -- number of separate search channels
c                    <= a_maxnchan, defined in a_inputs.inc (integer)
c-------------------------------------------------------
c ifirst() (OUTPUT) (integer) -- array of dimension a_maxnchan
c                      (defined in a_inputs.inc)
c                      gives first element index
c                      in sig, backg, backw,
c                      ncand arrays.  Use this and ifirst of
c                      the next channel to find out how big a channel's
c                      histogram is.
c-------------------------------------------------------
c character*40 channame() (OUTPUT) -- string array of dimension
c                      a_maxnchan for channel names
c-------------------------------------------------------
c nbins (OUTPUT) (integer) -- total number of histogram bins
c                   output for all channels, arranged end to
c                   end. 
c-------------------------------------------------------
c sig() (OUTPUT) (real)  -- array of dimension a_maxnbin
c                           (defined in a_inputs.inc)
c                           containing the expected accepted Higgs
c                           signal in each bin of each channel.
c-------------------------------------------------------
c backg() (OUTPUT) (real)  -- array of dimension a_maxnbin
c                           (defined in a_inputs.inc)
c                           containing the SUBTRACTABLE SM
c                           background in each bin of each channel.
c-------------------------------------------------------
c backw() (OUTPUT) (real)  -- array of dimension a_maxnbin
c                           (defined in a_inputs.inc)
c                           containing the TOTAL SM
c                           background in each bin of each channel.
c
c Note: at the moment backg() is either zero (for the 183 GeV analyses) or
c is identical to backw() (for the 189 GeV analyses except H+H-);
c Systematics to be added soon.
c-------------------------------------------------------
c ncand() (OUTPUT) (integer) -- array of dimension a_maxnbin
c                           (defined in a_inputs.inc)
c                           containing the observed candidate count
c                           in each analysis bin.
c-------------------------------------------------------
c corsig() (OUTPUT) (real) -- array of dimension a_maxnchan
c                      (defined in a_inputs.inc)
c                      gives size of correlated term of signal
c                      systematic for channel
c-------------------------------------------------------
c uncsig() (OUTPUT) (real) -- array of dimension a_maxnchan
c                      (defined in a_inputs.inc)
c                      gives size of uncorrelated term of signal
c                      systematic for channel
c-------------------------------------------------------
c corbkg() (OUTPUT) (real) -- array of dimension a_maxnchan
c                      (defined in a_inputs.inc)
c                      gives size of correlated term of background
c                      systematic for channel
c-------------------------------------------------------
c uncbkg() (OUTPUT) (real) -- array of dimension a_maxnchan
c                      (defined in a_inputs.inc)
c                      gives size of uncorrelated term of background
c                      systematic for channel
c-------------------------------------------------------
c dsig(a_maxnerr,a_maxnchan) (OUTPUT) (REAL):
c      dsig(I,J): sig FRACTIONAL error for source I in channel J
c-------------------------------------------------------
c dback(a_maxnerr,a_maxnchan) (OUTPUT) (REAL):
c      dback(I,J): bkg FRACTIONAL error for source I in channel J
c-------------------------------------------------------
c sysname(a_maxnerr,a_maxnchan) (OUTPUT) (CHARACTER*20)
c      sysname(I,J): name tag for source I in channel J
c-------------------------------------------------------
c nerrch(a_maxnchan) (OUTPUT) (INTEGER)
c      nerrch(J): number of error sources reported for channel J
c-------------------------------------------------------
c chanlumi() (OUTPUT) (real) -- array of dimension a_maxnchan
c                      (defined in a_inputs.inc)
c                     The luminosity used in channel I
c
c
      subroutine a_inputs(xmass,xsec,brfrac,iopt,nchan,ifirst,
     >                    channame,nbins,sig,backg,backw,ncand,
     >                    corsig,uncsig,corbkg,uncbkg,
     >                    dsig,dback,sysname,nerrch,chanlumi)
      implicit none
      include 'a_inputs.inc'
c
c added by PTD:
c
      logical xtest18x,xtest19x,xtesty2k
      parameter (xtest18x=.false.,xtest19x=.false.,xtesty2k=.false.)
      real aux(10)
      integer j
c
c arguments
      real xmass(nmass),xsec(nxsec,*),brfrac(16)
      integer nchan,ifirst(a_maxnchan),iopt,iopt2
      real chanlumi(a_maxnchan)
      real corsig(a_maxnchan),uncsig(a_maxnchan)
      real corbkg(a_maxnchan),uncbkg(a_maxnchan)
      character*40 channame(a_maxnchan)
      integer nbins
      real sig(a_maxnbin),backg(a_maxnbin),backw(a_maxnbin)
      integer ncand(a_maxnbin)
c For detailed error breakdown:
      integer nerrch(a_maxnchan)
      real dsig(a_maxnerr,a_maxnchan)
      real dback(a_maxnerr,a_maxnchan)
      character*20 sysname(a_maxnerr,a_maxnchan)
c
      integer nerrch_aux
      real dsig_aux(a_maxnerr)
      real dback_aux(a_maxnerr)
      character*20 sysname_aux(a_maxnerr)

      logical init
      data init /.true./
      save init
      logical switch,dosyst,subbg

      integer nbinsint,nbinsint1,nbinsint2,ibin1,ibin2
      real sighist(100),sighist1(100),sighist2(100)
      real sighist1s(100),sighist2s(100) 
      real sighist3(100),sighist3s(100),sighist1t(100),sighist2t(100) 
      real sighist1a(100),sighist2a(100),sighist1as(100),sighist2as(100) 
      real sighist2d(100,100),bkghist2d(100,100)
      real backqq(100),backww(100),backzz(100)
      real backeez(100),backoth(100)
      real backhist1(100),backhist2(100)
      real xl,xh,xl1,xu1,xl2,xu2,candmass,candbtag,xu
      real xl1o,xu1o,xl2o,xu2o
      real bkglevel,bkgtotal
      real res1ch,xlzh,xlah,xlww,xlee,xlzz,xlhphm,xxll
      integer i,ibin,candhist2d(100,100)
      character*40 histfile(20)
c
      character*70 a_version,a_vers_date
      parameter (a_version=
     +' *** You are running version 4.00 of the ALEPH code. *** ',
     +a_vers_date=
     +'          *** Released June 19, 2002. ***           ')
      logical a_first
      data a_first / .true. /

c masses
      real mh,mapole,mhh,mhc,mreco(2000)

c cross sections
      real xhz(a_maxnener),xha(a_maxnener),xhhz(a_maxnener)
      real xhha(a_maxnener),xhnunu(a_maxnener),xhee(a_maxnener)
      real xhnenetot(a_maxnener),xheetot(a_maxnener)
      real xhphm(a_maxnener)
      real xs172,xs172n,xs172e
      real xs161,xs161n,xs161e
      real ratech,rate2ch,rate3ch,backch

c branching fractions
      real bhbb,bhcc,bhtata,bhss,bhglgl,bhaa
      real babb,bacc,batata,bass,baglgl
      real bhhbb,bhn1n1,bhctn,bhgaga,bhww

      real Abhbb,Abhhad,AMSSMbhbb,AMSSMbabb

*  Z0 branchings
      real z0tonn,z0toee,z0tomumu,z0totata
      real z0toh,z0tob,z0toc
      data z0tonn/0.2001/,z0toee/0.03366/,z0totata/0.03360/
      data z0tomumu/0.03367/
      data z0toh /0.699 /,z0tob /0.1508 /,z0toc/0.120/
      save z0tonn,z0toee,z0tomumu,z0totata,z0toh,z0tob,z0toc

c ALEPH 183 SM and MSSM functions
c mssm first, then sm
      real*8 xdouble,ydouble
      integer nacand,iana,ichan
      real*8 A183_HABBBB_EFF
      real*8 A183_HABBBB_BKG
      integer A183_HABBBB_NUMCAND
      real*8 A183_HABBBB_MASS_CAND
      real*8 A183_HABBBB_BTAG_CAND
      real*8 A183_HABBBB_MASS_SIG
      real*8 A183_HABBBB_MASS_BKG
      real*8 A183_HABBBB_BTAG_SIG
      real*8 A183_HABBBB_BTAG_BKG
      real*8 A183_HATTBB_EFF
      real*8 A183_HATTBB_BKG
      integer A183_HATTBB_NUMCAND
      real*8 A183_HATTBB_MASS_CAND
      real*8 A183_HATTBB_MASS_SIG
      real*8 A183_HATTBB_MASS_BKG
      external A183_HABBBB_EFF
      external A183_HABBBB_BKG
      external A183_HABBBB_NUMCAND
      external A183_HABBBB_MASS_CAND
      external A183_HABBBB_BTAG_CAND
      external A183_HABBBB_MASS_SIG
      external A183_HABBBB_MASS_BKG
      external A183_HABBBB_BTAG_SIG
      external A183_HABBBB_BTAG_BKG
      external A183_HATTBB_EFF
      external A183_HATTBB_BKG
      external A183_HATTBB_NUMCAND
      external A183_HATTBB_MASS_CAND
      external A183_HATTBB_MASS_SIG
      external A183_HATTBB_MASS_BKG

      real*8 A183_HQQ_EFF
      real*8 A183_HQQ_BKG
      integer A183_HQQ_NUMCAND
      real*8 A183_HQQ_MASS_CAND
      real*8 A183_HQQ_MASS_SIG
      real*8 A183_HQQ_MASS_BKG
      real*8 A183_HNN_EFF
      real*8 A183_HNN_WWF_EFF
      real*8 A183_HNN_BKG
      integer A183_HNN_NUMCAND
      real*8 A183_HNN_MASS_CAND
      real*8 A183_HNN_BTAG_CAND
      real*8 A183_HNN_MASS_SIG
      real*8 A183_HNN_MASS_BKG
      real*8 A183_HNN_BTAG_SIG
      real*8 A183_HNN_BTAG_BKG
      real*8 A183_HLL_EFF
      real*8 A183_HLL_BKG
      integer A183_HLL_NUMCAND
      real*8 A183_HLL_MASS_CAND
      real*8 A183_HLL_BTAG_CAND
      real*8 A183_HLL_MASS_SIG
      real*8 A183_HLL_MASS_BKG
      real*8 A183_HLL_BTAG_SIG
      real*8 A183_HLL_BTAG_BKG
      real*8 A183_HTT_EFF
      real*8 A183_HTT_BKG
      integer A183_HTT_NUMCAND
      real*8 A183_HTT_MASS_CAND
      real*8 A183_HTT_MASS_SIG
      real*8 A183_HTT_MASS_BKG
      real*8 A183_TTQQ_EFF
      real*8 A183_TTQQ_BKG
      integer A183_TTQQ_NUMCAND
      real*8 A183_TTQQ_MASS_CAND
      real*8 A183_TTQQ_MASS_SIG
      real*8 A183_TTQQ_MASS_BKG
      external A183_HQQ_EFF
      external A183_HQQ_BKG
      external A183_HQQ_NUMCAND
      external A183_HQQ_MASS_CAND
      external A183_HQQ_MASS_SIG
      external A183_HQQ_MASS_BKG
      external A183_HNN_EFF
      external A183_HNN_WWF_EFF
      external A183_HNN_BKG
      external A183_HNN_NUMCAND
      external A183_HNN_MASS_CAND
      external A183_HNN_BTAG_CAND
      external A183_HNN_MASS_SIG
      external A183_HNN_MASS_BKG
      external A183_HNN_BTAG_SIG
      external A183_HNN_BTAG_BKG
      external A183_HLL_EFF
      external A183_HLL_BKG
      external A183_HLL_NUMCAND
      external A183_HLL_MASS_CAND
      external A183_HLL_BTAG_CAND
      external A183_HLL_MASS_SIG
      external A183_HLL_MASS_BKG
      external A183_HLL_BTAG_SIG
      external A183_HLL_BTAG_BKG
      external A183_HTT_EFF
      external A183_HTT_BKG
      external A183_HTT_NUMCAND
      external A183_HTT_MASS_CAND
      external A183_HTT_MASS_SIG
      external A183_HTT_MASS_BKG
      external A183_TTQQ_EFF
      external A183_TTQQ_BKG
      external A183_TTQQ_NUMCAND
      external A183_TTQQ_MASS_CAND
      external A183_TTQQ_MASS_SIG
      external A183_TTQQ_MASS_BKG
c
c---- ALEPH 188.6 GeV functions SM/MSSM;
c
      real*8 A189_4jet_eff
      real*8 A189_4jet_sig_mh
      real*8 A189_4jet_sig_nn
      real*8 A189_4jet_sig_msum
      real*8 A189_4jet_sig_fvar
      real*8 A189_4jet_bkg
      real*8 A189_4jet_bkg_mh
      real*8 A189_4jet_bkg_nn
      real*8 A189_4jet_bkg_msum
      real*8 A189_4jet_bkg_fvar
      integer A189_4jet_numcand
      real*8 A189_4jet_mh_cand
      real*8 A189_4jet_nn_cand
      real*8 A189_4jet_msum_cand
      real*8 A189_4jet_fvar_cand

      real*8 A189_hnn_eff
      real*8 A189_hnn_wwf_eff
      real*8 A189_hnn_mass_sig
      real*8 A189_hnn_bkg
      real*8 A189_hnn_mass_bkg
      integer A189_hnn_numcand
      real*8 A189_hnn_mass_cand

      real*8 A189_hll_eff
      real*8 A189_hll_mass_sig
      real*8 A189_hll_btag_sig
      real*8 A189_hll_bkg
      real*8 A189_hll_mass_bkg
      real*8 A189_hll_btag_bkg
      integer A189_hll_numcand
      real*8 A189_hll_mass_cand
      real*8 A189_hll_btag_cand

      real*8 A189_tt_eff
      real*8 A189_tt_mass_sig
      real*8 A189_tt_bkg
      real*8 A189_tt_mass_bkg
      integer A189_tt_numcand
      real*8 A189_tt_mass_cand
      real ahc_lumi, ahc_eff, ahc_bkg_dis, ahc_sig_dis

      external A189_4jet_eff
      external A189_4jet_sig_mh
      external A189_4jet_sig_nn
      external A189_4jet_sig_msum
      external A189_4jet_sig_fvar
      external A189_4jet_bkg
      external A189_4jet_bkg_mh
      external A189_4jet_bkg_nn
      external A189_4jet_bkg_msum
      external A189_4jet_bkg_fvar
      external A189_4jet_numcand
      external A189_4jet_mh_cand
      external A189_4jet_nn_cand
      external A189_4jet_msum_cand
      external A189_4jet_fvar_cand

      external A189_hnn_eff
      external A189_hnn_wwf_eff
      external A189_hnn_mass_sig
      external A189_hnn_bkg
      external A189_hnn_mass_bkg
      external A189_hnn_numcand
      external A189_hnn_mass_cand

      external A189_hll_eff
      external A189_hll_mass_sig
      external A189_hll_btag_sig
      external A189_hll_bkg
      external A189_hll_mass_bkg
      external A189_hll_btag_bkg
      external A189_hll_numcand
      external A189_hll_mass_cand
      external A189_hll_btag_cand

      external A189_tt_eff
      external A189_tt_mass_sig
      external A189_tt_bkg
      external A189_tt_mass_bkg
      external A189_tt_numcand
      external A189_tt_mass_cand
      external ahc_lumi, ahc_eff, ahc_sig_dis,ahc_bkg_dis
c
c  ALEPH 191.6 + 195.6 GeV functions
c
      real ah0_lumi
      external ah0_lumi
      integer iener,ityp,iebin
c
c Hll 192 - 202 GeV
       real*8 a_hll_bkg_level
       real*8 a_hll_mass_cand,a_hll_btag_cand
       integer a_hll_numcand
       external a_hll_bkg_level,a_hll_numcand,a_hll_mass_cand,
     +      a_hll_btag_cand
c
       real*8 a_hll_eff_bb_1999,a_hll_eff_tt_1999,
     +      a_hll_eff_other_1999
       external a_hll_eff_bb_1999,a_hll_eff_tt_1999,
     +      a_hll_eff_other_1999
       real*8 a_hll_sig_h0mass,a200_hll_sig_btag_bb,
     +        a200_hll_sig_btag_tt,a200_hll_sig_btag_other
       external a_hll_sig_h0mass,a200_hll_sig_btag_bb,
     +        a200_hll_sig_btag_tt,a200_hll_sig_btag_other
       real*8 a_hll_bkg_mass,a_hll_bkg_btag
       external a_hll_bkg_mass,a_hll_bkg_btag

cx       real*8 A192_hll_hmm_eff,A192_hll_hee_eff,A192_hll_zfus_eff
cx       external A192_hll_hmm_eff,A192_hll_hee_eff,A192_hll_zfus_eff
cx       real*8 A196_hll_hmm_eff,A196_hll_hee_eff,A196_hll_zfus_eff
cx
c       external A196_hll_hmm_eff,A196_hll_hee_eff,A196_hll_zfus_eff
c Hqq + hvv declarations (19x GeV):
       include 'hqqhvv_decl.inc'
c
c Xtt declarations (19x GeV):
       include 'taus_decl.inc'
c
c  Fermiophobic Higgs declarations: 
       include 'a_zhgg_91_210_decl.inc'
       include 'a_zhgg_ext_main.inc'
c
c  Invisible Higgs declarations:
       include 'a_invisible_decl.inc'

*  ALEPH external functions
      real effic_aleph
      real*8 hbb_sm,hhad_sm,hbb_mssm,abb_mssm
      external effic_aleph,hbb_sm,hhad_sm,hbb_mssm,abb_mssm
*  ALEPH background fields
      real ab161lq,   ab161nq,   ab161qb,   ab161tq,   ab161qt
      real ab172lq,   ab172nq,   ab172qb,   ab172tq,   ab172qt
*  ALEPH rate correction factor (9.Sept.97)
      integer nchal
      parameter (nchal=10)
*  branching
      real braal(nchal)
      real flumal(nchal),f170al(3)
      REAL a_ch_cor(nchal)
*  channel dependent efficiency and background
*  (no information about energy dependence of background)
      data ab161lq/0.06/,ab161nq/0.06/,ab161qb/0.17/,
     +     ab161tq/0.02/,ab161qt/0.05/
*  sum             0.36
      data ab172lq/0.11/,ab172nq/0.09/,ab172qb/0.23/,
     +     ab172tq/0.02/,ab172qt/0.03/
*  sum             0.48
*  ALEPH channel correction factors
      data a_ch_cor/1.,1.,1.07,1.,1.,1.,1.,1.07,1.,1./
      data flumal / 5*10.6,       5*10.9/
      data f170al /   1.1 ,  9.5 ,  10.6/
c
c     Y2000 declarations: ------------------------------------------
c
c     Background cross-section functions:
      real*8 al_xsect_dd,al_xsect_uu,al_xsect_ss,al_xsect_cc,
     +       al_xsect_bb,al_xsect_ww,al_xsect_zz,al_xsect_ewnu,
     +       al_xsect_zee,al_xsect_znn
      external al_xsect_dd,al_xsect_uu,al_xsect_ss,al_xsect_cc,
     +       al_xsect_bb,al_xsect_ww,al_xsect_zz,al_xsect_ewnu,
     +       al_xsect_zee,al_xsect_znn
c
c     Function to interpolate signal xsection array
      real xsec_interp
      external xsec_interp
c
      real themass(50),thebtag(50)
c
c     Hqq/Hnn Y2000
      include 'hqqhnn_decl_2000.inc'
c
c     Hll Y2000
      include 'hllxtt_decl_2000.inc'
c
c     Variables + COMMON needed for ECM-binning
      include 'a_2000_vars.inc'
      real lumi_in_bin(20)
c
c     Flavour-independent
      include 'a_flavind_decl.inc'
c
c     Actual definition of ECM-binning
      include 'a_setup_2000.inc'
c     --------------------------------------------------------------
c     
c
c---- Initialize:
c
      IF (A_FIRST) THEN
         write (6,*) ' '
         write (6,*) a_version
         write (6,*) a_vers_date
         write (6,*) ' '
         a_first = .false.
c
         aux(1) = 0.0
         aux(2) = 0.0
         do iebin=1,n_ebins_2000
            lumi_in_bin(iebin) = 0.0
            do iener = ilow_energy(iebin),ihigh_energy(iebin)
             lumi_in_bin(iebin) = lumi_in_bin(iebin) + lumi_2000(iener)
             aux(2) = aux(2) + 
     +            (199. + 0.1 * (iener-0.5))*lumi_2000(iener) !E_i*L_i
            end do              ! iener, small energy bins
            aux(1) = aux(1) + lumi_in_bin(iebin)
         end do                 ! iebin, large energy bins
c
         write (6,*) 
     +   '============ ALEPH ECM-binning in Y2000 =================='
         write (6,*) 
     +   '================ for NEUTRAL Higgs searches =============='
         write (6,20) 'BinName','Emin','Emax','nbins',' L (/pb)'
         write (6,*)
     +   '=========================================================='
         write (6,21) (ename(i),199.+(0.1*(ilow_energy(i)-1)),
     +        199.+(0.1*ihigh_energy(i)),
     +        ihigh_energy(i)-ilow_energy(i)+1,
     +        lumi_in_bin(i),i=1,n_ebins_2000)
         write (6,*) 
     +   '=========================================================='
         write (6,22) ' TOTAL (/pb) --> ',aux(1)
c         write (6,22) ' Lumi-weighted ECM (GeV) --> ',aux(2)/aux(1)
         
         write (6,*) ' '
 20      format (1x,5a10)
 21      format (1x,a10,2f10.2,i10,f10.5)
 22      format (a41,f10.5)
c
         write (6,*) 
     +   '============ ALEPH ECM-binning in Y2000 =================='
         write (6,*) 
     +   '================ for CHARGED Higgs searches =============='
         write (6,30) 'BinName',' L (/pb)'
         write (6,*)
     +   '=== cssc: ================================================'
         write (6,31) '204',ahc_lumi(11,3)
         write (6,31) '205',ahc_lumi(12,3)
         write (6,31) '206',ahc_lumi(13,3)
         write (6,31) '207',ahc_lumi(14,3)
         write (6,31) '208',ahc_lumi(15,3)
         write (6,*) 
     +   '=== tncs: ========================================='
         write (6,31) '205',ahc_lumi(12,2)
         write (6,*) 
     +   '=== tntn: ========================================='
         write (6,31) '205',ahc_lumi(12,1)
         write (6,*) 
     +   '=========================================================='
         write (6,*) ' '
 30      format (1x,a10,a10)
 31      format (1x,a10,f10.5)
c
      END IF
c
      call vzero(aux,10)
c
      mh = xmass(1)
      mapole = xmass(2)
      mhh = xmass(3)
      mhc = xmass(4)
c
      do i=1,a_maxnener
        xhz(i) = max(xsec(1,i),0.0)
        xha(i) = max(xsec(2,i),0.0)
        xhhz(i) = max(xsec(3,i),0.0)
        xhha(i) = max(xsec(4,i),0.0)
        xhnenetot(i) = max(xsec(5,i),0.0) ! new: vsn2.0
        xheetot(i) = max(xsec(6,i),0.0) ! new: vsn2.0
        xhphm(i) = max(xsec(7,i),0.0)
c
c     Now, from the new inputs must still 
c     derive the "old" xhee (WW fusion only) and xhnunu (ZZ fusion only)
c     variables, as they are still used in the analyses up to 189 GeV (incl.)
c
        xhee(i) = xheetot(i) - xhz(i)*z0toee
        xhnunu(i) = xhnenetot(i) - xhz(i) * z0tonn / 3.
      enddo
c
c set the h,A branching ratios:
      bhbb = brfrac(1)
      bhcc = brfrac(2)
      bhtata = brfrac(3)
      bhss   = brfrac(4)
      bhglgl = brfrac(5)
      bhaa   = brfrac(6)
      babb = brfrac(7)
      bacc = brfrac(8)
      batata = brfrac(9)
      bass   = brfrac(10)
      baglgl = brfrac(11)
      bhhbb  = brfrac(12)
      bhn1n1 = brfrac(13)
      bhctn = brfrac(14)
      bhgaga = brfrac(15)
      bhww = brfrac(16)
c
c---- Abhbb  is the SM Hbb BRatio: 
c     Abhhad is the SM H --> hadrons BRatio: 
c
      xdouble = mh
      Abhbb = SNGL( hbb_sm(xdouble) )
      Abhhad = SNGL( hhad_sm(xdouble) )
c
      AMSSMbhbb = SNGL( hbb_mssm(xdouble) )
      AMSSMbabb = SNGL( abb_mssm(DBLE(mapole)) )
c
c     Choose treatment of overlap branch, for neutral Higgs searches 
c     (4 jet and Xtt final states)
c
      if (iopt.eq.1) iopt2 = 1  ! treat overlap as hZ
      if (iopt.eq.2) iopt2 = 2  ! treat overlap as hA
      if (iopt.eq.0) then
         iopt2 = 2
         if (mhh.lt.111.) iopt2 = 1
         if (abs(mh-mApole).gt.20) iopt2 = 1
         if (0.75*mh+0.25*mApole.gt.89.) iopt2 = 1
      endif
C
C========================ALEPH================================
*  ALEPH channel ordering  172,161/ (e+m)q,nq,qb,tq,qt

      xs172 =(f170al(2)*xhz(10)+f170al(1)*xhz(9))/f170al(3)
      xs172n=(f170al(2)*xhnunu(10)+f170al(1)*xhnunu(9))/f170al(3)
      xs172e=(f170al(2)*xhee(10)+f170al(1)*xhee(9))/f170al(3)
      xs161 = xhz(8)
      xs161n = xhnunu(8)
      xs161e = xhee(8)

      braal(1) = (z0toee+z0tomumu)*(bhbb+bhcc+bhss+bhglgl)
      braal(2) = z0tonn*(bhbb+bhcc+bhss+bhglgl)
      braal(3) = z0toh*bhbb
      braal(4) = z0totata*(bhbb+bhcc+bhss+bhglgl)
      braal(5) = z0toh*bhtata
      do i=1,5
        braal(i+5) = braal(i)
      enddo

      nbins = 0
      nchan = 0
      call vzero(ifirst,a_maxnchan)
      call vzero(chanlumi,a_maxnchan)
c---- old systematic error arrays (still used for H+H-; Feb-2000)
      call vzero(corsig,a_maxnchan)
      call vzero(uncsig,a_maxnchan)
      call vzero(corbkg,a_maxnchan)
      call vzero(uncbkg,a_maxnchan)
c---- New, systematic error arrays with detailed breakdown by source.
      call vzero(dsig,a_maxnchan*a_maxnerr)
      call vzero(dback,a_maxnchan*a_maxnerr)
c
      call vzero(sig,a_maxnbin)
      call vzero(backg,a_maxnbin)
      call vzero(backw,a_maxnbin)
      call vzero(ncand,a_maxnbin)

c Zh -> leptons qqbar at 172 -- Gaussian + constant
c -- add in a t-channel component.  Question -- this channel also
c has muons in it -- without a t-channel component -- is this right?
c resolution is here "for formal reasons since it cancels, but the
c results are sensitive to the shape of the mass distributions
c in channels without events"
c no candidates

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 172 Zh->llqq'
        ratech = flumal(1)*braal(1)*
     >           xs172*a_ch_cor(1)*effic_aleph(mh,2,2)
        ratech = ratech*(1.+0.5*xs172e/xs172/z0toee)
        if (ratech.lt.0.0) ratech=0.0
        res1ch = 2.
        backch = ab172lq/35.
        call aghist(mh,res1ch,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then
         write (6,*) ' --> Switched OFF: '//'ALEPH 172 Zh->llqq'
      endif

c Zh -> nunubar qqbar at 172 -- histogram + constant

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 172 Zh-nunuqq'
        if (init) then
          histfile(1) = 'a_172_hnn_45.dat'
          histfile(2) = 'a_172_hnn_50.dat'
          histfile(3) = 'a_172_hnn_55.dat'
          histfile(4) = 'a_172_hnn_60.dat'
          histfile(5) = 'a_172_hnn_65.dat'
          histfile(6) = 'a_172_hnn_70.dat'
          histfile(7) = 'a_172_hnn_75.dat'
          histfile(8) = 'a_172_hnn_80.dat'
          do i=1,8
            call ahistread1(histfile(i),nchan)
          enddo
        endif
        ratech = flumal(2)*braal(2)*xs172*
     >           a_ch_cor(2)*effic_aleph(mh,2,1)
        if (ratech.lt.0.0) ratech=0.0
        backch = ab172nq/35.
        call asinterp1(nchan,mh,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 172 Zh->nunuqq'
      endif

c Zh -> qqbar bbbar at 172

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 172 Zh->qqbb'
        if (init) then
          histfile(1) = 'a_172_hqq_45.dat'
          histfile(2) = 'a_172_hqq_50.dat'
          histfile(3) = 'a_172_hqq_55.dat'
          histfile(4) = 'a_172_hqq_60.dat'
          histfile(5) = 'a_172_hqq_65.dat'
          histfile(6) = 'a_172_hqq_70.dat'
          histfile(7) = 'a_172_hqq_75.dat'
          histfile(8) = 'a_172_hqq_80.dat'
          do i=1,8
            call ahistread1(histfile(i),nchan)
          enddo
        endif
        call asinterp1(nchan,mh,nbinsint,xl,xh,sighist)
        ratech = flumal(3)*braal(3)*xs172*
     >           a_ch_cor(3)*effic_aleph(mh,2,3)
        if (ratech.lt.0.0) ratech=0.0
        backch = ab172qb/35.
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 172 Zh->qqbb'
      endif

c Zh -> tau+tau- qqbar at 172

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 172 Zh->ttqq'
        ratech = flumal(4)*braal(4)*xs172*
     >           a_ch_cor(4)*effic_aleph(mh,2,4)
        if (ratech.lt.0.0) ratech=0.0
        res1ch = 2.
        backch = ab172tq/35.
        call aghist(mh,res1ch,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 172 Zh->ttqq'
      endif

c Zh -> qqbar tau+tau- at 172

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 172 Zh->qqtt'
        ratech = flumal(5)*braal(5)*xs172*
     >           a_ch_cor(5)*effic_aleph(mh,2,5)
        if (ratech.lt.0.0) ratech=0.0
        res1ch = 2.
        backch = ab172qt/35.
        call aghist(mh,res1ch,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 172 Zh->qqtt'
      endif

c ALEPH 161 GeV channels
c llqq

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 161 Zh->llqq'
        ratech = flumal(6)*braal(6)*xs161*
     >           a_ch_cor(6)*effic_aleph(mh,1,2)
        ratech = ratech*(1.+0.5*xs161e/xs161/z0toee)
        if (ratech.lt.0.0) ratech=0.0
        res1ch = 2.
        backch = ab161lq/35.
        call aghist(mh,res1ch,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 161 Zh->llqq'
      endif

c Zh -> nunubar qqbar at 161 -- histogram + constant

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 161 Zh->nunuqq'
        if (init) then
          histfile(1) = 'a_161_hnn_45.dat'
          histfile(2) = 'a_161_hnn_50.dat'
          histfile(3) = 'a_161_hnn_55.dat'
          histfile(4) = 'a_161_hnn_60.dat'
          histfile(5) = 'a_161_hnn_65.dat'
          histfile(6) = 'a_161_hnn_70.dat'
          histfile(7) = 'a_161_hnn_75.dat'
          histfile(8) = 'a_161_hnn_80.dat'
          do i=1,8
            call ahistread1(histfile(i),nchan)
          enddo
        endif
        ratech = flumal(7)*braal(7)*xs161*
     >           a_ch_cor(7)*effic_aleph(mh,1,1)
        if (ratech.lt.0.0) ratech=0.0
        backch = ab161nq/35.
        call asinterp1(nchan,mh,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 161 Zh->nunuqq'
      endif

c Zh -> qqbar bbbar at 161

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 161 Zh->qqbb'
        if (init) then
          histfile(1) = 'a_161_hqq_45.dat'
          histfile(2) = 'a_161_hqq_50.dat'
          histfile(3) = 'a_161_hqq_55.dat'
          histfile(4) = 'a_161_hqq_60.dat'
          histfile(5) = 'a_161_hqq_65.dat'
          histfile(6) = 'a_161_hqq_70.dat'
          histfile(7) = 'a_161_hqq_75.dat'
          histfile(8) = 'a_161_hqq_80.dat'
          do i=1,8
            call ahistread1(histfile(i),nchan)
          enddo
        endif
        ratech = flumal(8)*braal(8)*xs161*
     >           a_ch_cor(8)*effic_aleph(mh,1,3)
        if (ratech.lt.0.0) ratech=0.0
        backch = ab161qb/35.
        call asinterp1(nchan,mh,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 161 Zh->qqbb'
      endif

c Zh -> tau+tau- qqbar at 161

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 161 Zh->ttqq'
        ratech = flumal(9)*braal(9)*xs161*
     >           a_ch_cor(9)*effic_aleph(mh,1,4)
        if (ratech.lt.0.0) ratech=0.0
        res1ch = 2.
        backch = ab161tq/35.
        call aghist(mh,res1ch,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 161 Zh->ttqq'
      endif

c Zh -> qqbar tau+tau- at 161

      switch = .false.
      dosyst = .false.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1
        channame(nchan) = 'ALEPH 161 Zh->qqtt'
        ratech = flumal(10)*braal(10)*xs161*
     >           a_ch_cor(10)*effic_aleph(mh,1,5)
        if (ratech.lt.0.0) ratech=0.0
        res1ch = 2.
        backch = ab161qt/35.
        call aghist(mh,res1ch,nbinsint,xl,xh,sighist)
        call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
        call abhcreate0(xl,xh,nbinsint,backch,backw(nbins+1))
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      elseif (xtest18x) then 
         write (6,*) ' --> Switched OFF: '//'ALEPH 161 Zh->qqtt'
      endif

c---------------
c 183 Channels
c---------------
c Zh -> qqbb -- three analyses

      switch = .false.
      dosyst = .true.
      subbg = .false.
      if (switch) then
         do iana=1,3
c
c iana= 1 (C.NN overlap), 2 (NN excl.), 3 (C excl.)
c
            nchan = nchan + 1 
            channame(nchan) = 'ALEPH 183 Zh -> qqbb'
            xlzh = xhz(14)*57.0
            xdouble = mh
            ratech = a183_hqq_eff(xdouble,iana)*z0toh*xlzh*
     >           (Abhhad)*bhbb/Abhbb
        if (xtest18x) write (6,*) '>> ',channame(nchan)(1:20),ratech
            if (ratech.lt.0.0) ratech=0.0
            nbinsint = 60
            call abhcreate2(35.,91.8,nbinsint,a183_hqq_mass_bkg,
     >           a183_hqq_bkg,
     >           iana,backw(nbins+1))
            call ascreate2(35.,91.8,nbinsint,a183_hqq_mass_sig,
     >           mh,iana,sighist)
            call ahistscal1(nbinsint,sighist,sig(nbins+1),ratech)
            nacand = A183_HQQ_NUMCAND(iana)
            do i=1,nacand
               candmass = A183_HQQ_MASS_CAND(iana,i)
               if (xtest18x) then
                  if (i.eq.1) write (6,*) channame(nchan),iana
                  write (6,*) 'Candidate #',i,candmass
               end if
               call abin1(candmass,35.,91.8,
     >              nbinsint,ibin)
               if (ibin.gt.0.and.ibin.le.nbinsint) then
                  ncand(nbins+ibin) = ncand(nbins+ibin) + 1
               endif 
            enddo               ! iana
            if (.not.subbg) then
               call vzero(backg(nbins+1),nbinsint)
            elseif (dosyst) then
               call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
            else
               call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
            endif
            ifirst(nchan) = nbins + 1
            nbins = nbins + nbinsint
         enddo
      endif                     ! switch
          
c Zh -> nnall -- Three two-dimensional analyses!  (Yikes!)
c reuse OPAL tools wherever possible

      switch = .false.
      dosyst = .true.
      subbg = .false.
      if (switch) then
        do iana=1,3
          nchan = nchan + 1 
          channame(nchan) = 'ALEPH 183 Zh -> nn h'
          xlzh = xhz(14)*57.0
          xlww = xhnunu(14)*57.0
          xdouble = mh
c
c          ratech = a183_hnn_wwf_eff(xdouble,iana)* ! wrong !
c     >             (bhbb+bhcc+bhss+bhglgl)*
c     >             (z0tonn*xlzh + xlww)/100.0
          ratech = a183_hnn_eff(xdouble,iana)* 
c     >             (bhbb+bhcc+bhss+bhglgl)* ! All decays included...
     >             (z0tonn*xlzh + xlww)*bhbb/Abhbb
        if (xtest18x) write (6,*) '>> ',channame(nchan)(1:20),ratech
          if (ratech.lt.0.0) ratech=0.0
          xl1 = 35.
          xu1 = 91.5
          xl2 = 0.983
          xu2 = 1.000
          if (iana.eq.3) then
            xl2 = 1.63
            xu2 = 2.00
          endif
c save for background normalization
          nbinsint1 = 60
          nbinsint2 = 70
          nbinsint  = 100
          call a2dzero1(nbinsint1,nbinsint2,sighist2d)
          call ascreate2(xl1,xu1,nbinsint1,a183_hnn_mass_sig,
     >                   mh,iana,sighist1)
          call ascreate2(xl2,xu2,nbinsint2,a183_hnn_btag_sig,
     >                   mh,iana,sighist2)
c Add together into 2D histogram.
          call a2dadd1(nbinsint1,nbinsint2,ratech,
     >                 sighist1,sighist2,sighist2d)

          call a2dzero1(nbinsint1,nbinsint2,bkghist2d)

          call abhcreate2(xl1,xu1,nbinsint1,a183_hnn_mass_bkg,
     >                    a183_hnn_bkg,iana,backhist1)
          call abhcreate2(xl2,xu2,nbinsint2,a183_hnn_btag_bkg,
     >                    a183_hnn_bkg,iana,backhist2)
          bkglevel = a183_hnn_bkg(iana)
          call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                 backhist1,backhist2,bkghist2d)

          call a2dzero2(nbinsint1,nbinsint2,candhist2d)
          nacand = A183_HNN_NUMCAND(iana)
          do i=1,nacand
            candmass = A183_HNN_MASS_CAND(iana,i)
            candbtag = A183_HNN_BTAG_CAND(iana,i)
            call abin1(candmass,xl1,xu1,
     >                 nbinsint1,ibin1)
            call abin1(candbtag,xl2,xu2,
     >                 nbinsint2,ibin2)
          if (ibin1.gt.0 .AND. ibin2.gt.0 .AND. 
     +        ibin1.le.nbinsint1 .AND. ibin2.le.nbinsint2)
     +           candhist2d(ibin1,ibin2) = candhist2d(ibin1,ibin2)+1
          enddo

          call arebin3(nbinsint1,nbinsint2,
     >                 sighist2d,bkghist2d,candhist2d,
     >                 nbinsint,
     >                 sig(nbins+1),backw(nbins+1),ncand(nbins+1))

          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
            call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
          else
            call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
          endif
          ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
        enddo
      endif

c Zh -> llall (ll -- ee or mumu) one 2D analysis

      switch = .false.
      dosyst = .true.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1 
        channame(nchan) = 'ALEPH 183 Zh -> ll h'
        xlzh = xhz(14)*57.0
        xlee = xhee(14)*57.0
        xdouble = mh
c 
        ratech = a183_hll_eff(xdouble)*
     >           ((z0toee+z0tomumu)*xlzh + xlee)*bhbb/Abhbb
c     >           *(bhbb+bhcc+bhss+bhglgl) ! all decay modes
        if (xtest18x) write (6,*) '>> ',channame(nchan)(1:20),ratech
        if (ratech.lt.0.0) ratech=0.0
        xl1 = 65.
        xu1 = 130.
        xl2 = 0.0
        xu2 = 2.0
        nbinsint1 = 100
        nbinsint2 = 100
        nbinsint  = 100
        call a2dzero1(nbinsint1,nbinsint2,sighist2d)
        call ascreate3(xl1,xu1,nbinsint1,a183_hll_mass_sig,
     >                 mh,sighist1)
        call ascreate3(xl2,xu2,nbinsint2,a183_hll_btag_sig,
     >                 mh,sighist2)

c Add together into 2D histogram.
        call a2dadd1(nbinsint1,nbinsint2,ratech,
     >               sighist1,sighist2,sighist2d)
        call a2dzero1(nbinsint1,nbinsint2,bkghist2d)

        call abhcreate5(xl1,xu1,nbinsint1,a183_hll_mass_bkg,
     >                  a183_hll_bkg,backhist1)
        call abhcreate5(xl2,xu2,nbinsint2,a183_hll_btag_bkg,
     >                  a183_hll_bkg,backhist2)
        bkglevel = a183_hll_bkg()
        call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >               backhist1,backhist2,bkghist2d)

        call a2dzero2(nbinsint1,nbinsint2,candhist2d)
        nacand = A183_HLL_NUMCAND()
        do i=1,nacand
          candmass = A183_Hll_MASS_CAND(i)
          candbtag = A183_Hll_BTAG_CAND(i)
          call abin1(candmass,xl1,xu1,
     >               nbinsint1,ibin1)
          call abin1(candbtag,xl2,xu2,
     >               nbinsint2,ibin2)
          if (ibin1.gt.0 .AND. ibin2.gt.0 .AND. 
     +        ibin1.le.nbinsint1 .AND. ibin2.le.nbinsint2)
     +         candhist2d(ibin1,ibin2) = candhist2d(ibin1,ibin2)+1
        enddo

        call arebin3(nbinsint1,nbinsint2,
     >               sighist2d,bkghist2d,candhist2d,
     >               nbinsint,
     >               sig(nbins+1),backw(nbins+1),ncand(nbins+1))

        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
        ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      endif

c Zh -> ttall -- one 1D analysis

      switch = .false.
      dosyst = .true.
      subbg = .false.

      if (switch) then
        nchan = nchan + 1 
        channame(nchan) = 'ALEPH 183 Zh -> tt h'
        xl1 = 50.
        xu1 = 102.
        nbinsint1 = 80
        if (mh.lt.60. .or. mh.gt.100.) goto 2061
        xlzh = xhz(14)*57.0
        xdouble = mh
        ratech = a183_htt_eff(xdouble)*z0totata*xlzh*bhbb/Abhbb
c     >           *(bhbb+bhcc+bhss+bhglgl) ! all decay modes
        if (xtest18x) write (6,*) '>> ',channame(nchan)(1:20),ratech
        if (ratech.lt.0.0) ratech=0.0

        call ascreate3(xl1,xu1,nbinsint1,
     >                 A183_HTT_MASS_SIG,mh,sighist)
        call ahistscal1(nbinsint1,sighist,sig(nbins+1),ratech)
        call abhcreate5(xl1,xu1,nbinsint1,
     >                  A183_HTT_MASS_BKG,
     >                  A183_HTT_BKG,backw(nbins+1))
        nacand = A183_HTT_NUMCAND()
        do i=1,nacand
          candmass = A183_HTT_MASS_CAND(i)
          call abin1(candmass,xl1,xu1,
     >               nbinsint1,ibin)
          if (ibin.gt.0.and.ibin.le.nbinsint1) then
            ncand(nbins+ibin) = ncand(nbins+ibin) + 1
          endif
        enddo
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint1)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint1)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint1)
        endif
 2061   ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint1
      endif                     ! switch

c Zh -> qqtt 
      switch = .false.
      dosyst = .true.
      subbg = .false.
cptd      if (switch.and.mh.gt.60. .and. mh.lt.100.) then
      if (switch) then
        nchan = nchan + 1 
        channame(nchan) = 'ALEPH 183 Zh -> qqtt'
        xl1 = 50.
        xu1 = 102.
        nbinsint1 = 80
        if (mh.lt.60. .or. mh.gt.100.) goto 2062
        xlzh = xhz(14)*57.0
        xdouble = mh
        ratech = a183_ttqq_eff(xdouble)*bhtata*xlzh*
     >           (z0toh)
        if (xtest18x) write (6,*) '>> ',channame(nchan)(1:20),ratech
        if (ratech.lt.0.0) ratech=0.0

        call ascreate3(xl1,xu1,nbinsint1,
     >                 A183_TTQQ_MASS_SIG,mh,sighist)
        call ahistscal1(nbinsint1,sighist,sig(nbins+1),ratech)
        call abhcreate5(xl1,xu1,nbinsint1,
     >                  A183_TTQQ_MASS_BKG,
     >                  A183_TTQQ_BKG,backw(nbins+1))
        nacand = A183_TTQQ_NUMCAND()
        do i=1,nacand
          candmass = A183_TTQQ_MASS_CAND(i)
          call abin1(candmass,xl1,xu1,
     >               nbinsint1,ibin)
          if (ibin.gt.0.and.ibin.le.nbinsint1) then
            ncand(nbins+ibin) = ncand(nbins+ibin) + 1
          endif
        enddo
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint1)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint1)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint1)
        endif
 2062   ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint1
      endif                     ! switch


c hA to bbbb -- only the mass sum is reconstructed
c use btag info in the second dimension I assume the mass sum
c is consistently used throughout for this.

      switch = .false.
      dosyst = .true.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1 
        channame(nchan) = 'ALEPH 183 Ah -> bbbb'
        xl1 = 70.
        xu1 = 183.
        xl2 = -100.
        xu2 = 67.
        nbinsint1 = 100
        nbinsint2 = 100
        nbinsint  = 100
        if ((mh+mapole).gt.180. .OR. (mh+mapole).lt.0.) goto 2001
        xlah = xha(14)*57.0
        xdouble = mh
        ydouble = mapole
        ratech = a183_habbbb_eff(xdouble,ydouble)*bhbb*babb*xlah
        if (xtest18x) write (6,*) '>> ',channame(nchan)(1:20),ratech
        if (ratech.lt.0.0) ratech=0.0

        call a2dzero1(nbinsint1,nbinsint2,sighist2d)
        call ascreate4(xl1,xu1,nbinsint1,a183_habbbb_mass_sig,
     >                 (mh+mapole)/2.0,sighist1)
        call ascreate5(xl2,xu2,nbinsint2,a183_habbbb_btag_sig,
     >                 sighist2)
c Add together into 2D histogram.
        call a2dadd1(nbinsint1,nbinsint2,ratech,
     >               sighist1,sighist2,sighist2d)
        if (xtest18x) then
           aux(1) = 0.0
           do i=1,nbinsint1
              do j=1,nbinsint2
                 aux(1) = aux(1) + sighist2d(i,j)
              end do
           end do
           write (6,*) 'hA 183 bbbb SIG:',aux(1)
        end if                  ! xtest18x

        call a2dzero1(nbinsint1,nbinsint2,bkghist2d)
        call abhcreate5(xl1,xu1,nbinsint1,a183_habbbb_mass_bkg,
     >                  a183_habbbb_bkg,backhist1)
        call abhcreate5(xl2,xu2,nbinsint2,a183_habbbb_btag_bkg,
     >                  a183_habbbb_bkg,backhist2)
        bkglevel = a183_habbbb_bkg()
        if (xtest18x) then
           write (6,*) 'bkglevel=',bkglevel
           aux(1) = 0.0
           do i=1,nbinsint1
                 aux(1) = aux(1) + backhist1(i)
           end do
           write (6,*) 'hA 183 bbbb Bbackhist1:',aux(1)
           aux(1) = 0.0
           do i=1,nbinsint2
                 aux(1) = aux(1) + backhist2(i)
           end do
           write (6,*) 'hA 183 bbbb Bbackhist2:',aux(1)
        end if                  ! xtest18x
        call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >               backhist1,backhist2,bkghist2d)

        if (xtest18x) then
           write (6,*) 'bkglevel=',bkglevel
           aux(1) = 0.0
           do i=1,nbinsint1
              do j=1,nbinsint2
                 aux(1) = aux(1) + bkghist2d(i,j)
              end do
           end do
           write (6,*) 'hA 183 bbbb BKG:',aux(1)
        end if                  ! xtest18x
        call a2dzero2(nbinsint1,nbinsint2,candhist2d)
        nacand = A183_HABBBB_NUMCAND()
        do i=1,nacand
          candmass = A183_HABBBB_MASS_CAND(i)
          candbtag = A183_HABBBB_BTAG_CAND(i)
          call abin1(candmass,xl1,xu1,
     >               nbinsint1,ibin1)
          call abin1(candbtag,xl2,xu2,
     >               nbinsint2,ibin2)
          if (ibin1.gt.0 .AND. ibin2.gt.0 .AND. 
     +        ibin1.le.nbinsint1 .AND. ibin2.le.nbinsint2)
     +         candhist2d(ibin1,ibin2) = candhist2d(ibin1,ibin2)+1
        enddo

        call arebin3(nbinsint1,nbinsint2,
     >               sighist2d,bkghist2d,candhist2d,
     >               nbinsint,
     >               sig(nbins+1),backw(nbins+1),ncand(nbins+1))


        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
        endif
 2001   ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint
      endif

c Ah --> ttbb -- this one uses the average mass of h and A.
c this one only works if the average of mh and mapole is bigger than 60.
c (otherwise get "this cannot be happening to me!" from the mass resolution
c function.

      switch = .false.
      dosyst = .true.
      subbg = .false.
      if (switch) then
        nchan = nchan + 1 
        channame(nchan) = 'ALEPH 183 Ah -> ttbb'
        xl1 = 50.
        xu1 = 92.
        nbinsint1 = 80
        if ((mh+mapole).gt.180. .OR. (mh+mapole).lt.120.) goto 2010
        xlah = xha(14)*57.0
c ack -- this efficiency is in percent -- better divide by 100.
        ratech = a183_hattbb_eff(Dble(mh),Dble(mapole))/100.0*
     >           (bhtata*babb/AMSSMbabb+bhbb*batata/AMSSMbhbb
     >       - bhtata*batata)*xlah
c     >           (bhtata*babb+bhbb*batata)*xlah
        if (xtest18x) write (6,*) '>> ',channame(nchan)(1:20),ratech
        if (ratech.lt.0.0) ratech=0.0

        call ascreate4(xl1,xu1,nbinsint1,
     >                 A183_HATTBB_MASS_SIG,(mh+mapole)/2.0,
     >                 sighist)
        call ahistscal1(nbinsint1,sighist,sig(nbins+1),ratech)
        call abhcreate5(xl1,xu1,nbinsint1,
     >                  A183_HATTBB_MASS_BKG,
     >                  A183_HATTBB_BKG,backw(nbins+1))
        nacand = A183_HATTBB_NUMCAND()
        do i=1,nacand
          candmass = A183_HATTBB_MASS_CAND(i)
          call abin1(candmass,xl1,xu1,
     >               nbinsint1,ibin)
          if (ibin.gt.0.and.ibin.le.nbinsint1) then
            ncand(nbins+ibin) = ncand(nbins+ibin) + 1
          endif
        enddo
        if (.not.subbg) then
          call vzero(backg(nbins+1),nbinsint1)
        elseif (dosyst) then
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint1)
        else
          call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint1)
        endif
 2010   ifirst(nchan) = nbins + 1
        nbins = nbins + nbinsint1
      endif
c
c 189 Channels 
c
c Four Jets -- three analyses

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do ichan = 1,4
          if (ichan.eq.1) iana = 1
          if (ichan.eq.2) iana = 1
          if (ichan.eq.3) iana = 2
          if (ichan.eq.4) iana = 3
          if ((ichan.eq.1).and.(iopt.eq.1)) then
            nchan = nchan + 1
            channame(nchan) = 'ALEPH 189 4b+4j overlap (opt 1)'
          else if ((ichan.eq.1).and.(iopt.eq.0)) then
            nchan = nchan + 1
            channame(nchan) = 'ALEPH 189 4b+4j overlap (automatic)'
          else if ((ichan.eq.2).and.(iopt.eq.2)) then
            nchan = nchan + 1
            channame(nchan) = 'ALEPH 189 4b+4j overlap (opt 2)'
          else if (ichan.eq.3) then
            nchan = nchan + 1
            channame(nchan) = 'ALEPH 189 4b only'
          else if (ichan.eq.4) then
            nchan = nchan + 1
            channame(nchan) = 'ALEPH 189 4j only'
          endif

          xlzh = xhz(15)*ah0_lumi(2)
          xlah = xha(15)*ah0_lumi(2)
          chanlumi(nchan) = ah0_lumi(2)

          xdouble = mh
          ydouble = mapole
          ratech = A189_4jet_eff(xdouble,iana,1)*z0toh*xlzh*
     >         Abhhad*bhbb/Abhbb
c     >             (bhbb+bhcc+bhss+bhglgl)
          if (xtest18x) write (6,*) '4 jets only / 189',ratech,Abhhad
          rate2ch= A189_4jet_eff((xdouble+ydouble)/2D0,iana,2)*
     >             bhbb*babb*xlah
          if (ratech.lt.0.0) ratech=0.0
          if (rate2ch.lt.0.0) rate2ch=0.0
c create binned shape info

          IF (ICHAN.EQ.1.and.iopt2.EQ.1) THEN
C hZ/hA 4 jets Overlap, Option 1 (using "hZ shapes": mH and NN)
            xl1 = 40.
            xu1 = 97.4
            xl2 = 0.951
            xu2 = 1.000
            nbinsint1 = 100
            nbinsint2 = 98
            nbinsint  = 100
            IF (CHANLUMI(NCHAN).EQ.0.0) GOTO 1891 ! NEXT CHANNEL

            nerrch(nchan) = 4
            sysname(1,nchan) = 'A189BT-B'
            sysname(2,nchan) = 'A189BT-LT'
            sysname(3,nchan) = 'A189-4J-OV-UNC-SIG'
            sysname(4,nchan) = 'A189-4J-OV-UNC-BKG'
            if ((ratech+rate2ch).ne.0.) then
              dsig(1,nchan) = sqrt( (ratech*0.04)**2 +
     >                              (rate2ch*0.04)**2 )/
     >                              (ratech+rate2ch)
              dsig(2,nchan) = 0.
              dsig(3,nchan) = sqrt( (ratech*0.04)**2 +
     >                              (rate2ch*0.02)**2 )/
     >                              (ratech+rate2ch)
              dsig(4,nchan) = 0.
            else
              dsig(1,nchan) = 0.
              dsig(2,nchan) = 0.
              dsig(3,nchan) = 0.
              dsig(4,nchan) = 0.
            endif
            dback(1,nchan) = 0.0
            dback(2,nchan) = 0.0
            dback(3,nchan) = 0.0
            dback(4,nchan) = 0.0

            call a2dzero1(nbinsint1,nbinsint2,sighist2d)

            call ascreate6(xl1,xu1,nbinsint1,A189_4jet_sig_mh,
     >                     mh,iana,1,sighist1)
            call ascreate6(xl2,xu2,nbinsint2,A189_4jet_sig_nn,
     >                     mh,iana,1,sighist2)
c Add together into 2D histogram.
            call a2dadd1(nbinsint1,nbinsint2,ratech,
     >                   sighist1,sighist2,sighist2d)

            call ascreate6(xl1,xu1,nbinsint1,A189_4jet_sig_mh,
     >                     (mh+mapole)/2.0,iana,2,sighist1)
            call ascreate6(xl2,xu2,nbinsint2,A189_4jet_sig_nn,
     >                     (mh+mapole)/2.0,iana,2,sighist2)

            call a2dadd1(nbinsint1,nbinsint2,rate2ch,
     >                   sighist1,sighist2,sighist2d)

            call a2dzero1(nbinsint1,nbinsint2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_mh,
     >                      a189_4jet_bkg,iana,1,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_nn,
     >                      a189_4jet_bkg,iana,1,backhist2)
            bkglevel = a189_4jet_bkg(iana,1)*176.2/175.5
            bkgtotal = bkglevel
            dback(2,nchan) = dback(2,nchan) +
     >                      (bkglevel*0.18)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.37)**2

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_mh,
     >                      a189_4jet_bkg,iana,2,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_nn,
     >                      a189_4jet_bkg,iana,2,backhist2)
            bkglevel = a189_4jet_bkg(iana,2)*176.2/175.5
            bkgtotal = bkgtotal + bkglevel
            dback(2,nchan) = dback(2,nchan) +
     >                      (bkglevel*1.00)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.57)**2

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_mh,
     >                      a189_4jet_bkg,iana,3,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_nn,
     >                      a189_4jet_bkg,iana,3,backhist2)
            bkglevel = a189_4jet_bkg(iana,3)*176.2/175.5
            bkgtotal = bkgtotal + bkglevel
            dback(1,nchan) = dback(1,nchan) +
     >                      (bkglevel*0.045)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.054)**2
            dback(1,nchan) = dback(1,nchan)/bkgtotal
            dback(2,nchan) = dback(2,nchan)/bkgtotal
            dback(4,nchan) = sqrt(dback(4,nchan))/bkgtotal

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call a2dzero2(nbinsint1,nbinsint2,candhist2d)
            nacand = A189_4jet_NUMCAND(iana)
            do i=1,nacand
              candmass = A189_4jet_MH_CAND(iana,i)
              candbtag = A189_4jet_NN_CAND(iana,i)


              call abin1(candmass,xl1,xu1,
     >                   nbinsint1,ibin1)
              call abin1(candbtag,xl2,xu2,
     >                   nbinsint2,ibin2)
              if (ibin1.gt.0 .AND. ibin2.gt.0 .AND. 
     +          ibin1.le.nbinsint1 .AND. ibin2.le.nbinsint2)
     +          candhist2d(ibin1,ibin2) = candhist2d(ibin1,ibin2)+1
            enddo

            call arebin3(nbinsint1,nbinsint2,
     >                   sighist2d,bkghist2d,candhist2d,
     >                   nbinsint,
     >                   sig(nbins+1),backw(nbins+1),ncand(nbins+1))

C hZ/hA 4 jets Overlap, Option 2 (using "hA shapes": Msum and b-tag)

          else if ((ichan.eq.2).and.(iopt2.eq.2)) then
            xl1 = 40.
            xu1 = 189.
            xl2 = -100.
            xu2 = 266.
            nbinsint1 = 100
            nbinsint2 = 100
            nbinsint  = 100
            IF (CHANLUMI(NCHAN).EQ.0.0) GOTO 1891 ! NEXT CHANNEL

            nerrch(nchan) = 4
            sysname(1,nchan) = 'A189BTAG-B'
            sysname(2,nchan) = 'A189BTAG-LT'
            sysname(3,nchan) = 'A189-4J-OV-UNC-SIG'
            sysname(4,nchan) = 'A189-4J-OV-UNC-BKG'
            if ((ratech+rate2ch).ne.0.) then
              dsig(1,nchan) = sqrt( (ratech*0.04)**2 +
     >                              (rate2ch*0.04)**2 )/
     >                              (ratech+rate2ch)
              dsig(2,nchan) = 0.
              dsig(3,nchan) = sqrt( (ratech*0.04)**2 +
     >                              (rate2ch*0.02)**2 )/
     >                              (ratech+rate2ch)
              dsig(4,nchan) = 0.
            else
              dsig(1,nchan) = 0.
              dsig(2,nchan) = 0.
              dsig(3,nchan) = 0.
              dsig(4,nchan) = 0.
            endif
            dback(1,nchan) = 0.0
            dback(2,nchan) = 0.0
            dback(3,nchan) = 0.0
            dback(4,nchan) = 0.0

            call a2dzero1(nbinsint1,nbinsint2,sighist2d)

            call ascreate6(xl1,xu1,nbinsint1,A189_4jet_sig_msum,
     >                     mh,iana,1,sighist1)
            call ascreate6(xl2,xu2,nbinsint2,A189_4jet_sig_fvar,
     >                     mh,iana,1,sighist2)

c Add together into 2D histogram.
            call a2dadd1(nbinsint1,nbinsint2,ratech,
     >                   sighist1,sighist2,sighist2d)

            call ascreate6(xl1,xu1,nbinsint1,A189_4jet_sig_msum,
     >                     (mh+mapole)/2.0,iana,2,sighist1)
            call ascreate6(xl2,xu2,nbinsint2,A189_4jet_sig_fvar,
     >                     (mh+mapole)/2.0,iana,2,sighist2)

            call a2dadd1(nbinsint1,nbinsint2,rate2ch,
     >                   sighist1,sighist2,sighist2d)

            call a2dzero1(nbinsint1,nbinsint2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_msum,
     >                      a189_4jet_bkg,iana,1,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_fvar,
     >                      a189_4jet_bkg,iana,1,backhist2)
            bkglevel = a189_4jet_bkg(iana,1)*176.2/175.5
            bkgtotal = bkglevel
            dback(2,nchan) = dback(2,nchan) +
     >                      (bkglevel*0.18)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.37)**2

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_msum,
     >                      a189_4jet_bkg,iana,2,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_fvar,
     >                      a189_4jet_bkg,iana,2,backhist2)
            bkglevel = a189_4jet_bkg(iana,2)*176.2/175.5
            bkgtotal = bkgtotal + bkglevel

            dback(2,nchan) = dback(2,nchan) +
     >                      (bkglevel*1.00)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.57)**2

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_msum,
     >                      a189_4jet_bkg,iana,3,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_fvar,
     >                      a189_4jet_bkg,iana,3,backhist2)
            bkglevel = a189_4jet_bkg(iana,3)*176.2/175.5
            bkgtotal = bkgtotal + bkglevel
            dback(1,nchan) = dback(1,nchan) +
     >                      (bkglevel*0.045)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.054)**2
            dback(1,nchan) = dback(1,nchan)/bkgtotal
            dback(2,nchan) = dback(2,nchan)/bkgtotal
            dback(4,nchan) = sqrt(dback(4,nchan))/bkgtotal

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call a2dzero2(nbinsint1,nbinsint2,candhist2d)
            nacand = A189_4jet_NUMCAND(iana)
            do i=1,nacand
              candmass = A189_4jet_MSUM_CAND(IANA,i)
              candbtag = A189_4jet_FVAR_CAND(IANA,i)
              call abin1(candmass,xl1,xu1,
     >                   nbinsint1,ibin1)
              call abin1(candbtag,xl2,xu2,
     >                   nbinsint2,ibin2)
              if (ibin1.gt.0 .AND. ibin2.gt.0 .AND. 
     +          ibin1.le.nbinsint1 .AND. ibin2.le.nbinsint2)
     +          candhist2d(ibin1,ibin2) = candhist2d(ibin1,ibin2)+1
            enddo

            call arebin3(nbinsint1,nbinsint2,
     >                   sighist2d,bkghist2d,candhist2d,
     >                   nbinsint,
     >                   sig(nbins+1),backw(nbins+1),ncand(nbins+1))

          ELSE IF (ICHAN.EQ.3) THEN 
            xl1 = 40.
            xu1 = 189.
            xl2 = -100.
            xu2 = 266.
            nbinsint1 = 100
            nbinsint2 = 100
            nbinsint  = 100
            IF (CHANLUMI(NCHAN).EQ.0.0) GOTO 1891 ! NEXT CHANNEL

            nerrch(nchan) = 4
            sysname(1,nchan) = 'A189BTAG-B'
            sysname(2,nchan) = 'A189BTAG-LT'
            sysname(3,nchan) = 'A189-4J-HA-UNC-SIG'
            sysname(4,nchan) = 'A189-4J-HA-UNC-BKG'
            if ((ratech+rate2ch).ne.0.) then
              dsig(1,nchan) = sqrt( (ratech*0.04)**2 +
     >                              (rate2ch*0.04)**2 )/
     >                              (ratech+rate2ch)
              dsig(2,nchan) = 0.
              dsig(3,nchan) = sqrt( (ratech*0.14)**2 +
     >                              (rate2ch*0.03)**2 )/
     >                              (ratech+rate2ch)
              dsig(4,nchan) = 0.
            else
              dsig(1,nchan) = 0.
              dsig(2,nchan) = 0.
              dsig(3,nchan) = 0.
              dsig(4,nchan) = 0.
            endif
            dback(1,nchan) = 0.0
            dback(2,nchan) = 0.0
            dback(3,nchan) = 0.0
            dback(4,nchan) = 0.0

            call a2dzero1(nbinsint1,nbinsint2,sighist2d)

            call ascreate6(xl1,xu1,nbinsint1,A189_4jet_sig_msum,
     >                     mh,iana,1,sighist1)
            call ascreate6(xl2,xu2,nbinsint2,A189_4jet_sig_fvar,
     >                     mh,iana,1,sighist2)

c Add together into 2D histogram.
            call a2dadd1(nbinsint1,nbinsint2,ratech,
     >                   sighist1,sighist2,sighist2d)

            call ascreate6(xl1,xu1,nbinsint1,A189_4jet_sig_msum,
     >                     (mh+mapole)/2.0,iana,2,sighist1)
            call ascreate6(xl2,xu2,nbinsint2,A189_4jet_sig_fvar,
     >                     (mh+mapole)/2.0,iana,2,sighist2)

            call a2dadd1(nbinsint1,nbinsint2,rate2ch,
     >                   sighist1,sighist2,sighist2d)

            call a2dzero1(nbinsint1,nbinsint2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_msum,
     >                      a189_4jet_bkg,iana,1,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_fvar,
     >                      a189_4jet_bkg,iana,1,backhist2)
            bkglevel = a189_4jet_bkg(iana,1)*176.2/175.5
            bkgtotal = bkglevel
            dback(2,nchan) = dback(2,nchan) +
     >                      (bkglevel*0.18)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.41)**2

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_msum,
     >                      a189_4jet_bkg,iana,2,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_fvar,
     >                      a189_4jet_bkg,iana,2,backhist2)
            bkglevel = a189_4jet_bkg(iana,2)*176.2/175.5
            bkgtotal = bkgtotal + bkglevel
            dback(2,nchan) = dback(2,nchan) +
     >                      (bkglevel*1.00)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.57)**2

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_msum,
     >                      a189_4jet_bkg,iana,3,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_fvar,
     >                      a189_4jet_bkg,iana,3,backhist2)
            bkglevel = a189_4jet_bkg(iana,3)*176.2/175.5
            bkgtotal = bkgtotal + bkglevel
            dback(1,nchan) = dback(1,nchan) +
     >                      (bkglevel*0.045)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.13)**2

            dback(1,nchan) = dback(1,nchan)/bkgtotal
            dback(2,nchan) = dback(2,nchan)/bkgtotal
            dback(4,nchan) = sqrt(dback(4,nchan))/bkgtotal

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call a2dzero2(nbinsint1,nbinsint2,candhist2d)
            nacand = A189_4jet_NUMCAND(iana)
            do i=1,nacand
              candmass = A189_4jet_MSUM_CAND(IANA,i)
              candbtag = A189_4jet_FVAR_CAND(IANA,i)
              call abin1(candmass,xl1,xu1,
     >                   nbinsint1,ibin1)
              call abin1(candbtag,xl2,xu2,
     >                   nbinsint2,ibin2)
          if (ibin1.gt.0 .AND. ibin2.gt.0 .AND. 
     +        ibin1.le.nbinsint1 .AND. ibin2.le.nbinsint2)
     +             candhist2d(ibin1,ibin2) = candhist2d(ibin1,ibin2)+1
            enddo

            call arebin3(nbinsint1,nbinsint2,
     >                   sighist2d,bkghist2d,candhist2d,
     >                   nbinsint,
     >                   sig(nbins+1),backw(nbins+1),ncand(nbins+1))

          ELSE IF (ICHAN.EQ.4) THEN
            xl1 = 40.
            xu1 = 97.4
            xl2 = 0.951
            xu2 = 1.000
            nbinsint1 = 100
            nbinsint2 = 50
            nbinsint  = 100
            IF (CHANLUMI(NCHAN).EQ.0.0) GOTO 1891 ! NEXT CHANNEL

            nerrch(nchan) = 4
            sysname(1,nchan) = 'A189BTAG-B'
            sysname(2,nchan) = 'A189BTAG-LT'
            sysname(3,nchan) = 'A189-4J-HZ-UNC-SIG'
            sysname(4,nchan) = 'A189-4J-HZ-UNC-BKG'
            if ((ratech+rate2ch).ne.0.) then
              dsig(1,nchan) = sqrt( (ratech*0.03)**2 +
     >                              (rate2ch*0.03)**2 )/
     >                              (ratech+rate2ch)
              dsig(2,nchan) = 0.
              dsig(3,nchan) = sqrt( (ratech*0.02)**2 +
     >                              (rate2ch*0.03)**2 )/
     >                              (ratech+rate2ch)
              dsig(4,nchan) = 0.
            else
              dsig(1,nchan) = 0.
              dsig(2,nchan) = 0.
              dsig(3,nchan) = 0.
              dsig(4,nchan) = 0.
            endif
            dback(1,nchan) = 0.0
            dback(2,nchan) = 0.0
            dback(3,nchan) = 0.0
            dback(4,nchan) = 0.0

            call a2dzero1(nbinsint1,nbinsint2,sighist2d)

            call ascreate6(xl1,xu1,nbinsint1,A189_4jet_sig_mh,
     >                     mh,iana,1,sighist1)
            call ascreate6(xl2,xu2,nbinsint2,A189_4jet_sig_nn,
     >                     mh,iana,1,sighist2)

c Add together into 2D histogram.
            call a2dadd1(nbinsint1,nbinsint2,ratech,
     >                   sighist1,sighist2,sighist2d)

            call ascreate6(xl1,xu1,nbinsint1,A189_4jet_sig_mh,
     >                     (mh+mapole)/2.0,iana,2,sighist1)
            call ascreate6(xl2,xu2,nbinsint2,A189_4jet_sig_nn,
     >                     (mh+mapole)/2.0,iana,2,sighist2)

            call a2dadd1(nbinsint1,nbinsint2,rate2ch,
     >                   sighist1,sighist2,sighist2d)

            call a2dzero1(nbinsint1,nbinsint2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_mh,
     >                      a189_4jet_bkg,iana,1,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_nn,
     >                      a189_4jet_bkg,iana,1,backhist2)
            bkglevel = a189_4jet_bkg(iana,1)*176.2/175.5
            bkgtotal = bkglevel

            dback(2,nchan) = dback(2,nchan) +
     >                      (bkglevel*0.10)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.18)**2

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_mh,
     >                      a189_4jet_bkg,iana,2,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_nn,
     >                      a189_4jet_bkg,iana,2,backhist2)
            bkglevel = a189_4jet_bkg(iana,2)*176.2/175.5
            bkgtotal = bkgtotal + bkglevel
            dback(2,nchan) = dback(2,nchan) +
     >                      (bkglevel*0.10)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.11)**2

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call abhcreate7(xl1,xu1,nbinsint1,a189_4jet_bkg_mh,
     >                      a189_4jet_bkg,iana,3,backhist1)
            call abhcreate7(xl2,xu2,nbinsint1,a189_4jet_bkg_nn,
     >                      a189_4jet_bkg,iana,3,backhist2)
            bkglevel = a189_4jet_bkg(iana,3)*176.2/175.5
            bkgtotal = bkgtotal + bkglevel
            dback(1,nchan) = dback(1,nchan) +
     >                      (bkglevel*0.03)
            dback(4,nchan) = dback(4,nchan) +
     >                      (bkglevel*0.036)**2

            dback(1,nchan) = dback(1,nchan)/bkgtotal
            dback(2,nchan) = dback(2,nchan)/bkgtotal
            dback(4,nchan) = sqrt(dback(4,nchan))/bkgtotal

            call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                   backhist1,backhist2,bkghist2d)

            call a2dzero2(nbinsint1,nbinsint2,candhist2d)
            nacand = A189_4jet_NUMCAND(iana)
            do i=1,nacand
              candmass = A189_4jet_MH_CAND(IANA,i)
              candbtag = A189_4jet_NN_CAND(IANA,i)
              call abin1(candmass,xl1,xu1,
     >             nbinsint1,ibin1)
              call abin1(candbtag,xl2,xu2,
     >             nbinsint2,ibin2)
              if (ibin1.gt.0 .AND. ibin2.gt.0 .AND. 
     +             ibin1.le.nbinsint1 .AND. ibin2.le.nbinsint2)
     +             candhist2d(ibin1,ibin2) = candhist2d(ibin1,ibin2)+1
           enddo

           call arebin3(nbinsint1,nbinsint2,
     >                   sighist2d,bkghist2d,candhist2d,
     >                   nbinsint,
     >                   sig(nbins+1),backw(nbins+1),ncand(nbins+1))

         ELSE ! Should  not do anything for this ICHAN / IANA combination
              GOTO 235
         ENDIF                  ! IANA

c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
            call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
          else
            call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
          endif
 1891     ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
 235   enddo                    ! ICHAN
      endif

c Missing Energy -- three analyses

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
         do iana=1,3
            nchan = nchan + 1 
            if (iana.eq.1) then
               channame(nchan) = 'ALEPH 189 Hnn overlap'
            else if (iana.eq.2) then
               channame(nchan) = 'ALEPH 189 Hnn Wis only'
            else if (iana.eq.3) then
               channame(nchan) = 'ALEPH 189 Hnn Ors only'
            endif
            
            xlzh = xhz(15)*ah0_lumi(2)
            xlww = xhnunu(15)*ah0_lumi(2)
            chanlumi(nchan) = ah0_lumi(2)
            
            xdouble = mh
            ratech = z0tonn*xlzh*
     >           (A189_HNN_EFF(xdouble,iana,1)*bhbb +
     >           A189_HNN_EFF(xdouble,iana,2)*bhtata +
     >           A189_HNN_EFF(xdouble,iana,3)*bhcc +
     >           A189_HNN_EFF(xdouble,iana,4)*bhglgl)
            ratech = ratech +
     >           xlww*
c     >           (xlww+xint_hnn_wwf )*!!!!! Add intfc term here !!!!!!!!
     >           (A189_HNN_WWF_EFF(xdouble,iana,1)*bhbb +
     >           A189_HNN_WWF_EFF(xdouble,iana,2)*bhtata +
     >           A189_HNN_WWF_EFF(xdouble,iana,3)*bhcc +
     >           A189_HNN_WWF_EFF(xdouble,iana,4)*bhglgl)
            if (xtest18x) then
               write (6,*) 'HNN 189 effs:'
               write (6,*) (A189_HNN_EFF(xdouble,iana,1))
               write (6,*) (A189_HNN_EFF(xdouble,iana,2))
               write (6,*) (A189_HNN_EFF(xdouble,iana,3))
               write (6,*) (A189_HNN_EFF(xdouble,iana,4))
               write (6,*) bhbb,bhtata,bhcc,bhglgl,
     +              (bhbb+bhtata+bhcc+bhglgl)
            end if
            if (ratech.lt.0.0) ratech=0.0
c     create binned shape info
            xl1 = 50.
            xu1 = 97.4
            nbinsint = 100
            IF (CHANLUMI(NCHAN).EQ.0.0) GOTO 1892 ! NEXT CHANNEL

            nerrch(nchan) = 4
            sysname(1,nchan) = 'A189BTAG-B'
            sysname(2,nchan) = 'A189BTAG-LT'
            if (iana.eq.1) then
              sysname(3,nchan) = 'A189-NN-OV-UNC-SIG'
              sysname(4,nchan) = 'A189-NN-OV-UNC-BKG'
              if (ratech.ne.0.) then
                dsig(1,nchan) = (ratech*0.025)/ratech
                dsig(2,nchan) = 0.
                dsig(3,nchan) = (ratech*0.035)/ratech
                dsig(4,nchan) = 0.
              else
                dsig(1,nchan) = 0.
                dsig(2,nchan) = 0.
                dsig(3,nchan) = 0.
                dsig(4,nchan) = 0.
              endif
              dback(1,nchan) = 
     >                    (A189_HNN_BKG(iana,3)*0.065)/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
              dback(2,nchan) = 
     >                   ((A189_HNN_BKG(iana,1)*0.151 +
     >                     A189_HNN_BKG(iana,2)*0.091))/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
              dback(3,nchan) = 0.
              dback(4,nchan) = sqrt(
     >                    (A189_HNN_BKG(iana,1)*0.430)**2 +
     >                    (A189_HNN_BKG(iana,2)*0.480)**2 +
     >                    (A189_HNN_BKG(iana,3)*0.063)**2 )/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
            else if (iana.eq.2) then
              sysname(3,nchan) = 'A189-NN-WI-UNC-SIG'
              sysname(4,nchan) = 'A189-NN-WI-UNC-BKG'
              if (ratech.ne.0.) then
                dsig(1,nchan) = (ratech*0.022)/ratech
                dsig(2,nchan) = 0.
                dsig(3,nchan) = (ratech*0.090)/ratech
                dsig(4,nchan) = 0.
              else
                dsig(1,nchan) = 0.
                dsig(2,nchan) = 0.
                dsig(3,nchan) = 0.
                dsig(4,nchan) = 0.
              endif
              dback(1,nchan) = 
     >                    (A189_HNN_BKG(iana,3)*0.032)/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
              dback(2,nchan) = 
     >                   ((A189_HNN_BKG(iana,1)*0.079 +
     >                     A189_HNN_BKG(iana,2)*0.141))/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
              dback(3,nchan) = 0.
              dback(4,nchan) = sqrt(
     >                    (A189_HNN_BKG(iana,1)*1.200)**2 +
     >                    (A189_HNN_BKG(iana,2)*0.300)**2 +
     >                    (A189_HNN_BKG(iana,3)*0.123)**2 )/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
            else if (iana.eq.3) then
              sysname(3,nchan) = 'A189-NN-OR-UNC-SIG'
              sysname(4,nchan) = 'A189-NN-OR-UNC-BKG'
              if (ratech.ne.0.) then
                dsig(1,nchan) = (ratech*0.020)/ratech
                dsig(2,nchan) = 0.
                dsig(3,nchan) = (ratech*0.045)/ratech
                dsig(4,nchan) = 0.
              else
                dsig(1,nchan) = 0.
                dsig(2,nchan) = 0.
                dsig(3,nchan) = 0.
                dsig(4,nchan) = 0.
              endif
              dback(1,nchan) = 
     >                    (A189_HNN_BKG(iana,3)*0.032)/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
              dback(2,nchan) = 
     >                   ((A189_HNN_BKG(iana,1)*0.060 +
     >                     A189_HNN_BKG(iana,2)*0.091))/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
              dback(3,nchan) = 0.
              dback(4,nchan) = sqrt(
     >                    (A189_HNN_BKG(iana,1)*0.290)**2 +
     >                    (A189_HNN_BKG(iana,2)*0.380)**2 +
     >                    (A189_HNN_BKG(iana,3)*0.070)**2 )/
     >                    (A189_HNN_BKG(iana,1)+
     >                     A189_HNN_BKG(iana,2)+
     >                     A189_HNN_BKG(iana,3))
            endif

            call ascreate2(xl1,xu1,nbinsint,A189_HNN_MASS_SIG,
     >           mh,iana,sighist)
            call ahistscal1(nbinsint,sighist,sig(nbins+1),
     >           ratech)
            
            call abhcreate7(xl1,xu1,nbinsint,
     >           A189_HNN_MASS_BKG,
     >           A189_HNN_BKG,iana,1,backqq)
            call abhcreate7(xl1,xu1,nbinsint,
     >           A189_HNN_MASS_BKG,
     >           A189_HNN_BKG,iana,2,backww)
            call abhcreate7(xl1,xu1,nbinsint,
     >           A189_HNN_MASS_BKG,
     >           A189_HNN_BKG,iana,3,backzz)
            call amerge3(nbinsint,backzz,backww,backqq,backw(nbins+1))

            do i = 1,nbinsint
              backw(nbins+i) = backw(nbins+i)*176.2/175.5
            enddo

            if (xtest18x) then
               call vzero(aux,10)
               do i=1,nbinsint
                  aux(1) = aux(1) + backqq(i)
                  aux(2) = aux(2) + backww(i)
                  aux(3) = aux(3) + backzz(i)
                  aux(4) = aux(4) + backw(nbins+i)
                  aux(5) = aux(5) + sig(nbins+i)
               end do
               write (6,*) 'Hnn 189 IANA, bkg(qq,ww,zz,tot), sig:',
     +              iana,(aux(i),i=1,5)
            end if              ! xtest18x
            
            nacand = A189_HNN_NUMCAND(iana)
            do i=1,nacand
               candmass = A189_HNN_MASS_CAND(iana,i)
               call abin1(candmass,xl1,xu1,
     >              nbinsint,ibin)
               if (ibin.gt.0.and.ibin.le.nbinsint) then
                  ncand(nbins+ibin) = ncand(nbins+ibin) + 1
               endif
            enddo
            
c     systematics
            if (.not.subbg) then
               call vzero(backg(nbins+1),nbinsint)
            elseif (dosyst) then
               call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
            else
               call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
            endif
 1892       ifirst(nchan) = nbins + 1
            nbins = nbins + nbinsint
         enddo                  ! (iana)
      endif                     ! (switch)

C Hll 189

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
         nchan = nchan + 1 
         channame(nchan) = 'ALEPH 189 Hll'
         
         xlzh = xhz(15)*ah0_lumi(2)
         xlzz = xhee(15)*ah0_lumi(2)
         chanlumi(nchan) = ah0_lumi(2)

         xdouble = mh
         ratech = xlzh*
     >        (A189_HLL_EFF(xdouble,1)*z0tomumu*bhbb/Abhbb +
     >        A189_HLL_EFF(xdouble,2)*z0toee*bhbb/Abhbb)
         ratech = ratech +
     >        xlzz*
     >        (A189_HLL_EFF(xdouble,3)*bhbb/Abhbb)
         if (ratech.lt.0.0) ratech=0.0


         nerrch(nchan) = 2
         sysname(1,nchan) = 'A189-LL-UNC-SIG'
         sysname(2,nchan) = 'A189-LL-UNC-BKG'
         if (ratech.ne.0.) then
           dsig(1,nchan) = (ratech*0.006)/ratech
           dsig(2,nchan) = 0.
         else
           dsig(1,nchan) = 0.
           dsig(2,nchan) = 0.
         endif
         dback(1,nchan) = 0.
         dback(2,nchan) = sqrt(
     >               (A189_HLL_BKG(1)*0.016)**2 +
     >               (A189_HLL_BKG(2)*0.075)**2 +
     >               (A189_HLL_BKG(3)*0.404)**2 )/
     >               (A189_HLL_BKG(1)+
     >                A189_HLL_BKG(2)+
     >                A189_HLL_BKG(3))

c     create binned shape info
         xl1 = 55.
         xu1 = 115.
         xl2 = 0.0
         xu2 = 2.0
c
         nbinsint1 = 100
         nbinsint2 = 100
         nbinsint  = 100
         IF (CHANLUMI(NCHAN).EQ.0.0) GOTO 1893 ! NEXT CHANNEL

         call a2dzero1(nbinsint1,nbinsint2,sighist2d)

         call ascreate3(xl1,xu1,nbinsint1,A189_HLL_MASS_SIG,
     >        mh,sighist1)
         call ascreate5(xl2,xu2,nbinsint2,A189_HLL_BTAG_SIG,
     >        sighist2)

c Add together into 2D histogram.
         call a2dadd1(nbinsint1,nbinsint2,ratech,
     >                sighist1,sighist2,sighist2d)

         call a2dzero1(nbinsint1,nbinsint2,bkghist2d)

         call abhcreate2(xl1,xu1,nbinsint1,a189_hll_mass_bkg,
     >                   a189_hll_bkg,1,backhist1)
         call abhcreate2(xl2,xu2,nbinsint1,a189_hll_btag_bkg,
     >                   a189_hll_bkg,1,backhist2)
         bkglevel = a189_hll_bkg(1)*176.2/175.5
         call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                backhist1,backhist2,bkghist2d)

         call abhcreate2(xl1,xu1,nbinsint1,a189_hll_mass_bkg,
     >                   a189_hll_bkg,2,backhist1)
         call abhcreate2(xl2,xu2,nbinsint1,a189_hll_btag_bkg,
     >                   a189_hll_bkg,2,backhist2)
         bkglevel = a189_hll_bkg(2)*176.2/175.5
         call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                backhist1,backhist2,bkghist2d)

         call abhcreate2(xl1,xu1,nbinsint1,a189_hll_mass_bkg,
     >                   a189_hll_bkg,3,backhist1)
         call abhcreate2(xl2,xu2,nbinsint1,a189_hll_btag_bkg,
     >                   a189_hll_bkg,3,backhist2)
         bkglevel = a189_hll_bkg(3)*176.2/175.5
         call a2dadd1(nbinsint1,nbinsint2,bkglevel,
     >                backhist1,backhist2,bkghist2d)

         call a2dzero2(nbinsint1,nbinsint2,candhist2d)
         nacand = A189_hll_NUMCAND()
         do i=1,nacand
           candmass = A189_hll_mass_CAND(i)
           candbtag = A189_hll_btag_CAND(i)
           call abin1(candmass,xl1,xu1,
     >                nbinsint1,ibin1)
           call abin1(candbtag,xl2,xu2,
     >                nbinsint2,ibin2)
           if (ibin1.gt.0 .AND. ibin2.gt.0 .AND. 
     +          ibin1.le.nbinsint1 .AND. ibin2.le.nbinsint2)
     +          candhist2d(ibin1,ibin2) = candhist2d(ibin1,ibin2)+1
        enddo

        call arebin3(nbinsint1,nbinsint2,
     >                sighist2d,bkghist2d,candhist2d,
     >                nbinsint,
     >                sig(nbins+1),backw(nbins+1),ncand(nbins+1))
         
c     systematics
         if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
         elseif (dosyst) then
            call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
         else
            call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
         endif
 1893    ifirst(nchan) = nbins + 1
         nbins = nbins + nbinsint
      endif                     ! (switch)

c tt -- three analyses

      switch = .true.
      dosyst = .true.
      subbg = .true.
      if (switch) then
        do iana=1,3
          nchan = nchan + 1 
          if (iana.eq.1) then
            channame(nchan) = 'ALEPH 189 tt HZ/HA overlap'
          else if (iana.eq.2) then
            channame(nchan) = 'ALEPH 189 tt HA only'
          else if (iana.eq.3) then
            channame(nchan) = 'ALEPH 189 tt HZ only'
          endif

          xlzh = xhz(15)*ah0_lumi(2)
          xlah = xha(15)*ah0_lumi(2)
          chanlumi(nchan) = ah0_lumi(2)

          xdouble = mh
          ydouble = mapole
          ratech = A189_tt_eff((xdouble+ydouble)/2D0,iana,1)*
     >           (bhtata*babb/AMSSMbabb+bhbb*batata/AMSSMbhbb
     >       - bhtata*batata)*xlah
c     >             xlah*(bhbb*batata+bhtata*babb)

          rate2ch= A189_tt_eff(xdouble,iana,2)*
     >             xlzh*bhtata

          rate3ch= A189_tt_eff(xdouble,iana,3)*
     >             xlzh*z0totata
c     >         *bhbb/Abhbb
          if (xtest18x) write (6,*) '189 w/ taus',ratech,rate2ch,rate3ch
          if (ratech.lt.0.0) ratech=0.0
          if (rate2ch.lt.0.0) rate2ch=0.0
          if (rate3ch.lt.0.0) rate3ch=0.0

          nerrch(nchan) = 4
          sysname(1,nchan) = 'A189BTAG-B'
          sysname(2,nchan) = 'A189BTAG-LT'
          if (iana.eq.1) then
            sysname(3,nchan) = 'A189-TT-OV-UNC-SIG'
            sysname(4,nchan) = 'A189-TT-OV-UNC-BKG'
            if ((ratech+rate2ch+rate3ch).ne.0.) then
              dsig(1,nchan) = (rate3ch*0.002)/
     >                        (ratech+rate2ch+rate3ch)
              dsig(2,nchan) = (rate2ch*0.012)/
     >                        (ratech+rate2ch+rate3ch)

              dsig(3,nchan) = sqrt(  (ratech*0.018)**2 +
     >                               (rate2ch*0.042)**2 +
     >                               (rate3ch*0.020)**2 )/
     >                        (ratech+rate2ch+rate3ch)
              dsig(4,nchan) = 0.
            else
              dsig(1,nchan) = 0.
              dsig(2,nchan) = 0.
              dsig(3,nchan) = 0.
              dsig(4,nchan) = 0.
            endif
            dback(1,nchan) = 0.
            dback(2,nchan) = 0.
            dback(3,nchan) = 0.
            dback(4,nchan) = sqrt( (A189_TT_BKG(iana,1)*0.330)**2 +
     >                             (A189_TT_BKG(iana,2)*0.710)**2 +
     >                             (A189_TT_BKG(iana,3)*0.300)**2 +
     >                             (A189_TT_BKG(iana,4)*0.071)**2)/
     >                             (A189_TT_BKG(iana,1)+
     >                              A189_TT_BKG(iana,2)+
     >                              A189_TT_BKG(iana,3)+
     >                              A189_TT_BKG(iana,4))
          else if (iana.eq.2) then
            sysname(3,nchan) = 'A189-TT-HA-SIG-UNC'
            sysname(4,nchan) = 'A189-TT-HA-BKG-UNC'
            if ((ratech+rate2ch+rate3ch).ne.0.) then
              dsig(1,nchan) = (rate3ch*0.001)/
     >                        (ratech+rate2ch+rate3ch)
              dsig(2,nchan) = (rate2ch*0.013)/
     >                        (ratech+rate2ch+rate3ch)
              dsig(3,nchan) = sqrt(  (ratech*0.0360)**2 +
     >                               (rate2ch*0.110)**2 +
     >                               (rate3ch*0.067)**2 )/
     >                        (ratech+rate2ch+rate3ch)
              dsig(4,nchan) = 0.
            else
              dsig(1,nchan) = 0.
              dsig(2,nchan) = 0.
              dsig(3,nchan) = 0.
              dsig(4,nchan) = 0.
            endif
            dback(1,nchan) = (A189_TT_BKG(iana,4)*0.009)/
     >                            (A189_TT_BKG(iana,1)+
     >                             A189_TT_BKG(iana,2)+
     >                             A189_TT_BKG(iana,3)+
     >                             A189_TT_BKG(iana,4))
            dback(2,nchan) = 0.
            dback(3,nchan) = 0.
            dback(4,nchan) = sqrt( (A189_TT_BKG(iana,1)*0.580)**2 +
     >                             (A189_TT_BKG(iana,2)*0.350)**2 +
     >                             (A189_TT_BKG(iana,3)*0.240)**2 +
     >                             (A189_TT_BKG(iana,4)*0.130)**2)/
     >                             (A189_TT_BKG(iana,1)+
     >                              A189_TT_BKG(iana,2)+
     >                              A189_TT_BKG(iana,3)+
     >                              A189_TT_BKG(iana,4))
          else if (iana.eq.3) then
            sysname(3,nchan) = 'A189-TT-HZ-SIG-UNC'
            sysname(4,nchan) = 'A189-TT-HZ-BKG-UNC'
            if ((ratech+rate2ch+rate3ch).ne.0.) then
              dsig(1,nchan) = ((ratech*0.006) +
     >                         (rate3ch*0.003))/
     >                         (ratech+rate2ch+rate3ch)
              dsig(2,nchan) =  (rate2ch*0.009)/
     >                         (ratech+rate2ch+rate3ch)
              dsig(3,nchan) = sqrt(  (ratech*0.089)**2 +
     >                               (rate2ch*0.047)**2 +
     >                               (rate3ch*0.060)**2 )/
     >                        (ratech+rate2ch+rate3ch)
              dsig(4,nchan) = 0.
            else
              dsig(1,nchan) = 0.
              dsig(2,nchan) = 0.
              dsig(3,nchan) = 0.
              dsig(4,nchan) = 0.
            endif
            dback(1,nchan) = (A189_TT_BKG(iana,4)*0.006)/
     >                            (A189_TT_BKG(iana,1)+
     >                             A189_TT_BKG(iana,2)+
     >                             A189_TT_BKG(iana,3)+
     >                             A189_TT_BKG(iana,4))
            dback(2,nchan) = 0.
            dback(3,nchan) = 0.
            dback(4,nchan) = sqrt( (A189_TT_BKG(iana,1)*0.500)**2 +
     >                             (A189_TT_BKG(iana,2)*0.710)**2 +
     >                             (A189_TT_BKG(iana,3)*0.260)**2 +
     >                             (A189_TT_BKG(iana,4)*0.082)**2)/
     >                             (A189_TT_BKG(iana,1)+
     >                              A189_TT_BKG(iana,2)+
     >                              A189_TT_BKG(iana,3)+
     >                              A189_TT_BKG(iana,4))
          endif

c create binned shape info
          xl = 50.
          xu = 110.
          nbinsint = 60
          IF (CHANLUMI(NCHAN).EQ.0.0) GOTO 1894 ! NEXT CHANNEL

          call ascreate6(xl,xu,nbinsint,A189_tt_mass_sig,
     >                   (mh+mapole)/2.0,iana,1,sighist1)
          call ascreate6(xl,xu,nbinsint,A189_tt_mass_sig,
     >                   mh,iana,2,sighist2)
          call ascreate6(xl,xu,nbinsint,A189_tt_mass_sig,
     >                   mh,iana,3,sighist3)

          call ahistscal1(nbinsint,sighist1,sighist1s,ratech)
          call ahistscal1(nbinsint,sighist2,sighist2s,rate2ch)
          call ahistscal1(nbinsint,sighist3,sighist3s,rate3ch)

          call amerge3(nbinsint,sighist1s,sighist2s,sighist3s,
     >                 sig(nbins+1))


          call abhcreate7(xl,xu,nbinsint,
     >       A189_tt_mass_bkg,A189_tt_bkg,iana,1,backeez)
          call abhcreate7(xl,xu,nbinsint,
     >       A189_tt_mass_bkg,A189_tt_bkg,iana,2,backqq)
          call abhcreate7(xl,xu,nbinsint,
     >       A189_tt_mass_bkg,A189_tt_bkg,iana,3,backww)
          call abhcreate7(xl,xu,nbinsint,
     >       A189_tt_mass_bkg,A189_tt_bkg,iana,4,backzz)
          call amerge4(nbinsint,backeez,backqq,backww,backzz,
     >                 backw(nbins+1))

          do i = 1,nbinsint
            backw(nbins+i) = backw(nbins+i)*176.2/175.5
          enddo

          nacand = A189_TT_NUMCAND(iana)
          do i=1,nacand
            candmass = A189_TT_MASS_CAND(iana,i)
            call abin1(candmass,xl,xu,nbinsint,ibin)
            if (ibin.gt.0.and.ibin.le.nbinsint) then
              ncand(nbins+ibin) = ncand(nbins+ibin) + 1
            endif
          enddo

c systematics
          if (.not.subbg) then
            call vzero(backg(nbins+1),nbinsint)
          elseif (dosyst) then
            call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
          else
            call vscale(backw(nbins+1),1.0,backg(nbins+1),nbinsint)
          endif
 1894     ifirst(nchan) = nbins + 1
          nbins = nbins + nbinsint
       enddo                    ! IANA
      endif

c
c ++++++++++++++++++ Searches on the 1999 data +++++++++++++++
c
c   ----- 191.6 + 195.5 + 199.5 + 201.6 GeV Channels  -----
c
c     Four Jets -- three analyses
c
      write(*,*) ' *** 4 jet 1999 ***'
      include 'a_4jets_192_202.inc' 
c
c     Missing Energy -- three analyses
c
      write(*,*) ' *** Hnn 1999 ***'
      include 'a_hnn_192_202.inc' 
C
C     Hll 192 - 202 GeV
C
      write(*,*) ' *** Hll 1999 ***'
      include 'a_hll_192_202.inc'
c
c     Xtt 192 - 202 GeV
c     
      write(*,*) ' *** Xtt 1999 ***'
      include 'a_xtt_192_202.inc'
c
c ++++++++++++++++++ Searches on the 2000 data +++++++++++++++
c
c      write(*,*) '*** Filling 2000 data ***'
c
c     4 jet Y2000 
c
      write(*,*) ' *** 4 jet 2000 *** '
      include 'a_4jets_2000_syst.inc'
c
c     Hnn Y2000 
c
      write(*,*) ' *** Hnn 2000 *** '
      include 'a_hnn_2000_syst.inc'
c
c     Hll Y2000 
c
      write(*,*) ' *** Hll 2000 *** '
      include 'a_hll_2000.inc'
c
c     Xtt Y2000 
c
      write(*,*) ' *** Xtt 2000 *** '
      include 'a_xtt_2000.inc'
c
c     Charged Higgs 183 - 208 GeV
c
c      write(*,*) ' *** Charged higgs ***'
c      include 'a_hphm_183_208.inc'
c
c     Fermiophobic Higgs, all LEP1 and LEP2 energies up to 210 GeV
c
c      write(*,*) ' *** Fermiophobic Higgs *** '
c      include 'a_zhgg_91_210.inc'
c
c     Invisible Higgs, 189 - 209 GeV
c
c      write(*,*) ' *** Invisible Higgs *** '
c      include 'a_invisible_189_208.inc'
c
c     Flavour-independent Higgs, 189 - 209 GeV
c
c      write(*,*) ' *** Flavour-independent Higgs *** '
c      include 'a_flavind_main.inc'
c
c---- Done.
c
      init = .false.
c
c     Set the ifirst for the next (non-existing) channel:
c     this allows the user to find the size of all (including the last) 
c     channels as nnnbins=ifirst(nchan+1)-ifirst(nchan)
c
      nchan = nchan + 1
      channame(nchan) = 'ALEPH XXX Empty'
      ifirst(nchan) = nbins + 1
      return
      end
c
