c-*-FORTRAN-*-
c
      REAL FUNCTION XSEC_INTERP(iprocess,xsec,target_energy)
c
c     This function will interpolate linearly the input array XSEC(IPROCESS,ICMS)
c     to obtain the interpolated xsection at a c.o.m. energy TARGET_ENERGY.
c
c     This code is adapted from C. Tully's interpolation routine.
c
c                                                    PTD, 20-Jun-2000.
c
c ARRAY xsec(,) is assumed defined as in the s/r a_inputs():
c-------------------------------------------------------
c  xsec(7,a_maxnener) -- cross-sections (defined below) INPUT (real) in picobarns
c
c Two indices for cross sections -- first one: type of cross section
c  1 = sigma(e+e- -> Zh)  -- at several energies
c  2 = sigma(e+e- -> hA)  -- at several energies
c  3 = sigma(e+e- -> ZH) (heavy higgs)
c  4 = sigma(e+e- -> HA) (heavy higgs)  (currently unused)
c  5 = sigma(e+e- -> h nue nue ) *total* cross-section
c      (i.e., includes HZ + WW-fusion + interference)
c  6 = sigma(e+e- -> hee ) *total* cross-section
c      (i.e., includes HZ + ZZ-fusion + interference)
c  7 = sigma(e+e- -> H+H-)
c
c Second index for cross section input, the energy point:
c   Energy lists for cross sections:  (dimensioned a_maxnener,
c                                      defined in a_inputs.inc)
c iener=
c      1: 88.4   GeV
c      2: 89.4
c      3: 90.2
c      4: 91.4
c      5: 92.0
c      6: 93.0
c      7: 93.4
c      8: 161.3
c      9: 170.0
c     10: 172.0
c     11: 130.0
c     12: 136.0
c     13: 182.0
c     14: 183.0
c     15: 188.6
c     16: 191.6
c     17: 195.5
c     18: 199.5
c     19: 201.6
c     20: 202.5
c     21: 203.0
c     22: 203.5
c     23: 204.0
c     24: 204.5
c     25: 205.0
c     26: 205.5
c     27: 206.0
c     28: 206.5
c     29: 207.0
c     30: 207.5
c     31: 208.0
c     32: 208.5
c     33: 209.0
c     34: 209.5
c     35: 210.0
c
c--------------------------------------------------------
c
      implicit none
      integer iprocess,i,iene(2),ioffset
c
c     +---------------------------------------------------------------------+
c     | NB there is an offset between the indices in the cross-section 
c     | database (by C Tully) and in the XSEC(,IENER) array !
c     | The two are matched by using IOFFSET
c     | 
c     | BEAR IN MIND that the value of IOFFSET may have to change in the 
c     | future if, e.g., the cross-section database is updated...
c     +---------------------------------------------------------------------+
c
      parameter (ioffset=8)
c
      real target_energy,aux(2)
      real xsec(7,*),factor,rxs
c following include defines relation of IENER index and actual ECM values:
      include 'a_cross_sections.inc'
c
C Check bounds
      if(target_energy.lt.rsqrts(4).or.
     +     target_energy.gt.rsqrts(nsqrts))then
         write(*,*) '<XSEC_INTERP>'
         write(*,*) 'TARGET ENERGY =',target_energy,'GeV!'
         write(*,*) 'You are trying to extrapolate!'
         write(*,*) 'Evidently you have lost your mind.'
         write(*,*) 'Will return ZERO xsection.'
         xsec_interp = 0.0
         return
c         stop
      endif
      
C Find upper and lower calculated points
      do i=4,nsqrts-1
         if(target_energy.le.rsqrts(i+1).and.
     +        target_energy.gt.rsqrts(i))then
            iene(1)=i
            iene(2)=i+1
         endif
      enddo
c
      aux(1) = xsec(iprocess,iene(1)+ioffset)
      aux(2) = xsec(iprocess,iene(2)+ioffset)
c
      factor = (target_energy - rsqrts(iene(1)))/
     +     (rsqrts(iene(2)) - rsqrts(iene(1)))
c
      rxs = aux(1) + (aux(2)-aux(1))*factor
c
      rxs = max(rxs,0.0)
c
      xsec_interp = rxs
c
      return
      end
c

