c-*-FORTRAN-*-
c
	SUBROUTINE A_XTT_SYSTEMATICS(iener_s,iana_s,nchan_s, ! input
     +                                  ratesig_s,ratebgd_s, !input
     +                   dsig_s,dback_s,sysname_s,nerrch_s) !output
c
c       Returns the FRACTIONAL errors DSIG_S(isource) and DBACK_S(isource)
c       for the Xtt channels. The errors are detailed by source for the 
c       given channel NCHAN_S. (isource runs from 1 to nerrch_s(nchan_s))
c
c       NB How it works:
c       what the call to this  subroutine does is to insert the 1D arrays
c       DSIG_S(i=1 to a_maxnerr) and 
c       DBACK_S(i=1 to a_maxnerr) into the appropriate row of the  
c       big-picture 2D arrays DSIG(isource,nchan) and DBACK(isource,nchan)
c       defined in the main code.
c
c       Created: Pedro Teixeira-Dias, 22-Feb-2000.
c
c       Mods:
c
c	iener = 3,6 --> 192-202 GeV
c       iana = 1,2,3 --> hA only, hZ only, overlap, resp.
c       
      implicit none
      include 'a_inputs.inc'
      integer iener_s,iana_s,nchan_s,i
c
      integer nerrch_s!(a_maxnchan)
      real dsig_s(a_maxnerr)
      real dback_s(a_maxnerr)
      character*20 sysname_s(a_maxnerr)
c
      real ratesig_s(10),ratebgd_s(5) ! to match dimensions in taus_decl.inc
      real aux(3)
c
c       The systematic uncertainties for 192 - 202 GeV are reported 
c       independently of ECM;
c	
      if (iener_s.eq.3) then	! 192 GeV
	 nerrch_s = 6	! total number of sources (s and b)
	 if (iana_s.eq.1) then	! hA exclusive
	    sysname_s(1) = 'A192-TT-HA-MCSTA-SIG'
	    sysname_s(2) = 'A192-TT-HA-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A192-TT-HA-JSMR-SIG'
	    sysname_s(6) = 'A192-TT-HA-JSMR-BKG'
	 else if (iana_s.eq.2) then ! hZ exclusive
	    sysname_s(1) = 'A192-TT-HZ-MCSTA-SIG'
	    sysname_s(2) = 'A192-TT-HZ-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A192-TT-HZ-JSMR-SIG'
	    sysname_s(6) = 'A192-TT-HZ-JSMR-BKG'
	 else if (iana_s.eq.3) then ! hZ and hA overlap
	    sysname_s(1) = 'A192-TT-OV-MCSTA-SIG'
	    sysname_s(2) = 'A192-TT-OV-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A192-TT-OV-JSMR-SIG'
	    sysname_s(6) = 'A192-TT-OV-JSMR-BKG'
	 end if			! iana_s
c      
      else if (iener_s.eq.4) then ! 196 GeV
	 nerrch_s = 6	! total number of sources (s and b)
	 if (iana_s.eq.1) then	! hA exclusive
	    sysname_s(1) = 'A196-TT-HA-MCSTA-SIG'
	    sysname_s(2) = 'A196-TT-HA-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A196-TT-HA-JSMR-SIG'
	    sysname_s(6) = 'A196-TT-HA-JSMR-BKG'
	 else if (iana_s.eq.2) then ! hZ exclusive
	    sysname_s(1) = 'A196-TT-HZ-MCSTA-SIG'
	    sysname_s(2) = 'A196-TT-HZ-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A196-TT-HZ-JSMR-SIG'
	    sysname_s(6) = 'A196-TT-HZ-JSMR-BKG'
	 else if (iana_s.eq.3) then ! hZ and hA overlap
	    sysname_s(1) = 'A196-TT-OV-MCSTA-SIG'
	    sysname_s(2) = 'A196-TT-OV-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A196-TT-OV-JSMR-SIG'
	    sysname_s(6) = 'A196-TT-OV-JSMR-BKG'
	 end if			! iana_s
c       
      else if (iener_s.eq.5) then ! 200 GeV
	 nerrch_s = 6	! total number of sources (s and b)
	 if (iana_s.eq.1) then	! hA exclusive
	    sysname_s(1) = 'A200-TT-HA-MCSTA-SIG'
	    sysname_s(2) = 'A200-TT-HA-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A200-TT-HA-JSMR-SIG'
	    sysname_s(6) = 'A200-TT-HA-JSMR-BKG'
	 else if (iana_s.eq.2) then ! hZ exclusive
	    sysname_s(1) = 'A200-TT-HZ-MCSTA-SIG'
	    sysname_s(2) = 'A200-TT-HZ-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A200-TT-HZ-JSMR-SIG'
	    sysname_s(6) = 'A200-TT-HZ-JSMR-BKG'
	 else if (iana_s.eq.3) then ! hZ and hA overlap
	    sysname_s(1) = 'A200-TT-OV-MCSTA-SIG'
	    sysname_s(2) = 'A200-TT-OV-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A200-TT-OV-JSMR-SIG'
	    sysname_s(6) = 'A200-TT-OV-JSMR-BKG'
	 end if			! iana_s
c       
      else if (iener_s.eq.6) then ! 202 GeV
	 nerrch_s = 6	! total number of sources (s and b)
	 if (iana_s.eq.1) then	! hA exclusive
	    sysname_s(1) = 'A202-TT-HA-MCSTA-SIG'
	    sysname_s(2) = 'A202-TT-HA-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A202-TT-HA-JSMR-SIG'
	    sysname_s(6) = 'A202-TT-HA-JSMR-BKG'
	 else if (iana_s.eq.2) then ! hZ exclusive
	    sysname_s(1) = 'A202-TT-HZ-MCSTA-SIG'
	    sysname_s(2) = 'A202-TT-HZ-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A202-TT-HZ-JSMR-SIG'
	    sysname_s(6) = 'A202-TT-HZ-JSMR-BKG'
	 else if (iana_s.eq.3) then ! hZ and hA overlap
	    sysname_s(1) = 'A202-TT-OV-MCSTA-SIG'
	    sysname_s(2) = 'A202-TT-OV-MCSTA-BKG'
	    sysname_s(3) = 'A19X-BSMR-BB'
	    sysname_s(4) = 'A19X-BSMR-LT'
	    sysname_s(5) = 'A202-TT-OV-JSMR-SIG'
	    sysname_s(6) = 'A202-TT-OV-JSMR-BKG'
	 end if			! iana_s
	end if			! iener_s
	
c
c      +----------------------+
c       192 - 202 GeV, in 1999
c      +----------------------+
c
c       The systematic unc. for 192 - 202 GeV are reported independently of the
c       ECM value:
c
C     ITYP defines the signal: 
C       1=HZ->bbtt, 2=HZ->tttt, 3=HZ->cctt, 4=HZ->(other)tt,
C       5=ttZ
C       6=hA->bbtt, 7=hA->tttt, 8=hA->cctt, 9=hA->(other)tt 
c
c     4 different bgd types:
c     ITYP=1 (eeZ+Wenu), 2 (qq), 3 (WW), 4 (ZZ)
c
c
      IF (IENER_S.GE.3 .AND. IENER_S.LE.6) THEN ! 192 - 202 GeV
c       
c       
c       hZ->htt signal
	 aux(1) = 
     +ratesig_s(1) + ratesig_s(2) + ratesig_s(3) + ratesig_s(4)
c       ttZ signal
	 aux(2) = ratesig_s(5)
c       hA->bbtt signal
	 aux(3) = 
     +ratesig_s(6) + ratesig_s(7) + ratesig_s(8) + ratesig_s(9) 
c       Initialize error arrays
	 do i=1,nerrch_s
	    dsig_s(i) = 0.00
	    dback_s(i) = 0.00
	 end do
c       
c      +-------------------+
c       hA exclusive branch
c      +-------------------+
c
	 if (iana_s.eq.1) then	! hA exclusive
c signal MC stats
	    if ((aux(1)+aux(2)+aux(3)).gt.0.0)
     +              dsig_s(1) = sqrt ( (aux(1)*0.142)**2 + 
     +                                 (aux(2)*0.204)**2 + 
     +                                 (aux(3)*0.096)**2 ) 
     +	                          / (aux(1)+aux(2)+aux(3))
c backgd MC stats
	 if ((ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4)).gt.0.0)
     +                dback_s(2) = sqrt ( (ratebgd_s(1)*1.000)**2 + 
     +                                    (ratebgd_s(2)*0.700)**2 + 
     +                                    (ratebgd_s(3)*0.449)**2 +
     +                                    (ratebgd_s(4)*0.258)**2 ) 
     +	   / (ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4))
c d0,z0 smearing: signal(htt,hA) and ZZ in correlation
         if ((aux(1) + aux(3)).gt.0.0)
     +      dsig_s(3) = ( aux(1)*0.014 + aux(3)*0.010  )
     +	                          / (aux(1) + aux(3))
	      dback_s(3) = 0.00
c d0,z0 smearing: signal(ttZ) and eeZ, qq, WW in correlation 
c (but not correlated to the above)
	      dsig_s(4) = 0.00
         if ((ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3)).gt.0.0)
     +      dback_s(4) = 
     +     (ratebgd_s(1)*0.50 + ratebgd_s(2)*0.00 + ratebgd_s(3)*0.00)
     +                / (ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3))
c jet smearing: signal
	 if ((aux(1)+aux(2)+aux(3)).gt.0.0)
     +                dsig_s(5) = sqrt ( (aux(1)*0.010)**2 + 
     +                                   (aux(2)*0.00)**2 + 
     +                                   (aux(3)*0.023)**2 ) 
     +	                          / (aux(1)+aux(2)+aux(3))
c jet smearing: background
	 if ((ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4)).gt.0.0)
     +      dback_s(6) = sqrt ( (ratebgd_s(1)*0.50)**2 + 
     +                                    (ratebgd_s(2)*0.00)**2 + 
     +                                    (ratebgd_s(3)*0.10)**2 + 
     +                                    (ratebgd_s(4)*0.034)**2 ) 
     +	   / (ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4))
c
c
c      +-------------------+
c       hZ exclusive branch
c      +-------------------+
c
	   else if (iana_s.eq.2) then ! hZ exclusive
c signal MC stats
	 if ((aux(1)+aux(2)+aux(3)).gt.0.0)
     +      dsig_s(1) = sqrt ( (aux(1)*0.030)**2 + 
     +                                   (aux(2)*0.020)**2 + 
     +                                   (aux(3)*0.035)**2 ) 
     +	                          / (aux(1)+aux(2)+aux(3))
c backgd MC stats
	 if ((ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4)).gt.0.0)
     +      dback_s(2) = sqrt ( (ratebgd_s(1)*0.189)**2 + 
     +                                    (ratebgd_s(2)*0.229)**2 + 
     +                                    (ratebgd_s(3)*0.052)**2 + 
     +                                    (ratebgd_s(4)*0.057)**2 ) 
     +	   / (ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4))
c d0,z0 smearing: signal(htt,hA) and ZZ in correlation
         if ((aux(1) + aux(3)).gt.0.0)
     +      dsig_s(3) = ( aux(1)*0.005 + aux(3)*0.104 )
     +	                          / (aux(1) + aux(3))
	      dback_s(3) = 0.00
c d0,z0 smearing: signal(ttZ) and eeZ, qq, WW in correlation 
c (but not correlated to the above)
	      dsig_s(4) = 0.001
         if ((ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3)).gt.0.0)
     +      dback_s(4) = 
     +(ratebgd_s(1)*0.160+ratebgd_s(2)*0.053+ratebgd_s(3)*0.0095)
     +                / (ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3))
c jet smearing: signal
	 if ((aux(1)+aux(2)+aux(3)).gt.0.0)
     +      dsig_s(5) = sqrt ( (aux(1)*0.002)**2 + 
     +                                   (aux(2)*0.005)**2 + 
     +                                   (aux(3)*0.002)**2 ) 
     +	                          / (aux(1)+aux(2)+aux(3))
c jet smearing: background
	 if ((ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4)).gt.0.0)
     +      dback_s(6) = sqrt ( (ratebgd_s(1)*0.00)**2 + 
     +                                    (ratebgd_s(2)*0.00)**2 + 
     +                                    (ratebgd_s(3)*0.025)**2 + 
     +                                    (ratebgd_s(4)*0.00)**2 ) 
     +	   / (ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4))
c
c
c      +--------------+
c       overlap branch
c      +--------------+
c
	   else if (iana_s.eq.3) then ! overlap
c signal MC stats
	 if ((aux(1)+aux(2)+aux(3)).gt.0.0)
     +      dsig_s(1) = sqrt ( (aux(1)*0.016)**2 + 
     +                                   (aux(2)*0.036)**2 + 
     +                                   (aux(3)*0.012)**2 ) 
     +	                          / (aux(1)+aux(2)+aux(3))
c backgd MC stats
	 if ((ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4)).gt.0.0)
     +      dback_s(2) = sqrt ( (ratebgd_s(1)*0.316)**2 + 
     +                                    (ratebgd_s(2)*0.700)**2 + 
     +                                    (ratebgd_s(3)*0.174)**2 + 
     +                                    (ratebgd_s(4)*0.086)**2 ) 
     +	   / (ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4))
c d0,z0 smearing: signal(htt,hA) and ZZ in correlation
         if ((aux(1) + aux(3)).gt.0.0)
     +      dsig_s(3) = ( aux(1)*0.002 + aux(3)*0.003 )
     +	                          / (aux(1) + aux(3))
	      dback_s(3) = 0.0111
c d0,z0 smearing: signal(ttZ) and eeZ, qq, WW in correlation 
c (but not correlated to the above)
	      dsig_s(4) = 0.019
         if ((ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3)).gt.0.0)
     +      dback_s(4) = 
     +(ratebgd_s(1)*0.20 + ratebgd_s(2)*0.00 + ratebgd_s(3)*0.076)
     +                / (ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3))
c jet smearing: signal
	 if ((aux(1)+aux(2)+aux(3)).gt.0.0)
     +      dsig_s(5) = sqrt ( (aux(1)*0.001)**2 + 
     +                                   (aux(2)*0.001)**2 + 
     +                                   (aux(3)*0.001)**2 ) 
     +	                          / (aux(1)+aux(2)+aux(3))
c jet smearing: background
	 if ((ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4)).gt.0.0)
     +      dback_s(6) = sqrt ( (ratebgd_s(1)*0.05)**2 + 
     +                                    (ratebgd_s(2)*0.00)**2 + 
     +                                    (ratebgd_s(3)*0.015)**2 + 
     +                                    (ratebgd_s(4)*0.008)**2 ) 
     +	   / (ratebgd_s(1)+ratebgd_s(2)+ratebgd_s(3)+ratebgd_s(4))
c
	   end if		! IANA_S (branch)
	END IF			! IENER_S (ECM)
c
      if (.FALSE.) then
	 write (6,*) '<a_xtt_systematics> iener=',iener_s
	 write (6,*) (i,sysname_s(i),
     +    dsig_s(i),dback_s(i),i=1,nerrch_s)
      end if
c
	END
c-----------------------------------------------------------------------------
c
	SUBROUTINE A_HLL_SYSTEMATICS(iener_s,ratesig_s,ratebgd_s, !input
     +                   dsig_s,dback_s,sysname_s,nerrch_s) !output
c
c       Returns the FRACTIONAL errors DSIG_S(isource) and DBACK_S(isource)
c       for the hll channels. The errors are detailed by source for the 
c       given channel NCHAN_S. (isource runs from 1 to nerrch_s)
c
c       NB How it works:
c       what the call to this  subroutine does is to insert the 1D arrays
c       DSIG_S(i=1 to a_maxnerr) and 
c       DBACK_S(i=1 to a_maxnerr) into the appropriate row of the  
c       big-picture 2D arrays DSIG(isource,nchan) and DBACK(isource,nchan)
c       defined in the main code.
c
c       Created: Pedro Teixeira-Dias, 22-Feb-2000.
c
c       Mods:
c       - For the 1999 analysis:---------------------------
c	iener = 3,6 --> 192-202 GeV
c       ratesig(1) =  bbll
c       ratesig(2) =  ttll
c       ratesig(3) =  (cc+gg)ll
c       ratebgd(1/2/3) = ZZ/eeZ/other 
c
      implicit none
      include 'a_inputs.inc'
      integer iener_s,ismbin,i
c
      integer nerrch_s!(a_maxnchan)
      real dsig_s(a_maxnerr)
      real dback_s(a_maxnerr)
      character*20 sysname_s(a_maxnerr)
c
      real ratesig_s(10),ratebgd_s(5) ! to match dimensions in taus_decl.inc
      real aux(3)
c
c       Reported sources are:
c
      if (iener_s.eq.3) then	! 192 GeV
	 nerrch_s = 11	! total number of sources (s and b)
	 sysname_s(1) = 'A192-HLL-MCSTATS-SIG'
	 sysname_s(2) = 'A192-HLL-MCSTATS-BKG'
	 sysname_s(3) = 'A19X-HLL-LID'
	 sysname_s(4) = 'A192-HLL-LOANGLE-SIG'
	 sysname_s(5) = 'A192-HLL-LOANGLE-BKG'
	 sysname_s(6) = 'A192-HLL-ISOLANG-SIG'
	 sysname_s(7) = 'A192-HLL-ISOLANG-BKG'
	 sysname_s(8) = 'A192-HLL-PTSUM-SIG'
	 sysname_s(9) = 'A192-HLL-PTSUM-BKG'
	 sysname_s(10) = 'A192-HLL-TRACKSM-SIG'
	 sysname_s(11) = 'A192-HLL-TRACKSM-BKG'
      else if (iener_s.eq.4) then	! 196 GeV
	 nerrch_s = 11	! total number of sources (s and b)
	 sysname_s(1) = 'A196-HLL-MCSTATS-SIG'
	 sysname_s(2) = 'A196-HLL-MCSTATS-BKG'
	 sysname_s(3) = 'A19X-HLL-LID'
	 sysname_s(4) = 'A196-HLL-LOANGLE-SIG'
	 sysname_s(5) = 'A196-HLL-LOANGLE-BKG'
	 sysname_s(6) = 'A196-HLL-ISOLANG-SIG'
	 sysname_s(7) = 'A196-HLL-ISOLANG-BKG'
	 sysname_s(8) = 'A196-HLL-PTSUM-SIG'
	 sysname_s(9) = 'A196-HLL-PTSUM-BKG'
	 sysname_s(10) = 'A196-HLL-TRACKSM-SIG'
	 sysname_s(11) = 'A196-HLL-TRACKSM-BKG'
      else if (iener_s.eq.5) then	! 200 GeV
	 nerrch_s = 11	! total number of sources (s and b)
	 sysname_s(1) = 'A200-HLL-MCSTATS-SIG'
	 sysname_s(2) = 'A200-HLL-MCSTATS-BKG'
	 sysname_s(3) = 'A19X-HLL-LID'
	 sysname_s(4) = 'A200-HLL-LOANGLE-SIG'
	 sysname_s(5) = 'A200-HLL-LOANGLE-BKG'
	 sysname_s(6) = 'A200-HLL-ISOLANG-SIG'
	 sysname_s(7) = 'A200-HLL-ISOLANG-BKG'
	 sysname_s(8) = 'A200-HLL-PTSUM-SIG'
	 sysname_s(9) = 'A200-HLL-PTSUM-BKG'
	 sysname_s(10) = 'A200-HLL-TRACKSM-SIG'
	 sysname_s(11) = 'A200-HLL-TRACKSM-BKG'
      else if (iener_s.eq.6) then	! 202 GeV
	 nerrch_s = 11	! total number of sources (s and b)
	 sysname_s(1) = 'A202-HLL-MCSTATS-SIG'
	 sysname_s(2) = 'A202-HLL-MCSTATS-BKG'
	 sysname_s(3) = 'A19X-HLL-LID'
	 sysname_s(4) = 'A202-HLL-LOANGLE-SIG'
	 sysname_s(5) = 'A202-HLL-LOANGLE-BKG'
	 sysname_s(6) = 'A202-HLL-ISOLANG-SIG'
	 sysname_s(7) = 'A202-HLL-ISOLANG-BKG'
	 sysname_s(8) = 'A202-HLL-PTSUM-SIG'
	 sysname_s(9) = 'A202-HLL-PTSUM-BKG'
	 sysname_s(10) = 'A202-HLL-TRACKSM-SIG'
	 sysname_s(11) = 'A202-HLL-TRACKSM-BKG'
      end if			! IENER_S
c
c     Initialize error arrays
      do i=1,nerrch_s
	 dsig_s(i) = 0.00
	 dback_s(i) = 0.00
      end do
c
c     Here, use the typical numbers that Tom Greening reported for hll
c     (for mh=107 and ECM=200 GeV);
c
      IF (IENER_S.GE.3 .AND. IENER_S.LE.6) THEN ! 192 - 202 GeV ------------------
c       MC stats; sig and background
	dsig_s(1) = 0.005
	dback_s(2) = sqrt( (ratebgd_s(1)*0.025)**2 + 
     +                   (ratebgd_s(2)*0.059)**2 + 
     +                   (ratebgd_s(3)*0.086)**2 ) 
     + / (ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3))
c
	dsig_s(3) = 0.002
	dback_s(3) = 0.002
c
	dsig_s(4) = 0.00
	dback_s(5) = 0.07*ratebgd_s(3) 
     + / (ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3))
c
	dsig_s(6) = 0.002 
	dback_s(7) = sqrt( (ratebgd_s(1)*0.002)**2 + 
     +                   (ratebgd_s(2)*0.011)**2 + 
     +                   (ratebgd_s(3)*0.055)**2 ) 
     + / (ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3))
c
	dsig_s(8) = 0.00
	dback_s(9) = 0.166*ratebgd_s(3) 
     + / (ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3))
c
	dsig_s(10) = 0.001
	dback_s(11) = sqrt( (ratebgd_s(1)*0.001)**2 + 
     +                   (ratebgd_s(2)*0.011)**2 ) 
     + / (ratebgd_s(1) + ratebgd_s(2) + ratebgd_s(3))
c
      END IF ! IENER_S
c
      if (.FALSE.) then
	 write (6,*) '<a_hll_systematics> iener/ismbin=',iener_s,ismbin
	 write (6,*) (i,sysname_s(i),
     +    dsig_s(i),dback_s(i),i=1,nerrch_s)
      end if
c
      end




