c---------------------------------------------------------------

c subroutine oghist  --  make a histogram from a Gaussian
c distribution -- take it out to +- 5 sigma in 50 bins
c input -- mean, sigma, out: nbins, xl, xh, sighist(1:nbins)
c nbins is 50
c warning -- no particular normalization
c note -- with fixed nbins and fixed number of sigma,
c you always get the same sighist, up to a normalization factor.

      subroutine aghist(mean,sigma,nbins,xl,xh,sighist)
      implicit none
      real mean,sigma,xl,xh,sighist(*)
      integer nbins,i
      real x,dx
      nbins = 50
      xl = mean - 5.0*sigma
      xh = mean + 5.0*sigma
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        sighist(i) = exp(-(x-mean)**2/(2.0*sigma**2))
      enddo
      return
      end
c---------------------------------------------------------------

c subroutine abin1  -- find which bin a number is in
      subroutine abin1(x,xl,xh,nbins,ibin)
      implicit none
      real x,xl,xh,dx
      integer nbins,ibin
      dx = (xh-xl)/float(nbins)
      ibin = int((x-xl)/dx)+1
      if (x.eq.xh) ibin=nbins
      return
      end

c---------------------------------------------------------------
c subroutine abin_fancy  -- find which bin a number is in
      subroutine abin_fancy(x,xl,xh,nbins,xchange,ibin)
      implicit none
      real x,xl,xh,dx1,dx2,xchange
      integer nbins,ibin
      dx1 = (xchange-xl)/float(nbins/2)
      ibin = int((x-xl)/dx1)+1
      if (ibin.le.nbins/2) return
      dx2 = (xh-xchange)/float(nbins-nbins/2)
      ibin = nbins/2 + int((x-xchange)/dx2) + 1
      if (x.eq.xh) ibin=nbins
      return
      end

c---------------------------------------------------------------

c subroutine oghist2  --  make a histogram from a 2D Gaussian
c distribution -- take it out to +- 3 sigma in 10 bins in each
c direction.  res1, res2, and resc are resolutions in mh, ma,
c and the correlation, respectively.  Written for use with
c the hA -> bbtautau/tautaubb channels
c -- no rotation of variables here.

      subroutine aghist2(mh,ma,res1,res2,resc,xl1,xu1,
     >                   nbins1,xl2,xu2,nbins2,nbins,histo)
      real mh,ma,res1,res2,resc,xl1,xl2,xu1,xu2,histo(*)
      integer nbins1,nbins2
      integer i,j
      real xmh,xma,dxmh,dxma
      real a,b,c,d,e,f,g,h,det,dx,dy
      nbins1 = 10
      nbins2 = 10
      xl1 = mh - 3.0*res1
      xu1 = mh + 3.0*res1
      xl2 = ma - 3.0*res2
      xu2 = ma + 3.0*res2
      dxmh = (xu1-xl1)/float(nbins1)
      dxma = (xu2-xl2)/float(nbins2)
c make the covariance matrix and invert it
      a = res1**2
      b = res1*res2*resc
      c = b
      d = res2**2
      det = (a*d - b*c)
      e = d/det
      f = -b/det
      g = -c/det
      h = a/det
      k = 0
      do i=1,nbins1
        do j=1,nbins2
          k = k + 1
          xmh = xl1 + dxmh*(float(i)-0.5)
          xma = xl1 + dxma*(float(j)-0.5)
          dx = (xmh - mh)
          dy = (xma - ma)
          histo(k) = exp(-(e*dx*dx+(f+g)*dx*dy+h*dy*dy)/2.0)
        enddo
      enddo
      nbins = nbins1*nbins2
      return
      end

c---------------------------------------------------------------
c for use with oghist2 and the 161, 172, 183 ah -> bbtt / ttbb channels
c these double up on the background by calling the function twice with
c mh <-> ma -- uses same binning conventions as oghist2 -- no rotation
c of variables
c ---- not used in the ALEPH code 
c      subroutine obhcreate3(xl1,xu1,nbins1,
c     >                      xl2,xu2,nbins2,func,histo)
c      implicit none
c      real xl1,xl2,xu1,xu2,histo(*),func
c      integer nbins1,nbins2
c      integer i,j,k
c      real xmh,xma,dxmh,dxma
c      external func
c
c      dxmh = (xu1-xl1)/float(nbins1)
c      dxma = (xu2-xl2)/float(nbins2)
c      k = 0
c      do i=1,nbins1
c        do j=1,nbins2
c          k = k + 1
c          xmh = xl1 + dxmh*(float(i)-0.5)
c          xma = xl1 + dxma*(float(j)-0.5)
c          histo(k) = (func(xmh,xma)+func(xma,xmh))*dxmh*dxma
c        enddo
c      enddo
c      return
c      end

c---------------------------------------------------------------
c and a corresponding bin-finder -- for use with 
c candidates with channels using oghist2 and obhcreate3

      subroutine abin3(xl1,xu1,nbins1,
     >                      xl2,xu2,nbins2,mh,ma,ibin)
      implicit none
      real xl1,xl2,xu1,xu2,mh,ma
      integer nbins1,nbins2,ibin
      real dx1,dx2
      integer i,j
      dx1 = (xu1 - xl1)/float(nbins1)
      dx2 = (xu2 - xl2)/float(nbins2)
      i = int((mh-xl1)/dx1) + 1
      j = int((ma-xl2)/dx2) + 1
      ibin = j + nbins2*(i-1)
c handle the error case where the entry is outside the histogram.  Give
c it an overflow bin number which will be dealt with in the caller.
      if (i.lt.0 .or. i.gt. nbins1) ibin = nbins1*nbins2+10
      if (j.lt.0 .or. j.gt. nbins2) ibin = nbins1*nbins2+10     
      return
      end

c---------------------------------------------------------------

c subroutine obhcreate0 -- produces a background histogram from a constant level
c                          and histogram spec (xl, xh, nbins)
c  (that's a zero in the name, for zero'th order background)
c assume level gives background/GeV

      subroutine abhcreate0(xl,xh,nbins,backch,bhist)
      implicit none
      real backch
      real xl,xh,bhist(*)
      integer nbins
      integer i
      real x,dx
      dx = (xh-xl)/float(nbins)
      do i=1,nbins
        x = xl + (float(i)-0.5)*dx
        bhist(i) = backch*dx
      enddo
      return
      end

c---------------------------------------------------------------
c subroutine orebin1 -- rebin a signal rate histogram in place by combining
c  neighboring channels -- close down the lower and upper limits
c  if the histogram has very small entries near the ends.
c  for use in making 2D histos smaller, need to rebin the 1D ones with
c  fewer bins and concentrate on the important regions, not all the zeros
c  on the ends.  Chop off ends if each bin is less than 1E-3 of the max. value,
c  -- keep chopping until you get an entry within 1E-3 of the max. value.
c ---- not used in the ALEPH code
c      subroutine orebin1(nbins,xl,xh,histo,newbins)
c      implicit none
c      integer nbins,newbins
c      real xl,xh,histo(*)
c      real htmp(200)
c      integer i,j,imin,imax
c      real xlo,xuo,xln,xun,bolap
c      real vmaxa,vm,dx,dxn
c      external vmaxa
c
c      if (nbins.gt.200) then
c        write(*,*) 'Too many bins in input histo, orebin1'
c        write(*,*) 'max 200, ',nbins
c        stop
c      endif
c      if (newbins.le.0) then
c        write(*,*) 'orebin1; newbins <= 0'
c        stop
c      endif
c
c      dx = (xh-xl)/float(nbins)
c      vm = vmaxa(histo,nbins)
c
c      if (vm.le.0.0) then
cc don't have to rebin if it's all zero anyway
c        nbins = newbins
c        return
c      endif
c
c      do i=1,nbins
c        if ( abs(histo(i))/vm .ge. 1.0E-3 ) goto 10
c      enddo
c 10   imin = i
c      do i=nbins,imin,-1
c        if ( abs(histo(i))/vm .ge. 1.0E-3 ) goto 20
c      enddo
c 20   imax = i
c      xh = xl + float(imax)*dx
c      xl = xl + float(imin-1)*dx
c
c      do i=imin,imax
c        htmp(i-imin+1) = histo(i)
c      enddo
c      nbins = imax - imin + 1
c
c      dxn = (xh-xl)/float(newbins)
c      do i=1,newbins
c        xln = xl + float(i-1)*dxn
c        xun = xln + dxn
c        histo(i) = 0.0
c        do j=1,nbins
c          xlo = xl + float(j-1)*dx
c          xuo = xlo + dx
c          bolap = max(0.0,min(xun,xuo)-max(xln,xlo))/dx
c          histo(i) = histo(i) + bolap*htmp(j)
c        enddo
c      enddo
c      nbins = newbins
c
c      return
c      end

c---------------------------------------------------------------

c subroutine ohistc2  -- combine two independent 1D histograms into
c a 2D histogram.  First index is mass sum, second is mass difference
c when using it with 2D rotated masses
c ---- not used in ALEPH code
c      subroutine ohistc2(nbins1,xl1,xh1,sighist1,
c     >               nbins2,xl2,xh2,sighist2,
c     >               nbins,sighist)
c      implicit none
c      integer nbins1,nbins2,nbins
c      real xl1,xl2,xh1,xh2,sighist1(*),sighist2(*),sighist(*)
c      integer i,j,k
c      nbins = nbins1*nbins2
c      k = 0
c      do i=1,nbins1
c        do j=1,nbins2
c          k = k + 1
c          sighist(k) = sighist1(i)*sighist2(j)
c        enddo
c      enddo
c      return
c      end

c---------------------------------------------------------------

c subroutine ohistscal1 -- scales a 1D histogram so that its integral is
c                          the given factor -- does not change the histogram -- gives
c                          a copy in hcontout
c ---- not used in ALEPH code anymore
c      subroutine ohistscal1(nbins,hcontin,hcontout,scale)
c      implicit none
c      integer nbins
c      real hcontin(*),hcontout(*),scale
c      real sum,vsum
c      external vsum
c      sum = vsum(hcontin,nbins)
c      if (sum.lt.0.0) then
c         write(*,*) 'Histogram sum is negative in ohistscal1'
c         return
c      endif
c      if (sum.eq.0.0) return
c      call vscale(hcontin,scale/sum,hcontout,nbins)
c      return
c      end


c-------------------------------------------------------------------------
c interpolation utilities from P. Bock, renamed with a "T" in front
c so as not to redefine them when using the library.
c added "A" to name to avoid overlap with OPAL's code
      SUBROUTINE ATRHPAR(NBIN,AHIS,XL,XU,XM,SIG,SUM,AMAX,IER)
*  find mean mass, mass variance, content sum
      IMPLICIT NONE
      INTEGER NBIN,IER
      REAL AHIS(NBIN),XL,XU,XM,SIG,SUM,AMAX
      INTEGER I,IMAX
      REAL X,DX,SUMX,SUMX2
*  look for maximum
      IF (NBIN.LE.0) THEN
         IER=4
         GOTO 999
      ENDIF
      IER=0
      DX=(XU-XL)/NBIN
      IMAX=1
      IF (AHIS(1).LT.0.) THEN
         IER=2
         AHIS(1)=0.
      ENDIF
      DO 1 I=2,NBIN
       IF (AHIS(I).LT.0.) THEN
          IER=2
       ELSEIF (AHIS(I).GT.AHIS(IMAX)) THEN
          IMAX=I
       ENDIF
    1 CONTINUE
*
*  mean, variance, sum and maximum
      SUM=0.
      SUMX=0.
      SUMX2=0.
      DO 2 I=1,NBIN
       IF (AHIS(I).GT.0.) THEN
          X=XL+(0.5+FLOAT(I-1))*DX
          SUM=SUM+AHIS(I)
          SUMX=SUMX+X*AHIS(I)
          SUMX2=SUMX2+X**2*AHIS(I)
       ENDIF
    2 CONTINUE
      IF (SUM.LT.1.E-6) THEN
         IER=4
         GOTO 999
      ENDIF
C     XM=SUMX/SUM
*  take maximum
      XM=XL+(FLOAT(IMAX)-0.5)*DX
C     SIG=SQRT((SUMX2-SUMX**2/SUM)/SUM)
*  take variance around maximum
      SIG=SQRT(SUMX2/SUM-2.*SUMX/SUM*XM+XM**2)
*  maximum amplitude
      AMAX=AHIS(IMAX)
  999 RETURN
      END

c added "A" to name to avoid overlap with OPAL's code
      SUBROUTINE ATRHADD(NBIN1,AH1,XL1,XU1,XM1,SIG1,SUM1,AMAX1,
     +                  NBIN2,AH2,XL2,XU2,XM2,SIG2,SUM2,AMAX2,W,
     +                  NBIN, AH, XL, XU, DX, SUM)
*  combine two histograms
*CBO  19-10-97 scaling with rms omitted
      IMPLICIT NONE
      INTEGER NBIN1,NBIN2,NBIN
      REAL AH1(NBIN1),XL1,XU1,XM1,SIG1,SUM1,AMAX1
      REAL AH2(NBIN2),XL2,XU2,XM2,SIG2,SUM2,AMAX2,W
      REAL AH(*),XL,XU,DX,SUM
      REAL XM,SIG,S1,S2,Y,DX1,DX2,W1,W2,X,X1,X2,SLOP
      INTEGER I,INDEX
      REAL ATRSLOP
      EXTERNAL ATRSLOP
*
*  copy one of the histograms if the second one is empty
      IF ((NBIN1.LE.0.AND.NBIN2.LE.0).OR.NBIN.EQ.0) THEN
        NBIN=0
        GOTO 999
      ELSEIF (NBIN1.LE.0) THEN
        DO 1 I=1,NBIN2
         AH(I)=AH2(I)
    1   CONTINUE
        XL=XL2
        XU=XU2
        DX=(XU-XL)/FLOAT(NBIN2)
        SUM=SUM2
        NBIN=NBIN2
        GOTO 999
      ELSEIF (NBIN2.LE.0) THEN
        DO 2 I=1,NBIN1
         AH(I)=AH1(I)
    2   CONTINUE
        XL=XL1
        XU=XU1
        DX=(XU-XL)/FLOAT(NBIN1)
        SUM=SUM1
        NBIN=NBIN1
        GOTO 999
      ENDIF
*
*  select lower/upper abscissa limit
      XL=XL1
      XU=XU1
      IF (XU2.GT.XU) XU=XU2
      IF (XL2.LT.XL) XL=XL2
      DX=(XU-XL)/FLOAT(NBIN)
*  error, if NBIN is < MAX(NBIN1,NBIN2)
C     IF (NBIN.LT.MAX(NBIN1,NBIN2)) THEN
C        DO 11 I=1,NBIN
C         AH(I)=0.
C  11    CONTINUE
C        SUM=0.
C        GOTO 999
C     ENDIF
*
*  compute mean mass
      XM=W*XM1+(1.-W)*XM2
*  check for 1 bin histograms (special case)
CBO      S1=SIG1
      S1=1.
      IF (SIG1.LT.1.E-5) S1=(XU1-XL1)/SQRT(12.)
CBO      S2=SIG2
      S2=1.
      IF (SIG2.LT.1.E-5) S2=(XU2-XL2)/SQRT(12.)
      SIG=SQRT(W*S1**2+(1.-W)*S2**2)
*
*  abscissa rescaling factors = SIG/S1,SIG/S2
*
      IF (NBIN.EQ.1) THEN
         AH(1)=1.
         SUM=1.
         GOTO 999
      ENDIF
*
*  bin widths
      DX1=(XU1-XL1)/FLOAT(NBIN1)
      DX2=(XU2-XL2)/FLOAT(NBIN2)
*  rescale histogram amplitudes:
*  normalise sum of values to 1.
*  larger new bin width -> less function values are stored
*  larger new sigma     -> increased density of function values
*  both effects together may cancel each other
      W1=W/SUM1*S1/SIG*DX/DX1
      W2=(1.-W)/SUM2*S2/SIG*DX/DX2
      DO 3 I=1,NBIN
*  define bin of sum histogram
       X=XL+(0.5+FLOAT(I-1))*DX
       AH(I)=0.
*  contribution of first histogram
       X1=(X-XM)*S1/SIG+XM1
       INDEX=IFIX((X1-XL1)/DX1+1.)
       IF (INDEX.LE.0) GOTO 31
       IF (INDEX.GT.NBIN1) GOTO 31
       SLOP=ATRSLOP(INDEX,NBIN1,AH1,AMAX1)
*
       AH(I)=AH(I)
     +      +W1*(AH1(INDEX)+(X1-(FLOAT(INDEX)-0.5)*DX1-XL1)*SLOP)
*
*  contribution of second histogram
  31   X2=(X-XM)*S2/SIG+XM2
       INDEX=IFIX((X2-XL2)/DX2+1.)
       IF (INDEX.LE.0) GOTO 3
       IF (INDEX.GT.NBIN2) GOTO 3
       SLOP=ATRSLOP(INDEX,NBIN2,AH2,AMAX2)
*
       AH(I)=AH(I)+W2*(AH2(INDEX)
     +      +(X2-(0.5+FLOAT(INDEX-1))*DX2-XL2)*SLOP)
    3 CONTINUE
*
      Y=0.
      SUM=0.
      DO 4 I=1,NBIN
       IF (AH(I).LT.0.) AH(I)=0.
       IF (AH(I).GT.Y) Y=AH(I)
       SUM=SUM+AH(I)
    4 CONTINUE
      IF (SUM.GT.0.) THEN
         DO 5 I=1,NBIN
          AH(I)=AH(I)/Y
          IF (AH(I).LT.1.E-7) AH(I)=0.
    5    CONTINUE
      ENDIF
      SUM=SUM/Y
  999 RETURN
      END
c a slope calculator

      FUNCTION ATRSLOP(I,NDIST,DIST,DISMAX)
      INTEGER I,NDIST
      REAL DIST(NDIST),DISMAX,ATRSLOP
*
      ATRSLOP=0.
      IF (NDIST.LE.1.OR.I.LT.1.OR.I.GT.NDIST) GOTO 999
      IF (I.EQ.1) THEN
         ATRSLOP=DIST(2)-DIST(1)
         GOTO 900
      ELSEIF (I.EQ.NDIST) THEN
         ATRSLOP=DIST(NDIST)-DIST(NDIST-1)
         GOTO 900
      ELSEIF (DIST(I).GE.DIST(I-1).AND.DIST(I).GE.DIST(I+1)) THEN
         GOTO 999
      ELSEIF (DIST(I).LE.DIST(I-1).AND.DIST(I).LE.DIST(I+1)) THEN
         GOTO 999
      ELSE
         ATRSLOP=0.5*(DIST(I+1)-DIST(I-1))
         IF (ATRSLOP.GT.0.) THEN
            IF ((DIST(I)+0.5*ATRSLOP).GT.DIST(I+1))
     +          ATRSLOP=2.*(DIST(I+1)-DIST(I))
            IF ((DIST(I)-0.5*ATRSLOP).LT.DIST(I-1))
     +          ATRSLOP=2.*(DIST(I)-DIST(I-1))
         ELSEIF (ATRSLOP.LT.0.) THEN
            IF ((DIST(I)+0.5*ATRSLOP).LT.DIST(I+1))
     +          ATRSLOP=2.*(DIST(I+1)-DIST(I))
            IF ((DIST(I)-0.5*ATRSLOP).GT.DIST(I-1))
     +          ATRSLOP=2.*(DIST(I)-DIST(I-1))
         ENDIF
CBO      GOTO 999
      ENDIF
*
  900 IF (ABS(ATRSLOP).GT.(2.*DIST(I))) THEN
         IF (ATRSLOP.GT.0.) THEN
            ATRSLOP=2.*DIST(I)
         ELSE
            ATRSLOP=-2.*DIST(I)
         ENDIF
      ENDIF
      IF (ABS(ATRSLOP).GT.2.*(DISMAX-DIST(I))) THEN
         IF (ATRSLOP.GT.0.) THEN
            ATRSLOP=2.*(DISMAX-DIST(I))
         ELSE
            ATRSLOP=2.*(-DISMAX+DIST(I))
         ENDIF
      ENDIF
*
  999 RETURN
      END


c
c     DEBUG / TEST RESULTS PRINTOUT 
c
c     Modified:
c     - Add histogramming option to check shapes; PTD, 18-Feb-2000.
c
      subroutine a_debug(nchan,ifirst,channame,
     +                   nbins,sig,backg,backw,ncand,
     +                   corsig,uncsig,corbkg,uncbkg,
     +                   deltasig,deltaback,sysname,nerrch,chanlumi)
c
      implicit none
      include 'a_inputs.inc'
      integer nchan,ifirst(a_maxnchan),nbins,ncand(a_maxnbin)
      real chanlumi(a_maxnchan)
      character*40 channame(a_maxnchan)
      real sig(a_maxnbin),backg(a_maxnbin),backw(a_maxnbin)
      integer i,j,imax,active(a_maxnchan)
      real totsig,totbackg,totbackw,totcw
      real corsig(a_maxnchan),uncsig(a_maxnchan)
      real corbkg(a_maxnchan),uncbkg(a_maxnchan)
      integer ntotc,nnn
      real xmi,xma

      logical bigdebug,findcnob,smalldebug,systable
      logical xhistos
      parameter (smalldebug=.true.,systable=.true.)
      parameter (bigdebug=.false.)
      parameter (findcnob=.false.)
      parameter (xhistos=.true.)
c For detailed error breakdown:
      integer nerrch(a_maxnchan)
      real deltasig(a_maxnerr,a_maxnchan)
      real deltaback(a_maxnerr,a_maxnchan)
      character*20 sysname(a_maxnerr,a_maxnchan)
c
c      write (6,'(a/(i3,i6,a1,a40))') ' Found the following channels:',
c     +     (i,ifirst(i),' ',channame(i),i=1,nchan)
c
      if (xhistos) then
c
c     Loop over all channels (exc. last one, a dummy)
c
         do i=1,nchan-1       
            nnn = ifirst(i+1) - ifirst(i)
            xmi = float(ifirst(i))
            xma = float(ifirst(i+1))
c
            call hbook1(i,channame(i),nnn,xmi,xma,0.) ! signal hist
            call hbook1(1000+i,channame(i),nnn,xmi,xma,0.) ! sub backgd hist
            call hbook1(2000+i,channame(i),nnn,xmi,xma,0.) ! tot backgd hist
            call hbook1(3000+i,channame(i),nnn,xmi,xma,0.) ! candidates
c
c     Now loop over all bins in this channel
c
            do j=ifirst(i),ifirst(i+1)-1
               call hfill(i,float(j),0.,sig(j))
               call hfill(1000+i,float(j),0.,backg(j))
c NB for channels without background subtraction plot backw instead!
               call hfill(2000+i,float(j),0.,backw(j))
               call hfill(3000+i,float(j),0.,float(ncand(j)))
               
            end do              ! j
         end do                 ! i
c
         call hrput(0,'aleph_pdfs.rz','T')
c
      end if                    ! xhistos
c
c     Find candidates with zero bgd:
c
      if (findcnob) then
        do i=1,nchan
           write (6,*) 'Channel #',i
          imax = nbins
          if (i.lt.nchan) imax = ifirst(i+1) - 1
          do j=ifirst(i),imax
            if (ncand(j).gt.0.and.backg(j).le.0.) then
              write(*,*) 'Channel ',channame(i)(1:30),
     >                   ' has a candidate without bg'
              write(*,*) 'chan j, cand, bg: ',j,ncand(j),backg(j)
            endif
          enddo
        enddo
      endif

      if (smalldebug.or.bigdebug) then
          write (6,'(/a5,a6,10x,a10,6x,3(3x,a6),1x,a5,1x,a4)') 
     +        'NCHAN','IFIRST','CHANNEL-ID',
     +        'TOTSIG','TOTBGD','SUBBGD','NCAND','LUMI'
          write (6,*)
     +'-------------------------------------------------------------',
     +'-------------'
c
        do i=1,nchan
          totcw = 0.0
          totsig = 0.0
          totbackg = 0.0
          totbackw = 0.0
          ntotc = 0
          imax = nbins
          if (i.lt.nchan) imax = ifirst(i+1) - 1
          do j=ifirst(i),imax
            totsig = totsig + sig(j)
            totbackg = totbackg + backg(j)
            totbackw = totbackw + backw(j)
            ntotc = ntotc + ncand(j)
c
            if (backg(j).gt.0.) then
              totcw = totcw + float(ncand(j))*sig(j)/backg(j)
            endif
          enddo
cc          if (totsig .gt. 0.0) then
             write(6,101) i,ifirst(i),' ',channame(i)(1:30),
     >               totsig,totbackw,totbackg,ntotc,chanlumi(i)
cc          else
cc             write (6,102) i,ifirst(i),' ',channame(i)(1:30)
cc          end if
 101      format(i3,1x,i6,a1,a30,3(1x,f6.2),1x,i3,4x,f5.1)
 102      format(i3,1x,i6,a1,a30)
c
c     Flag the active/not-active channels: active() = 1/0
c     
          if (totsig .gt. 0.0) then
             active(i) = 1
          else
             active(i) = 0
          end if
c     
       enddo                    ! i=1,nchan
       write (6,*)
     +'-------------------------------------------------------------'
      endif
c
c          
c     Now print the table with the systematics for all the channels
c     (OPTIONAL)
c
      IF (SYSTABLE) THEN
         write (6,'(/a/a/a/a)')
     +        ' <SYSTEMATICS TABLE> ',' ', 
     +        'NCHAN   CORSIG    UNCSIG    CORBKG    UNCBKG',
     +        '--------------------------------------------'
         do i=1,nchan
c     active channels only:
            if (active(i) .ne. 0) 
     +           write (6,'(i4,4f10.3)') 
     +           i,corsig(i),uncsig(i),corbkg(i),uncbkg(i)
         end do                 ! i
         write (6,'(a)') 
     +        '--------------------------------------------'
      END IF                    ! SYSTABLE

c
c     Dump the new systematics:
c     
      IF (SYSTABLE) THEN
         do i=1,nchan
c     active channels only:
            if (active(i) .ne. 0) 
     +           write (6,'(A,I,A,A,(/A,2(A6,F6.4)))') 
     +           'NCHAN=',i,' CHANNAME=',CHANNAME(I),
     +           (SYSNAME(J,I),' DSIG ',DELTASIG(J,I),
     +           ' DBAK ',DELTABACK(J,I),J=1,NERRCH(I))
         end do                 ! i
         write (6,'(a)') 
     +        '--------------------------------------------'
      END IF                    ! SYSTABLE

        

      if (bigdebug) then
        totsig = 0.0
        totbackg = 0.0
        totbackw = 0.0
        ntotc = 0
        do i=1,nbins
          write(*,*) i,sig(i),backg(i),backw(i),ncand(i)
          totsig = totsig + sig(i)
          totbackg = totbackg + backg(i)
          totbackw = totbackw + backw(i)
          ntotc = ntotc + ncand(i)
          if (ncand(i).gt.0.and.backg(i).gt.0.0) then
             write(*,*) 'Cand weights this bin: ',
     >       float(ncand(i))*sig(i)/backg(i)
          endif
        enddo
        write(*,*) 'Total signal: ',totsig
        write(*,*) 'Total background: ',totbackg
        write(*,*) 'Total bacw: ',totbackw
        write(*,*) 'Total ncand: ',ntotc
      endif

      return
      end
