c-*-FORTRAN-*-
c
      real function a_xtt_bkg_level(iana,ibkg,iener)
c
c Returns the backgrounds expected in the Xtt searches at different energies;
c (Currently only valid for ECM >= 191.6 GeV)
c
c iener = centre-of-mass energy index
c iener = 1 (183 GeV), 2 (188.6), 3 (191.6), 4 (195.6)
c ibkg = bgd type (varies depending on iener)
c     for 192-202 GeV: 1(eeZ+Wenu), 2(qq), 3(WW), 4(ZZ)
c iana = 1 (hZ only), 2 (hA only), 3 (overlap) 
c
c Created:                             Pedro Teixeira-Dias, 31-July-1999.
c
c Modified:
c     - Update: final results for 192 -202 GeV analyses.
c                                                      PTD, 14-Feb-2000.
c
c
      implicit none
      integer iener,ibkg,iana,ienermax,ibkgmax,i,j
      parameter (ienermax=6,ibkgmax=4)
      logical first
      real xtt_norm_bkg(ienermax,ibkgmax) 
      real xtt_norm_bkg_ha(ienermax,ibkgmax) ! hA exclusive, bgd per pb
      real xtt_norm_bkg_hz(ienermax,ibkgmax) ! hZ exclusive, bgd per pb
      real xtt_norm_bkg_ov(ienermax,ibkgmax) ! hA/hZ overlap, bgd per pb
      SAVE xtt_norm_bkg_ha,xtt_norm_bkg_hz,xtt_norm_bkg_ov
      data first / .true. /
c
      real ah0_lumi
      external ah0_lumi
c
      a_xtt_bkg_level = -1.0
c
c---- Enter here the expected backgrounds per unit luminosity
c
      IF (FIRST) THEN
         FIRST = .FALSE.
c
         do i=1,ienermax
            do j=1,ibkgmax
               xtt_norm_bkg_hz(i,j) = 0.0
               xtt_norm_bkg_ha(i,j) = 0.0
               xtt_norm_bkg_ov(i,j) = 0.0
            end do
         end do
c     
c     192 GeV:
c*OPTB 0.00199 0.02175 0.02539 0.01792 
*LRCH 28.923
         xtt_norm_bkg_ha(3,1) = 0.00199 / 28.923
         xtt_norm_bkg_ha(3,2) = 0.02175 / 28.923
         xtt_norm_bkg_ha(3,3) = 0.02539 / 28.923
         xtt_norm_bkg_ha(3,4) = 0.01792 / 28.923
*OPTB 0.02595 0.07824 0.4258 0.4155
*LRCH 28.923
         xtt_norm_bkg_hz(3,1) = 0.02595 / 28.923
         xtt_norm_bkg_hz(3,2) = 0.07824 / 28.923
         xtt_norm_bkg_hz(3,3) = 0.4258 / 28.923
         xtt_norm_bkg_hz(3,4) = 0.4155 / 28.923
*OPTB 0.01794 0.005437 0.05274 0.1548
*LRCH 28.923
         xtt_norm_bkg_ov(3,1) = 0.01794 / 28.923
         xtt_norm_bkg_ov(3,2) = 0.005437 / 28.923
         xtt_norm_bkg_ov(3,3) = 0.05274 / 28.923
         xtt_norm_bkg_ov(3,4) = 0.1548 / 28.923
c     
c     196 GeV:
c
*LRCH 79.834
*OPTB 0.02226 0.01424 0.02194 0.07306
         xtt_norm_bkg_ha(4,1) = 0.02226 / 79.834
         xtt_norm_bkg_ha(4,2) = 0.01424 / 79.834
         xtt_norm_bkg_ha(4,3) = 0.02194 / 79.834
         xtt_norm_bkg_ha(4,4) = 0.07306 / 79.834
*OPTB 0.1143 0.3050 1.316 1.215
         xtt_norm_bkg_hz(4,1) = 0.1143 / 79.834
         xtt_norm_bkg_hz(4,2) = 0.3050 / 79.834
         xtt_norm_bkg_hz(4,3) = 1.316 / 79.834
         xtt_norm_bkg_hz(4,4) = 1.215 / 79.834
*OPTB 0.03339 0.05825 0.1042 0.5343
         xtt_norm_bkg_ov(4,1) = 0.03339 / 79.834
         xtt_norm_bkg_ov(4,2) = 0.05825 / 79.834
         xtt_norm_bkg_ov(4,3) = 0.1042 / 79.834
         xtt_norm_bkg_ov(4,4) = 0.5343 / 79.834
c     
c     200 GeV:
c
*LRCH 86.298
*OPTB 0. 0.03028 0.02500 0.07397
         xtt_norm_bkg_ha(5,1) = 0. / 86.298
         xtt_norm_bkg_ha(5,2) = 0.03028 / 86.298
         xtt_norm_bkg_ha(5,3) = 0.02500 / 86.298
         xtt_norm_bkg_ha(5,4) =  0.07397/ 86.298
*OPTB 0.1702 0.2862 1.825 1.524
         xtt_norm_bkg_hz(5,1) = 0.1702 / 86.298
         xtt_norm_bkg_hz(5,2) = 0.2862 / 86.298
         xtt_norm_bkg_hz(5,3) = 1.825 / 86.298
         xtt_norm_bkg_hz(5,4) = 1.524 / 86.298
*OPTB 0.06077 0.03028 0.1650 0.6657
         xtt_norm_bkg_ov(5,1) = 0.06077 / 86.298
         xtt_norm_bkg_ov(5,2) = 0.03028 / 86.298
         xtt_norm_bkg_ov(5,3) = 0.1650 / 86.298
         xtt_norm_bkg_ov(5,4) = 0.6657 / 86.298
c     
c     202 GeV:
c
*LRCH 41.991
*OPTB 0.005961 0.01421 0.02931 0.02621
         xtt_norm_bkg_ha(6,1) = 0.005961 / 41.991
         xtt_norm_bkg_ha(6,2) = 0.01421 / 41.991
         xtt_norm_bkg_ha(6,3) = 0.02931 / 41.991
         xtt_norm_bkg_ha(6,4) = 0.02621 / 41.991
*OPTB 0.1103 0.09991 1.0454 0.6766
         xtt_norm_bkg_hz(6,1) = 0.1103 / 41.991
         xtt_norm_bkg_hz(6,2) = 0.09991 / 41.991
         xtt_norm_bkg_hz(6,3) = 1.0454 / 41.991
         xtt_norm_bkg_hz(6,4) = 0.6766 / 41.991
*OPTB 0.02981 0.01387 0.08467 0.3169
         xtt_norm_bkg_ov(6,1) = 0.02981 / 41.991
         xtt_norm_bkg_ov(6,2) = 0.01387 / 41.991
         xtt_norm_bkg_ov(6,3) = 0.08467 / 41.991
         xtt_norm_bkg_ov(6,4) = 0.3169 / 41.991
c
      END IF                    ! FIRST
c
c---- 192 - 202 GeV:
c
      IF (IENER.GE.3 .OR. IENER.LE.6) THEN
         IF (IBKG.GE.1 .AND. IBKG.LE.4) THEN
            IF (IANA.EQ.1) THEN ! hA only
               a_xtt_bkg_level = xtt_norm_bkg_ha(iener,ibkg) * 
     +              ah0_lumi(iener)
            ELSEIF (IANA.EQ.2) THEN ! hZ only
               a_xtt_bkg_level = xtt_norm_bkg_hz(iener,ibkg) * 
     +              ah0_lumi(iener)
            ELSEIF (IANA.EQ.3) THEN ! hZ/hA overlap
               a_xtt_bkg_level = xtt_norm_bkg_ov(iener,ibkg) * 
     +              ah0_lumi(iener)
            END IF              ! iana
         END IF                 ! ibkg
      END IF                    ! iener
c
      if (a_xtt_bkg_level.lt.0.0) then
         write (6,*) ' <a_xtt_bkg_level> Error ! Invalid IENER/IBKG!',
     +        iener,ibkg
         a_xtt_bkg_level = 0.0
      end if
c
      end

