c-*-FORTRAN-*-
c
c A series of Xtt functions to return the properties of selected candidates
c as a function of the ECM of the search.
c (Currently only valid for ECM >= 191.6 GeV)
c
c iener = centre-of-mass energy index
c iener = 1 (183 GeV), 2 (188.6), 3 (191.6), 4 (195.6)
c iana = 1 (hA only), 2 (hZ only), 3 (hA/hZ overlap)
c
c Created:                             Pedro Teixeira-Dias, 31-July-1999.
c
c Modified:
c	- Updated: final results for 192 - 202 GeV.    PTD, 14-Feb-2000.
c
c
C---------------------------------------------------------------------
      integer function A_XTT_NUMCAND(iana,iener)
      implicit none
      integer iener,iana
c
      A_XTT_NUMCAND = 0 
c
c     Input protection:
      if (iana.lt.1 .or. iana.gt.3 .or. 
     +    iener.lt.3 .or. iener.gt.6) then
         write (6,*) ' <a_xtt_numcand> Error! Invalid IANA/IENER!',
     +        iana,iener
         return
      end if                    ! protection
c     
      if (iener.eq.3) then
         if (iana.eq.1) a_xtt_numcand = 0 ! hA only
         if (iana.eq.2) a_xtt_numcand = 1 ! hZ only
         if (iana.eq.3) a_xtt_numcand = 0 ! overlap
      elseif (iener.eq.4) then          
         if (iana.eq.1) a_xtt_numcand = 0       
         if (iana.eq.2) a_xtt_numcand = 1     
         if (iana.eq.3) a_xtt_numcand = 0       
      elseif (iener.eq.5) then          
         if (iana.eq.1) a_xtt_numcand = 1       
         if (iana.eq.2) a_xtt_numcand = 7      
         if (iana.eq.3) a_xtt_numcand = 0       
      elseif (iener.eq.6) then          
         if (iana.eq.1) a_xtt_numcand = 0       
         if (iana.eq.2) a_xtt_numcand = 2     
         if (iana.eq.3) a_xtt_numcand = 0       
      end if
c
      end
C---------------------------------------------------------------------
      real*8 function A_XTT_MASS_CAND(iana,iener,icand)
      implicit none
      integer icand,iener,iana

      A_XTT_MASS_CAND = 10000.
c
c     Input protection:
      if (iana.lt.1 .or. iana.gt.3 .or. 
     +    iener.lt.3 .or. iener.gt.6) then
         write (6,*) ' <a_xtt_mass_cand> Error! Invalid IANA/IENER',
     +        iana,iener
         return
      end if                    ! protection
c     
      IF (IENER.EQ.3) THEN
         if (iana.eq.2) then
            if (icand.eq.1)  a_xtt_mass_cand = 95.5171
         end if
      ELSEIF (IENER.EQ.4) THEN             
         if (iana.eq.2) then
            if (icand.eq.1)  a_xtt_mass_cand = 59.0596
         end if
      ELSEIF (IENER.EQ.5) THEN             
         if (iana.eq.1) then
            if (icand.eq.1)  a_xtt_mass_cand = 63.6243
         else if (iana.eq.2) then
            if (icand.eq.1)  a_xtt_mass_cand = 75.1686
            if (icand.eq.2)  a_xtt_mass_cand = 94.7660
            if (icand.eq.3)  a_xtt_mass_cand = 61.4637
            if (icand.eq.4)  a_xtt_mass_cand = 69.8920
            if (icand.eq.5)  a_xtt_mass_cand = 95.8347
            if (icand.eq.6)  a_xtt_mass_cand = 114.397
            if (icand.eq.7)  a_xtt_mass_cand = 104.480
         end if
      ELSEIF (IENER.EQ.6) THEN
         if (iana.eq.2) then
            if (icand.eq.1)  a_xtt_mass_cand = 106.997
            if (icand.eq.2)  a_xtt_mass_cand = 51.2912
         end if
      END IF
c
      end
c---------------------------------------------------------------------
