c-*-FORTRAN-*-
c
      REAL*8 FUNCTION A_XTT_EFF(hmass,iana,istyp,iener)
c
c     Returns the efficiency for a specific signal type (tau final states).
c
c     INPUTS:
c     =======
c     HMASS (real*8), (mh+mA)/2, for 192 and 196 GeV.
c     IANA, branch index: 1 (hA only), 2 (hZ only), 3 (hZ/hA overlap)
c     IENER, centre-of-mass energy index:
c     1 (183 GeV), 2 (188.6), 3 (191.6), 4 (195.5), 5 (199.5), 6 (201.6) GeV
c
c
c     Created:                             Pedro Teixeira-Dias, 31-Jul-1999.
c
c     Modified:
c     - Updated: Xtt analysis final results for 192 - 202 GeV. 
c                                                          PTD, 14-Feb-2000.
c
      implicit none
      integer istyp,iana,iener
      double precision hmass
c
      real*8 
     +  a192_tt_haonly_eff,a192_tt_hzonly_eff,a192_tt_overlap_eff,
     +  a196_tt_haonly_eff,a196_tt_hzonly_eff,a196_tt_overlap_eff,
     +  a200_tt_haonly_eff,a200_tt_hzonly_eff,a200_tt_overlap_eff,
     +  a202_tt_haonly_eff,a202_tt_hzonly_eff,a202_tt_overlap_eff
      external
     +  a192_tt_haonly_eff,a192_tt_hzonly_eff,a192_tt_overlap_eff,
     +  a196_tt_haonly_eff,a196_tt_hzonly_eff,a196_tt_overlap_eff,
     +  a200_tt_haonly_eff,a200_tt_hzonly_eff,a200_tt_overlap_eff,
     +  a202_tt_haonly_eff,a202_tt_hzonly_eff,a202_tt_overlap_eff
c
      a_xtt_eff = 0.D0
C
      IF (IENER.LT.3 .OR. IENER.GT.6 .OR. 
     +     IANA.LT.1 .OR. IANA.GT.3) THEN
         WRITE (6,*) '<a_xtt_eff> Invalid IENER/IANA!',iener,iana
         RETURN
      END IF
c
      IF (IENER .EQ. 3) THEN
         if (iana.eq.1) then
            a_xtt_eff = A192_tt_haonly_eff(hmass,istyp)
         else if (iana.eq.2) then
            a_xtt_eff = A192_tt_hzonly_eff(hmass,istyp)
         else if (iana.eq.3) then
            a_xtt_eff = A192_tt_overlap_eff(hmass,istyp)
         end if
      ELSE IF (IENER .EQ. 4) THEN
         if (iana.eq.1) then
            a_xtt_eff = A196_tt_haonly_eff(hmass,istyp)
         else if (iana.eq.2) then
            a_xtt_eff = A196_tt_hzonly_eff(hmass,istyp)
         else if (iana.eq.3) then
            a_xtt_eff = A196_tt_overlap_eff(hmass,istyp)
         end if
      ELSE IF (IENER .EQ. 5) THEN
         if (iana.eq.1) then
            a_xtt_eff = A200_tt_haonly_eff(hmass,istyp)
         else if (iana.eq.2) then
            a_xtt_eff = A200_tt_hzonly_eff(hmass,istyp)
         else if (iana.eq.3) then
            a_xtt_eff = A200_tt_overlap_eff(hmass,istyp)
         end if
      ELSE IF (IENER .EQ. 6) THEN
         if (iana.eq.1) then
            a_xtt_eff = A202_tt_haonly_eff(hmass,istyp)
         else if (iana.eq.2) then
            a_xtt_eff = A202_tt_hzonly_eff(hmass,istyp)
         else if (iana.eq.3) then
            a_xtt_eff = A202_tt_overlap_eff(hmass,istyp)
         end if
      END IF
c
      a_xtt_eff = max(a_xtt_eff,0.D0)
c
      end
      
c
c-----------------------------------------------------------------------------
c

      DOUBLE PRECISION FUNCTION HTT_EFF_MAP(MASS1, MASS2)
C     This routine provides a scaling factor for the tau analysis
C     efficiencies based on a study of scalar bosons.
C     Dependence on m_1+m_2 is implicit in the efficiency maps;
C     this function gives the scaling as a function of m_1-m_2.
c
c     Created:                              Jason Nielsen, 30-Jul-1999.
c     Modified:       
c     - do not allow correction to go negative;       PTD, 30-Jul-1999.
c
      IMPLICIT NONE
      DOUBLE PRECISION MASS1, MASS2, DELTAM
      DELTAM = ABS(MASS1 - MASS2)
      HTT_EFF_MAP = 1.D0 - 0.49599D-02 * DELTAM
     $     - 0.39054D-03 * DELTAM**2.
c
      IF (HTT_EFF_MAP .LT. 0.D0) HTT_EFF_MAP = 0.D0
c
      RETURN
      END









