c-*-FORTRAN-*-
c
      DOUBLE PRECISION FUNCTION A_XTT_SIG_MASS(x,hms,ichan,istyp,iener)
c
c     returns the signal shape (tau final states) for a given
c     ICHAN = 1 (hA excl), 2 (hZ excl), 3 (overlap treated as hA), 
c             4 (overlap treated as hZ)
c     ISTYP = signal type
c     IENER = centre-of-mass energy; 3,4,5,6 --> 192, 196, 200, 202 GeV
c     X = reconstructed Higgs mass
c     HMASS = reference Higgs mass.
c
c     Created:                               Pedro Teixeira-Dias, 31-Jul-1999.
c
c     Modified:
c     - Updated: Xtt final results for 192 - 202 GeV;        PTD, 14-Feb-2000.
c
c
      implicit none
      integer iana,istyp,iener,ichan
      real*8 x,hms
      real*8 
     +     a192_tt_sig_mass,a196_tt_sig_mass,
     +     a200_tt_sig_mass,a202_tt_sig_mass
      external
     +     a192_tt_sig_mass,a196_tt_sig_mass,
     +     a200_tt_sig_mass,a202_tt_sig_mass
c
      a_xtt_sig_mass = 1.D-8
c
c     Allowed branches and allowed signal types for 192 -202 GeV:
      IF (IENER.GE.3 .AND. IENER .LE.6) THEN
         IF (ICHAN.LT.1 .OR. ICHAN.GT.4 .OR. 
     +       ISTYP.LT.1 .OR. ISTYP.GT.9) THEN
            write (6,*) '<a_xtt_sig_mass> Invalid ICHAN/ISTYP!',
     +           ichan,istyp
         END IF
      ELSE
         write (6,*) '<a_xtt_sig_mass> Invalid IENER!',iener
      END IF
c
      IF (IENER.EQ.3) THEN
         a_xtt_sig_mass = a192_tt_sig_mass(x,hms,ichan,istyp)
      ELSEIF (IENER.EQ.4) THEN
         a_xtt_sig_mass = a196_tt_sig_mass(x,hms,ichan,istyp)
      ELSEIF (IENER.EQ.5) THEN
         a_xtt_sig_mass = a200_tt_sig_mass(x,hms,ichan,istyp)
      ELSEIF (IENER.EQ.6) THEN
         a_xtt_sig_mass = a202_tt_sig_mass(x,hms,ichan,istyp)
      END IF
c
      END
c
c---------------------------  B A C K G R O U N D ------------------------
c
      DOUBLE PRECISION FUNCTION A_XTT_BKG_MASS(RECMAS,ICHAN,IBKG,IENER)
c
      implicit none
      integer iener,ibkg,ichan
      double precision recmas
c
      real*8
     +A192_tt_haonly_eezewnu_mass, A192_tt_haonly_qq_mass,
     +A192_tt_haonly_ww_mass, A192_tt_haonly_zz_mass,
     +A192_tt_hzonly_eezewnu_mass, A192_tt_hzonly_qq_mass,
     +A192_tt_hzonly_ww_mass, A192_tt_hzonly_zz_mass,
     +A192_tt_asha_eezewnu_mass, A192_tt_asha_qq_mass, 
     +A192_tt_asha_ww_mass,
     +A192_tt_asha_zz_mass, A192_tt_ashz_eezewnu_mass, 
     +A192_tt_ashz_qq_mass,
     +A192_tt_ashz_ww_mass, A192_tt_ashz_zz_mass,
c
     +A196_tt_haonly_eezewnu_mass, A196_tt_haonly_qq_mass,
     +A196_tt_haonly_ww_mass, A196_tt_haonly_zz_mass,
     +A196_tt_hzonly_eezewnu_mass, A196_tt_hzonly_qq_mass,
     +A196_tt_hzonly_ww_mass, A196_tt_hzonly_zz_mass,
     +A196_tt_asha_eezewnu_mass, A196_tt_asha_qq_mass, 
     +A196_tt_asha_ww_mass,
     +A196_tt_asha_zz_mass, A196_tt_ashz_eezewnu_mass, 
     +A196_tt_ashz_qq_mass,
     +A196_tt_ashz_ww_mass, A196_tt_ashz_zz_mass,
c
     +A200_tt_haonly_eezewnu_mass, A200_tt_haonly_qq_mass,
     +A200_tt_haonly_ww_mass, A200_tt_haonly_zz_mass,
     +A200_tt_hzonly_eezewnu_mass, A200_tt_hzonly_qq_mass,
     +A200_tt_hzonly_ww_mass, A200_tt_hzonly_zz_mass,
     +A200_tt_asha_eezewnu_mass, A200_tt_asha_qq_mass, 
     +A200_tt_asha_ww_mass,
     +A200_tt_asha_zz_mass, A200_tt_ashz_eezewnu_mass, 
     +A200_tt_ashz_qq_mass,
     +A200_tt_ashz_ww_mass, A200_tt_ashz_zz_mass,
c
     +A202_tt_haonly_eezewnu_mass, A202_tt_haonly_qq_mass,
     +A202_tt_haonly_ww_mass, A202_tt_haonly_zz_mass,
     +A202_tt_hzonly_eezewnu_mass, A202_tt_hzonly_qq_mass,
     +A202_tt_hzonly_ww_mass, A202_tt_hzonly_zz_mass,
     +A202_tt_asha_eezewnu_mass, A202_tt_asha_qq_mass, 
     +A202_tt_asha_ww_mass,
     +A202_tt_asha_zz_mass, A202_tt_ashz_eezewnu_mass, 
     +A202_tt_ashz_qq_mass,
     +A202_tt_ashz_ww_mass, A202_tt_ashz_zz_mass
c
      external
     +A192_tt_haonly_eezewnu_mass, A192_tt_haonly_qq_mass,
     +A192_tt_haonly_ww_mass, A192_tt_haonly_zz_mass,
     +A192_tt_hzonly_eezewnu_mass, A192_tt_hzonly_qq_mass,
     +A192_tt_hzonly_ww_mass, A192_tt_hzonly_zz_mass,
     +A192_tt_asha_eezewnu_mass, A192_tt_asha_qq_mass, 
     +A192_tt_asha_ww_mass,
     +A192_tt_asha_zz_mass, A192_tt_ashz_eezewnu_mass, 
     +A192_tt_ashz_qq_mass,
     +A192_tt_ashz_ww_mass, A192_tt_ashz_zz_mass,
c
     +A196_tt_haonly_eezewnu_mass, A196_tt_haonly_qq_mass,
     +A196_tt_haonly_ww_mass, A196_tt_haonly_zz_mass,
     +A196_tt_hzonly_eezewnu_mass, A196_tt_hzonly_qq_mass,
     +A196_tt_hzonly_ww_mass, A196_tt_hzonly_zz_mass,
     +A196_tt_asha_eezewnu_mass, A196_tt_asha_qq_mass, 
     +A196_tt_asha_ww_mass,
     +A196_tt_asha_zz_mass, A196_tt_ashz_eezewnu_mass, 
     +A196_tt_ashz_qq_mass,
     +A196_tt_ashz_ww_mass, A196_tt_ashz_zz_mass,
c
     +A200_tt_haonly_eezewnu_mass, A200_tt_haonly_qq_mass,
     +A200_tt_haonly_ww_mass, A200_tt_haonly_zz_mass,
     +A200_tt_hzonly_eezewnu_mass, A200_tt_hzonly_qq_mass,
     +A200_tt_hzonly_ww_mass, A200_tt_hzonly_zz_mass,
     +A200_tt_asha_eezewnu_mass, A200_tt_asha_qq_mass, 
     +A200_tt_asha_ww_mass,
     +A200_tt_asha_zz_mass, A200_tt_ashz_eezewnu_mass, 
     +A200_tt_ashz_qq_mass,
     +A200_tt_ashz_ww_mass, A200_tt_ashz_zz_mass,
c
     +A202_tt_haonly_eezewnu_mass, A202_tt_haonly_qq_mass,
     +A202_tt_haonly_ww_mass, A202_tt_haonly_zz_mass,
     +A202_tt_hzonly_eezewnu_mass, A202_tt_hzonly_qq_mass,
     +A202_tt_hzonly_ww_mass, A202_tt_hzonly_zz_mass,
     +A202_tt_asha_eezewnu_mass, A202_tt_asha_qq_mass, 
     +A202_tt_asha_ww_mass,
     +A202_tt_asha_zz_mass, A202_tt_ashz_eezewnu_mass, 
     +A202_tt_ashz_qq_mass,
     +A202_tt_ashz_ww_mass, A202_tt_ashz_zz_mass
c
      a_xtt_bkg_mass = 1.D-8
c
c     Allowed branches and allowed bgd types for 192 -202 GeV:
      IF (IENER.GE.3 .AND. IENER .LE.6) THEN
         IF (ICHAN.LT.1 .OR. ICHAN.GT.4 .OR. 
     +       IBKG.LT.1 .OR. IBKG.GT.4) THEN
            write (6,*) '<a_xtt_bkg_mass> Invalid ICHAN/IBKG!',
     +           ichan,ibkg
         END IF
      ELSE
         write (6,*) '<a_xtt_bkg_mass> Invalid IENER!',iener
      END IF
c
      IF (IENER.EQ.3) THEN ! -------- 192 GeV ---------
      if (ichan.eq.1) then   ! hA only
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A192_tt_haonly_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A192_tt_haonly_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A192_tt_haonly_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A192_tt_haonly_zz_mass(recmas)
         endif
      else if (ichan.eq.2) then ! hZ only
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A192_tt_hzonly_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A192_tt_hzonly_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A192_tt_hzonly_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A192_tt_hzonly_zz_mass(recmas)
         endif
      else if (ichan.eq.3) then ! overlap treated as hA
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A192_tt_asha_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A192_tt_asha_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A192_tt_asha_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A192_tt_asha_zz_mass(recmas)
         endif
      else if (ichan.eq.4) then ! overlap treated as hZ
         if (ibkg.eq.1) then
            a_xtt_bkg_mass = A192_tt_ashz_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A192_tt_ashz_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A192_tt_ashz_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A192_tt_ashz_zz_mass(recmas)
         endif
      end if ! ichan
      ELSE IF (IENER.EQ.4) THEN ! -------- 196 GeV ---------
      if (ichan.eq.1) then   ! hA only
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A196_tt_haonly_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A196_tt_haonly_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A196_tt_haonly_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A196_tt_haonly_zz_mass(recmas)
         endif
      else if (ichan.eq.2) then ! hZ only
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A196_tt_hzonly_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A196_tt_hzonly_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A196_tt_hzonly_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A196_tt_hzonly_zz_mass(recmas)
         endif
      else if (ichan.eq.3) then ! overlap treated as hA
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A196_tt_asha_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A196_tt_asha_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A196_tt_asha_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A196_tt_asha_zz_mass(recmas)
         endif
      else if (ichan.eq.4) then ! overlap treated as hZ
         if (ibkg.eq.1) then
            a_xtt_bkg_mass = A196_tt_ashz_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A196_tt_ashz_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A196_tt_ashz_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A196_tt_ashz_zz_mass(recmas)
         endif
      end if ! ichan
      ELSE IF (IENER.EQ.5) THEN ! -------- 200 GeV ---------
      if (ichan.eq.1) then   ! hA only
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A200_tt_haonly_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A200_tt_haonly_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A200_tt_haonly_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A200_tt_haonly_zz_mass(recmas)
         endif
      else if (ichan.eq.2) then ! hZ only
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A200_tt_hzonly_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A200_tt_hzonly_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A200_tt_hzonly_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A200_tt_hzonly_zz_mass(recmas)
         endif
      else if (ichan.eq.3) then ! overlap treated as hA
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A200_tt_asha_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A200_tt_asha_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A200_tt_asha_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A200_tt_asha_zz_mass(recmas)
         endif
      else if (ichan.eq.4) then ! overlap treated as hZ
         if (ibkg.eq.1) then
            a_xtt_bkg_mass = A200_tt_ashz_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A200_tt_ashz_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A200_tt_ashz_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A200_tt_ashz_zz_mass(recmas)
         endif
      end if ! ichan
      ELSE IF (IENER.EQ.6) THEN ! -------- 202 GeV ---------
      if (ichan.eq.1) then   ! hA only
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A202_tt_haonly_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A202_tt_haonly_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A202_tt_haonly_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A202_tt_haonly_zz_mass(recmas)
         endif
      else if (ichan.eq.2) then ! hZ only
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A202_tt_hzonly_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A202_tt_hzonly_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A202_tt_hzonly_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A202_tt_hzonly_zz_mass(recmas)
         endif
      else if (ichan.eq.3) then ! overlap treated as hA
         if (ibkg.eq.1) then 
            a_xtt_bkg_mass = A202_tt_asha_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A202_tt_asha_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A202_tt_asha_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A202_tt_asha_zz_mass(recmas)
         endif
      else if (ichan.eq.4) then ! overlap treated as hZ
         if (ibkg.eq.1) then
            a_xtt_bkg_mass = A202_tt_ashz_eezewnu_mass(recmas)
         else if (ibkg.eq.2) then
            a_xtt_bkg_mass = A202_tt_ashz_qq_mass(recmas)
         else if (ibkg.eq.3) then
            a_xtt_bkg_mass = A202_tt_ashz_ww_mass(recmas)
         else if (ibkg.eq.4) then
            a_xtt_bkg_mass = A202_tt_ashz_zz_mass(recmas)
         endif
      end if ! ichan
      END IF
c
      end
