c
c Modified:
c     - subtracted WW background is reduced by 2.5% to account for
c       theoretical systematic on the cross section;        
c                                                P Seager, 16-Feb-2000.
c     - fixed wrong sign in one efficiency parameterization;
c     - luminosity uncertty. moved form UNCORrelated to CORrelated error array 
c                                                P Seager, 17-Feb-2000.
c
c     - update of 189, 192, 196, 200, 202 inputs
c     - new inputs from year 2000
c                                               E.Locci, 21-June-2000.  
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C +++ Luminosities
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      REAL FUNCTION AHC_LUMI(IE,C)
C------------------------------------------------------------------------------
C     Intergrated luminosity (pb-1) of the ALEPH data samples analyzed
C     in the charged Higgs search
C
C     Input:     IE    sqrt(s) index (1=130, 2=136, 3=161, 4=172, 
C                                     5=183, 6=189, 7=192, 8=196,
C                                     9=200, 10=202, 11=204, 12=205,
C                                     13=206, 14=207, 15=208)
C                 C    channel (1=tntn, 2=tncs, 3= cssc)
C
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
C - Arguments
      INTEGER    IE,C
C - Common blocks
C - Auxiliary variables
      REAL       LUMI(15)
C - Data statements
      DATA       LUMI / 2.8, 2.8, 11.1, 10.7, 56.9, 176.4 ,28.9 ,
     +                  79.8, 86.3, 41.9, 7.2, 72.3, 19.1, 107.5, 7.8 /
C - Macros
C - Statements
      AHC_LUMI= 0.
      IF( IE.GE.1 .AND. IE.LE.15 ) AHC_LUMI= LUMI(IE)
C      IF (C.EQ.3.AND.IE.EQ.6) AHC_LUMI = 173.6
      IF (C.EQ.1.AND.IE.EQ.6) AHC_LUMI = 173.6
      IF (C.EQ.2.AND.IE.EQ.6) AHC_LUMI = 176.2
      IF ((C.EQ.1.OR.C.EQ.2).AND.IE.EQ.10) AHC_LUMI = 42.0
      IF ((C.EQ.1.OR.C.EQ.2).AND.IE.EQ.12) AHC_LUMI = 217.2
C - Over !
      RETURN
      END 
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C +++ Efficiencies
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      REAL FUNCTION AHC_EFF(IE,C,MH)
C------------------------------------------------------------------------------
C     Get efficiency
C
C     Input:     IE    sqrt(s) index (1=130, 2=136, 3=161, 4=172, 
C                                     5=183, 6=189, 7=192, 8=196,
C                                     9=200, 10=202, 11=204, 12=205,
C                                     13=206, 14=207, 15=208)
C                 C    channel (1=tntn, 2=tncs, 3= cssc)
C                MH    Charged Higgs mass 
C
C Mods:
C =====
C     - Add protection to 189 GeV efficiencies: should be zero for mH outside
C       specified ranges;                                 PTD, 16-Jun-1999.
C
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
C - Arguments
      INTEGER    IE, C
      REAL       MH
C - Common blocks
C - Auxiliary variables
      REAL       EFF, PAR(3,3), PAR6(4)
C - Data statements
      DATA       PAR/ -622.7, 35.324, -0.25386,
     .                -368.8, 26.883, -0.20730,
     .                 280.2,  1.413,  0.0195  /,
     .           PAR6 /-0.298813, 0.258936E-01, -0.351332E-03,
     .                  0.174166E-05/
C - Macros
C - Statements
      AHC_EFF= 0.
      IF( C.EQ.1 ) THEN
        IF (IE.LE.2) THEN
          EFF=(PAR(1,1)+PAR(2,1)*MH+PAR(3,1)*MH**2)/1000.
        ELSE IF(IE.EQ.3) THEN
          EFF=(PAR(1,2)+PAR(2,2)*MH+PAR(3,2)*MH**2)/1000.
        ELSE IF(IE.EQ.4) THEN
          EFF=(PAR(1,3)+PAR(2,3)*MH+PAR(3,3)*MH**2)/1000.
        ELSE IF(IE.EQ.5) THEN
          EFF=0.23788+0.32304E-02*MH
        ELSE IF(IE.EQ.6) THEN
          EFF= PAR6(1) + PAR6(2)*MH + PAR6(3)*MH**2 +
     .         PAR6(4)*MH**3 
CC No cut on E12
CC        ELSE IF(IE.EQ.7) THEN ! 192
CC          EFF= 0.1659+0.00252*MH
CC        ELSE IF(IE.EQ.8) THEN ! 196
CC          EFF= 0.1659+0.00252*MH
CC        ELSE IF(IE.EQ.9) THEN ! 200
CC          EFF= 0.1659+0.00252*MH
CC        ELSE IF(IE.EQ.10) THEN ! 202
CC          EFF= 0.1659+0.00252*MH
CC        ELSE IF(IE.EQ.12) THEN ! 205
CC          EFF= -0.87259+0.49960E-01*MH-0.54397E-03*MH**2
CC     +       +0.14478E-05*MH**3
CC        ENDIF
cc cut E12=0
        ELSE IF(IE.EQ.7) THEN ! 192
          EFF= 0.1659+0.00252*MH*0.935*0.956
        ELSE IF(IE.EQ.8) THEN ! 196
          EFF= 0.1659+0.00252*MH*0.935*0.956
        ELSE IF(IE.EQ.9) THEN ! 200
          EFF= 0.1659+0.00252*MH*0.935*0.956
        ELSE IF(IE.EQ.10) THEN ! 202
          EFF= 0.1659+0.00252*MH*0.935*0.956
        ELSE IF(IE.EQ.12) THEN ! 205
          EFF=(0.16557+0.0022422D0*MH)*0.9093
        ENDIF
CC
        IF (IE.LE.5) THEN
         EFF=0.97*EFF                     ! 3% Systematics
        ENDIF
        IF (IE.LE.2 ) THEN               ! These are E12 inefficiencies ... 
          EFF=0.995*EFF                  ! ... year dependent
        ELSEIF (IE.EQ.3) THEN
          EFF=0.96*EFF
        ELSEIF (IE.EQ.4) THEN
          EFF=0.98*EFF
        ELSEIF (IE.EQ.5) THEN
          EFF=0.9542*EFF
        ELSEIF (IE.EQ.6) THEN
          EFF=0.92*EFF
        ENDIF
      ELSE IF( C.EQ.2 ) THEN
        EFF= 0.
        IF (IE.LE.2 ) THEN
          IF( MH.LE.65. ) THEN
            EFF= -3.2854 + 0.16763*MH - 0.0017520*MH**2
          END IF
        ELSEIF (IE.EQ.3) THEN
          IF( MH.LE.75. ) THEN
            EFF= -4.6167 + 0.25478*MH -0.0039542*MH**2 +
     .            0.18487E-4*MH**3
          END IF
        ELSEIF (IE.EQ.4) THEN
          IF( MH.LE.75. ) THEN
            EFF=  25.833 - 1.9053*MH + 0.053161*MH**2 - 
     .           0.64884E-03*MH**3 + 0.29014E-05*MH**4 
          END IF
        ELSEIF (IE.EQ.5) THEN
          IF( MH.LE.85. ) THEN
            EFF= 2.7062 - 1.0376*MH + 0.73465E-01*MH**2 - 
     .           0.22166E-02*MH**3 + 0.33796E-04*MH**4 -
     .           0.25754E-06*MH**5 + 0.78092E-09*MH**6
          END IF
        ELSEIF (IE.EQ.6) THEN
          IF( MH.GE.55. .AND. MH.LE.90.0 ) THEN
           EFF = -0.49215+0.033257*mh-
     +                        0.00029042*mh**2
          ENDIF
        ELSEIF (IE.EQ.7) THEN
          IF( MH.GE.55. .AND. MH.LE.95.0 ) THEN
           EFF = -1.0269+0.048595*mh-
     +                        0.00039720*mh**2
          ENDIF
        ELSEIF (IE.EQ.8) THEN
          IF( MH.GE.55. .AND. MH.LE.95.0 ) THEN
           EFF = -0.25426+0.026131*mh-
     +                        0.00023304*mh**2
          ENDIF
        ELSEIF (IE.EQ.9) THEN
          IF( MH.GE.55. .AND. MH.LE.95.0 ) THEN
           EFF = -0.31703+0.27668E-01*mh-
     +                        0.245050E-03*mh**2
          ENDIF
        ELSEIF (IE.EQ.10) THEN
          IF( MH.GE.55. .AND. MH.LE.95.0 ) THEN
           EFF = -0.58802+0.034515*mh
     +                       -0.00028349*mh**2
          ENDIF
        ELSEIF (IE.EQ.12) THEN
          IF( MH.GE.55. .AND. MH.LE.95.0 ) THEN
           EFF = 20.725-1.0583*mh+(0.20556E-01)*mh**2
     +         -0.17520E-03*mh**3+0.54895E-06*mh**4
           EFF = -0.096137+0.021007*mh-0.00018693*mh**2  
          ENDIF
        ENDIF
        IF( IE.LE.5 ) EFF= 0.97*EFF       ! 3% Systematics
C        IF( IE.EQ.6 ) THEN
C         EFF= 0.950*EFF       
C        ELSEIF (IE.EQ.7) THEN
C         EFF= 0.968*EFF
C        ELSEIF (IE.EQ.8) THEN
C         EFF= 0.949*EFF
C        ELSEIF (IE.EQ.9) THEN
C         EFF= 0.949*EFF
C        ELSEIF (IE.EQ.10) THEN
C         EFF= 0.950*EFF
C        ENDIF
      ELSE IF( C.EQ.3 ) THEN
        IF( IE.LE.2 ) THEN
          EFF= -58.344 + 4.4132*MH - 0.12423*MH**2 +
     .                0.0015499*MH**3 - 0.72358e-5*MH**4
        ELSE IF( IE.EQ.3 ) THEN
          IF( MH.LE.50 ) THEN
            EFF= 0.38034 - 0.0063101*(50.-MH)
          ELSE
            EFF= 0.38034 - 0.0034471*(MH-50.)
          ENDIF
        ELSE IF( IE.EQ.4 ) THEN
          EFF= -1.9404 + 0.11360*MH - 0.0018343*MH**2 + 
     .                0.97532E-5*MH**3
        ELSE IF( IE.EQ.5 ) THEN
          EFF= -8.7928 + 0.59303*MH - 0.014200 *MH**2 +
     .                0.14948E-3*MH**3 - 0.58653E-06*MH**4
        ELSE IF( IE.EQ.6 ) THEN
          EFF = -6.650873 +0.2785414 *MH
     +                       -3.4225592E-03*MH**2
     +                       +1.3369694E-05*MH**3
        ELSE IF( IE.EQ.7 ) THEN
          EFF = -2.7333315E-02+1.2501711E-02*MH
     +                       +8.9107431E-05*MH**2
     +                       -1.8203497E-06*MH**3
        ELSE IF( IE.EQ.8 ) THEN
          EFF = -4.0864613E-02+1.2569138E-02*MH
     +                       +9.2819697E-05*MH**2
     +                       -1.7872530E-06*MH**3
        ELSE IF( IE.EQ.9 ) THEN
          EFF = -0.1420571 +1.3611015E-02*MH
     +                       +1.0790591E-04*MH**2
     +                       -1.8859197E-06*MH**3
        ELSE IF( IE.EQ.10 ) THEN
          EFF = -0.1529342 +1.3666991E-02*MH
     +                       +1.0837410E-04*MH**2
     +                       -1.8552965E-06*MH**3
        ELSE IF( IE.EQ.11 ) THEN
          EFF = -7.0463151E-02+1.2470203E-02*MH
     +                       +9.7267148E-05*MH**2
     +                       -1.6672419E-06*MH**3
        ELSE IF( IE.EQ.12 ) THEN
          EFF = -0.12025 +0.13157E-01*MH
     +                       +0.10165E-03*MH**2
     +                       -0.17263E-05*MH**3
        ELSE IF( IE.EQ.13 ) THEN
          EFF = -0.1114608 +1.2791768E-02*MH
     +                       +1.0303574E-04*MH**2
     +                       -1.6975196E-06*MH**3
        ELSE IF( IE.EQ.14 ) THEN
          EFF = -0.91006E-01+0.12630E-01*MH
     +                       +0.97164E-04*MH**2
     +                       -0.16300E-05*MH**3
        ELSE IF( IE.EQ.15 ) THEN
          EFF = -0.1181155 +1.2897307E-02*MH
     +                       +1.0455905E-04*MH**2
     +                       -1.7030842E-06*MH**3
        ENDIF
        IF( IE.LE.5 ) THEN
          EFF= 0.98*EFF         ! Systematics ... 2%
        END IF
C        IF( IE.EQ.6 ) THEN
C         EFF= 0.97*EFF       
C        ELSEIF (IE.EQ.7) THEN
C         EFF= 0.981*EFF
C        ELSEIF (IE.EQ.8) THEN
C         EFF= 0.981*EFF
C        ELSEIF (IE.EQ.9) THEN
C         EFF= 0.981*EFF
C        ELSEIF (IE.EQ.10) THEN
C         EFF= 0.981*EFF
C        ENDIF
      END IF
C - Output
      AHC_EFF= MAX(EFF,0.)
C - Protection, 189 GeV efficiencies:
C      IF (C.EQ.1 .AND. (MH.LT.45.0 .OR. MH.GT.94.3)) AHC_EFF = 0.0
C      IF (C.EQ.2 .AND. (MH.LT.50.0 .OR. MH.GT.80.0)) AHC_EFF = 0.0
C      IF (C.EQ.3 .AND. (MH.LT.50.0 .OR. MH.GT.80.0)) AHC_EFF = 0.0
C - Over!
      RETURN
      END 

C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C +++ Background
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      SUBROUTINE AHC_BKG(IE,C,MH,NUB,NUBT)
C------------------------------------------------------------------------------
C     Expected bkg. For C=3 (cscs) it is the bkg 
C     in window [MH+DM0-DM,MH+DM0+DM] from analytical integration 
C     of distributions fitted on MC
C
C     Input:     IE    sqrt(s) index (1=130, 2=136, 3=161, 4=172, 
C                                     5=183, 6=189, 7=192, 8=196
C                                     9=200, 10=202, 11=204, 12=205,
C                                     13=206, 14=207, 15=208)
C                 C    channel (1=tntn, 2=tncs, 3= cssc)
C                MH    Charged Higgs mass 
C     Output:    NUB   subtractible bkg
C                NUBT  total bkg
C
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
      REAL       DM, DM0
      PARAMETER( DM= 3., DM0=-0.2 )
      REAL       LUMI_183
      PARAMETER( LUMI_183= 0.0569 )
C - Arguments
      INTEGER    IE, C
      REAL       MH, NUB, NUBT
C - Common blocks
C - Auxiliary variables
      INTEGER    I, IM
      REAL       M, M0, MMI, MMX, BKGS, BKGT, DMH,
     .           B133, B161, B172, B183, XMX, XW,
     .           BKGT1, BKGT2,
     .           TNTN_BKG, BTNCS(91)
      EXTERNAL   TNTN_BKG
C - Data statements
      DATA       BTNCS / 10*1.,
     .                1.0, 1.0, 1.0, 1.1, 1.1, 1.1, 1.2, 1.1,
     .                1.1, 1.1, 1.2, 1.2, 1.2, 1.2, 1.2, 1.3,
     .                1.3, 1.3, 1.3, 1.4, 1.3, 1.3, 1.4, 1.4,
     .                1.3, 1.3, 1.4, 1.4, 1.4, 1.4, 1.5, 1.6,
     .                1.6, 1.6, 1.6, 1.7, 1.7, 1.8, 1.9, 2.0,
     .                2.1, 2.2, 2.2, 2.2, 2.2, 2.4, 2.5, 2.6,
     .                2.8, 2.9, 3.1, 3.2, 3.4, 3.7, 3.9, 3.9,
     .                4.0, 4.2, 4.5, 4.7, 5.1, 5.3, 5.8, 6.2,
     .                6.7, 7.2, 7.5, 8.2, 8.7, 9.2, 9.9,10.4,
     .               11.2,11.8,12.5,12.8,13.2,13.8,14.2,14.2,
     .               14.7 /
C - Macros
C - Statements
      BKGS= 0.
      BKGT= 0.
C - Define window
      M0= MH + DM0
      MMI= M0 - DM
      MMX= M0 + DM
      IF( C.EQ.1 ) THEN
        BKGS= TNTN_BKG(MH,0.,1,IE+1,2)
        BKGT= TNTN_BKG(MH,0.,0,IE+1,2)
      ELSE IF( C.EQ.2 ) THEN
        BKGT= 0.
        IF( IE.EQ.1 .OR. IE.EQ.2 ) THEN
          IF( MH.LT.65. ) BKGT= 0.15
        ELSE IF( IE.EQ.3  ) THEN
          IF( MH.LT.80.5 ) BKGT= .8
        ELSE IF( IE.EQ.4 ) THEN
          IF( MH.LT.86.0 ) BKGT= 1.0
        ELSE IF( IE.EQ.5 ) THEN
          MMI = 39.75
          DMH =  0.50
          IM= INT((MH-MMI-DMH/2.)/DMH) + 1
          IM= MIN(IM,91)
          IF( IM.GE.1 ) BKGT= BTNCS(IM)
        ELSE IF( IE.EQ.6 ) THEN
          MMI = 20.00
          MMX = 94.30
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 68.04 !69.52
          END IF
        ELSE IF( IE.EQ.7 ) THEN
          MMI = 20.00
          MMX = 96.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 12.05 !12.31 
          END IF
        ELSE IF( IE.EQ.8 ) THEN
          MMI = 20.00
          MMX = 98.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 37.57 !38.38
          END IF
        ELSE IF( IE.EQ.9 ) THEN
          MMI = 20.00
          MMX = 100.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 41.62 !42.52
         END IF
        ELSE IF( IE.EQ.10 ) THEN
          MMI = 20.00
          MMX = 101.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 21.89 !22.36
          END IF
        ELSE IF( IE.EQ.12 ) THEN
          MMI = 40.00
          MMX = 102.5
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 118.0
          END IF
        END IF
        IF( IE.LE.5 ) BKGS = 0.80*BKGT
        IF (IE.EQ.6) THEN
          BKGS = BKGT !0.949*BKGT
        ELSEIF (IE.EQ.7) THEN
          BKGS = BKGT !0.947*BKGT
        ELSEIF (IE.EQ.8) THEN
          BKGS = BKGT !0.949*BKGT
        ELSEIF (IE.EQ.9) THEN
          BKGS = BKGT !0.949*BKGT
        ELSEIF (IE.EQ.10) THEN
          BKGS = BKGT !0.950*BKGT
        ELSEIF (IE.EQ.12) THEN
          BKGS = BKGT
       ENDIF 
      ELSE IF( C.EQ.3 ) THEN
        IF (IE.LE.5) THEN
         CALL AHC_BKG_CSSC(IE,MH,BKGS)
         BKGT= MAX(BKGS,0.)
        ELSE IF (IE.EQ.6) THEN
          MMI = 60.00
          MMX = 94.30
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 600.630
          END IF
        ELSE IF (IE.EQ.7) THEN
          MMI = 60.00
          MMX = 96.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 106.721
          END IF
        ELSE IF (IE.EQ.8) THEN
          MMI = 60.00
          MMX = 98.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 301.182
          END IF
        ELSE IF (IE.EQ.9) THEN
          MMI = 60.00
          MMX = 100.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 352.644
          END IF
        ELSE IF (IE.EQ.10) THEN
          MMI = 60.00
          MMX = 101.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 187.393
          END IF
        ELSE IF (IE.EQ.11) THEN
          MMI = 60.00
          MMX = 102.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 33.173
          END IF
        ELSE IF (IE.EQ.12) THEN
          MMI = 60.00
          MMX = 102.50
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 335.682
          END IF
        ELSE IF (IE.EQ.13) THEN
          MMI = 60.00
          MMX = 103.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 88.358
          END IF
        ELSE IF (IE.EQ.14) THEN
          MMI = 60.00
          MMX = 103.50
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 503.140
          END IF
        ELSE IF (IE.EQ.15) THEN
          MMI = 60.00
          MMX = 104.00
          IF( MH.GE.MMI .AND. MH.LE.MMX ) THEN
            BKGT= 37.322
          END IF
        ENDIF  
C - Systematics
        IF( IE.LE.5 ) THEN
          BKGS = .89*BKGT            ! 11% for 130-183 inclusive ...
        END IF 
        IF (IE.EQ.6) THEN
          BKGS = BKGT !0.970*BKGT
        ELSEIF (IE.EQ.7) THEN
          BKGS = BKGT !0.969*BKGT
        ELSEIF (IE.EQ.8) THEN
          BKGS = BKGT !0.969*BKGT
        ELSEIF (IE.EQ.9) THEN
          BKGS = BKGT !0.969*BKGT
        ELSEIF (IE.EQ.10) THEN
          BKGS = BKGT !0.969*BKGT
        ELSEIF (IE.EQ.11) THEN
          BKGS = BKGT
        ELSEIF (IE.EQ.12) THEN
          BKGS = BKGT
        ELSEIF (IE.EQ.13) THEN
          BKGS = BKGT
        ELSEIF (IE.EQ.14) THEN
          BKGS = BKGT
        ELSEIF (IE.EQ.15) THEN
          BKGS = BKGT
        ENDIF 
      END IF
C - Output variable
      NUB = BKGS
      NUBT= BKGT
C - Over!
      RETURN
      END 

      real function tntn_bkg(mstau,mchi,proc,necm,dmflag)
C
C total (proc=0) or subtractable (proc=1) background for stau search at
C low dm (dmflag=1) or high dm (dmflag=2)
C
C   necm=1:  91 GeV
C   necm=2: 130 GeV
C   necm=3: 136 GeV
C   necm=4: 161 GeV
C   necm=5: 172 GeV
C   necm=6: 183 GeV
C   necm=7: 189 GeV
C   necm=8: 192 GeV
C   necm=9: 196 GeV
C   necm=10: 200 GeV
C   necm=11: 202 GeV
C   necm=12: 204 GeV
C   necm=13: 205 GeV
C   necm=14: 206 GeV
C   necm=15: 207 GeV
C   necm=16: 208 GeV
C
      implicit none

      integer proc,necm,dmflag
      real mstau,mchi

      real wwpar(6,1)
      data wwpar/-0.22154,     0.36933E-01,  0.89864E-02,
     .           -0.26628E-03, 0.28873E-05, -0.11132E-07/
      real bpar(4,1)
      data bpar/1.0338, 0.52932E-01, -0.81476E-03, 0.42494E-05/

      real dm,btot,bsub,ww,b

      dm=mstau-mchi
      btot=0.
      bsub=0.
      if (necm.eq.1) then
        bsub=0.
        btot=1.
      elseif (necm.eq.2) then
        bsub=0.1
        btot=0.5
      elseif (necm.eq.3) then
        bsub=0.1
        btot=0.5
      elseif (necm.eq.4) then
        if (dmflag.eq.1) then
          bsub=-0.73110E-01+0.17215E-01*dm-0.31280E-03*dm**2+
     .          0.24188E-05*dm**3-0.68577E-08*dm**4
          btot=bsub+0.41152+0.49245E-02*dm-0.30757E-04*dm**2

C   E12G inefficiency (in addition to E12)
          bsub=0.986*bsub
          btot=0.986*btot
        else
          bsub=0.3
          btot=0.5
        endif
      elseif (necm.eq.5) then
        if (dmflag.eq.1) then
          bsub=-0.52180E-01+0.85941E-02*dm+0.18048E-02*dm**2-
     .          0.60263E-04*dm**3+0.70841E-06*dm**4-0.28878E-08*dm**5
          btot=bsub+0.27227+0.52521E-02*dm-0.34831E-04*dm**2

C   E12G inefficiency (in addition to E12)
          bsub=0.98*bsub
          btot=0.98*btot
        else
          bsub=0.9
          btot=1.
        endif
      elseif (necm.eq.6) then
C 183
        if (dmflag.eq.1) then
C  low dm
          ww=wwpar(1,1)+wwpar(2,1)*dm+wwpar(3,1)*dm**2+wwpar(4,1)*dm**3+
     .       wwpar(5,1)*dm**4+wwpar(6,1)*dm**5
          b=bpar(1,1)+bpar(2,1)*dm+bpar(3,1)*dm**2+bpar(4,1)*dm**3
          btot=b+ww
          bsub=ww

C   E12G inefficiency (in addition to E12)
          bsub=0.9671*bsub
          btot=0.9671*btot
        else
C  high dm
C          bsub=5.5
C          btot=5.5+1.3
          btot = 6.46
          bsub = 0.925*btot  
        endif
      elseif (necm.eq.7) then
C 189
C  high dm
C        bsub=12.7 
C        btot=12.7 + 2.76
        btot = 15.17 !15.46
        bsub = btot !0.925*btot
      elseif (necm.eq.8) then
C 192
CC        btot = 4.22 !4.28 no cut on E12
        btot = 2.84 ! cut E12=0
        bsub = btot
      elseif (necm.eq.9) then
C 196
CC        btot = 11.81 !11.99 no cut on E12
        btot = 7.86 ! cut E12=0
        bsub = btot 
      elseif (necm.eq.10) then
C 200
CC        btot = 13.11 !13.31 no cut on E12
        btot = 9.12 ! cut E12=0
        bsub = btot
      elseif (necm.eq.11) then
C 202
CC        btot = 6.37 !6.46 no cut on E12
        btot = 4.46 ! cut E12=0
        bsub = btot
      elseif (necm.eq.13) then
C 205
        btot = 22.0
        bsub = btot
      endif

C E12 inefficiencies
      if ((necm.eq.2).or.(necm.eq.3)) then
        bsub=0.995*bsub
        btot=0.995*btot
      elseif (necm.eq.4) then
        bsub=0.96*bsub
        btot=0.96*btot
      elseif (necm.eq.5) then
        bsub=0.98*bsub
        btot=0.98*btot
      elseif (necm.eq.6) then
C        bsub=0.9542*bsub
C        btot=0.9542*btot
        bsub=1.00*bsub           ! Already taken into account
        btot=1.00*btot
      elseif (necm.eq.7) then
C        bsub=0.92*bsub
C        btot=0.92*btot
        bsub=1.00*bsub          ! Already taken into account 
        btot=1.00*btot
      endif

C ensure phycical values
      btot=max(btot,0.)
      bsub=max(bsub,0.)

      if (proc.eq.0) then
C total background
        tntn_bkg=MAX(btot,0.)
      else
C subtractable background
        tntn_bkg=MAX(bsub,0.)
      endif

      end

C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C +++ Mass distributions
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      REAL FUNCTION AHC_BKG_DIS(IE,C,M,MH)
C------------------------------------------------------------------------------
C     Bkg probability mass distribution
C     Set to 1. for C=1,2
C     Normalized to +-3 GeV window for C= 3
C
C     Input:     IE    sqrt(s) index (1=130, 2=136, 3=161, 4=172, 
C                                     5=183, 6=189, 7=192, 8=196,
C                                     9=200, 10=202, 11=204, 12=205,
C                                     13=206, 14=207, 15=208)
C                 C    channel (1=tntn, 2=tncs, 3= cssc)
C                 M    reconstructed mass
C                MH    Charged Higgs reference mass (needed because of 
C                      the sliding cut)
C
C Mods:
C =====
C
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
      REAL       DM, DM0, SMALL
      PARAMETER( DM= 3., DM0=-0.2, SMALL= 1.E-5 )
C - Arguments
      INTEGER    IE, C
      REAL       M, MH
C - Common blocks
C - Auxiliary variables
      INTEGER    I
      REAL       A133(5), A161(5), A172(5), A183(5), A189(5), 
     .           B161(3), B172(3), B183(3), B172_2(3), B189(3), 
     .           MLW(6), MUP(6), MMI, MMX, AA, BKG
       real*8 A_TVQQ_SM_189
       real*8 A_TVQQ_SM_205
       real*8 A_TVQQ_SM_202
       real*8 A_TVQQ_SM_200
       real*8 A_TVQQ_SM_196
       real*8 A_TVQQ_SM_192
       real*8 A_QQQQ_SM_208
       real*8 A_QQQQ_SM_207
       real*8 A_QQQQ_SM_206
       real*8 A_QQQQ_SM_205
       real*8 A_QQQQ_SM_204
       real*8 A_QQQQ_SM_202
       real*8 A_QQQQ_SM_200
       real*8 A_QQQQ_SM_196
       real*8 A_QQQQ_SM_192
       real*8 A_QQQQ_SM_189
       EXTERNAL A_TVQQ_SM_189,A_TVQQ_SM_202, ! added, PTD 26-02-2000.
     +      A_TVQQ_SM_205,A_TVQQ_SM_200,A_TVQQ_SM_196,A_TVQQ_SM_192,
     +      A_QQQQ_SM_208,A_QQQQ_SM_207,A_QQQQ_SM_206,A_QQQQ_SM_205,
     +      A_QQQQ_SM_204,A_QQQQ_SM_202,A_QQQQ_SM_200,A_QQQQ_SM_196,
     +      A_QQQQ_SM_192,A_QQQQ_SM_189
C - Data statements
      DATA       A133 / -1.4517, 0.60548E-01, -0.57338E-03, 2*0. /,
     .           A161 / 0.64588 , -0.18242E-01, 0.61834E-04, 
     .                  0.40310E-05, -0.30927E-07 /,
     .           A172 / -0.24165, 0.52404E-02, 0.62478E-04, 
     .                  0.21905E-05, -0.41810E-07 /,
     .           A183 / -3.6082, 0.11997, -0.81847E-04, 
     .                  -0.13686E-04, 0.66468E-07 /,
C     .           A189 / -19.12451, 0.285112, 0.4941711E-02, 
C     .                   0.1424927E-04, -0.1129860E-05 /,
     .           A189 / -3.3115, 0.15526,-0.71248E-03, 
     .                   0., 0. /,
     .           B189 / 143.53, 1.0896, 80.348 /
     .           B161 /  0.24358, 0.47268, 78.956 /,
     .           B172 /  8.8257, 2.6731, 80.285 /,
     .           B183 / 48.279, 2.5831, 80.295 /,
C     .           B189 / 274.9575, 4.019085, 80.32246 /,
     .           B172_2 / 0.59059, 2.9273, 74.122 /,
     .           MLW  / 5*35., 47. /,
     .           MUP  / 2*68., 80.5, 86., 91.5, 80. /
C - Macros
C - Statements
      IF (IE.LE.6) THEN ! protect against MLW/MUP(IE>6)! PTD 26-02-2000.
         MMI= MAX( MH + DM0 - DM, MLW(IE) )
         MMX= MIN( MH + DM0 + DM, MUP(IE) )
      END IF
C - Get normalized bkg
      IF( C.EQ.1 ) THEN
        BKG= 1.
      ELSE IF( C.EQ.2 ) THEN
        BKG= 1.
        IF( IE.EQ.6 ) THEN
          BKG= 0.
          MMI= 20.0
          MMX= 94.3
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_TVQQ_SM_189(DBLE(M)))
          END IF
        END IF
        IF( IE.EQ.7 ) THEN
          BKG= 0.
          MMI= 20.0
          MMX= 96.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_TVQQ_SM_192(DBLE(M)))
          END IF
        END IF
        IF( IE.EQ.8 ) THEN
          BKG= 0.
          MMI= 20.0
          MMX= 98.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_TVQQ_SM_196(DBLE(M)))
          END IF
        END IF
        IF( IE.EQ.9 ) THEN
          BKG= 0.
          MMI= 20.0
          MMX= 100.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_TVQQ_SM_200(DBLE(M)))
          END IF
        END IF
        IF( IE.EQ.10 ) THEN
          BKG= 0.
          MMI= 20.0
          MMX= 101.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_TVQQ_SM_202(DBLE(M)))
          END IF
        END IF
        IF( IE.EQ.12 ) THEN
          BKG= 0.
          MMI= 40.0
          MMX= 102.5
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_TVQQ_SM_205(DBLE(M)))
          END IF
        END IF
      ELSE IF( C.EQ.3 ) THEN
        BKG= 0.
        IF (IE.EQ.6) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 94.3
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_189(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.7) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 96.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_192(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.8) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 98.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_196(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.9) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 100.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_200(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.10) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 101.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_202(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.11) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 102.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_204(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.12) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 102.5
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_205(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.13) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 103.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_206(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.14) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 103.5
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_207(DBLE(M)))
          END IF
        ENDIF
        IF (IE.EQ.15) THEN
          BKG= 0.
          MMI= 60.0
          MMX= 104.0
          IF( M.GT.MMI .AND. M.LE.MMX ) THEN
            BKG= SNGL(A_QQQQ_SM_208(DBLE(M)))
          END IF
        ENDIF
        IF( M.GT.MMI .AND. M.LT.MMX .AND.IE.LE.5) THEN ! added IE, PTD 26-02-00
          CALL AHC_BKG_CSSC(IE,MH,AA)
          IF( IE.EQ.1 .OR. IE.EQ.2 ) THEN
            BKG= ( A133(1) + A133(2)*M + A133(3)*M**2 ) / AA
          ELSE IF( IE.EQ.3 ) THEN
            BKG= ( A161(1) + A161(2)*M + A161(3)*M**2 +
     .             A161(4)*M**3 + A161(5)*M**4 +
     .             B161(1)/(B161(2)+(M-B161(3))**2) ) / AA
          ELSE IF( IE.EQ.4 ) THEN
            BKG= ( A172(1) + A172(2)*M + A172(3)*M**2 +
     .             A172(4)*M**3 + A172(5)*M**4 +
     .             B172(1)/(B172(2)+(M-B172(3))**2) +
     .             B172_2(1)/(B172_2(2)+(M-B172_2(3))**2) ) / AA
          ELSE IF( IE.EQ.5 ) THEN
            BKG= ( A183(1) + A183(2)*M + A183(3)*M**2 +
     .             A183(4)*M**3 + A183(5)*M**4 +
     .             B183(1)/(B183(2)+(M-B183(3))**2) ) / AA
          END IF
        END IF
        BKG= MAX(0.,BKG)
      END IF
C - Output variable
      AHC_BKG_DIS= BKG
C - Over!
      RETURN
      END 



      REAL FUNCTION AHC_SIG_DIS(IE,C,M,MH)
C------------------------------------------------------------------------------
C     Signal probability mass distribution
C     Set to 1. for C=1,2
C     For C= 3: Breit-Wigner with mean MH+DM0 and width GG(sqrt(s))
C     normalized in [MH+DM0-DM,MH+DM0+DM]
C
C     Input:     IE    sqrt(s) index (1=130, 2=136, 3=161, 4=172, 
C                                     5=183, 6=189, 7=192, 8=196,
C                                     9=200, 10=202, 11=204, 12=205,
C                                     13=206, 14=207, 15=208)
C                 C    channel (1=tntn, 2=tncs, 3= cssc)
C                 M    reconstructed mass
C                MH    Charged Higgs reference mass (needed because of 
C                      the sliding cut)
C
C Mods:
C =====
C     - Add a separate "FIRST" variable (FIRST2) for the cssc channel!
C     (otherwise could not initialize BOTH the tncs and cssc channels in the 
C     same run...)                                           PTD, 21-Jun-1999.
C
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
      REAL       DM, DM0, DM02, MMI, MMX
      PARAMETER( DM= 3., DM0=-0.2, 
     .           DM02= 0.269, MMI= 50., MMX= 77.5 )
C - Arguments
      INTEGER    IE, C
      REAL       M, MH
C - Common blocks
C - Auxiliary variables
      INTEGER    I, ENE
      REAL       GG(6), M0, AA(6), UU, AA2, GG2
      SAVE       AA, AA2
      LOGICAL    FIRST,FIRST2
C - Data statements
      DATA       GG / 0.58, 0.58, 0.80, 0.75, 0.75, 0.95 /,
     .           GG2 / 1.5739 /,
     .           FIRST,FIRST2 /.TRUE., .TRUE./
C
C  Phil's stuff
C
       REAL*8 A_TVQQ_SIG_208,A_QQQQ_SIG_208
       REAL*8 A_TVQQ_SIG_207,A_QQQQ_SIG_207
       REAL*8 A_TVQQ_SIG_206,A_QQQQ_SIG_206
       REAL*8 A_TVQQ_SIG_205,A_QQQQ_SIG_205
       REAL*8 A_TVQQ_SIG_204,A_QQQQ_SIG_204
       REAL*8 A_TVQQ_SIG_202,A_QQQQ_SIG_202
       REAL*8 A_TVQQ_SIG_200,A_QQQQ_SIG_200
       REAL*8 A_TVQQ_SIG_196,A_QQQQ_SIG_196
       REAL*8 A_TVQQ_SIG_192,A_QQQQ_SIG_192
       REAL*8 A_TVQQ_SIG_189,A_QQQQ_SIG_189

C - Macros
C - Statements
      ENE= IE
      IF( C.EQ.1 ) THEN
        AHC_SIG_DIS= 1.
      ELSE IF( C.EQ.2 ) THEN
        AHC_SIG_DIS= 1.
        IF (IE.EQ.6) THEN
         AHC_SIG_DIS = 0.0
         AHC_SIG_DIS = SNGL(A_TVQQ_SIG_189(DBLE(M),DBLE(MH)))
         IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
        ENDIF
        IF (IE.EQ.7) THEN
         AHC_SIG_DIS = 0.0
         AHC_SIG_DIS = SNGL(A_TVQQ_SIG_192(DBLE(M),DBLE(MH)))
         IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
        ENDIF
        IF (IE.EQ.8) THEN
         AHC_SIG_DIS = 0.0
         AHC_SIG_DIS = SNGL(A_TVQQ_SIG_196(DBLE(M),DBLE(MH)))
         IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
        ENDIF
        IF (IE.EQ.9) THEN
         AHC_SIG_DIS = 0.0
         AHC_SIG_DIS = SNGL(A_TVQQ_SIG_200(DBLE(M),DBLE(MH)))
         IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
        ENDIF
        IF (IE.EQ.10) THEN
         AHC_SIG_DIS = 0.0
         AHC_SIG_DIS = SNGL(A_TVQQ_SIG_202(DBLE(M),DBLE(MH)))
         IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
        ENDIF
        IF (IE.EQ.12) THEN
         AHC_SIG_DIS = 0.0
         AHC_SIG_DIS = SNGL(A_TVQQ_SIG_205(DBLE(M),DBLE(MH)))
         IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
        ENDIF
      ELSE IF( C.EQ.3 ) THEN
       IF (IE.LE.5) THEN
        IF( FIRST2 ) THEN
          DO I=1,6
            AA(I)= GG(I) / (2*ATAN(DM/GG(I)))
          END DO
          FIRST2= .FALSE.
        END IF
        M0= MH+DM0
        IF( ABS(M-M0).GT.DM ) THEN
          AHC_SIG_DIS= 0.
        ELSE 
C - BW
          AHC_SIG_DIS= AA(ENE) / ( (M-M0)**2 + GG(ENE)**2 )
        END IF
       ELSEIF (IE.EQ.6) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_189(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.7) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_192(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.8) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_196(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.9) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_200(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.10) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_202(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.11) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_204(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.12) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_205(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.13) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_206(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.14) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_207(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ELSEIF (IE.EQ.15) THEN
        AHC_SIG_DIS = 0.0
        AHC_SIG_DIS = SNGL(A_QQQQ_SIG_208(DBLE(M),DBLE(MH)))
        IF (AHC_SIG_DIS.LE.0.0) AHC_SIG_DIS = 0.0
       ENDIF
      END IF
C - Over!
      RETURN
      END 

C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C +++ Candidates
C +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      SUBROUTINE AHC_CANDIDATES(IE,C,MH,NC,MR)
C------------------------------------------------------------------------------
C     Get number of candidates acting onto a given channel C,
C     for a given energy IE, for a given mass hypothesis MH;
C     for C=3 the list of reconstructed masses is also returned
C
C     Input:     IE    sqrt(s) index (1=130, 2=136, 3=161, 4=172, 5=183,
C                                     6=189, 7=192, 8=196, 
C                                     9=200, 10=202, 11=204, 12=205,
C                                     13=206, 14=207, 15=208)
C                      for C=3, abs(IE) is the sqrt(s) index as above, and 
C                      IE > 0 : get candidates in the DM window around MH
C                      IE < 0 : get all candidates irrespective of MH
C                 C    channel (1=tntn, 2=tncs, 3= cssc)
C                MH    Charged Higgs reference mass 
C     Output:    NC    Number of observed candidates
C                MR(1,...,500) Reconstructed masses for C=3
C                             (Set to 0. for C= 1 or 2)
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
      INTEGER    NCMX
      PARAMETER( NCMX= 2000 )
C - Arguments
      INTEGER    IE, C, NC
      REAL       MH, MR(NCMX)
C - Common blocks
C - Auxiliary variables
      INTEGER    I
      REAL       MASS, TNTN_CAND
      EXTERNAL   TNTN_CAND
C - Data statements
C - Macros
C - Statements
C - Read candidates masses
      NC= 0
      IF( C.EQ.1 ) THEN
        NC= INT(TNTN_CAND(MH,0.,IE+1,2))
      ELSE IF( C.EQ.2 ) THEN
        IF( IE.EQ.5 ) THEN
          IF( MH.LT.50.75 ) THEN
            NC= 2
          ELSE IF( MH.LT.52.25 ) THEN
            NC= 1
          ELSE IF( MH.GE.52.25 .AND. MH.LT.53.75 ) THEN
            NC= 0
          ELSE IF( MH.GE.53.75 .AND. MH.LT.59.25 ) THEN
            NC= 1
          ELSE IF( MH.GE.59.25 .AND. MH.LT.64.75 ) THEN
            NC= 2
          ELSE IF( MH.GE.64.75 .AND. MH.LT.65.75 ) THEN
            NC= 3
          ELSE IF( MH.GE.65.75 .AND. MH.LT.67.25 ) THEN
            NC= 4
          ELSE IF( MH.GE.67.25 .AND. MH.LT.68.25 ) THEN
            NC= 5
          ELSE IF( MH.GE.68.25 .AND. MH.LT.71.25 ) THEN
            NC= 6
          ELSE IF( MH.GE.71.25 .AND. MH.LT.72.75 ) THEN
            NC= 5
          ELSE IF( MH.GE.72.75 .AND. MH.LT.73.75 ) THEN
            NC= 6
          ELSE IF( MH.GE.73.75 .AND. MH.LT.77.75 ) THEN
            NC= 5
          ELSE IF( MH.GE.77.75 .AND. MH.LT.79.25 ) THEN
            NC= 6
          ELSE IF( MH.GE.79.25 .AND. MH.LT.79.75 ) THEN
            NC= 5
          ELSE IF( MH.GE.79.75 .AND. MH.LT.80.25 ) THEN
            NC= 7
          ELSE IF( MH.GE.80.25 .AND. MH.LT.80.75 ) THEN
            NC= 8
          ELSE IF( MH.GE.80.75 .AND. MH.LT.82.25 ) THEN
            NC= 9
          ELSE IF( MH.GE.82.25 .AND. MH.LT.83.25 ) THEN
            NC= 11
          ELSE IF( MH.GE.83.25 .AND. MH.LT.84.25 ) THEN
            NC= 13
          ELSE IF( MH.GE.84.25 .AND. MH.LT.84.75 ) THEN
            NC= 12
          ELSE IF( MH.GE.84.75 .AND. MH.LT.85.25 ) THEN
            NC= 11
          END IF  
        ELSE IF( ABS(IE).GE.6 ) THEN
          CALL TNCS_CAND(IE,MH,NC,MR)
        END IF
      ELSE IF( C.EQ.3 ) THEN
       IF (IE.LE.5) THEN
        CALL CSCS_CAND(IE,MH,NC,MR)
       ELSE
        CALL CSCS_CAND(-IE,MH,NC,MR)
       ENDIF
      END IF
C - Over!
      RETURN
      END 

      real function tntn_cand(ms,mn,necm,dmflag)
C
C   necm=1:  91 GeV
C   necm=2: 130 GeV
C   necm=3: 136 GeV
C   necm=4: 161 GeV
C   necm=5: 172 GeV
C   necm=6: 183 GeV
C   necm=7: 189 GeV
C   necm=8: 192 GeV
C   necm=9: 196 GeV
C   necm=10: 200 GeV
C   necm=11: 202 GeV
C   necm=12: 204 GeV
C   necm=13: 205 GeV
C   necm=14: 206 GeV
C   necm=15: 207 GeV
C   necm=16: 208 GeV
C
      implicit none

      real ms,mn
      integer necm,dmflag
      real dm

      dm=ms-mn
      if (necm.eq.1) then
        tntn_cand=1.
      elseif (necm.eq.2) then
        tntn_cand=0.
      elseif (necm.eq.3) then
        tntn_cand=0.
      elseif (necm.eq.4) then
        if (dmflag.eq.1) then
          if (dm.lt.4.) then
            tntn_cand=0.
          else
            tntn_cand=1.
          endif
        else
          tntn_cand=1.
        endif
      elseif (necm.eq.5) then
        if (dmflag.eq.1) then
          if (dm.lt.24.9) then
            tntn_cand=0.
          else
C 42503 1364
            tntn_cand=1.
          endif
        else
          tntn_cand=0.
        endif
      elseif (necm.eq.6) then
        if (dmflag.eq.1) then
          if (dm.lt.4.5) then
            tntn_cand=0.
          elseif (dm.lt.18.7) then
C 44363 4459
            tntn_cand=1.
          elseif (dm.lt.22.3) then
C 44841 2984
            tntn_cand=2.
          elseif (dm.lt.26.6) then
C 44745 2069
            tntn_cand=3.
          else
C 44385 13184
            tntn_cand=4.
          endif
        else
          tntn_cand=4.
        endif
      elseif (necm.eq.7) then
        if (dmflag.eq.1) then
        else
          tntn_cand=20
          IF( ms.GT.93. ) tntn_cand= 19
        endif
      elseif (necm.eq.8) then
CC       tntn_cand=3 ! 192 GeV no cut on E12
       tntn_cand=3 ! cut E12=0
      elseif (necm.eq.9) then
CC       tntn_cand=13 ! 196 GeV no cut on E12
       tntn_cand=12 ! cut E12=0
      elseif (necm.eq.10) then
CC       tntn_cand=11 ! 200 GeV no cut on E12
       tntn_cand=11 ! cut E12=0
      elseif (necm.eq.11) then
CC       tntn_cand=9 ! 202 GeV no cut on E12
       tntn_cand=7 ! cut E12=0
      elseif (necm.eq.13) then
       tntn_cand=17 ! cut E12=0
      endif

      end

      SUBROUTINE CSCS_CAND(IE,MH,NC,MR)
C------------------------------------------------------------------------------
C     Get number of candidates for the cssc channel
C
C     Input:     IE    abs(IE): sqrt(s) index (1=130, 2=136, 3=161, 4=172, 
C                                              5=183, 6=189, 7=192, 8=196,
C                                              9=200, 10=202)
C                      IE>0 => get candidates in the DM window around MH
C                      IE<0 => get all candidates masses
C                MH    Charged Higgs reference mass ( irrelevant for IE<0 )
C     Output:    NC    Number of observed candidates
C                MR(1,...,500) Reconstructed masses for C=3
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
      INTEGER    NCMX,
     .           NC130, NC136, NC161, NC172, NC183, NC189,
     .           NC192, NC196, NC200, NC202, NC204, NC205, 
     .           NC206, NC207, NC208
      PARAMETER( NCMX= 2000,
     .           NC130=1, NC136= 2, 
     .           NC161= 7, NC172= 29, NC183= 162, NC189= 554, 
     .           NC192= 112, NC196= 308, NC200= 342, NC202= 149,
     .           NC204= 37, NC205= 329, NC206= 76, NC207= 501,
     .           NC208= 25)
      REAL       DM, DM0
      PARAMETER( DM= 3., DM0=-0.2 )
C - Arguments
      INTEGER    IE, NC
      REAL       MH, MR(NCMX)
C - Common blocks
C - Auxiliary variables
      INTEGER    I
      REAL       C130(NC130), C136(NC136), C161(NC161), 
     .           C172(NC172), C183(NC183), C189(NC189),
     .           C192(NC192), C196(NC196), C200(NC200),
     .           C202(NC202), C204(NC204), C205(NC205), 
     .           C206(NC206), C207(NC207), C208(NC208),
     .           MMI, MMX
C - Data statements
      DATA       C130 / 53.98 /,
     .           C136 / 57.56, 62.54 /,
     .           C161 /
     .           43.40, 55.17, 73.59, 74.35, 78.11, 78.43,
     .           79.24 /,
     .           C172 /
     .           37.58, 42.10, 44.96, 50.57, 52.37, 55.53,
     .           60.83, 62.77, 63.12, 70.35, 71.21, 72.77,
     .           75.14, 75.44, 77.24, 77.38, 79.13, 79.15,
     .           79.31, 79.34, 80.00, 80.42, 80.94, 81.12,
     .           81.20, 81.23, 81.50, 82.79, 83.10 /,
     .           C183 /
     .           42.49, 43.68, 46.44, 48.64, 49.51, 49.77,
     .           50.21, 51.41, 52.89, 53.05, 53.25, 56.95,
     .           58.28, 58.47, 58.95, 59.13, 59.21, 59.49,
     .           61.50, 61.78, 62.49, 62.76, 63.00, 63.65,
     .           64.78, 66.10, 66.33, 66.81, 67.00, 68.30,
     .           68.61, 69.10, 69.66, 69.67, 69.94, 70.44,
     .           70.70, 70.79, 71.14, 71.23, 72.25, 72.88,
     .           72.94, 74.44, 74.50, 74.51, 75.01, 75.18,
     .           75.84, 75.97, 76.07, 76.21, 76.54, 76.73,
     .           77.11, 77.23, 77.36, 77.36, 77.46, 77.69,
     .           78.43, 78.48, 78.49, 78.55, 78.63, 78.68,
     .           78.71, 78.79, 78.83, 78.85, 78.85, 78.89,
     .           78.92, 78.96, 79.02, 79.05, 79.13, 79.30,
     .           79.39, 79.42, 79.44, 79.45, 79.54, 79.54,
     .           79.58, 79.68, 79.72, 79.86, 79.93, 79.93,
     .           79.98, 80.05, 80.08, 80.15, 80.38, 80.42,
     .           80.42, 80.45, 80.51, 80.56, 80.57, 80.65,
     .           80.65, 80.69, 80.75, 80.80, 80.85, 80.85,
     .           80.95, 80.97, 81.07, 81.11, 81.17, 81.18,
     .           81.25, 81.34, 81.49, 81.50, 81.56, 81.57,
     .           81.80, 81.88, 81.90, 81.94, 82.08, 82.17,
     .           82.50, 82.56, 82.89, 82.94, 83.05, 83.36,
     .           83.51, 83.55, 83.58, 83.59, 83.72, 83.76,
     .           83.87, 83.90, 84.27, 84.28, 84.43, 84.54,
     .           84.57, 84.79, 85.04, 85.71, 85.73, 86.23,
     .           86.27, 86.56, 86.91, 87.04, 87.11, 87.15,
     .           87.78, 87.82, 87.88, 88.97, 89.91, 89.95 /
      DATA       C189 /
     .           60.05,
     .           60.15, 60.19, 60.21, 60.30, 60.41, 60.44,
     .           60.61, 60.64, 61.02, 61.03, 61.09, 61.36,
     .           61.41, 61.51, 61.51, 61.82, 62.24, 62.48,
     .           62.60, 62.67, 62.74, 62.75, 62.85, 63.02,
     .           63.04, 63.12, 63.13, 63.18, 63.22, 63.35,
     .           63.36, 63.40, 63.47, 63.58, 63.66, 63.81,
     .           63.95, 64.06, 64.19, 64.26, 64.29, 64.30,
     .           64.39, 64.74, 65.13, 65.22, 65.50, 65.58,
     .           65.69, 65.71, 65.76, 65.80, 65.91, 66.25,
     .           66.38, 66.41, 66.42, 66.43, 66.65, 66.82,
     .           66.87, 66.91, 67.06, 67.13, 67.35, 67.52,
     .           67.66, 67.75, 68.07, 68.16, 68.28, 68.30,
     .           68.37, 68.40, 68.46, 68.46, 68.55, 68.88,
     .           69.12, 69.18, 69.21, 69.24, 69.43, 69.45,
     .           69.61, 69.65, 69.72, 69.76, 69.85, 69.87,
     .           69.90, 70.08, 70.44, 70.46, 70.61, 70.70,
     .           70.71, 71.02, 71.08, 71.08, 71.20, 71.25,
     .           71.37, 71.40, 71.51, 71.62, 71.69, 71.74,
     .           71.75, 71.94, 72.14, 72.15, 72.15, 72.23,
     .           72.29, 72.49, 72.51, 72.62, 72.71, 72.76,
     .           72.78, 72.84, 72.90, 72.94, 72.97, 73.04,
     .           73.04, 73.16, 73.22, 73.43, 73.56, 73.79,
     .           74.18, 74.18, 74.23, 74.31, 74.35, 74.42,
     .           74.54, 74.55, 74.55, 74.57, 74.58, 74.66,
     .           74.73, 74.75, 74.81, 74.82, 74.86, 74.88,
     .           74.97, 74.99, 75.03, 75.07, 75.14, 75.17,
     .           75.36, 75.37, 75.65, 75.65, 75.71, 75.76,
     .           75.80, 75.96, 76.06, 76.17, 76.26, 76.27,
     .           76.30, 76.30, 76.38, 76.39, 76.42, 76.44,
     .           76.44, 76.48, 76.58, 76.60, 76.69, 76.71,
     .           76.71, 76.75, 76.78, 76.92, 76.94, 76.95,
     .           77.07, 77.08, 77.13, 77.30, 77.31, 77.34,
     .           77.36, 77.37, 77.38, 77.42, 77.44, 77.51,
     .           77.51, 77.51, 77.54, 77.55, 77.56, 77.58,
     .           77.59, 77.60, 77.60, 77.63, 77.64, 77.68,
     .           77.76, 77.85, 77.93, 77.96, 77.99, 78.03,
     .           78.06, 78.12, 78.12, 78.22, 78.29, 78.31,
     .           78.48, 78.49, 78.49, 78.58, 78.59, 78.61,
     .           78.65, 78.71, 78.72, 78.72, 78.75, 78.76,
     .           78.84, 78.85, 78.86, 78.90, 78.92, 78.92,
     .           78.92, 78.92, 78.99, 79.01, 79.02, 79.03,
     .           79.03, 79.03, 79.06, 79.06, 79.08, 79.13,
     .           79.16, 79.17, 79.17, 79.23, 79.24, 79.25,
     .           79.26, 79.28, 79.35, 79.41, 79.41, 79.43,
     .           79.50, 79.50, 79.54, 79.56, 79.60, 79.61,
     .           79.62, 79.65, 79.66, 79.69, 79.71, 79.73,
     .           79.73, 79.74, 79.76, 79.76, 79.77, 79.79,
     .           79.80, 79.80, 79.82, 79.82, 79.83, 79.83,
     .           79.84, 79.85, 79.87, 79.89, 79.89, 79.92,
     .           79.93, 79.93, 79.95, 79.95, 79.97, 80.01,
     .           80.03, 80.05, 80.08, 80.11, 80.20, 80.20,
     .           80.20, 80.22, 80.23, 80.23, 80.25, 80.25,
     .           80.26, 80.26, 80.34, 80.38, 80.39, 80.41,
     .           80.42, 80.44, 80.44, 80.46, 80.48, 80.50,
     .           80.52, 80.53, 80.57, 80.57, 80.61, 80.61,
     .           80.63, 80.64, 80.65, 80.71, 80.73, 80.73,
     .           80.74, 80.76, 80.78, 80.80, 80.84, 80.86,
     .           80.90, 80.93, 80.94, 80.96, 81.00, 81.03,
     .           81.10, 81.11, 81.11, 81.12, 81.13, 81.16,
     .           81.16, 81.16, 81.18, 81.19, 81.21, 81.21,
     .           81.23, 81.26, 81.29, 81.29, 81.34, 81.34,
     .           81.40, 81.41, 81.41, 81.43, 81.47, 81.47,
     .           81.48, 81.48, 81.49, 81.50, 81.52, 81.54,
     .           81.57, 81.59, 81.61, 81.62, 81.63, 81.63,
     .           81.66, 81.66, 81.68, 81.70, 81.72, 81.73,
     .           81.75, 81.76, 81.76, 81.78, 81.79, 81.88,
     .           81.95, 81.97, 82.02, 82.06, 82.08, 82.10,
     .           82.10, 82.13, 82.16, 82.16, 82.16, 82.26,
     .           82.26, 82.30, 82.31, 82.33, 82.33, 82.34,
     .           82.37, 82.37, 82.38, 82.41, 82.41, 82.45,
     .           82.56, 82.57, 82.59, 82.69, 82.78, 82.84,
     .           82.85, 82.91, 82.92, 82.94, 82.96, 82.96,
     .           82.98, 82.99, 83.01, 83.19, 83.25, 83.32,
     .           83.43, 83.44, 83.52, 83.59, 83.60, 83.65,
     .           83.66, 83.68, 83.73, 83.73, 83.75, 83.85,
     .           83.85, 83.94, 83.95, 84.04, 84.07, 84.07,
     .           84.08, 84.12, 84.14, 84.17, 84.17, 84.19,
     .           84.24, 84.33, 84.37, 84.55, 84.56, 84.58,
     .           84.63, 84.68, 84.90, 85.01, 85.06, 85.07,
     .           85.10, 85.12, 85.20, 85.25, 85.29, 85.35,
     .           85.35, 85.46, 85.57, 85.59, 85.63, 85.68,
     .           85.69, 85.77, 85.91, 85.92, 85.98, 85.98,
     .           86.23, 86.33, 86.53, 86.55, 86.65, 86.67,
     .           86.75, 86.76, 86.79, 87.04, 87.14, 87.28,
     .           87.51, 87.58, 87.67, 87.83, 87.91, 88.17,
     .           88.21, 88.25, 88.52, 88.77, 88.82, 88.84,
     .           89.07, 89.17, 89.20, 89.27, 89.34, 89.50,
     .           89.50, 89.54, 89.71, 89.99, 90.20, 90.31,
     .           90.31, 90.32, 90.45, 90.70, 91.24, 91.55,
     .           91.59, 91.73, 91.84, 91.95, 92.10, 92.11,
     .           92.25, 92.27, 92.28, 92.30, 92.65, 92.71,
     .           92.86, 93.23, 93.41, 93.47, 93.47, 93.86,
     .           94.01 /
      DATA       C192 /
     .           60.17, 61.04, 61.72, 62.04,
     .           63.12, 63.61, 66.08, 66.56, 67.02, 67.79,
     .           68.06, 68.89, 69.09, 69.65, 70.02, 70.37,
     .           71.34, 72.22, 72.23, 72.30, 72.47, 72.69,
     .           72.73, 73.05, 73.06, 73.20, 73.22, 73.82,
     .           74.11, 74.33, 74.63, 74.80, 74.85, 74.95,
     .           74.98, 75.01, 75.08, 75.23, 75.25, 75.29,
     .           75.51, 76.47, 77.01, 77.05, 77.60, 77.60,
     .           78.04, 78.25, 78.40, 78.85, 78.87, 79.12,
     .           79.17, 79.73, 79.82, 79.90, 79.91, 79.91,
     .           79.94, 79.99, 80.12, 80.32, 80.38, 80.65,
     .           80.66, 80.75, 80.79, 81.08, 81.15, 81.39,
     .           81.40, 81.48, 81.51, 81.52, 81.85, 81.94,
     .           82.00, 82.02, 82.02, 82.27, 82.44, 82.57,
     .           82.67, 82.77, 83.12, 83.14, 83.21, 83.28,
     .           83.32, 83.34, 83.73, 84.12, 84.16, 84.22,
     .           84.36, 84.67, 84.91, 84.93, 85.16, 85.51,
     .           86.16, 86.44, 86.56, 87.51, 87.87, 87.88,
     .           89.37, 89.83, 90.85, 93.15, 94.41, 94.89 /
      DATA       C196 /
     .           60.51,
     .           60.55, 60.87, 61.09, 61.58, 62.51, 62.65,
     .           62.78, 62.82, 62.83, 63.86, 64.20, 64.21,
     .           64.28, 64.32, 64.55, 64.67, 64.72, 64.81,
     .           64.99, 65.07, 65.25, 65.32, 65.56, 65.88,
     .           66.12, 66.14, 66.32, 66.33, 66.40, 66.96,
     .           67.19, 67.42, 67.56, 67.72, 67.77, 67.78,
     .           67.79, 68.27, 68.78, 69.13, 70.04, 70.64,
     .           70.68, 71.14, 71.22, 71.39, 71.69, 72.44,
     .           72.48, 72.87, 72.88, 73.02, 73.03, 73.18,
     .           73.23, 73.55, 73.87, 74.15, 74.32, 74.61,
     .           74.65, 74.75, 74.82, 74.85, 75.05, 75.08,
     .           75.18, 75.83, 76.01, 76.15, 76.20, 76.25,
     .           76.38, 76.57, 76.63, 76.72, 76.79, 76.82,
     .           76.97, 77.03, 77.09, 77.21, 77.30, 77.44,
     .           77.58, 77.64, 77.65, 77.74, 77.84, 77.98,
     .           78.26, 78.36, 78.43, 78.47, 78.59, 78.61,
     .           78.67, 78.68, 78.76, 78.82, 78.84, 78.86,
     .           78.98, 79.03, 79.18, 79.19, 79.20, 79.24,
     .           79.25, 79.27, 79.29, 79.34, 79.37, 79.38,
     .           79.39, 79.45, 79.53, 79.55, 79.56, 79.57,
     .           79.59, 79.60, 79.63, 79.64, 79.66, 79.71,
     .           79.78, 79.81, 79.82, 79.84, 79.90, 80.00,
     .           80.01, 80.06, 80.08, 80.09, 80.10, 80.19,
     .           80.19, 80.21, 80.30, 80.30, 80.35, 80.39,
     .           80.39, 80.40, 80.40, 80.42, 80.45, 80.49,
     .           80.51, 80.52, 80.54, 80.56, 80.60, 80.67,
     .           80.78, 80.80, 80.80, 80.82, 80.83, 80.87,
     .           80.89, 80.96, 80.99, 81.00, 81.00, 81.04,
     .           81.08, 81.12, 81.12, 81.13, 81.13, 81.15,
     .           81.20, 81.34, 81.40, 81.42, 81.42, 81.43,
     .           81.44, 81.46, 81.52, 81.60, 81.60, 81.63,
     .           81.65, 81.65, 81.67, 81.68, 81.70, 81.71,
     .           81.74, 81.78, 81.83, 81.93, 81.98, 82.00,
     .           82.08, 82.16, 82.16, 82.20, 82.28, 82.45,
     .           82.47, 82.51, 82.51, 82.55, 82.57, 82.65,
     .           82.66, 82.71, 82.83, 82.83, 82.84, 82.97,
     .           83.00, 83.02, 83.07, 83.08, 83.08, 83.10,
     .           83.22, 83.22, 83.38, 83.72, 83.77, 83.85,
     .           84.33, 84.66, 84.69, 84.74, 84.77, 84.78,
     .           84.86, 84.89, 85.04, 85.17, 85.19, 85.21,
     .           85.22, 85.38, 85.39, 85.42, 85.53, 85.53,
     .           85.66, 85.92, 85.99, 86.15, 86.58, 86.82,
     .           86.82, 87.04, 87.64, 87.96, 88.12, 88.14,
     .           88.58, 89.03, 89.35, 89.48, 89.86, 89.92,
     .           90.30, 90.31, 90.89, 91.06, 91.23, 91.34,
     .           91.36, 91.40, 91.93, 92.06, 92.23, 92.24,
     .           92.32, 92.43, 92.47, 92.71, 92.90, 92.91,
     .           93.23, 93.32, 93.38, 93.43, 93.55, 93.56,
     .           93.80, 94.00, 94.19, 94.20, 94.23, 94.48,
     .           95.27, 95.28, 95.38, 95.48, 95.58, 95.93,
     .           96.05, 96.14, 96.28, 96.74, 96.76, 96.95,
     .           97.40 /
      DATA       C200 /
     .           60.03, 60.56, 60.79, 60.90, 61.13,
     .           61.48, 61.54, 61.56, 62.42, 62.72, 62.97,
     .           63.28, 63.54, 64.00, 64.42, 64.73, 64.94,
     .           65.55, 65.60, 65.61, 65.65, 65.73, 65.90,
     .           66.23, 66.25, 66.31, 67.38, 67.40, 67.52,
     .           67.65, 69.04, 69.33, 69.37, 69.75, 70.53,
     .           71.14, 71.25, 71.50, 71.69, 71.97, 72.63,
     .           72.67, 72.71, 72.99, 73.08, 73.15, 73.31,
     .           73.34, 73.46, 73.70, 74.09, 74.14, 74.26,
     .           74.27, 74.39, 74.50, 74.84, 74.90, 74.96,
     .           75.08, 75.41, 75.50, 75.51, 75.81, 75.88,
     .           76.18, 76.21, 76.21, 76.22, 76.35, 76.36,
     .           76.41, 76.43, 76.56, 76.56, 76.89, 76.97,
     .           76.99, 77.02, 77.02, 77.02, 77.19, 77.32,
     .           77.37, 77.39, 77.43, 77.44, 77.49, 77.50,
     .           77.53, 77.60, 77.67, 77.93, 77.97, 78.01,
     .           78.02, 78.22, 78.27, 78.32, 78.41, 78.46,
     .           78.48, 78.63, 78.63, 78.65, 78.66, 78.73,
     .           78.80, 78.81, 78.82, 78.86, 78.88, 78.89,
     .           78.90, 78.90, 79.08, 79.09, 79.16, 79.19,
     .           79.21, 79.22, 79.29, 79.31, 79.39, 79.43,
     .           79.45, 79.52, 79.53, 79.54, 79.56, 79.60,
     .           79.60, 79.62, 79.63, 79.65, 79.69, 79.71,
     .           79.73, 79.82, 79.84, 79.84, 79.85, 79.86,
     .           79.86, 79.88, 80.01, 80.01, 80.04, 80.08,
     .           80.08, 80.15, 80.17, 80.18, 80.28, 80.38,
     .           80.42, 80.45, 80.47, 80.51, 80.54, 80.57,
     .           80.58, 80.59, 80.60, 80.70, 80.86, 80.88,
     .           80.92, 80.94, 80.95, 81.12, 81.12, 81.13,
     .           81.14, 81.15, 81.15, 81.16, 81.19, 81.23,
     .           81.25, 81.32, 81.36, 81.36, 81.37, 81.37,
     .           81.38, 81.51, 81.52, 81.53, 81.65, 81.66,
     .           81.69, 81.71, 81.72, 81.72, 81.83, 81.86,
     .           81.90, 81.90, 81.91, 81.97, 82.07, 82.10,
     .           82.12, 82.37, 82.38, 82.41, 82.47, 82.52,
     .           82.57, 82.60, 82.73, 82.79, 82.80, 82.84,
     .           82.84, 82.84, 82.91, 82.91, 83.00, 83.01,
     .           83.09, 83.10, 83.25, 83.33, 83.35, 83.77,
     .           83.83, 83.85, 83.98, 84.00, 84.08, 84.12,
     .           84.14, 84.15, 84.21, 84.23, 84.25, 84.33,
     .           84.49, 84.53, 84.69, 84.72, 84.78, 84.86,
     .           85.09, 85.26, 85.94, 86.02, 86.04, 86.07,
     .           86.26, 86.38, 86.49, 86.56, 86.69, 86.78,
     .           86.91, 86.98, 87.05, 87.17, 87.24, 87.27,
     .           87.38, 87.41, 87.42, 87.84, 87.98, 87.99,
     .           88.05, 88.11, 88.26, 88.34, 88.47, 88.62,
     .           88.74, 88.79, 88.82, 88.84, 89.15, 89.16,
     .           89.33, 89.51, 89.55, 89.56, 89.64, 89.65,
     .           89.79, 89.80, 89.82, 89.90, 90.05, 90.19,
     .           90.27, 90.47, 90.47, 90.52, 90.56, 90.86,
     .           90.90, 91.16, 91.30, 91.33, 91.43, 91.52,
     .           91.68, 91.70, 92.01, 92.05, 92.37, 92.51,
     .           92.57, 92.77, 92.80, 93.28, 93.58, 93.66,
     .           93.96, 93.98, 94.80, 95.11, 95.37, 96.06,
     .           96.29, 96.32, 96.97, 96.99, 97.01, 97.25,
     .           97.26, 97.38, 97.80, 97.97, 98.44, 98.45,
     .           98.48, 98.51, 99.05, 99.09, 99.18, 99.22,
     .           99.22 /
      DATA       C202 /
     .           60.58, 61.62, 62.14, 62.98, 64.93,
     .           66.21, 66.23, 67.38, 67.57, 67.85, 68.55,
     .           69.83, 71.03, 71.54, 72.22, 72.25, 72.66,
     .           72.88, 74.16, 74.46, 74.54, 75.29, 75.52,
     .           75.61, 75.86, 75.88, 76.08, 76.66, 77.06,
     .           77.10, 77.25, 77.28, 77.34, 77.73, 77.75,
     .           77.78, 78.06, 78.19, 78.36, 78.41, 78.42,
     .           78.52, 78.96, 79.07, 79.09, 79.12, 79.13,
     .           79.26, 79.49, 79.56, 79.61, 79.63, 79.74,
     .           79.78, 79.78, 79.80, 79.82, 79.99, 80.06,
     .           80.09, 80.10, 80.29, 80.40, 80.42, 80.43,
     .           80.46, 80.48, 80.53, 80.54, 80.58, 80.68,
     .           80.77, 80.84, 80.90, 81.11, 81.15, 81.16,
     .           81.26, 81.28, 81.46, 81.72, 81.73, 81.83,
     .           81.87, 81.92, 82.01, 82.09, 82.12, 82.21,
     .           82.22, 82.25, 82.31, 82.33, 82.40, 82.52,
     .           82.58, 82.62, 82.75, 83.07, 83.07, 83.08,
     .           83.66, 83.79, 83.86, 84.08, 84.18, 84.70,
     .           84.70, 84.76, 84.80, 84.96, 85.13, 85.48,
     .           85.64, 85.90, 86.09, 86.19, 86.49, 86.51,
     .           86.59, 86.69, 87.24, 87.32, 87.71, 88.26,
     .           88.52, 89.10, 89.50, 89.79, 90.28, 90.36,
     .           90.69, 91.06, 91.32, 91.35, 91.86, 93.65,
     .           94.65, 95.53, 95.83, 95.96, 96.10, 96.63,
     .           97.48, 98.28, 98.61, 99.45, 99.94,100.39 /
      DATA       C204 /
     .            64.21,  64.78,
     .            66.61,  67.26,  68.58,  69.98,  71.48,  73.06,
     .            74.01,  75.10,  77.86,  78.01,  78.11,  78.16,
     .            79.18,  79.31,  79.73,  80.08,  80.11,  80.31,
     .            80.75,  82.10,  82.99,  83.21,  83.23,  83.47,
     .            83.65,  85.47,  86.11,  87.23,  88.71,  90.42,
     .            90.91,  92.54,  94.67,  96.28, 100.56 /
      DATA       C205 /
     .            60.02,  60.04,  60.76,
     .            60.97,  61.10,  61.12,  61.37,  61.53,  61.94,
     .            62.11,  62.59,  63.16,  63.27,  64.01,  64.45,
     .            64.85,  65.35,  66.05,  66.07,  66.26,  67.37,
     .            67.94,  68.04,  68.14,  68.17,  68.19,  68.62,
     .            68.63,  69.06,  69.24,  69.33,  69.73,  69.83,
     .            69.85,  69.92,  70.10,  70.60,  70.96,  71.07,
     .            71.16,  71.26,  71.75,  72.01,  72.73,  73.45,
     .            73.57,  73.59,  73.70,  73.72,  73.84,  73.94,
     .            74.01,  74.12,  74.21,  74.50,  74.61,  75.27,
     .            75.28,  75.94,  76.35,  76.42,  76.44,  76.53,
     .            76.65,  76.74,  77.02,  77.13,  77.19,  77.31,
     .            77.49,  77.59,  77.62,  77.69,  77.71,  77.94,
     .            78.01,  78.02,  78.04,  78.21,  78.26,  78.40,
     .            78.46,  78.51,  78.61,  78.64,  78.70,  78.73,
     .            78.75,  78.78,  78.82,  78.84,  78.85,  78.94,
     .            78.97,  78.97,  78.97,  78.99,  79.06,  79.06,
     .            79.06,  79.14,  79.16,  79.17,  79.23,  79.24,
     .            79.27,  79.32,  79.32,  79.36,  79.47,  79.50,
     .            79.50,  79.51,  79.55,  79.55,  79.56,  79.56,
     .            79.59,  79.67,  79.74,  79.75,  79.78,  79.80,
     .            79.80,  79.86,  79.87,  79.87,  79.87,  79.90,
     .            79.96,  79.98,  80.00,  80.01,  80.09,  80.10,
     .            80.14,  80.16,  80.16,  80.19,  80.21,  80.22,
     .            80.26,  80.32,  80.35,  80.41,  80.50,  80.50,
     .            80.60,  80.61,  80.65,  80.75,  80.76,  80.77,
     .            80.80,  80.81,  80.86,  80.87,  80.87,  80.87,
     .            80.90,  80.91,  80.93,  80.98,  80.98,  81.04,
     .            81.07,  81.07,  81.10,  81.12,  81.13,  81.18,
     .            81.20,  81.22,  81.35,  81.44,  81.45,  81.48,
     .            81.48,  81.54,  81.55,  81.56,  81.63,  81.66,
     .            81.68,  81.68,  81.71,  81.72,  81.77,  81.78,
     .            81.81,  81.81,  81.82,  81.85,  81.88,  81.96,
     .            82.01,  82.06,  82.06,  82.08,  82.09,  82.11,
     .            82.12,  82.13,  82.23,  82.27,  82.28,  82.35,
     .            82.49,  82.52,  82.54,  82.55,  82.57,  82.65,
     .            82.67,  82.88,  83.39,  83.44,  83.48,  83.59,
     .            83.59,  83.63,  83.64,  83.68,  83.90,  83.96,
     .            84.08,  84.11,  84.18,  84.20,  84.28,  84.28,
     .            84.31,  84.33,  84.35,  84.37,  84.47,  84.78,
     .            84.86,  84.98,  85.08,  85.08,  85.21,  85.23,
     .            85.35,  85.35,  85.36,  85.43,  85.60,  85.61,
     .            85.69,  85.71,  85.96,  85.97,  86.22,  86.31,
     .            86.44,  86.83,  87.42,  87.61,  87.69,  87.84,
     .            87.92,  88.70,  88.89,  88.89,  89.11,  89.43,
     .            90.08,  90.10,  90.21,  90.30,  90.39,  90.47,
     .            90.51,  90.78,  90.81,  90.83,  90.90,  90.93,
     .            91.12,  91.25,  91.52,  91.53,  91.72,  92.00,
     .            92.04,  92.07,  92.20,  92.35,  92.36,  92.48,
     .            92.76,  92.77,  92.78,  92.94,  93.00,  93.01,
     .            93.02,  93.06,  93.18,  93.67,  93.78,  94.03,
     .            94.06,  94.91,  95.46,  95.51,  95.63,  95.74,
     .            95.77,  95.97,  96.19,  96.67,  96.77,  96.88,
     .            97.17,  97.52,  98.07,  98.15,  99.49,  99.94,
     .           100.32, 100.40, 100.59, 100.76, 101.55, 101.55,
     .           101.74, 102.13 /
      DATA       C206 /
     .            61.46,
     .            62.28,  63.18,  63.68,  63.75,  65.39,  65.66,
     .            67.60,  69.73,  69.84,  70.31,  71.38,  73.81,
     .            75.24,  75.80,  76.96,  77.37,  77.72,  78.56,
     .            78.60,  79.29,  79.30,  79.32,  79.43,  79.47,
     .            79.56,  79.62,  79.63,  80.04,  80.22,  80.26,
     .            80.26,  80.38,  80.48,  80.56,  80.61,  80.70,
     .            80.82,  80.91,  81.10,  81.44,  81.48,  81.57,
     .            81.65,  81.68,  81.88,  82.77,  83.20,  83.70,
     .            84.06,  84.16,  84.35,  85.80,  86.55,  88.23,
     .            88.64,  89.37,  89.95,  90.35,  90.46,  91.33,
     .            91.69,  92.38,  92.98,  93.06,  93.21,  93.30,
     .            94.12,  94.28,  95.76,  97.01,  98.61,  99.08,
     .            99.62, 101.83, 102.65 /
      DATA       C207 /
     .            60.44,  60.64,  60.69,
     .            60.75,  60.86,  61.15,  61.17,  61.40,  61.43,
     .            61.58,  61.66,  61.67,  61.90,  62.30,  62.37,
     .            62.39,  63.67,  64.24,  64.58,  64.78,  65.12,
     .            65.24,  65.48,  65.48,  65.66,  65.73,  65.86,
     .            66.10,  66.15,  66.33,  66.46,  66.79,  67.00,
     .            67.16,  67.16,  67.81,  68.23,  68.67,  69.69,
     .            69.77,  70.36,  70.42,  71.03,  71.29,  71.31,
     .            71.36,  71.45,  71.51,  71.51,  71.56,  71.62,
     .            71.69,  72.17,  72.33,  72.47,  72.47,  72.70,
     .            72.74,  72.82,  73.01,  73.14,  73.28,  73.62,
     .            73.66,  73.75,  74.35,  74.37,  74.47,  74.50,
     .            74.53,  74.58,  74.69,  74.87,  74.95,  74.96,
     .            75.20,  75.26,  75.31,  75.39,  75.44,  75.46,
     .            75.47,  75.48,  75.71,  75.71,  75.73,  75.85,
     .            75.86,  75.96,  76.34,  76.57,  76.71,  76.72,
     .            76.73,  76.74,  76.80,  76.93,  76.94,  77.01,
     .            77.05,  77.07,  77.14,  77.20,  77.22,  77.24,
     .            77.33,  77.39,  77.40,  77.43,  77.64,  77.66,
     .            77.75,  77.88,  77.91,  77.91,  77.97,  78.17,
     .            78.19,  78.24,  78.25,  78.27,  78.28,  78.29,
     .            78.30,  78.33,  78.35,  78.39,  78.40,  78.44,
     .            78.50,  78.51,  78.58,  78.64,  78.64,  78.66,
     .            78.67,  78.71,  78.73,  78.74,  78.76,  78.82,
     .            78.83,  78.83,  78.84,  78.86,  78.87,  78.90,
     .            78.91,  78.91,  78.96,  78.97,  79.00,  79.01,
     .            79.17,  79.17,  79.18,  79.18,  79.23,  79.28,
     .            79.28,  79.31,  79.33,  79.38,  79.41,  79.44,
     .            79.50,  79.52,  79.53,  79.55,  79.56,  79.57,
     .            79.59,  79.65,  79.75,  79.77,  79.77,  79.78,
     .            79.79,  79.82,  79.87,  79.90,  79.91,  79.95,
     .            79.96,  79.98,  80.00,  80.00,  80.01,  80.03,
     .            80.13,  80.15,  80.19,  80.21,  80.21,  80.25,
     .            80.25,  80.31,  80.32,  80.35,  80.35,  80.37,
     .            80.38,  80.38,  80.40,  80.41,  80.41,  80.42,
     .            80.42,  80.44,  80.45,  80.49,  80.51,  80.52,
     .            80.54,  80.54,  80.54,  80.62,  80.62,  80.63,
     .            80.64,  80.65,  80.71,  80.72,  80.78,  80.79,
     .            80.81,  80.86,  80.87,  80.88,  80.90,  80.92,
     .            80.96,  81.00,  81.00,  81.01,  81.03,  81.03,
     .            81.05,  81.07,  81.10,  81.10,  81.11,  81.11,
     .            81.11,  81.16,  81.17,  81.19,  81.21,  81.21,
     .            81.21,  81.21,  81.22,  81.29,  81.30,  81.32,
     .            81.37,  81.37,  81.41,  81.41,  81.48,  81.52,
     .            81.56,  81.56,  81.58,  81.58,  81.60,  81.60,
     .            81.63,  81.68,  81.69,  81.69,  81.74,  81.78,
     .            81.82,  81.82,  81.84,  81.85,  81.86,  81.87,
     .            81.89,  81.94,  81.98,  82.00,  82.05,  82.05,
     .            82.06,  82.08,  82.13,  82.13,  82.14,  82.15,
     .            82.20,  82.21,  82.21,  82.25,  82.28,  82.29,
     .            82.29,  82.29,  82.29,  82.39,  82.42,  82.44,
     .            82.44,  82.48,  82.50,  82.56,  82.57,  82.59,
     .            82.60,  82.61,  82.62,  82.63,  82.71,  82.72,
     .            82.72,  82.73,  82.75,  82.77,  82.80,  82.81,
     .            82.85,  82.92,  82.95,  83.01,  83.05,  83.09,
     .            83.11,  83.14,  83.20,  83.25,  83.28,  83.36,
     .            83.38,  83.38,  83.38,  83.45,  83.50,  83.56,
     .            83.60,  83.62,  83.63,  83.72,  83.83,  83.86,
     .            83.87,  83.89,  83.98,  84.01,  84.08,  84.14,
     .            84.15,  84.20,  84.20,  84.29,  84.41,  84.45,
     .            84.46,  84.57,  84.59,  84.75,  84.79,  84.95,
     .            84.98,  85.26,  85.29,  85.30,  85.50,  85.69,
     .            85.70,  85.73,  85.76,  85.78,  85.92,  86.00,
     .            86.09,  86.31,  86.45,  86.53,  86.55,  86.57,
     .            86.82,  87.04,  87.18,  87.21,  87.22,  87.39,
     .            87.54,  87.71,  88.04,  88.08,  88.17,  88.23,
     .            88.28,  88.33,  88.37,  88.38,  88.38,  88.53,
     .            88.62,  88.71,  88.73,  88.84,  88.96,  89.20,
     .            89.26,  89.28,  89.30,  89.35,  89.35,  89.37,
     .            89.39,  89.42,  89.58,  89.64,  89.68,  89.93,
     .            90.19,  90.35,  90.75,  90.76,  90.81,  90.84,
     .            90.95,  90.98,  91.06,  91.12,  91.46,  91.75,
     .            91.76,  91.97,  92.01,  92.15,  92.52,  92.57,
     .            92.63,  92.73,  92.74,  92.77,  92.90,  92.97,
     .            92.97,  93.01,  93.03,  93.03,  93.10,  93.28,
     .            93.32,  93.32,  93.42,  93.44,  93.47,  94.16,
     .            94.23,  94.33,  94.42,  94.70,  94.81,  94.91,
     .            94.93,  94.95,  95.08,  95.37,  95.49,  95.74,
     .            95.78,  95.95,  96.02,  96.04,  96.29,  96.60,
     .            96.69,  96.92,  96.96,  97.01,  97.33,  97.46,
     .            97.81,  97.83,  98.05,  98.23,  98.34,  98.93,
     .            99.39,  99.71,  99.72,  99.83,  99.86, 100.13,
     .           100.25, 100.31, 100.93, 101.07, 101.14, 101.39,
     .           101.56, 101.83, 102.06, 102.24, 102.59, 102.59 /
      DATA       C208 /
     .            64.69,  75.23,  76.16,  78.06,
     .            79.01,  79.05,  79.36,  79.54,  79.58,  79.65,
     .            80.22,  81.54,  81.65,  82.19,  82.28,  84.75,
     .            88.61,  89.19,  89.69,  90.01,  90.46,  93.16,
     .            95.80,  98.80, 100.29 /
C - Macros
C - Statements
      NC= 0
      MMI= MH + DM0 - DM
      MMX= MH + DM0 + DM
      I= 1
      IF( IE.EQ.1 ) THEN 
        DO WHILE( I.LE.NC130 .AND. C130(I).LT.MMX ) 
          IF( C130(I).GT.MMI ) THEN
            NC= NC+1
            IF( NC.LE.NCMX ) MR(NC)= C130(I)
          END IF
          I= I+1
        END DO
      ELSE IF( IE.EQ.2 ) THEN 
        DO WHILE( I.LE.NC136 .AND. C136(I).LT.MMX ) 
          IF( C136(I).GT.MMI ) THEN
            NC= NC+1
            IF( NC.LE.NCMX ) MR(NC)= C136(I)
          END IF
          I= I+1
        END DO
      ELSE IF( IE.EQ.3 ) THEN 
        DO WHILE( I.LE.NC161 .AND. C161(I).LT.MMX ) 
          IF( C161(I).GT.MMI ) THEN
            NC= NC+1
            IF( NC.LE.NCMX ) MR(NC)= C161(I)
          END IF
          I= I+1
        END DO
      ELSE IF( IE.EQ.4 ) THEN 
        DO WHILE( I.LE.NC172 .AND. C172(I).LT.MMX ) 
          IF( C172(I).GT.MMI ) THEN
            NC= NC+1
            IF( NC.LE.NCMX ) MR(NC)= C172(I)
          END IF
          I= I+1
        END DO
      ELSE IF( IE.EQ.5 ) THEN 
        DO WHILE( I.LE.NC183 .AND. C183(I).LT.MMX ) 
          IF( C183(I).GT.MMI ) THEN
            NC= NC+1
            IF( NC.LE.NCMX ) MR(NC)= C183(I)
          END IF
          I= I+1
        END DO
C - Option all masses now ...
      ELSE IF( IE.EQ.-1 ) THEN
        NC= NC130 
        DO I=1,NC130
          IF( I.LE.NCMX ) MR(I)= C130(I)
        END DO
      ELSE IF( IE.EQ.-2 ) THEN
        NC= NC136 
        DO I=1,NC136
          IF( I.LE.NCMX ) MR(I)= C136(I)
        END DO
      ELSE IF( IE.EQ.-3 ) THEN
        NC= NC161
        DO I=1,NC161
          IF( I.LE.NCMX ) MR(I)= C161(I)
        END DO
      ELSE IF( IE.EQ.-4 ) THEN
        NC= NC172 
        DO I=1,NC172
          IF( I.LE.NCMX ) MR(I)= C172(I)
        END DO
      ELSE IF( IE.EQ.-5 ) THEN
        NC= NC183 
        DO I=1,NC183
          IF( I.LE.NCMX ) MR(I)= C183(I)
        END DO
      ELSE IF( IE.EQ.-6 ) THEN
        NC= NC189 
        DO I=1,NC189
          IF( I.LE.NCMX ) MR(I)= C189(I)
        END DO
      ELSE IF( IE.EQ.-7 ) THEN
        NC= NC192 
        DO I=1,NC192
          IF( I.LE.NCMX ) MR(I)= C192(I)
        END DO
      ELSE IF( IE.EQ.-8 ) THEN
        NC= NC196 
        DO I=1,NC196
          IF( I.LE.NCMX ) MR(I)= C196(I)
        END DO
      ELSE IF( IE.EQ.-9 ) THEN
        NC= NC200 
        DO I=1,NC200
          IF( I.LE.NCMX ) MR(I)= C200(I)
        END DO
      ELSE IF( IE.EQ.-10 ) THEN
        NC= NC202 
        DO I=1,NC202
          IF( I.LE.NCMX ) MR(I)= C202(I)
        END DO
      ELSE IF( IE.EQ.-11 ) THEN
        NC= NC204 
        DO I=1,NC204
          IF( I.LE.NCMX ) MR(I)= C204(I)
        END DO
      ELSE IF( IE.EQ.-12 ) THEN
        NC= NC205 
        DO I=1,NC205
          IF( I.LE.NCMX ) MR(I)= C205(I)
        END DO
      ELSE IF( IE.EQ.-13 ) THEN
        NC= NC206 
        DO I=1,NC206
          IF( I.LE.NCMX ) MR(I)= C206(I)
        END DO
      ELSE IF( IE.EQ.-14 ) THEN
        NC= NC207 
        DO I=1,NC207
          IF( I.LE.NCMX ) MR(I)= C207(I)
        END DO
      ELSE IF( IE.EQ.-15 ) THEN
        NC= NC208 
        DO I=1,NC208
          IF( I.LE.NCMX ) MR(I)= C208(I)
        END DO
      END IF
C - Over !
      RETURN
      END 

      SUBROUTINE TNCS_CAND(IE,MH,NC,MR)
C------------------------------------------------------------------------------
C     Get number of candidates for the cssc channel
C
C     Input:     IE    IE: sqrt(s) index (1=130, 2=136, 3=161, 4=172, 5=183, 
C                                         6=189, 7=192, 8=196, 9=200, 10=202)
C                MH    Charged Higgs reference mass ( irrelevant for IE<0 )
C     Output:    NC    Number of observed candidates
C                MR(1,...,500) Reconstructed masses for C=3
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
      INTEGER    NCMX,
     .           NC130, NC136, NC161, NC172, NC183, NC189,
     .           NC192, NC196, NC200, NC202, NC205
      PARAMETER( NCMX= 500,
     .           NC130= 0, NC136= 0, 
     .           NC161= 0, NC172= 0, NC183= 0, NC189= 68,
     .           NC192= 7, NC196= 31, NC200= 36, NC202= 16,
     .           NC205= 127  )

C - Arguments
      INTEGER    IE, NC
      REAL       MH, MR(NCMX)
C - Common blocks
C - Auxiliary variables
      INTEGER    I
      REAL       C189(NC189),C192(NC192),C196(NC196)
      REAL       C200(NC200),C202(NC202),C205(NC205)
C - Data statements

      DATA       C189 /
     .           80.01, 81.92, 78.04, 81.06, 79.82, 78.43,
     .           81.74, 84.47, 77.26, 87.46, 90.87, 78.95,
     .           81.83, 82.51, 78.42, 69.87, 84.88, 81.01,
     .           80.22, 78.56, 73.33, 27.15, 82.84, 78.43,
     .           79.98, 81.58, 70.81, 87.57, 78.59, 73.18,
     .           82.59, 72.56, 85.44, 77.98, 
     .           89.73, 80.57, 70.43, 79.94, 78.91, 78.89,
     .           63.93, 77.04, 55.79, 81.05, 85.82, 81.68,
     .           80.04, 77.62, 73.33, 82.80, 83.35, 83.37,
     .           89.41, 79.93, 80.87, 77.17, 79.02, 82.75,
     .           88.09, 80.10, 85.72, 81.37, 69.85, 86.69,
     .           82.44, 41.27, 79.38, 77.43 /
      DATA       C192 /
     .           60.32, 79.92, 80.85, 69.78, 77.85, 76.08,
     .           50.24 /
      DATA       C196 /
     .           79.58, 90.54, 67.24, 82.85, 80.29, 61.27,
     .           80.44, 78.17, 63.72, 80.63, 75.08, 83.94,
     .           75.22, 83.46, 80.91, 79.99, 82.12, 74.77,
     .           91.39, 78.41, 81.47, 81.54, 73.88, 82.95,
     .           78.56, 79.61, 78.44, 90.92, 82.42, 80.87,
     .           78.04 /
      DATA       C200 /
     .           79.44, 79.05, 81.68, 80.05, 79.52, 87.85,
     .           67.59, 85.28, 80.37, 82.05, 72.19, 80.22,
     .           62.19, 85.36, 83.04, 84.55, 79.20, 77.47,
     .           89.66, 82.95, 79.10, 74.18, 88.50, 79.71,
     .           75.19, 89.73, 81.52, 76.95, 94.77, 79.94,
     .           83.28, 73.23, 80.84, 83.83, 78.98, 81.44 /
      DATA       C202 /
     .           73.10, 67.93, 78.25, 83.08, 76.87, 88.59,
     .           80.06, 84.72, 79.64, 81.34, 76.26, 83.52,
     .           82.26, 72.10, 82.32, 87.28 /
      DATA       C205 /
     .           45.32, 45.95, 52.49, 54.22,
     .           55.36, 57.71, 58.25, 58.50, 62.37, 62.84,
     .           63.45, 64.96, 65.03, 68.37, 68.85, 70.94,
     .           73.29, 73.97, 74.40, 74.43, 74.48, 74.59,
     .           74.97, 75.44, 75.74, 75.78, 76.40, 76.68,
     .           76.87, 76.94, 77.05, 77.09, 77.45, 77.62,
     .           77.67, 77.89, 78.03, 78.10, 78.14, 78.26,
     .           78.39, 78.50, 78.68, 78.76, 79.02, 79.42,
     .           79.53, 79.55, 79.58, 79.76, 79.85, 79.90,
     .           79.96, 79.97, 80.00, 80.05, 80.07, 80.20,
     .           80.24, 80.38, 80.42, 80.49, 80.54, 80.77,
     .           80.80, 80.82, 80.92, 80.96, 81.19, 81.20,
     .           81.28, 81.37, 81.54, 81.63, 81.64, 81.80,
     .           81.80, 81.89, 82.10, 82.11, 82.23, 82.23,
     .           82.28, 82.42, 82.43, 82.55, 82.65, 82.74,
     .           82.82, 82.98, 83.05, 83.11, 83.12, 83.28,
     .           84.28, 84.47, 84.57, 84.58, 84.63, 84.66,
     .           84.82, 84.84, 84.88, 85.45, 86.58, 86.61,
     .           86.82, 86.92, 87.18, 87.74, 88.53, 88.54,
     .           88.67, 88.85, 89.25, 89.74, 89.87, 90.18,
     .           90.74, 90.92, 91.04, 91.77, 93.02, 94.02,
     .           94.06, 96.49, 98.56 /

C - Macros
C - Statements
      NC= 0
      IF( IE.EQ.1 ) THEN 
      ELSE IF( IE.EQ.2 ) THEN 
      ELSE IF( IE.EQ.3 ) THEN 
      ELSE IF( IE.EQ.4 ) THEN 
      ELSE IF( IE.EQ.5 ) THEN 
      ELSE IF( IE.EQ.6 ) THEN 
       NC= NC189
       DO I=1,NC189
        IF (I.LE.NCMX) MR(I)= C189(I)
       END DO
      ELSE IF( IE.EQ.7 ) THEN 
       NC= NC192
       DO I=1,NC192
        IF (I.LE.NCMX) MR(I)= C192(I)
       END DO
      ELSE IF( IE.EQ.8 ) THEN 
       NC= NC196
       DO I=1,NC196
        IF (I.LE.NCMX) MR(I)= C196(I)
       END DO
      ELSE IF( IE.EQ.9 ) THEN 
       NC= NC200
       DO I=1,NC200
        IF (I.LE.NCMX) MR(I)= C200(I)
       END DO
      ELSE IF( IE.EQ.10 ) THEN 
       NC= NC202
       DO I=1,NC202
        IF (I.LE.NCMX) MR(I)= C202(I)
       END DO
      ELSE IF( IE.EQ.12 ) THEN 
       NC= NC205
       DO I=1,NC205
        IF (I.LE.NCMX) MR(I)= C205(I)
       END DO
      END IF
C - Over !
      RETURN
      END 

      SUBROUTINE AHC_BKG_CSSC(IE,MH,NBT)
C------------------------------------------------------------------------------
C     Total expected bkg for the cssc channel
C     within the +-3 GeV window
C
C     Input:     IE    sqrt(s) index (1=130, 2=136, 3=161, 4=172, 
C                                              5=183, 6=189, 7=192, 8=196,
C                                              9=200, 10=202)
C                MH    Charged Higgs reference mass (needed because of 
C                      the sliding cut)
C     Output     NBT   Number of expected bkg events
C
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
      REAL       DM, DM0
      PARAMETER( DM= 3., DM0=-0.2 )
C - Arguments
      INTEGER    IE
      REAL       MH, NBT
C - Common blocks
C - Auxiliary variables
      REAL       A133(5), A161(5), A172(5), A183(5), A189(5), 
     .           B161(3), B172(3), B183(3), B172_2(3), B189(3), 
     .           MLW(6), MUP(6), MMI, MMX, M, BT, BT2, BS
C - Data statements
      DATA       A133 / -1.4517, 0.60548E-01, -0.57338E-03, 2*0. /,
     .           A161 / 0.64588 , -0.18242E-01, 0.61834E-04, 
     .                  0.40310E-05, -0.30927E-07 /,
     .           A172 / -0.24165, 0.52404E-02, 0.62478E-04, 
     .                  0.21905E-05, -0.41810E-07 /,
     .           A183 / -3.6082, 0.11997, -0.81847E-04, 
     .                  -0.13686E-04, 0.66468E-07 /,
C     .           A189 / -19.12451, 0.285112, 0.4941711E-02, 
C     .                   0.1424927E-04, -0.1129860E-05 /,
     .           A189 / -3.3115, 0.15526,-0.71248E-03, 
     .                   0., 0. /,
     .           B189 / 143.53, 1.0896, 80.348 /
     .           B161 /  0.24358, 0.47268, 78.956 /,
     .           B172 /  8.8257, 2.6731, 80.285 /,
     .           B183 / 48.279, 2.5831, 80.295 /,
C     .           B189 / 274.9575, 4.019085, 80.32246 /,
     .           B172_2 / 0.59059, 2.9273, 74.122 /,
     .           MLW  / 5*35., 47. /,
     .           MUP  / 2*68., 80.5, 86., 91.5, 80. /
C - Macros
C - Statements
      MMI= MAX( MH + DM0 - DM, MLW(IE) )
      MMI= MIN( MMI, MUP(IE) )
      MMX= MIN( MH + DM0 + DM, MUP(IE) )
      NBT = 0.
C - Polynomial part
      IF( IE.EQ.1 .OR. IE.EQ.2 ) THEN
        CALL AHC_BKG_POLY(A133,MMI,MMX,BT)
        BT= BT/2.
      ELSE IF( IE.EQ.3 ) THEN
        CALL AHC_BKG_POLY(A161,MMI,MMX,BT)
      ELSE IF( IE.EQ.4 ) THEN
        CALL AHC_BKG_POLY(A172,MMI,MMX,BT)
      ELSE IF( IE.EQ.5 ) THEN
        CALL AHC_BKG_POLY(A183,MMI,MMX,BT)
C      ELSE IF( IE.EQ.6 ) THEN
C        CALL AHC_BKG_POLY(A189,MMI,MMX,BT)
      END IF
      NBT= BT
C - W peak ...
      IF( IE.EQ.3 ) THEN
        CALL AHC_BKG_BW(B161,MMI,MMX,BT)
      ELSE IF( IE.EQ.4 ) THEN
        CALL AHC_BKG_BW(B172,MMI,MMX,BT)
        CALL AHC_BKG_BW(B172_2,MMI,MMX,BT2)
        BT= BT + BT2
      ELSE IF( IE.EQ.5 ) THEN
        CALL AHC_BKG_BW(B183,MMI,MMX,BT)
C      ELSE IF( IE.EQ.6 ) THEN
C        CALL AHC_BKG_BW(B189,MMI,MMX,BT)
      END IF
      NBT= NBT + BT
C - Over!
      RETURN
      END 

      SUBROUTINE AHC_BKG_POLY(A,MMI,MMX,BKG)
C------------------------------------------------------------------------------
C Cumulative bkg ... polynomial part
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
C - Arguments
      REAL       A(5), MMI, MMX, BKG
C - Common blocks
C - Auxiliary variables
C - Data statements
C - Macros
C - Statements
      BKG= A(1)*(MMX   -MMI   )    + 
     .     A(2)*(MMX**2-MMI**2)/2. +
     .     A(3)*(MMX**3-MMI**3)/3. + 
     .     A(4)*(MMX**4-MMI**4)/4. +
     .     A(5)*(MMX**5-MMI**5)/5. 
C - Over!
      RETURN
      END 

      SUBROUTINE AHC_BKG_BW(B,MMI,MMX,BKG)
C------------------------------------------------------------------------------
C Cumulative bkg ... Breit-Wigner part
C------------------------------------------------------------------------------
      IMPLICIT   NONE
C - Parameters & Constants
      REAL       PI
      PARAMETER( PI= 3.141592654 )
C - Arguments
      REAL       B(3), MMI, MMX, BKG
C - Common blocks
C - Auxiliary variables
      REAL       ERF, XMI, XMX
C - Data statements
C - Macros
C - Statements
      XMI= (MMI-B(3)) / SQRT(B(2))
      XMX= (MMX-B(3)) / SQRT(B(2))
C - Calculate
      BKG= B(1)/SQRT(B(2))*(ATAN(XMX)-ATAN(XMI)) 
C - Over!
      RETURN
      END 


********************************************************************
*        Function for 189 signal interpolation using MLPfit        *
********************************************************************


      DOUBLE PRECISION FUNCTION A_TVQQ_SIG_189(X,HMS)

      IMPLICIT NONE

      REAL*8 X
      real*8 hms
      REAL*4 AMTRUE,AMRECO,A_TVQQ_MLP_189

      A_TVQQ_SIG_189 = 0.0D0

      AMTRUE = 1.0 - ((90.0-REAL(HMS))/40.0)
      AMRECO = (REAL(X)-15.0)/90.0

      IF (HMS.GT.50.0D0.AND.HMS.LT.90.0D0) THEN
       IF (X.GT.15.0D0.AND.X.LT.105.0D0) THEN
        A_TVQQ_SIG_189 = DBLE(A_TVQQ_MLP_189(AMRECO,AMTRUE))
       ENDIF
      ENDIF

      RETURN
      END



********************************************************************
*        Function for 192 signal interpolation using MLPfit        *
********************************************************************


      DOUBLE PRECISION FUNCTION A_TVQQ_SIG_192(X,HMS)

      IMPLICIT NONE

      REAL*8 X
      real*8 hms
      REAL*4 AMTRUE,AMRECO,A_TVQQ_MLP_192

      A_TVQQ_SIG_192 = 0.0D0

      AMTRUE = 1.0 - ((95.0-REAL(HMS))/40.0)
      AMRECO = (REAL(X)-15.0)/90.0

      IF (HMS.GT.55.0D0.AND.HMS.LT.95.0D0) THEN
       IF (X.GT.15.0D0.AND.X.LT.105.0D0) THEN
        A_TVQQ_SIG_192 = DBLE(A_TVQQ_MLP_192(AMRECO,AMTRUE))
       ENDIF
      ENDIF

      RETURN
      END


********************************************************************
*        Function for 196 signal interpolation using MLPfit        *
********************************************************************


      DOUBLE PRECISION FUNCTION A_TVQQ_SIG_196(X,HMS)

      IMPLICIT NONE

      REAL*8 X
      real*8 hms
      REAL*4 AMTRUE,AMRECO,A_TVQQ_MLP_196

      A_TVQQ_SIG_196 = 0.0D0

      AMTRUE = 1.0 - ((95.0-REAL(HMS))/40.0)
      AMRECO = (REAL(X)-15.0)/90.0

      IF (HMS.GT.55.0D0.AND.HMS.LT.95.0D0) THEN
       IF (X.GT.15.0D0.AND.X.LT.105.0D0) THEN
        A_TVQQ_SIG_196 = DBLE(A_TVQQ_MLP_196(AMRECO,AMTRUE))
       ENDIF
      ENDIF

      RETURN
      END



********************************************************************
*        Function for 200 signal interpolation using MLPfit        *
********************************************************************


      DOUBLE PRECISION FUNCTION A_TVQQ_SIG_200(X,HMS)

      IMPLICIT NONE

      REAL*8 X
      real*8 hms
      REAL*4 AMTRUE,AMRECO,A_TVQQ_MLP_200

      A_TVQQ_SIG_200 = 0.0D0

      AMTRUE = 1.0 - ((95.0-REAL(HMS))/40.0)
      AMRECO = (REAL(X)-15.0)/90.0

      IF (HMS.GT.55.0D0.AND.HMS.LT.95.0D0) THEN
       IF (X.GT.15.0D0.AND.X.LT.105.0D0) THEN
        A_TVQQ_SIG_200 = DBLE(A_TVQQ_MLP_200(AMRECO,AMTRUE))
       ENDIF
      ENDIF

      RETURN
      END



********************************************************************
*        Function for 202 signal interpolation using MLPfit        *
********************************************************************


      DOUBLE PRECISION FUNCTION A_TVQQ_SIG_202(X,HMS)

      IMPLICIT NONE

      REAL*8 X
      real*8 hms
      REAL*4 AMTRUE,AMRECO,A_TVQQ_MLP_202

      A_TVQQ_SIG_202 = 0.0D0

      AMTRUE = 1.0 - ((95.0-REAL(HMS))/40.0)
      AMRECO = (REAL(X)-15.0)/90.0

      IF (HMS.GT.55.0D0.AND.HMS.LT.95.0D0) THEN
       IF (X.GT.15.0D0.AND.X.LT.105.0D0) THEN
        A_TVQQ_SIG_202 = DBLE(A_TVQQ_MLP_202(AMRECO,AMTRUE))
       ENDIF
      ENDIF

      RETURN
      END



********************************************************************
*        Function for 202 signal interpolation using MLPfit        *
********************************************************************


      DOUBLE PRECISION FUNCTION A_TVQQ_SIG_205(X,HMS)

      IMPLICIT NONE

      REAL*8 X
      real*8 hms
      REAL*4 AMTRUE,AMRECO,A_TVQQ_MLP_205

      A_TVQQ_SIG_205 = 0.0D0

      AMTRUE = 1.0 - ((95.0-REAL(HMS))/40.0)
      AMRECO = (REAL(X)-15.0)/90.0

      IF (HMS.GT.55.0D0.AND.HMS.LT.95.0D0) THEN
       IF (X.GT.15.0D0.AND.X.LT.105.0D0) THEN
        A_TVQQ_SIG_205 = DBLE(A_TVQQ_MLP_205(AMRECO,AMTRUE))
       ENDIF
      ENDIF

      RETURN
      END



********************************************************************
*        Function for weighted average of smooths for signal       *
********************************************************************


      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_189(X,HMS)

      IMPLICIT NONE

      DOUBLE PRECISION sign_hphm189_4j,X,HMS

      A_QQQQ_SIG_189 = sign_hphm189_4j(X,HMS)

      RETURN
      END


*********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_192(X,HMS)

      IMPLICIT NONE
      DOUBLE PRECISION sign_hphm192_4j,X,HMS

      A_QQQQ_SIG_192 = sign_hphm192_4j(X,HMS)

      RETURN
      END


**********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_196(X,HMS)

      IMPLICIT NONE

      DOUBLE PRECISION sign_hphm196_4j,X,HMS

      A_QQQQ_SIG_196 = sign_hphm196_4j(X,HMS)


      RETURN
      END


**********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_200(X,HMS)

      IMPLICIT NONE

      DOUBLE PRECISION sign_hphm200_4j,X,HMS

      A_QQQQ_SIG_200 = sign_hphm200_4j(X,HMS)

      RETURN
      END



**********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_202(X,HMS)

      IMPLICIT NONE
      DOUBLE PRECISION sign_hphm202_4j,X,HMS

      A_QQQQ_SIG_202 = sign_hphm202_4j(X,HMS)

      RETURN
      END



**********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_204(X,HMS)

      IMPLICIT NONE
      DOUBLE PRECISION sign_hphm204_4j,X,HMS

      A_QQQQ_SIG_204 = sign_hphm204_4j(X,HMS)

      RETURN
      END



**********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_205(X,HMS)

      IMPLICIT NONE
      DOUBLE PRECISION sign_hphm205_4j,X,HMS

      A_QQQQ_SIG_205 = sign_hphm205_4j(X,HMS)

      RETURN
      END



**********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_206(X,HMS)

      IMPLICIT NONE
      DOUBLE PRECISION sign_hphm206_4j,X,HMS

      A_QQQQ_SIG_206 = sign_hphm206_4j(X,HMS)

      RETURN
      END



**********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_207(X,HMS)

      IMPLICIT NONE
      DOUBLE PRECISION sign_hphm207_4j,X,HMS

      A_QQQQ_SIG_207 = sign_hphm207_4j(X,HMS)

      RETURN
      END




**********************************************************************

      DOUBLE PRECISION FUNCTION A_QQQQ_SIG_208(X,HMS)

      IMPLICIT NONE
      DOUBLE PRECISION sign_hphm208_4j,X,HMS

      A_QQQQ_SIG_208 = sign_hphm208_4j(X,HMS)

      RETURN
      END













